<?php

class BatteryLevelController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'view', 'admin'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
 
    public function beforeAction($action) {

        if (Yii::app()->user->isGuest && Yii::app()->controller->action->id != "login") {
            Yii::app()->user->loginRequired();
        }
        return true;
    }

    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new BatteryLevel;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['BatteryLevel'])) {
            $model->attributes = $_POST['BatteryLevel'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['BatteryLevel'])) {
            $model->attributes = $_POST['BatteryLevel'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
//     if (Yii::app()->user->isGuest)
//        $this->redirect(Yii::app()->createUrl('//user/user/login'));
//        else
        if (Yii::app()->user->data()->superuser == 1) {
            $sql = "SELECT battery_level.id , sites.id AS SiteId ,sites.name AS SiteName , battery_level.Device_emi, battery_level.Time,battery_level.Status,battery_level.Battery_level
                 FROM battery_level
                 INNER JOIN sites ON battery_level.Site = sites.id
                 WHERE battery_level.id IN (SELECT MAX(id)
                 FROM battery_level
                 GROUP BY battery_level.Device_emi)";

            $BatteryLevel = Yii::app()->db->createCommand($sql)->queryAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;

            $sql = "SELECT battery_level.id , sites.id AS SiteId ,sites.name AS SiteName , battery_level.Device_emi, battery_level.Time,battery_level.Status,battery_level.Battery_level
                 FROM battery_level
                 INNER JOIN sites ON battery_level.Site = sites.id
                 WHERE battery_level.id IN (SELECT MAX(id)
                 FROM battery_level
                  WHERE battery_level.Site ='" . $SiteId . "'
                 GROUP BY battery_level.Device_emi)";

            $BatteryLevel = Yii::app()->db->createCommand($sql)->queryAll();
        }


//                $ass = CJSON::encode($BatteryLevel);
//                echo $ass;
//                die;

        $this->render('index', array('BatteryLevel' => $BatteryLevel,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new BatteryLevel('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['BatteryLevel']))
            $model->attributes = $_GET['BatteryLevel'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = BatteryLevel::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'battery-level-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    protected function gridStatusColumn($data) {
        $image = $data->Status == 'CHARGING' ? '/images/battery-plug1.png' : '/images/battery-unplug1.png';

        return CHtml::image(Yii::app()->baseUrl . $image, 'Status');
    }

}
