<?php

class DesignationSalaryChangesController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view','PendingDesignationSalaries','GetData','ApproveOrReject'),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new DesignationSalaryChanges;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['DesignationSalaryChanges']))
		{
			$model->attributes=$_POST['DesignationSalaryChanges'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['DesignationSalaryChanges']))
		{
			$model->attributes=$_POST['DesignationSalaryChanges'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('DesignationSalaryChanges');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new DesignationSalaryChanges('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['DesignationSalaryChanges']))
			$model->attributes=$_GET['DesignationSalaryChanges'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return DesignationSalaryChanges the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=DesignationSalaryChanges::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param DesignationSalaryChanges $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='designation-salary-changes-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
	public function actionPendingDesignationSalaries(){
		$this->render('_pendingSalaries');
	}

	public function actionGetData(){
		$pendingChanges = Yii::app()->db->createCommand("SELECT dsc.* 
			FROM designation_salary_changes dsc
			WHERE dsc.Status = 1")->queryAll();

		foreach($pendingChanges as $pendingChange){
		$changedBy = User::model()->findByPk($pendingChange['CreatedBy']);
		$designation = Designation::model()->findByPk($pendingChange['DesignationId']);
		echo '<tr>';
			echo '<td>'.$designation->type.'</td>';
			echo '<td>'.$pendingChange['Siteid'].'</td>';
			echo '<td>'.number_format((float)$pendingChange['MonthlySalary'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['DailySalary'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['MonthlyBasicSalary'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['MonthlyBRA1'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['MonthlyBRA2'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['MonthlyBRA3'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['DailyBasicSalary'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['DailyBRA1'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['DailyBRA2'], 2, '.', '').'</td>';
			echo '<td>'.number_format((float)$pendingChange['DailyBRA3'], 2, '.', '').'</td>';
			echo '<td>'.$changedBy->username.'</td>';
			echo '<td>'.$pendingChange['CreatedOn'].'</td>';
			echo '<td style="vertical-align: middle;"><a class="actionbtn approve-btn" onclick="approveOrReject('.$pendingChange['id'].','.$pendingChange['DesignationId'].','.$pendingChange['Siteid'].',true)">Accept</a></td>';
			echo '<td style="vertical-align: middle;"><a class="actionbtn reject-btn" onclick="approveOrReject('.$pendingChange['id'].','.$pendingChange['DesignationId'].','.$pendingChange['Siteid'].',false)">Reject</a></td>';
		echo '</tr>';
		}
	}

	public function actionApproveOrReject(){
		$selfId = $_POST['id'];
		$designationId = $_POST['designationId'];
		$siteId = $_POST['siteId'];
		$isApprove = $_POST['isApprove'] == 'true'?true:false;

		if($isApprove){
			$designationSalaryChange = DesignationSalaryChanges::model()->findByPk($selfId);
			$incentives = DesignationIncentiveChanges::model()->findAllByAttributes(['designation_salary_changes_id'=>$selfId,'status'=>1]);
			$affectedEmployees = EmployeeDesignationSalaryChanges::model()->findAllByAttributes(['designation_salary_chagne_id'=>$selfId,'designation_id'=>$designationId,'status'=>1]);
			// print_r(CJSON::encode($affectedEmployees));die;
					
			$designationSalary = new DesignationSalary;

			DesignationSalary::model()->updateAll(array('Status' => 0), "DesignationId=" . $designationId . " AND Siteid =" . $siteId . "");

			$designationSalary->MonthlySalary = $designationSalaryChange->MonthlySalary;
			$designationSalary->DailySalary = $designationSalaryChange->DailySalary;
			$designationSalary->MonthlyBasicSalary = $designationSalaryChange->MonthlyBasicSalary;
			$designationSalary->MonthlyBRA1 = $designationSalaryChange->MonthlyBRA1;
			$designationSalary->MonthlyBRA2 = $designationSalaryChange->MonthlyBRA2;
			$designationSalary->MonthlyBRA3 = $designationSalaryChange->MonthlyBRA3;
			$designationSalary->DailyBasicSalary = $designationSalaryChange->DailyBasicSalary;
			$designationSalary->DailyBRA1 = $designationSalaryChange->DailyBRA1;
			$designationSalary->DailyBRA2 = $designationSalaryChange->DailyBRA2;
			$designationSalary->DailyBRA3 = $designationSalaryChange->DailyBRA3;
			$designationSalary->CreatedBy = $designationSalaryChange->CreatedBy;
			$designationSalary->CreatedOn = $designationSalaryChange->CreatedOn;
			$designationSalary->DesignationId = $designationSalaryChange->DesignationId;
			$designationSalary->Status = 1;
			$designationSalary->Siteid = $designationSalaryChange->Siteid ;
			

			if($designationSalary->save()){

				//==================================add designation Incentive ======================================
				DesignationIncentive::model()->updateAll(array( 'status' => 0),"status = 1 AND designation_id =". $designationSalary->DesignationId ." AND site_id = ".$designationSalary->Siteid." ");
				if(!empty($incentives)){
					
					foreach($incentives as $incentive){
						$designationIncentive = new DesignationIncentive;
						$designationIncentive->incentive_id = $incentive->incentive_id ;
						$designationIncentive->designation_id = $incentive->designation_id ;
						$designationIncentive->incentive_amount_monthly = $incentive->incentive_amount_monthly ;
						$designationIncentive->incentive_amount_daily = $incentive->incentive_amount_daily ;
						$designationIncentive->site_id = $incentive->site_id ;
						$designationIncentive->CreatedBy = $incentive->CreatedBy ;
						$designationIncentive->createdOn = $incentive->createdOn ;
						$designationIncentive->status = 1 ;
						$designationIncentive->save();
					}
				}
				//===================================end===========================================================
				foreach($affectedEmployees as $affectedEmployee){

					$employee = Employee::model()->findByPk($affectedEmployee->emp_id);
          if($employee->statusId == 1){          
					$empPaymentMethod = Paymentmethod::model()->findByPk($employee->paymentmethodid);
					
					// inactive old record befor insert new record
                    EmployeeIncentive::model()->updateAll(array('status' => 0), "employee_id=" . $employee->id . " AND status = 1 AND site_id = ".$employee->siteid."");

                    // save employee_incentive
                    $dIncentives = DesignationIncentive::model()->findAllByAttributes(array('designation_id' => $designationSalary->DesignationId,'status'=>1,'site_id'=>$designationSalary->Siteid));
                    foreach($dIncentives as $dIncentive){

                        $eIncentive = new EmployeeIncentive;

                        $eIncentive->employee_id = $employee->id;
                        $eIncentive->incentive_id = $dIncentive['incentive_id'];
                        if ($empPaymentMethod->type == "DAILY") {
                            $eIncentive->incentive_amount = $dIncentive['incentive_amount_daily'];
                        }else{
                            $eIncentive->incentive_amount = $dIncentive['incentive_amount_monthly'];
                        }
                        $eIncentive->createdBy = Yii::app()->user->id;
                        $eIncentive->createdOn = date("Y-m-d H:i:s");
                        $eIncentive->status = 1;
                        $eIncentive->site_id = $employee->siteid;
                        $eIncentive->save();
                        
                    }
					//end
		    $empSalary = new Employeesalary;
                    $empSalary::model()->updateAll(array('Status' => 0), "employeeid=" . $employee->id . " AND Status = 1");

                    if ($empPaymentMethod->type == "DAILY") {
                        $Wage = $designationSalary != null ? $designationSalary->DailySalary : 0;
                        $monthlyWage = 26 * $Wage;
                    } else {
                        $Wage = $designationSalary != null ? $designationSalary->MonthlySalary : 0;
                        $monthlyWage = $Wage;
					}
					
		    $dailyWage = Yii::app()->paymentUtil->getDayWage($Wage, $empPaymentMethod->type, $employee->labourcategory->name);
                    $hourlyRate = Yii::app()->paymentUtil->getHourlyRate($Wage, $empPaymentMethod->type, $employee->labourcategory->name);
                    $doubleOTRate = Yii::app()->paymentUtil->getDoubleOTRate($Wage, $empPaymentMethod->type, $employee->labourcategory->name);
		    $normalOTRate = Yii::app()->paymentUtil->getOvetimeRateNormalDay($Wage, $empPaymentMethod->type, $employee->labourcategory->name);
					
		    $empSalary->employeeid = $employee->id;
                    $empSalary->monthsalary = $monthlyWage;
                    $empSalary->DalySalary = $dailyWage;
                    $empSalary->HourlyRate = $hourlyRate;
                    $empSalary->DoubleOTRate = $doubleOTRate;
                    $empSalary->OTRate = $normalOTRate;
                    $empSalary->CreatedBy = Yii::app()->user->id;
                    $empSalary->CreatedOn = date("Y-m-d H:i");
                    $empSalary->Status = 1;
                    $empSalary->salaryChanged = 1;
                    $empSalary->site_id = $employee->siteid;
                    
                    //new change(basic,bra1,....)
                    if ($empPaymentMethod->type == "DAILY") {
                        $empSalary->BasicSalary = $designationSalary->DailyBasicSalary;
                        $empSalary->BRA1 = $designationSalary->DailyBRA1;
                        $empSalary->BRA2 = $designationSalary->DailyBRA2;
                        $empSalary->BRA3 = $designationSalary->DailyBRA3;
                    }else{
                        $empSalary->BasicSalary = $designationSalary->MonthlyBasicSalary;
                        $empSalary->BRA1 = $designationSalary->MonthlyBRA1;
                        $empSalary->BRA2 = $designationSalary->MonthlyBRA2;
                        $empSalary->BRA3 = $designationSalary->MonthlyBRA3;
                    }
                    //end 
				$empSalary->save();
					
				}

				DesignationSalaryChanges::model()->updateAll(array('Status' => 0), "id=" . $selfId . " AND Status = 1");
				DesignationIncentiveChanges::model()->updateAll(array('status' => 0), "designation_salary_changes_id=" . $selfId . " AND status = 1");
				EmployeeDesignationSalaryChanges::model()->updateAll(array('status' => 0), "designation_salary_chagne_id=" . $selfId . " AND status = 1");
			}
    }
			echo 'approved';
		}else{
			DesignationSalaryChanges::model()->updateAll(array('Status' => -1), "id=" . $selfId . " AND Status = 1");
			DesignationIncentiveChanges::model()->updateAll(array('status' => -1), "designation_salary_changes_id=" . $selfId . " AND status = 1");
			EmployeeDesignationSalaryChanges::model()->updateAll(array('status' => -1), "designation_salary_chagne_id=" . $selfId . " AND status = 1");

			echo 'rejected';
		}
	}
}
