<?php

class DesignationSalaryController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'create', 'admin', 'view', 'SalaryByDesignation'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update',),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function beforeAction($action) {

        if (Yii::app()->user->isGuest && Yii::app()->controller->action->id != "login") {
            Yii::app()->user->loginRequired();
        }
        return true;
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new DesignationSalaryChanges;
        // $models = new Designation;
        
// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);
        $model->CreatedOn = date("Y-m-d H:i");
        $model->Status = 1;
        //set incentives for dropdown
        $incentives = Incentive::model()->findAllByAttributes(array('status' => 1,));
        $data = array();
        
        foreach ($incentives as $incentive)
            $data[$incentive->id] = $incentive->name;
        //==============
        if (isset($_POST['DesignationSalaryChanges'])) {
            $date = date('Y-m-d H:i:s');

            if(isset($_POST['employees'])){
                $nics = $_POST['employees'];
            }else{
                $nics = [];
            }
            $model->attributes = $_POST['DesignationSalaryChanges'];

            if(Yii::app()->user->isAdmin()){
                $designations = Designation::model()->findByPk($model->DesignationId);
                $model->Siteid = $designations->site;
            }

            $oldDetailsOfDesignation = DesignationSalary::model()->findByAttributes(['DesignationId'=>$model->DesignationId,'Siteid'=>$model->Siteid,'Status'=>1]);

            
            $model->DailySalary = $model->DailyBasicSalary + $model->DailyBRA1 + $model->DailyBRA2 + $model->DailyBRA3 ;
            $model->MonthlySalary = $model->MonthlyBasicSalary + $model->MonthlyBRA1 + $model->MonthlyBRA2 + $model->MonthlyBRA3 ;
            $id = $model->DesignationId;
            $siteid = $model->Siteid;
            // $model::model()->updateAll(array('Status' => 0), "DesignationId=" . $id . " AND Siteid =" . $siteid . "");

            if ($model->save()){    //if (true){
                //save designation incentive
               if(isset($_POST['incentive_amount']) || isset($_POST['incentive_amount_daily'])){
                    $amount = $_POST['incentive_amount'];
                    $dailyAmount = $_POST['incentive_amount_daily'];
                    

                    // deactive old record befor insert new record
                    //DesignationIncentive::model()->updateAll(array( 'status' => 0),"status = 1 AND designation_id =". $model->DesignationId ." AND site_id = ".$model->Siteid." ");
                    // insert new record
                    for($i = 0; $i < count($amount);$i++){
                        //check whether incentive is exist
                        // $isIncentiveAvailable = DesignationIncentiveChanges::model()->findByAttributes(array('designation_id'=>$model->DesignationId,'incentive_id'=>$i+1,'status' => 1,'site_id'=>$model->Siteid));
                        if (!(($amount[$i] == '' && $dailyAmount[$i] == '')||($amount[$i] == 0 && $dailyAmount[$i] == 0)||($amount[$i] == '' && $dailyAmount[$i] == 0)||($amount[$i] == 0 && $dailyAmount[$i] == ''))) {
                            $designationIncentives = new DesignationIncentiveChanges;
                            
                            $designationIncentives->incentive_id = $i+1;
                            $designationIncentives->designation_id = $model->DesignationId;
                            $designationIncentives->incentive_amount_monthly = $amount[$i] == '' ? 0:$amount[$i];
                            $designationIncentives->incentive_amount_daily = $dailyAmount[$i] == '' ? 0:$dailyAmount[$i];
                            $designationIncentives->site_id = $model->Siteid;
                            $designationIncentives->designation_salary_changes_id = $model->id;
                            $designationIncentives->CreatedBy = Yii::app()->user->id;
                            $designationIncentives->createdOn = date("Y-m-d H:i:s");
                            $designationIncentives->status = 1;
                            $designationIncentives->save();
                        }
                        
                    }
                    
                }
                //end
                foreach ($nics as $nic) {
                    $employee = Employee::model()->findByAttributes(array('nic' => $nic));
                    $empPaymentMethod = Paymentmethod::model()->findByPk($employee->paymentmethodid);

                    $employeeSalaryChange = new EmployeeDesignationSalaryChanges;
                    $employeeSalaryChange->emp_id = $employee->id;
                    $employeeSalaryChange->designation_id = $model->DesignationId;
                    $employeeSalaryChange->designation_salary_chagne_id = $model->id;
                    $employeeSalaryChange->status = 1;
                    $employeeSalaryChange->save();
                }
                $new_model = new DesignationSalaryChanges;
                $new_model->CreatedOn = date("Y-m-d H:i");
                $new_model->Status = 1;
                //=================================send mail==================================
                $members = Yii::app()->db->createCommand("SELECT EGM.* 
                    FROM email_groups EG
                    INNER JOIN email_group_members EGM ON EGM.email_group_id = EG.id
                    WHERE EG.group_name = 'DESIGNATION SALARY OVERWRITE' AND EGM.email_group_id = EG.id AND EGM.status = 1 AND EGM.site_id ='".$model->Siteid."'")->queryAll();
                if(!empty($members))
                    //Yii::app()->commonUtil->SendMail('designationSalaryChange','DESIGNATION SALARY CHANGE',$members,$oldDetailsOfDesignation,$model);
                //====================================================================================
                Yii::app()->user->setFlash('success', "Salary change sent for approval process..");
                $this->render('create', array('model' => $new_model,'data'=>$data));
            }
        }else{
            $this->render('create', array(
                'model' => $model,'data'=>$data
            ));
        }

        
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['DesignationSalary'])) {
            $model->attributes = $_POST['DesignationSalary'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('DesignationSalary');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {

        $model = new DesignationSalary('search');
        $model->unsetAttributes();  // clear any default values
        //$sitid = Yii::app()->user->data()->SiteId;
        //$DesignationSalary = DesignationSalary::model()->findAllByAttributes(array('Siteid' => $sitid,'Status' =>1));
//        print_r($DesignationSalary);
//           die;
        //if (isset($_GET['DesignationSalary']))
        //model->attributes = $DesignationSalary;

        if (isset($_GET['DesignationSalary']))
            $model->attributes = $_GET['DesignationSalary'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = DesignationSalary::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'designation-salary-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionSalaryByDesignation() {

        $designation = $_POST["Designation"];
        if (Yii::app()->user->data()->superuser == 1) {
            $designationModel = DesignationSalary::model()->findByAttributes(array("DesignationId" => $designation, "Status" => 1));
            $employees = Yii::app()->db->createCommand('SELECT e.nic, e.FullName FROM `employee_designation` ed inner join employee e on e.id = ed.EmployeeId where ed.DesignationId=' . $designation . ' and ed.Status = 1')->queryAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $designationModel = DesignationSalary::model()->findByAttributes(array("DesignationId" => $designation, "Siteid" => $SiteId, "Status" => 1));
            $employees = Yii::app()->db->createCommand('SELECT e.nic, e.FullName FROM `employee_designation` ed inner join employee e on e.id = ed.EmployeeId where ed.DesignationId=' . $designation . ' and ed.Status = 1 AND e.siteid=' . $SiteId . '')->queryAll();
        }


        if ($designationModel != null) {
            $this->_sendResponse(200, CJSON::encode(array("MonthlySalary" => $designationModel->MonthlySalary, "DailySalary" => $designationModel->DailySalary,"MonthlyBasicSalary"=>$designationModel->MonthlyBasicSalary,"MonthlyBRA1"=>$designationModel->MonthlyBRA1,"MonthlyBRA2"=>$designationModel->MonthlyBRA2,"MonthlyBRA3"=>$designationModel->MonthlyBRA3,"DailyBasicSalary"=>$designationModel->DailyBasicSalary,"DailyBRA1"=>$designationModel->DailyBRA1,"DailyBRA2"=>$designationModel->DailyBRA2,"DailyBRA3"=>$designationModel->DailyBRA3, "employees" => $employees)));
        } else {
            $this->_sendResponse(200, CJSON::encode(array("MonthlySalary" => 0, "DailySalary" => 0, "employees" => $employees)));
        }
    }

}
