<?php

class EmailGroupMembersController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view','GetMembers'),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new EmailGroupMembers;
		// if(Yii::app()->user->isAdmin())
		// 	$model
		if(isset($_POST['EmailGroupMembers']) && !empty($_POST['user_name']) && !empty($_POST['email']))
		{
			$names = $_POST['user_name'];
			$emails = $_POST['email'];
			EmailGroupMembers::model()->updateAll(['status'=>0],"email_group_id =  ".$_POST['EmailGroupMembers']['email_group_id']." AND site_id = ".$_POST['EmailGroupMembers']['site_id']." AND status = 1");
			for($i=0;$i<count($emails);$i++){
				$member = new EmailGroupMembers;
				$member->email_group_id = $_POST['EmailGroupMembers']['email_group_id'];
				$member->site_id = $_POST['EmailGroupMembers']['site_id'];
				$member->email =  $emails[$i] == '' ? 'notSet':$emails[$i];
				$member->name =  $names[$i] == '' ? $emails[$i]:$names[$i];
				$member->status = 1;
				if($member->email != 'notSet'){
					$member->save();
				}
			}
			Yii::app()->user->setFlash('success', "Group has been created..");
			$this->render('create',['model'=>new EmailGroupMembers]);
		}else{

			$this->render('create',array(
				'model'=>$model,
			));
		}
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['EmailGroupMembers']))
		{
			$model->attributes=$_POST['EmailGroupMembers'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('EmailGroupMembers');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new EmailGroupMembers('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['EmailGroupMembers']))
			$model->attributes=$_GET['EmailGroupMembers'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return EmailGroupMembers the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=EmailGroupMembers::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param EmailGroupMembers $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='email-group-members-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}

	public function actionGetMembers(){
		$group_id = $_POST['group_id'];
		$site_id = $_POST['site_id'];
		
		$GropMembers = Yii::app()->db->createCommand("SELECT * 
			FROM email_group_members EM	 
			WHERE EM.email_group_id	 = $group_id AND EM.site_id = $site_id AND  EM.status = 1")->queryAll();
		
		$this->_sendResponse(200, CJSON::encode($GropMembers));
	}
}
