<?php

class EmployeeDesignationController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'ChangeDesignations', 'view'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new EmployeeDesignation;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['EmployeeDesignation'])) {
            $model->attributes = $_POST['EmployeeDesignation'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    public function actionChangeDesignations() {

        $model = new EmployeeDesignation;

        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
            $designations = Designation::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
            $designations = Designation::model()->findAllByAttributes(array('site' => $SiteId));
        }

        if (isset($_POST['employees']) && $_POST['designation']) {

            
            foreach ($_POST['employees'] as $employee) {

                $emp_id = $employee;
                $designation_id = $_POST['designation'];
                
                Employee::model()->updateAll(array('designationid' => $designation_id), 'id ="' . $emp_id . '"');
                $employee = Employee::model()->findByPk($emp_id);

                $employeedesigna = new EmployeeDesignation;
                $employeedesigna::model()->updateAll(array('Status' => 0), 'EmployeeId ="' . $employee->id . '"');
                $employeedesigna->Status = 1;
                $employeedesigna->EmployeeId = $employee->id;
                $employeedesigna->DesignationId = $employee->designationid;
                $employeedesigna->DateTime = date('Y-m-d H:i:s');
                if ($employeedesigna->save()) {

                    EmployeeDesignationDetails::model()->updateAll(array('status' => 0), "employee_id=" . $employee->id . " AND site_id=" . $employee->siteid . " AND Status = 1");
                    $employeeDesignation = new EmployeeDesignationDetails;
                    $employeeDesignation->employee_id = $employee->id;
                    $employeeDesignation->site_id = $employee->siteid;
                    $employeeDesignation->designation_id = $employee->designationid;
                    $employeeDesignation->created_on = date('Y-m-d H:i:s');
                    $employeeDesignation->changed_by = Yii::app()->user->id;
                    $employeeDesignation->status = 1;
                    $employeeDesignation->save();

                    $designationSalary = DesignationSalary::model()->findByAttributes(array("DesignationId" => $employee->designationid, "Siteid" => $employee->siteid, "Status" => 1));

                    if ($employee->paymentmethod['type'] == "DAILY") {
                        $Wage = $designationSalary != null ? $designationSalary->DailySalary : 0;
                        $monthlyWage = 26 * $Wage;

                        $basic = $designationSalary != null ? $designationSalary->DailyBasicSalary : 0;
                        $bra1 = $designationSalary != null ? $designationSalary->DailyBRA1 : 0;
                        $bra2 = $designationSalary != null ? $designationSalary->DailyBRA2 : 0;
                        $bra3 = $designationSalary != null ? $designationSalary->DailyBRA3 : 0;
                    } else {
                        $Wage = $designationSalary != null ? $designationSalary->MonthlySalary : 0;
                        $monthlyWage = $Wage;

                        $basic = $designationSalary != null ? $designationSalary->MonthlyBasicSalary : 0;
                        $bra1 = $designationSalary != null ? $designationSalary->MonthlyBRA1 : 0;
                        $bra2 = $designationSalary != null ? $designationSalary->MonthlyBRA2 : 0;
                        $bra3 = $designationSalary != null ? $designationSalary->MonthlyBRA3 : 0;
                    }

                    $dailyWage = Yii::app()->paymentUtil->getDayWage($Wage, $employee->paymentmethod['type'], $employee->labourcategory->name);
                    $hourlyRate = Yii::app()->paymentUtil->getHourlyRate($Wage, $employee->paymentmethod['type'], $employee->labourcategory->name);
                    $doubleOTRate = Yii::app()->paymentUtil->getDoubleOTRate($Wage, $employee->paymentmethod['type'], $employee->labourcategory->name);
                    $normalOTRate = Yii::app()->paymentUtil->getOvetimeRateNormalDay($Wage, $employee->paymentmethod['type'], $employee->labourcategory->name);

                    Employeesalary::model()->updateAll(array('Status' => 0), 'employeeid ="' . $employee->id . '" AND site_id ="' . $employee->siteid . '" AND Status ="' . 1 . '"');
                    
                    $empSalary = new Employeesalary;

                    $empSalary->employeeid = $employee->id;
                    $empSalary->monthsalary = $monthlyWage;
                    $empSalary->DalySalary = $dailyWage;
                    $empSalary->HourlyRate = $hourlyRate;
                    $empSalary->DoubleOTRate = $doubleOTRate;
                    $empSalary->OTRate = $normalOTRate;
                    $empSalary->CreatedBy = Yii::app()->user->id;
                    $empSalary->CreatedOn = date("Y-m-d H:i");
                    $empSalary->Status = 1;
                    $empSalary->salaryChanged = 1;
                    $empSalary->site_id = $employee->siteid;
                    $empSalary->BasicSalary = $basic;
                    $empSalary->BRA1 = $bra1;
                    $empSalary->BRA2 = $bra2;
                    $empSalary->BRA3 = $bra3;
                    $empSalary->save();

                    $designationIncentives = DesignationIncentive::model()->findAllByAttributes(array("designation_id" => $employee->designationid, "site_id" => $employee->siteid, "status" => 1));
                    EmployeeIncentive::model()->updateAll(array('status' => 0), 'employee_id ="' . $employee->id . '" AND site_id ="' . $employee->siteid . '"');
                    if ($designationIncentives) {

                        foreach ($designationIncentives as $designationIncentive) {

                            $newEmployeeIncentive = new EmployeeIncentive;

                            $newEmployeeIncentive->employee_id = $employee->id;
                            $newEmployeeIncentive->incentive_id = $designationIncentive['incentive_id'];

                            if ($employee->paymentmethod['type'] == "DAILY")
                                $newEmployeeIncentive->incentive_amount = $designationIncentive['incentive_amount_daily'];
                            else
                                $newEmployeeIncentive->incentive_amount = $designationIncentive['incentive_amount_monthly'];

                            $newEmployeeIncentive->createdBy = Yii::app()->user->id;
                            $newEmployeeIncentive->createdOn = date('Y-m-d H:i:s');
                            $newEmployeeIncentive->site_id = $employee->siteid;
                            $newEmployeeIncentive->status = 1;
                            $newEmployeeIncentive->save();
                        }
                    }
                }
            }
            $this->redirect(array('Employee/admin'));
        }

        $this->render('employeeDesignation', array(
            'model' => $model, 'employees' => $employees, 'designations' => $designations,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['EmployeeDesignation'])) {
            $model->attributes = $_POST['EmployeeDesignation'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('EmployeeDesignation');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new EmployeeDesignation('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['EmployeeDesignation']))
            $model->attributes = $_GET['EmployeeDesignation'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = EmployeeDesignation::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'employee-designation-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

}
