<?php

class EmployeeIncentiveController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view','AddIncentive'),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new EmployeeIncentive;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['EmployeeIncentive']))
		{
			$model->attributes=$_POST['EmployeeIncentive'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['EmployeeIncentive']))
		{
			$model->attributes=$_POST['EmployeeIncentive'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('EmployeeIncentive');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new EmployeeIncentive('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['EmployeeIncentive']))
			$model->attributes=$_GET['EmployeeIncentive'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return EmployeeIncentive the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=EmployeeIncentive::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param EmployeeIncentive $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='employee-incentive-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}

	public function actionAddIncentive(){
		if(isset($_POST['incentiveTypes']) && isset($_POST['incentiveAmount']) && isset($_POST['empId'])){
			$incentiveTypes = $_POST['incentiveTypes'];
			$incentiveAmount = $_POST['incentiveAmount'];
			$empId = $_POST['empId'];
			$employee = Employee::model()->findByPk($empId);

			for($i = 0;$i<count($incentiveTypes);$i++){

				$isIncentiveAvailable = EmployeeIncentive::model()->findByAttributes(array('employee_id'=>$empId,'incentive_id'=>$incentiveTypes[$i],'site_id'=>$employee->siteid,'status' => 1));
                if (empty($isIncentiveAvailable)) {
					$eIncentive = new EmployeeIncentive;

					$eIncentive->employee_id = $empId;
					$eIncentive->incentive_id = $incentiveTypes[$i];
					$eIncentive->incentive_amount = $incentiveAmount[$i]== '' ? 0:$incentiveAmount[$i];
					$eIncentive->createdBy = Yii::app()->user->id;
					$eIncentive->createdOn = date("Y-m-d H:i:s");
					$eIncentive->site_id = $employee->siteid;
					$eIncentive->status = 1;
					$eIncentive->save();
				}
			}
			print_r(true);
		}else{
			echo 'Erro Occurred';
		}

		
	}
}
