<?php

class EmployeeSalaryChangeApprovalController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view','PendingSalaryChange','GetData','ApproveOrReject','ViewDetails'),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new EmployeeSalaryChangeApproval;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['EmployeeSalaryChangeApproval']))
		{
			$model->attributes=$_POST['EmployeeSalaryChangeApproval'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['EmployeeSalaryChangeApproval']))
		{
			$model->attributes=$_POST['EmployeeSalaryChangeApproval'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('EmployeeSalaryChangeApproval');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new EmployeeSalaryChangeApproval('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['EmployeeSalaryChangeApproval']))
			$model->attributes=$_GET['EmployeeSalaryChangeApproval'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return EmployeeSalaryChangeApproval the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=EmployeeSalaryChangeApproval::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param EmployeeSalaryChangeApproval $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='employee-salary-change-approval-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}

	public function actionPendingSalaryChange(){
		$pendingChanges = Yii::app()->db->createCommand("SELECT ESC.emp_id id,E.nic nic,ESold.BasicSalary oldBasic,ESold.BRA1 oldBRA1,ESold.BRA2 oldBRA2,ESold.BRA3 oldBRA3,ESnew.BasicSalary newBasic,ESnew.BRA1 newBRA1,ESnew.BRA2 newBRA2,ESnew.BRA3 newBRA3,ESC.changed_by,ESC.changed_on
			FROM employee_salary_change_approval ESC
			LEFT JOIN employeesalary ESold ON ESold.id = ESC.old_emp_salary_id
			INNER JOIN employeesalary ESnew ON ESnew.id = ESC.new_emp_salary_id
			INNER JOIN employee E ON E.id = ESC.emp_id
			WHERE ESC.status = 1")->queryAll();
		$this->render('pendingSalary',['pendingChanges'=>$pendingChanges]);
		// print_r(CJSON::encode($pendingChanges));die;
	}

	public function actionGetData(){
		$pendingChanges = Yii::app()->db->createCommand("SELECT ESC.id id,IFNULL(ESC.old_emp_salary_id, 0) AS old_emp_salary_id,ESC.new_emp_salary_id,ESC.emp_id emp_id,E.nic nic,ESold.BasicSalary oldBasic,ESold.BRA1 oldBRA1,ESold.BRA2 oldBRA2,ESold.BRA3 oldBRA3,ESnew.BasicSalary newBasic,ESnew.BRA1 newBRA1,ESnew.BRA2 newBRA2,ESnew.BRA3 newBRA3,ESC.changed_by,ESC.changed_on
			FROM employee_salary_change_approval ESC
			LEFT JOIN employeesalary ESold ON ESold.id = ESC.old_emp_salary_id
			INNER JOIN employeesalary ESnew ON ESnew.id = ESC.new_emp_salary_id
			INNER JOIN employee E ON E.id = ESC.emp_id
			WHERE ESC.status = 1")->queryAll();

		foreach($pendingChanges as $pendingChange){
		$changedBy = User::model()->findByPk($pendingChange['changed_by']);
		echo '<tr>';
			echo '<td>'.$pendingChange['emp_id'].'</td>';
			echo '<td>'.$pendingChange['nic'].'</td>';
			echo '<td class="old">'.$pendingChange['oldBasic'].'</td>';
			echo '<td class="new">'.$pendingChange['newBasic'].'</td>';
			echo '<td class="old">'.$pendingChange['oldBRA1'].'</td>';
			echo '<td class="new">'.$pendingChange['newBRA1'].'</td>';
			echo '<td class="old">'.$pendingChange['oldBRA2'].'</td>';
			echo '<td class="new">'.$pendingChange['newBRA2'].'</td>';
			echo '<td class="old">'.$pendingChange['oldBRA3'].'</td>';
			echo '<td class="new">'.$pendingChange['newBRA3'].'</td>';
			echo '<td>'.$changedBy->username.'</td>';
			echo '<td>'.$pendingChange['changed_on'].'</td>';
			echo '<td style="vertical-align: middle;"><a class="actionbtn approve-btn" onclick="approveOrReject('.$pendingChange['old_emp_salary_id'].','.$pendingChange['new_emp_salary_id'].','.$pendingChange['id'].',true)">Accept</a></td>';
			echo '<td style="vertical-align: middle;"><a class="actionbtn reject-btn" onclick="approveOrReject('.$pendingChange['old_emp_salary_id'].','.$pendingChange['new_emp_salary_id'].','.$pendingChange['id'].',false)">Reject</a></td>';
		echo '</tr>';
		}
	}

	public function actionApproveOrReject(){
		$oldEmpSlryId = $_POST['oldEmpSalaryId'];
		$newEmpSlryId = $_POST['newEmpSalaryId'];
		$selfId = $_POST['salaryChangeApprovalId'];
		$isApprove = $_POST['isApprove'] == 'true'?true:false;

		if($isApprove){
			Employeesalary::model()->updateAll(array('Status' => 0),"id=" . $oldEmpSlryId . "" );
			Employeesalary::model()->updateAll(array('Status' => 1),"id=" . $newEmpSlryId . "" );

			EmployeeSalaryChangeApproval::model()->updateAll(array('status' => 0,'approved_or_rejected_by'=>Yii::app()->user->id,'approved_or_rejected_on'=>date('Y-m-d H:m:i')),"id=" . $selfId . "" );
			echo true;

		}else{
			Employeesalary::model()->updateAll(array('Status' => 3),"id=" . $newEmpSlryId . "" );

			EmployeeSalaryChangeApproval::model()->updateAll(array('status' => -1,'approved_or_rejected_by'=>Yii::app()->user->id,'approved_or_rejected_on'=>date('Y-m-d H:m:i')),"id=" . $selfId . "" );
			echo true;
		}
	}
	public function actionViewDetails(){
		$id = $_POST['empId'];
		$details = Yii::app()->db->createCommand("SELECT IFNULL(ESC.approved_or_rejected_by,'-----') approved_or_rejected_by,IFNULL(ESC.approved_or_rejected_on,'-----') approved_or_rejected_on,ESC.id id,ESC.status,ESC.old_emp_salary_id,ESC.new_emp_salary_id,ESC.emp_id emp_id,E.nic nic,ESold.BasicSalary oldBasic,ESold.BRA1 oldBRA1,ESold.BRA2 oldBRA2,ESold.BRA3 oldBRA3,ESnew.BasicSalary newBasic,ESnew.BRA1 newBRA1,ESnew.BRA2 newBRA2,ESnew.BRA3 newBRA3,ESC.changed_by,ESC.changed_on
			FROM employee_salary_change_approval ESC
			LEFT JOIN employeesalary ESold ON ESold.id = ESC.old_emp_salary_id
			INNER JOIN employeesalary ESnew ON ESnew.id = ESC.new_emp_salary_id
			INNER JOIN employee E ON E.id = ESC.emp_id
			WHERE ESC.id = $id")->queryAll();
		
		foreach($details as $detail){
			$changedBy = User::model()->findByPk($detail['changed_by']);
			echo '<tr>';
				echo '<td>'.$detail['emp_id'].'</td>';
				echo '<td>'.$detail['nic'].'</td>';
				echo '<td class="old">'.$detail['oldBasic'].'</td>';
				echo '<td class="new">'.$detail['newBasic'].'</td>';
				echo '<td class="old">'.$detail['oldBRA1'].'</td>';
				echo '<td class="new">'.$detail['newBRA1'].'</td>';
				echo '<td class="old">'.$detail['oldBRA2'].'</td>';
				echo '<td class="new">'.$detail['newBRA2'].'</td>';
				echo '<td class="old">'.$detail['oldBRA3'].'</td>';
				echo '<td class="new">'.$detail['newBRA3'].'</td>';
				echo '<td>'.$changedBy->username.'</td>';
				echo '<td>'.$detail['changed_on'].'</td>';
				if($detail['status'] == 1){
					echo '<td style="vertical-align: middle;"><a class="actionbtn approve-btn" onclick="approveOrReject('.$detail['old_emp_salary_id'].','.$detail['new_emp_salary_id'].','.$detail['id'].',true)">Accept</a></td>';
					echo '<td style="vertical-align: middle;"><a class="actionbtn reject-btn" onclick="approveOrReject('.$detail['old_emp_salary_id'].','.$detail['new_emp_salary_id'].','.$detail['id'].',false)">Reject</a></td>';
				}else{
					$approvedOrRejectedBy = User::model()->findByPk($detail['approved_or_rejected_by']);
					echo '<td>'.$approvedOrRejectedBy->username.'</td>';
					echo '<td>'.$detail['approved_or_rejected_on'].'</td>';
				}
			echo '</tr>';
		}
	}
}
