<?php

class LeaveController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            //==============================================================================================================
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('Approvement', 'BulckLeaveCreate', 'findLeaveDetails', 'createLeaveReportPDF', 'createLeaveReportExcel', 'GetEligibleLeaves',
                    'GetLeaveTypeMasterData'),
                'users' => array('*'),
            ),
//            array('allow', // allow authenticated user to perform 'create' and 'update' actions
//                'actions' => array('create', 'update'),
//                'users' => array('@'),
//            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('Create', 'Update', 'admin', 'delete'),
                'users' => array('admin'),
            ),
            //==============================================================================================================
            array('allow', // allow only the owner to perform 'create'  actions
                'actions' => array('create',),
                'expression' => 'Yii::app()->user->can("Leave_Create")',
            ),
            array('allow', // allow only the owner to perform 'index'  actions
                'actions' => array('index'),
                'expression' => 'Yii::app()->user->can("Leave_Index")',
            ),
            array('allow', // allow only the owner to perform 'admin'  actions
                'actions' => array('admin'),
                'expression' => 'Yii::app()->user->can("Leave_Admin")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('view'),
                'expression' => 'Yii::app()->user->can("Leave_View")',
            ),
            array('allow', // allow only the owner to perform 'update'  actions
                'actions' => array('update'),
                'expression' => 'Yii::app()->user->can("Leave_Update")',
            ),
            array('allow', // allow only the owner to perform 'delete'  actions
                'actions' => array('delete'),
                'expression' => 'Yii::app()->user->can("Leave_Delete")',
            ),
            array('allow', // allow only the owner to perform 'Approvement'  actions
                'actions' => array('Approvement'),
                'expression' => 'Yii::app()->user->can("Leave_Approvement")',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function actionGetEligibleLeaves() {
        $empId = $_POST['EmpId'];
        echo CJSON::encode(Yii::app()->EligibleLeaveUtil->getEligibleLeavesByEmployee($empId));
        die;
    }

    public function actionGetLeaveTypeMasterData() {

        $isEmpty = $_POST['isArrayEmpty'];
        $isEmpty = $isEmpty == 'true' ? true : false;

        if ($isEmpty) {

            $lists = Yii::app()->db->createCommand("SELECT * FROM leavetype")->queryAll();
            echo "<option value=''></option>";
            foreach ($lists as $list) {
                echo "<option value='" . $list['id'] . "'>" . $list['Type'] . "</option>";
            }
        } else {

            $avoidedLeaveTypes = $_POST['avoidedTypes'];
            $lists = Yii::app()->db->createCommand("SELECT * FROM leavetype WHERE id NOT IN (" . implode(',', $avoidedLeaveTypes) . ")")->queryAll();
            echo "<option value=''></option>";
            foreach ($lists as $list) {
                echo "<option value='" . $list['id'] . "'>" . $list['Type'] . "</option>";
            }
        }
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        // echo CJSON::encode(Yii::app()->EligibleLeaveUtil->getEligibleLeavesByEmployee(1));die;
        //  print_r(CJSON::encode(21/60));die;

        $model = new Leave;
        $model->PaidType = 'Pay';
        //$employees = Employee::model()->findAll();
        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        if (isset($_POST['Leave'])) {
            // print_r(date('D',strtotime($_POST['Leave']['StartDate'])));
            // die;
            $date = date('Y-m-d H:i:s');
            $model->CreatedTime = $date;
            $model->Status = 0;

            $model->attributes = $_POST['Leave'];
            $employee = Employee::model()->findByAttributes(array('id' => $model->EmoloyeeId));
            $model->site = $employee->siteid;
            if ($model->day_type == "Half Day") {
                $model->No_Of_Hour = 4;
                $model->No_of_Day = 0;
            }

            $model->No_of_Day = $model->LeaveType == 2 ? 0 : $model->No_of_Day;
            $model->No_of_Day = $model->LeaveType == 10 ? 0 : $model->No_of_Day;

            if ($model->save()) {
                $dayCount = $model->day_type == "Half Day" ? 1 : (int) ($model->No_of_Day);
                $leveTypeStatus = $model->day_type == "Half Day" ? 1 : 0;

                $lDate = date($_POST['Leave']['StartDate']);
                $day = date('D', strtotime($lDate));

                for ($i = 0; $i < $dayCount; $i++) {
                    if (!($day == 'Sun')) {

                        $leaveday = new Leavedays;
                        $leaveday->leaveDays = $lDate;
                        $leaveday->EmpId = $model->EmoloyeeId;
                        $leaveday->Hours = $model->No_Of_Hour;
                        $leaveday->CreatedOn = $model->CreatedTime;
                        $leaveday->CreatedBy = $model->CreatedBy;
                        $leaveday->leaveId = $model->id;
                        $leaveday->leaveType = $model->PaidType;
                        $leaveday->leave_type_status = $leveTypeStatus;
                        $leaveday->save();
                    } else {
                        if ($employee->Shift_mode == 'ROSTER-BASE') {
                            $leaveday = new Leavedays;
                            $leaveday->leaveDays = $lDate;
                            $leaveday->EmpId = $model->EmoloyeeId;
                            $leaveday->Hours = $model->No_Of_Hour;
                            $leaveday->CreatedOn = $model->CreatedTime;
                            $leaveday->CreatedBy = $model->CreatedBy;
                            $leaveday->leaveId = $model->id;
                            $leaveday->leaveType = $model->PaidType;
                            $leaveday->leave_type_status = $leveTypeStatus;
                            $leaveday->save();
                        } else {
                            $dayCount++;
                        }
                    }
                    $lDate = date('Y-m-d', strtotime($lDate . ' + 1 days'));
                    $day = date('D', strtotime($lDate));
                }
                $this->redirect(array('admin'));
            }
        }

        $this->render('create', array(
            'model' => $model, 'employees' => $employees,
        ));
    }

    public function actionBulckLeaveCreate() {

        $model = new Leave;
        $model->PaidType = 'Pay';

        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        if (isset($_POST['employees'])) {

            if (isset($_POST['Leave'])) {

                foreach ($_POST['employees'] as $employee) {

                    $leaveModel = new Leave;
                    
                    $leaveModel->PaidType = 'Pay';
                    $leaveModel->EmoloyeeId = $employee;
                    $date = date('Y-m-d H:i:s');
                    $leaveModel->CreatedTime = $date;
                    $leaveModel->Status = 0;

                    $leaveModel->attributes = $_POST['Leave'];
                    $employee = Employee::model()->findByAttributes(array('id' => $leaveModel->EmoloyeeId));
                    $leaveModel->site = $employee->siteid;
                    if ($leaveModel->day_type == "Half Day") {
                        $leaveModel->No_Of_Hour = 4;
                        $leaveModel->No_of_Day = 0;
                    }

                    $leaveModel->No_of_Day = $leaveModel->LeaveType == 2 ? 0 : $leaveModel->No_of_Day;
                    $leaveModel->No_of_Day = $leaveModel->LeaveType == 10 ? 0 : $leaveModel->No_of_Day;

//                    $leaveModel->validate();
//                    print_r($leaveModel->getErrors());
//                        die;
                    if ($leaveModel->save()) {
                        
                        $dayCount = $leaveModel->day_type == "Half Day" ? 1 : (int) ($leaveModel->No_of_Day);
                        $leveTypeStatus = $leaveModel->day_type == "Half Day" ? 1 : 0;

                        $lDate = date($leaveModel->StartDate);
                        $day = date('D', strtotime($lDate));

                        for ($i = 0; $i < $dayCount; $i++) {
                            if (!($day == 'Sun')) {

                                $leaveday = new Leavedays;
                                $leaveday->leaveDays = $lDate;
                                $leaveday->EmpId = $leaveModel->EmoloyeeId;
                                $leaveday->Hours = $leaveModel->No_Of_Hour;
                                $leaveday->CreatedOn = $leaveModel->CreatedTime;
                                $leaveday->CreatedBy = $leaveModel->CreatedBy;
                                $leaveday->leaveId = $leaveModel->id;
                                $leaveday->leaveType = $leaveModel->PaidType;
                                $leaveday->leave_type_status = $leveTypeStatus;
                                $leaveday->save();
                            } else {
                                if ($employee->Shift_mode == 'ROSTER-BASE') {
                                    $leaveday = new Leavedays;
                                    $leaveday->leaveDays = $lDate;
                                    $leaveday->EmpId = $leaveModel->EmoloyeeId;
                                    $leaveday->Hours = $leaveModel->No_Of_Hour;
                                    $leaveday->CreatedOn = $leaveModel->CreatedTime;
                                    $leaveday->CreatedBy = $leaveModel->CreatedBy;
                                    $leaveday->leaveId = $leaveModel->id;
                                    $leaveday->leaveType = $leaveModel->PaidType;
                                    $leaveday->leave_type_status = $leveTypeStatus;
                                    $leaveday->save();
                                } else {
                                    $dayCount++;
                                }
                            }
                            $lDate = date('Y-m-d', strtotime($lDate . ' + 1 days'));
                            $day = date('D', strtotime($lDate));
                        }
                    }
                }
                $this->redirect(array('admin'));
            }
        }

        $this->render('bulckLeave', array(
            'model' => $model, 'employees' => $employees,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }
// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Leave'])) {
            $date = date('Y-m-d H:i:s');
            $model->CreatedTime = $date;
            $model->Status = 0;
            $model->attributes = $_POST['Leave'];

            if ($model->day_type == "Half Day") {
                $model->No_Of_Hour = 4;
                $model->No_of_Day = 0;
            }
            $model->No_of_Day = $model->LeaveType == 2 ? 0 : $model->No_of_Day;

            if ($model->save()) {

                Leavedays::model()->deleteAllByAttributes(array('leaveId' => $id));

                $dayCount = $model->day_type == "Half Day" ? 1 : (int) ($model->No_of_Day);
                $leveTypeStatus = $model->day_type == "Half Day" ? 1 : 0;

                $lDate = date($_POST['Leave']['StartDate']);
                $day = date('D', strtotime($lDate));

                for ($i = 0; $i < $dayCount; $i++) {
                    if (!($day == 'Sun')) {

                        $leaveday = new Leavedays;
                        $leaveday->leaveDays = $lDate;
                        $leaveday->EmpId = $model->EmoloyeeId;
                        $leaveday->Hours = $model->No_Of_Hour;
                        $leaveday->CreatedOn = $model->CreatedTime;
                        $leaveday->CreatedBy = $model->CreatedBy;
                        $leaveday->leaveId = $model->id;
                        $leaveday->leaveType = $model->PaidType;
                        $leaveday->leave_type_status = $leveTypeStatus;
                        $leaveday->save();
                    } else {
                        $dayCount++;
                    }
                    $lDate = date('Y-m-d', strtotime($lDate . ' + 1 days'));
                    $day = date('D', strtotime($lDate));
                }
            }



            $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model, 'employees' => $employees,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        // print_r('ff');die;
        if (Yii::app()->request->isPostRequest) {
            Leavedays::model()->deleteAllByAttributes(array('leaveId' => $id));
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Leave('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Leave']))
            $model->attributes = $_GET['Leave'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    public function actionIndex() {
        $status = 0;
        if (Yii::app()->user->data()->superuser == 1) {
            $Pendinglist = Leave::model()->findAllByAttributes(array('Status' => $status));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Pendinglist = Leave::model()->findAllByAttributes(array('Status' => $status, 'site' => $SiteId));
        }
// print_r(CJSON::encode($Pendinglist));die;
        $dataProvider = new CActiveDataProvider('Leave');
        $this->render('index', array(
            'dataProvider' => $dataProvider, 'Pendinglist' => $Pendinglist,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Leave::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'leave-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionApprovement() {

        $models = new Leave;
        $userid = Yii::app()->user->id;

        $leaveid = $_POST['leaveid'];
        $approvementno = $_POST['status'];
        if ($approvementno == 1) {

            $models::model()->updateAll(array('Status' => 1, 'Approvedtime' => date("Y-m-d H:i"), 'ApprovedBy' => $userid), 'id ="' . $leaveid . '"');
        }

        // 2 is rejected status
        else {
            $models::model()->updateAll(array('Status' => 2, 'Approvedtime' => date("Y-m-d H:i"), 'ApprovedBy' => $userid), 'id ="' . $leaveid . '"');
        }

        echo'sucsses';
    }

}
