<?php

class NonpayrollTimelogController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index','AttendanceExcel','TimelogReport', 'view'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new NonpayrollTimelog;

       if (Yii::app()->user->data()->superuser == 1) {
            $NonPayrollemployees = NonpayrollEmployee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $NonPayrollemployees = NonpayrollEmployee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        if (isset($_POST['NonpayrollTimelog'])) {
            
            $empl_id = $_POST['NonpayrollTimelog']['Employeeid'];
            $NonPayrollemployee = NonpayrollEmployee::model()->findByAttributes(array('id' => $empl_id));
            
            $model->attributes = $_POST['NonpayrollTimelog'];
            $model->manual = "YES";
            $model->Siteid = $NonPayrollemployee->siteid;
            $model->Accountid = $NonPayrollemployee->Accountid;
            $model->departmentid = $NonPayrollemployee->departmentid;
            $model->ValidStatus = 1;
            if ($model->save())
                $this->redirect(array('create'));
        }

        $this->render('create', array(
            'model' => $model,'NonPayrollemployees'=>$NonPayrollemployees
        ));
    }


   
    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['NonpayrollTimelog'])) {
            $model->attributes = $_POST['NonpayrollTimelog'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('NonpayrollTimelog');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new NonpayrollTimelog('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['NonpayrollTimelog']))
            $model->attributes = $_GET['NonpayrollTimelog'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = NonpayrollTimelog::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'nonpayroll-timelog-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }
        public function actionTimelogReport() {
        $model = new NonPayrollTimelogView;

       if (Yii::app()->user->data()->superuser == 1) {
            $NonPayrollemployees = NonpayrollEmployee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $NonPayrollemployees = NonpayrollEmployee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        if (isset($_POST['NonPayrollTimelogView'])) {
            
            $model->attributes = $_POST['NonPayrollTimelogView'];
         //   print_r($model->attributes);
         //   die;
           $logs = Timelog::model()->findAllBySql("select * from nonpayroll_timelog where Employeeid = ".$model->NonpayrollEmployee." AND DATE(PunchTime) >='$model->startDate' AND DATE(PunchTime) <= '$model->endDate' ORDER BY PunchTime ASC");
           $NonPayrollemployee = NonpayrollEmployee::model()->findByAttributes(array('id' => $model->NonpayrollEmployee));
              
                 $this->render('TimelogVeiw',array('model'=>$model,'logs' => $logs,'NonPayrollemployee'=>$NonPayrollemployee));
        }
       else {
         $this->render('TimelogReportView', array(
            'model'=>$model,'NonPayrollemployees'=>$NonPayrollemployees
        ));    
        }
       
    }
public function actionAttendanceExcel(){
    $objPHPExcel = new PHPExcel();
    $logs = CJSON::decode($_POST['logs']);
    $model = CJSON::decode($_POST['model']);
    $employeeDetails = CJSON::decode($_POST['employee']);

    $objPHPExcel->setActiveSheetIndex(0)
    ->setCellValue('B1', 'Employee Timelog For'.$model['startDate'].'---------'.$model['endDate'])
    ->setCellValue('E1', 'Generated On')
    ->setCellValue('F1', date("Y-m-d - h:i:sa"))
    ->setCellValue('B2', 'Name ')
    ->setCellValue('C2', $employeeDetails['title'] . ' ' . $employeeDetails['Namewithini'])
    ->setCellValue('D2', 'Customer Id' )
    ->setCellValue('E2', $employeeDetails['Accountid'])
    ->setCellValue('A3', 'Date')
    ->setCellValue('B3', 'Time')
    ->setCellValue('C3', 'Type');
    $y = 4;
    $styleArray = array(
        'font'  => array(
            'bold'  => true,
            'color' => array('rgb' => '#f79727'),
            'size'  => 10
        ));
    $objPHPExcel->getActiveSheet()->getStyle('A1:G3')->applyFromArray($styleArray);

    for($i = 0;$i < count($logs);$i++){

        $dateTime = new DateTime($logs[$i]['PunchTime']);
        $date = $dateTime->format('Y-m-d');
        $time = $dateTime->format('H:i:s');
        $objPHPExcel->setActiveSheetIndex(0)
        ->setCellValue('A'.$y, $date)
        ->setCellValue('B'.$y, $time)
        ->setCellValue('C'.$y, $logs[$i]['Type']);
        $y++;


    }

    $objPHPExcel->getActiveSheet()->setTitle($employeeDetails['nic']);

    $objPHPExcel->setActiveSheetIndex(0);

    ob_end_clean();
    ob_start();

    header('Content-Type: application/vnd.ms-excel');
    header('Content-Disposition: attachment;filename= Employee Timelog '.$employeeDetails['nic'].'Created On'.date("Y-m-d - h:i:sa").'.xls');
    header('Cache-Control: max-age=0');
    $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');
    $objWriter->save('php://output');
  }
}
