<?php

class PiecesDatailsController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'view', 'CreateBulk', 'GetEmployeesWithpiece','UpdateNumberofPiece', 'admin', 'delete'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update'),
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new PiecesDatails;

        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('paymentmethodid' => 4, 'statusId' => 1));
            $Sku = Sku::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('siteid' => $SiteId, 'paymentmethodid' => 4, 'statusId' => 1,));
            $Sku = Sku::model()->findAllByAttributes(array('site_id' => $SiteId));
        }


        if (Yii::app()->request->isAjaxRequest) {

            if (isset($_POST['PiecesDatails'])) {
                $model->attributes = $_POST['PiecesDatails'];
                $model->Employee = $_POST['PiecesDatails']['Employee'];
                $model->PieceType = $_POST['PiecesDatails']['PieceType'];
                $employee = Employee::model()->findByAttributes(array('id' => $_POST['PiecesDatails']['Employee']));
                $model->site_id = $employee->siteid;
                $Record = PiecesDatails::model()->findByAttributes(array('Employee' => $model->Employee, 'Date' => $model->Date, 'PieceType' => $model->PieceType));

                if (empty($Record)) {

                    if ($model->save()) {
                        Yii::app()->PiecesPaymentCalculationUtil->TimesheetCalculation($model);
                    }
                } else {

                    PiecesDatails::model()->updateAll(array('numberofpices' => $model->numberofpices), 'id ="' . $Record->id . '"');
                    $Updated_Record = PiecesDatails::model()->findByAttributes(array('id' => $Record->id));

                    Yii::app()->PiecesPaymentCalculationUtil->TimesheetCalculation($Updated_Record);
                }
            }
        }

        $this->render('create', array(
            'model' => $model, 'employees' => $employees, 'Sku' => $Sku
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
//        $model = $this->loadModel($id);
//
//// Uncomment the following line if AJAX validation is needed
//// $this->performAjaxValidation($model);
//
//        if (isset($_POST['PiecesDatails'])) {
//            $model->attributes = $_POST['PiecesDatails'];
//            if ($model->save())
//                $this->redirect(array('view', 'id' => $model->id));
//        }
//
//        $this->render('update', array(
//            'model' => $model,
//        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {

            Timesheet::model()->deleteAllByAttributes(array('pieces_datails_id' => $id));

            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('PiecesDatails');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new PiecesDatails('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['PiecesDatails']))
            $model->attributes = $_GET['PiecesDatails'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = PiecesDatails::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'pieces-datails-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionCreateBulk() {
        $model = new PiecesDatails;

        if (Yii::app()->user->data()->superuser == 1) {
            $Suppliers = Supplier::model()->findAll();
            $Sku = Sku::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Suppliers = Supplier::model()->findAll();
            $Sku = Sku::model()->findAllByAttributes(array('site_id' => $SiteId));
        }

            $this->render('CreateBulk', array(
            'model' => $model, 'Suppliers' => $Suppliers, 'Sku' => $Sku
        ));
    }

    public function actionGetEmployeesWithpiece() {
        //get data from ajax function

        $date = $_POST['date'];
        $MPSupplier = $_POST['MpSupplier'];
        $PieceType = $_POST['PieceType'];


        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('supplierid' => $MPSupplier,'paymentmethodid' => 4, 'statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('supplierid' => $MPSupplier,'paymentmethodid' => 4, 'siteid' => $SiteId, 'statusId' => 1));
        }
        $list = array(); //crate empty array
        if (!empty($employees)) {
            foreach ($employees as $employee) {
                $site = Sites::model()->findByPk($employee->siteid);
                $PieceRecord = PiecesDatails::model()->findByAttributes(array('Employee' => $employee->id, 'Date' => $date, 'PieceType' => $PieceType));

                $array = array();
                $array['empId'] = $employee->id;
                $array['Namewithini'] = $employee->Namewithini;
                $array['nic'] = $employee->nic;
                $array['site'] = $site->name;
                $array['NumberofPiece'] = array(); //2d array

                if (!empty($PieceRecord)) {

                    $array2 = array();
                    $array2['Id'] = $PieceRecord->id;
                    $array2['Npiece'] = $PieceRecord->numberofpices;
                    array_push($array['NumberofPiece'], $array2);
                } else {
                    $array3 = array();
                    $array3['Id'] = 0;
                    $array3['Npiece'] = '';
                    array_push($array['NumberofPiece'], $array3);
                }
                array_push($list, $array);
            }
        }
        $this->_sendResponse(200, CJSON::encode($list));
    }
       public function actionUpdateNumberofPiece() {
       
        $Empid = $_POST['empid'];
        $Pieceid = $_POST['pieceid'];
        $Date = $_POST['date'];
        $NumberofPieces = $_POST['NumberofPieces'];
        
        $employee = Employee::model()->findByAttributes(array('id' => $Empid));
        
        $PieceRecord = PiecesDatails::model()->findByAttributes(array('Employee' => $Empid, 'Date' => $Date, 'PieceType' => $Pieceid));

        if(empty($PieceRecord)){
            $model = new PiecesDatails;
            
                    $model->Employee = $Empid;
                    $model->Date = $Date;
                    $model->PieceType = $Pieceid;
                    $model->numberofpices = $NumberofPieces;
                    $model->site_id =$employee->siteid;
                   if ($model->save()) {
                       $result = Yii::app()->PiecesPaymentCalculationUtil->TimesheetCalculation($model);
                      if($result == TRUE){
                          $this->_sendResponse(200, CJSON::encode("Created Successfully"));
                      } else {
                            $this->_sendResponse(200, CJSON::encode("Get Errors"));
                        }
                       
                       }
                } else {

                     PiecesDatails::model()->updateAll(array('numberofpices' => $NumberofPieces), 'id ="' . $PieceRecord->id . '"');
                     $Updated_Record = PiecesDatails::model()->findByAttributes(array('id' => $PieceRecord->id));

                      $result = Yii::app()->PiecesPaymentCalculationUtil->TimesheetCalculation($Updated_Record);
                      if($result == TRUE){
                          $this->_sendResponse(200, CJSON::encode("Created Successfully"));
                      } else {
                            $this->_sendResponse(200, CJSON::encode("Get Errors"));
                   }
        }
    
        
    }

}
