<?php

class RosterController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            //==============================================================================================================================
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('AddEmployeeToPreviousTeam', 'index', 'GetTeamByShift', 'GetShiftByDate', 'CreateEmplyeeToShift', 'view', 'findRosterDetails', 'createRosterPDF', 'createRosterExcel', 'findPresenceDetails', 'findAbsenteeismDetails', 'createPresencePDF', 'createAbsentPDF', 'createPresenceExcel', 'createAbsentExcel', 'calendarEvents', 'mouserOverView'),
                'users' => array('*'),
            ),
//            array('allow', // allow authenticated user to perform 'create' and 'update' actions
//                'actions' => array('update'),
//                'users' => array('@'),
//            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            //==============================================================================================================================
            array('allow', // allow only the owner to perform 'create'  actions
                'actions' => array('create'),
                'expression' => 'Yii::app()->user->can("Roster_Create")',
            ),
            array('allow', // allow only the owner to perform 'index'  actions
                'actions' => array('index'),
                'expression' => 'Yii::app()->user->can("Roster_Index")',
            ),
            array('allow', // allow only the owner to perform 'admin'  actions
                'actions' => array('admin'),
                'expression' => 'Yii::app()->user->can("Roster_Admin")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('view'),
                'expression' => 'Yii::app()->user->can("Roster_View")',
            ),
            array('allow', // allow only the owner to perform 'update'  actions
                'actions' => array('update'),
                'expression' => 'Yii::app()->user->can("Roster_Update")',
            ),
            array('allow', // allow only the owner to perform 'delete'  actions
                'actions' => array('delete'),
                'expression' => 'Yii::app()->user->can("Roster_Delete")',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function beforeAction($action) {

        if (Yii::app()->user->isGuest && Yii::app()->controller->action->id != "login") {
            Yii::app()->user->loginRequired();
        }
        return true;
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Roster;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Roster'])) {
            $model->attributes = $_POST['Roster'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Roster'])) {
            $model->attributes = $_POST['Roster'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Roster('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Roster']))
            $model->attributes = $_GET['Roster'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Roster::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'roster-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

//===================================================================================================================================

    public function actionCalendarEvents() {
        $items = array();

        $model = Shift::model()->findAll();
        foreach ($model as $value) {

            $teamsSet = "";
            $logs = Yii::app()->db->createCommand("SELECT id,name FROM team WHERE id in (SELECT TeamId FROM employee_shift WHERE ShiftId = $value->id Group By TeamId)")->queryAll();

            if (!empty($logs)) {
                foreach ($logs as $log) {
                    $teamsSet = nl2br($teamsSet . "\n\n" . $log['name']);
                }
            } else {
                $teamsSet = "No teams are allocated.";
            }

            $items[] = array(
                'id' => $value->id,
                'title' => $value->name,
                'start' => $value->StartTime,
                'end' => $value->EndTime,
                'teamsSet' => $teamsSet,
                'teamsArray' => $logs
            );
        }



        echo CJSON::encode($items);
        Yii::app()->end();
    }

    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Roster');

        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

//================================================================================================================================
    //--------add missing employee to shift-------//
    public function actionCreateEmplyeeToShift() {

        $model = new Roster;
        $modelshiftToemplyee = new CreateShiftToEmployee;

        if (Yii::app()->user->data()->superuser == 1) {
            $models = Employee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $models = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        if (isset($_POST['modelshiftToemplyee'])) {

            if (isset($_POST['Emplyee'])) {

                $result = Yii::app()->AddMissingEmplyeeToShiftUtil->TeamshftCreate($_POST['modelshiftToemplyee'], $_POST['Emplyee']);
//              print_r($result[0][0]['Namewithini']);
//                die;
                if (!empty($result)) {
                    $this->render('index', array('result' => $result,));
                } else {
                    $this->render('CreateEmplyeetoShift', array(
                        'model' => $model, 'models' => $models, 'modelshiftToemplyee' => $modelshiftToemplyee,
                    ));
                }
            }
        } else {
            $this->render('CreateEmplyeetoShift', array(
                'model' => $model, 'models' => $models, 'modelshiftToemplyee' => $modelshiftToemplyee,
            ));
        }
    }

    public function actionGetShiftByDate() {

        $Date = ($_POST['Date']);
        $Shedule = Schedule::model()->findByAttributes(array('Date' => $Date));
        if (!empty($Shedule)) {
            if (Yii::app()->user->isAdmin()) {
                $Shift = Shift::model()->findAllByAttributes(array('schedulid' => $Shedule->id));
            } else {
                $siteId = Yii::app()->user->data()->SiteId;
                $Shift = Shift::model()->findAllByAttributes(array('schedulid' => $Shedule->id, 'SiteId' => $siteId));
            }
            $Shifts = CJSON::encode($Shift);
            echo $Shifts;
        } else {
            $data = [];
            $Data = CJSON::encode($data);
            echo $Data;
        }
    }

    public function actionGetTeamByShift() {

        $Shift = ($_POST['Shift']);

        if (!empty($Shift)) {
            $sql = "
             SELECT 
                team_shift.teamid,
                team.name
                FROM team_shift
                INNER JOIN team ON team_shift.teamid = team.id
                WHERE team_shift.shiftid ='" . $Shift . "'";


            $data = Yii::app()->db->createCommand($sql)->queryAll();
            $shiftdata = CJSON::encode($data);
            echo $shiftdata;
        } else {
            $emptydata = [];
            $Shift = CJSON::encode($emptydata);
            echo $Shift;
        }
    }

    //--------add missing employee to shift-------//
    public function actionAddEmployeeToPreviousTeam() {


        $model = new AddEmployeeToPreviousTeam;

        if (Yii::app()->user->data()->superuser == 1) {
            $Employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
            $Teams = Team::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
            $Teams = Team::model()->findAllByAttributes(array('siteid' => $SiteId));
        }

        if (isset($_POST['AddEmployeeToPreviousTeam'])and ( $_POST['Emplyees']) and ( $_POST['s2id_Team'])) {

            $StartDate = $_POST['AddEmployeeToPreviousTeam']['Sdate'];
            $EndDate = $_POST['AddEmployeeToPreviousTeam']['Edate'];

            $result = Yii::app()->AddMissingEmplyeeToShiftUtil->AddEmployeeToPreviousteem($StartDate, $EndDate, $_POST['Emplyees'], $_POST['s2id_Team']);

            if (!empty($result)) {
                    $this->render('view', array('result' => $result,));
                } else {
                    $this->render('AddEmployeeToPreviousTeam', array('model' => $model, 'Teams' => $Teams, 'Employees' => $Employees));
                }
             } else {
            $this->render('AddEmployeeToPreviousTeam', array(
                'model' => $model, 'Teams' => $Teams, 'Employees' => $Employees,
            ));
        }
    }

}
