<?php

class ShiftController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('AddNewEmployeeToShift'),
                'users' => array('*'),
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('create'),
                'expression' => 'Yii::app()->user->can("Shift_Create")',
            ),
            array('allow', // allow only the owner to perform 'index'  actions
                'actions' => array('index'),
                'expression' => 'Yii::app()->user->can("Shift_Index")',
            ),
            array('allow', // allow only the owner to perform 'admin'  actions
                'actions' => array('admin'),
                'expression' => 'Yii::app()->user->can("Shift_Admin")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('update'),
                'expression' => 'Yii::app()->user->can("Shift_Update")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('delete'),
                'expression' => 'Yii::app()->user->can("Shift_Delete")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('view'),
                'expression' => 'Yii::app()->user->can("Shift_View")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('autoFillShifts'),
                'expression' => 'Yii::app()->user->can("Shift_AutoFillShifts")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('viewCopyShift'),
                'expression' => 'Yii::app()->user->can("Shift_ViewCopyShift")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('getRelevantShifts'),
                'expression' => 'Yii::app()->user->can("Shift_GetRelevantShifts")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('getRelevantDates'),
                'expression' => 'Yii::app()->user->can("Shift_GetRelevantDates")',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Shift;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Shift'])) {
            $model->attributes = $_POST['Shift'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Shift'])) {
            $model->attributes = $_POST['Shift'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Shift');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Shift('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Shift']))
            $model->attributes = $_GET['Shift'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Shift::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'shift-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionAutoFillShifts() {

        $schedule = (int) $_POST['ScheduleID'];
        $data = Shift::getShifts($schedule);

        foreach ($data as $value => $name) {
            echo CHtml::tag('option', array('value' => $value), CHtml::encode($name), true);
        }
    }

    public function actionViewCopyShift() {

        $model = new CopyShiftsForm;
        if (isset($_POST['CopyShiftsForm'])) {

            $shiftid = $_POST['shift']; //selscted shiftid
            $copyDates = $_POST['dates']; // chosen dates
            $shift = Shift::model()->findByPk($shiftid);

            $shiftStart = new DateTime($shift->StartTime); //calculate duration of the shift
            $shiftEnd = new DateTime($shift->EndTime);
            $interval = $shiftEnd->diff($shiftStart);

            ob_start();
            foreach ($copyDates as $cDay) {

                $shiftArray;
                $shiftArray['starttime'] = $cDay . ' ' . date('H:i:s', strtotime($shift->StartTime));
                $begin = new DateTime($shiftArray['starttime']);
                $begin->add(new DateInterval('P0Y0M0DT' . $interval->h . 'H' . $interval->i . 'M' . $interval->s . 'S'));
                $shiftArray['endtime'] = $begin->format('Y-m-d H:i:s');
                $shiftArray['description'] = $shift->description;
                $shiftArray['salaryRate'] = $shift->salaryRate;
                $shiftArray['Shiftname'] = $shift->name;
                $shiftArray['FirstOTRate'] = $shift->FirstOTRate;
                $shiftArray['SecondOTRate'] = $shift->SecondOTRate;
                $shiftArray['FirstOTTimeRang'] = $shift->FirstOTTimeRang;
                $shiftArray['SecondOTRange'] = $shift->SecondOTRange;
                $shiftArray['GraceTime'] = $shift->GraceTime;
                $shiftArray['NOTGraceTime'] = $shift->NOTGraceTime;
                $shiftArray['DOTGraceTime'] = $shift->DOTGraceTime;
                $shiftArray['OTRoundup'] = $shift->OTRoundup;
                $shiftArray['ThirdOTRate'] = $shift->ThirdOTRate;
                $shiftArray['ThirdOTTimeRang'] = $shift->ThirdOTTimeRang;
                $shiftArray['TOTGraceTime'] = $shift->TOTGraceTime;
                $shiftArray['ExtraHourStatus'] = $shift->ExtraHourStatus;
                $shiftArray['ExtraHour'] = $shift->ExtraHour;
                $shiftArray['ExtraHourRate'] = $shift->ExtraHourRate;
                $shiftArray['PreOT'] = $shift->PreOTStatus;
                $shiftArray['FlexiShift'] = $shift->FlexyShift_Status;

                $shiftJsonArray = [];
                $shiftJsonArray[] = $shiftArray;
                $dataArray;
                $dateName = date('D', strtotime($cDay));

                if ($dateName == 'Sun') {
                    $dataArray['StartDate'] = date('Y-m-d', strtotime('this Sunday', strtotime($cDay))); // start of the week
                    $dataArray['EndDate'] = date('Y-m-d', strtotime('next Saturday', strtotime($cDay))); // end of the week
                } else if ($dateName == 'Sat') {
                    $dataArray['StartDate'] = date('Y-m-d', strtotime('last Sunday', strtotime($cDay))); // start of the week
                    $dataArray['EndDate'] = date('Y-m-d', strtotime('this Saturday', strtotime($cDay))); // end of the week
                } else {
                    $dataArray['StartDate'] = date('Y-m-d', strtotime('last Sunday', strtotime($cDay))); // start of the week
                    $dataArray['EndDate'] = date('Y-m-d', strtotime('next Saturday', strtotime($cDay))); // end of the week
                }

                $dataArray['date'] = $cDay;
                $dataArray['shift'] = $shiftJsonArray;

                $data = CJSON::encode($dataArray);
                Yii::app()->ShiftCreatApiUtil->ShiftCreate($data);
            }

            ob_end_clean();
            $this->redirect(array('roster/create'));
        } else {

            $this->render('//shift/testWizard', array('model' => $model));
        }
    }

    public function actionGetRelevantShifts() {
        $week = $_POST['week'];

        $roster = Roster::model()->findByPK($week);
        $siteid = Yii::app()->user->data()->SiteId;

        $shifts = Yii::app()->db->createCommand("SELECT id,name,StartTime,EndTime,DATE(StartTime) as day
         FROM shift WHERE DATE(StartTime)>='$roster->StartDate' AND DATE(StartTime)<='$roster->EndDate' AND SiteId= $siteid 
        ORDER by DATE(StartTime)")->queryAll();

        if (!empty($shifts)) {
            echo '
            <br/>
            <table class="table table-striped table-bordered table-advance table-hover" style ="padding:10px" >
            <thead>
                <tr>
                    <th>Shift Name</th>
                    <th>Day</th>
                    <th>Is Checked</th>                    
        
                </tr>
            </thead>
            <tbody>';

            foreach ($shifts as $shift) {

                echo '<tr>';
                $nameOfDay = date('l', strtotime($shift['day']));
                echo '<td>' . $shift['name'] . '</td>';
                echo '<td>' . $nameOfDay . '</td>';
                echo '<td> 
                    <input  id ="shiftid" type="radio" name="shift" value=' . $shift['id'] . '
                    style="margin-left:auto; margin-right:auto;">
                </td>';

                echo '</tr>';
            }


            echo '</tbody></table>';
        } else {
            echo '<h5>No shift can be found</h5>';
        }
    }

    public function actionGetRelevantDates() {
        $copyday1 = $_POST['day1'];
        $copyday2 = $_POST['day2'];
        $copyType = $_POST['type'];
        
       // $copyday1 = '2022-09-01';
//        $copyday2 = '2022-09-15';
//        $copyType = "WeekDays";
 
        echo '<br/>';

        switch ($copyType) {
            case "WeekDays":

                while (strtotime($copyday1) <= strtotime($copyday2)) {

                    if (Yii::app()->user->isAdmin()) {
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "'")->queryAll();
                    } else {

                        $SiteId = Yii::app()->user->data()->SiteId;
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "' AND ( holydays.type ='GENERAL' OR holydays.siteId = '" . $SiteId . "')")->queryAll();
                    }
                    
                    $nameOfDay = date('l', strtotime($copyday1));
                    if ($nameOfDay != "Sunday" and $nameOfDay != "Saturday" and empty($Holiday)) {

                        echo '<input type="checkbox" class="checkboxes" name="dates[]" value="' . $copyday1 . '" style="margin-left:auto; margin-right:auto;">' . $copyday1 . "     " . $nameOfDay . '</input><br/>';
                    }

                    $copyday1 = date("Y-m-d", strtotime("+1 day", strtotime($copyday1)));
                }
                break;
            case "SaturDays":
                while (strtotime($copyday1) <= strtotime($copyday2)) {
                    
                    if (Yii::app()->user->isAdmin()) {
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "'")->queryAll();
                    } else {

                        $SiteId = Yii::app()->user->data()->SiteId;
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "' AND ( holydays.type ='GENERAL' OR holydays.siteId = '" . $SiteId . "')")->queryAll();
                    }
                    $nameOfDay = date('l', strtotime($copyday1));
                    if ($nameOfDay == "Saturday" and empty($Holiday)) {

                        echo '<input type="checkbox" class="checkboxes" name="dates[]" value="' . $copyday1 . '" style="margin-left:auto; margin-right:auto;">' . $copyday1 . "     " . $nameOfDay . '</input><br/>';
                    }

                    $copyday1 = date("Y-m-d", strtotime("+1 day", strtotime($copyday1)));
                }
                break;
            case "SunDays":
                while (strtotime($copyday1) <= strtotime($copyday2)) {

                    if (Yii::app()->user->isAdmin()) {
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "'")->queryAll();
                    } else {

                        $SiteId = Yii::app()->user->data()->SiteId;
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "' AND ( holydays.type ='GENERAL' OR holydays.siteId = '" . $SiteId . "')")->queryAll();
                    }
                    $nameOfDay = date('l', strtotime($copyday1));
                    if ($nameOfDay == "Sunday" and empty($Holiday)) {

                        echo '<input type="checkbox" class="checkboxes" name="dates[]" value="' . $copyday1 . '" style="margin-left:auto; margin-right:auto;">' . $copyday1 . "     " . $nameOfDay . '</input><br/>';
                    }

                    $copyday1 = date("Y-m-d", strtotime("+1 day", strtotime($copyday1)));
                }
                break;
            case "HoliDays":
                while (strtotime($copyday1) <= strtotime($copyday2)) {

                    if (Yii::app()->user->isAdmin()) {
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "'")->queryAll();
                    } else {

                        $SiteId = Yii::app()->user->data()->SiteId;
                        $Holiday = Yii::app()->db->createCommand("SELECT *
                                        FROM holydays
                                        WHERE holydays.Date ='" . $copyday1 . "' AND ( holydays.type ='GENERAL' OR holydays.siteId = '" . $SiteId . "')")->queryAll();
                    }
                    $nameOfDay = date('l', strtotime($copyday1));
                    if (!empty($Holiday)) {

                        echo '<input type="checkbox" class="checkboxes" name="dates[]" value="' . $copyday1 . '" style="margin-left:auto; margin-right:auto;">' . $copyday1 . "     " . $nameOfDay . " - " . $Holiday[0]['Description'].'</input><br/>';
                    }

                    $copyday1 = date("Y-m-d", strtotime("+1 day", strtotime($copyday1)));
                }
                break;
            default:
                while (strtotime($copyday1) <= strtotime($copyday2)) {
                   
                $nameOfDay = date('l', strtotime($copyday1));
                    echo '<input type="checkbox" class="checkboxes" name="dates[]" value="' . $copyday1 . '" style="margin-left:auto; margin-right:auto;">' . $copyday1 . "     " . $nameOfDay . '</input><br/>';

                    $copyday1 = date("Y-m-d", strtotime("+1 day", strtotime($copyday1)));
                }
        }
    }

    public function actionAddNewEmployeeToShift() {
        $model = new AddNewEmployeeToShift;

        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'Shift_mode' => "ROSTER-BASE"));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'Shift_mode' => "ROSTER-BASE", 'siteid' => $SiteId));
        }
        $userid = Yii::app()->user->id;

        if (isset($_POST['AddNewEmployeeToShift']) and isset($_POST['Employees'])) {

            $MONTH = $_POST['AddNewEmployeeToShift']['Month'];
            $Stage = $_POST['AddNewEmployeeToShift']['Stage'];
            $Employees = $_POST['Employees'];

            $first_day = date('Y-m-01', strtotime($MONTH));
            $last_day = date('Y-m-t', strtotime($MONTH));
            $DayShiftName = "DAY_6AM-3PM";
            $NightShiftName = "NIGHT_6PM-2AM";
            $DayTeamName = "DAY_TEAM_6AM-3PM";
            $NightTeamName = "NIGHT_TEAM_6PM-2AM";

            switch ($Stage) {
                case "DDNNOO":

                    $i = 1;
                    while ($first_day <= $last_day) {


                        if ($i == 1 or $i == 2) {

                            $STime = '06:00';
                            // $ETime ='15:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '06:00' : '15:00';
                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($first_day . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $DayShiftName, $SiteId, $DayTeamName, $Employees);
                        } else if ($i == 3 or $i == 4) {

                            $STime = '18:00';

                            // $ETime ='03:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '18:00' : '02:00';

                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $Shift_end = date('Y-m-d', strtotime($first_day . ' +1 day'));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($Shift_end . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $NightShiftName, $SiteId, $NightTeamName, $Employees);
                        } else if ($i == 5 or $i == 6) {
                            //    Leave Create
                            Yii::app()->CreateNewEmployeeToShift->CreateLeaves($first_day, $SiteId, $Employees, $userid);
                        }

                        $i = $i == 6 ? 0 : $i;
                        $i += 1;
                        $first_day = date('Y-m-d', strtotime($first_day . ' +1 day'));
                    }

                    break;
                case "DNNOOD":
                    $i = 2;
                    while ($first_day <= $last_day) {


                        if ($i == 1 or $i == 2) {

                            $STime = '06:00';
                            // $ETime ='15:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '06:00' : '15:00';
                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($first_day . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $DayShiftName, $SiteId, $DayTeamName, $Employees);
                        } else if ($i == 3 or $i == 4) {

                            $STime = '18:00';
                            //   $ETime ='03:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '18:00' : '02:00';

                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $Shift_end = date('Y-m-d', strtotime($first_day . ' +1 day'));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($Shift_end . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $NightShiftName, $SiteId, $NightTeamName, $Employees);
                        } else if ($i == 5 or $i == 6) {
                            Yii::app()->CreateNewEmployeeToShift->CreateLeaves($first_day, $SiteId, $Employees, $userid);
                        }

                        $i = $i == 6 ? 0 : $i;
                        $i += 1;
                        $first_day = date('Y-m-d', strtotime($first_day . ' +1 day'));
                    }

                    break;
                case "NNOODD":

                    $i = 3;
                    while ($first_day <= $last_day) {


                        if ($i == 1 or $i == 2) {

                            $STime = '06:00';
                            //  $ETime ='15:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '06:00' : '15:00';
                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($first_day . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $DayShiftName, $SiteId, $DayTeamName, $Employees);
                        } else if ($i == 3 or $i == 4) {
                            $STime = '18:00';
                            //   $ETime ='03:00';
                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '18:00' : '02:00';

                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $Shift_end = date('Y-m-d', strtotime($first_day . ' +1 day'));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($Shift_end . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $NightShiftName, $SiteId, $NightTeamName, $Employees);
                        } else if ($i == 5 or $i == 6) {
                            Yii::app()->CreateNewEmployeeToShift->CreateLeaves($first_day, $SiteId, $Employees, $userid);
                        }

                        $i = $i == 6 ? 0 : $i;
                        $i += 1;
                        $first_day = date('Y-m-d', strtotime($first_day . ' +1 day'));
                    }

                    break;
                case "NOODDN":
                    $i = 4;
                    while ($first_day <= $last_day) {


                        if ($i == 1 or $i == 2) {

                            $STime = '06:00';
                            // $ETime ='15:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '06:00' : '15:00';
                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($first_day . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $DayShiftName, $SiteId, $DayTeamName, $Employees);
                        } else if ($i == 3 or $i == 4) {

                            $STime = '18:00';
                            // $ETime ='03:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '18:00' : '02:00';

                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $Shift_end = date('Y-m-d', strtotime($first_day . ' +1 day'));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($Shift_end . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $NightShiftName, $SiteId, $NightTeamName, $Employees);
                        } else if ($i == 5 or $i == 6) {
                            Yii::app()->CreateNewEmployeeToShift->CreateLeaves($first_day, $SiteId, $Employees, $userid);
                        }

                        $i = $i == 6 ? 0 : $i;
                        $i += 1;
                        $first_day = date('Y-m-d', strtotime($first_day . ' +1 day'));
                    }

                    break;
                case "OODDNN":
                    $i = 5;
                    while ($first_day <= $last_day) {


                        if ($i == 1 or $i == 2) {

                            $STime = '06:00';
                            //   $ETime ='15:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '06:00' : '15:00';
                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($first_day . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $DayShiftName, $SiteId, $DayTeamName, $Employees);
                        } else if ($i == 3 or $i == 4) {
                            $STime = '18:00';
                            //  $ETime ='03:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '18:00' : '02:00';

                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $Shift_end = date('Y-m-d', strtotime($first_day . ' +1 day'));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($Shift_end . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $NightShiftName, $SiteId, $NightTeamName, $Employees);
                        } else if ($i == 5 or $i == 6) {
                            Yii::app()->CreateNewEmployeeToShift->CreateLeaves($first_day, $SiteId, $Employees, $userid);
                        }

                        $i = $i == 6 ? 0 : $i;
                        $i += 1;
                        $first_day = date('Y-m-d', strtotime($first_day . ' +1 day'));
                    }

                    break;
                case "ODDNNO":
                    $i = 6;
                    while ($first_day <= $last_day) {

                        if ($i == 1 or $i == 2) {

                            $STime = '06:00';
                            //    $ETime ='15:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '06:00' : '15:00';
                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($first_day . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $DayShiftName, $SiteId, $DayTeamName, $Employees);
                        } else if ($i == 3 or $i == 4) {
                            $STime = '18:00';
                            //  $ETime ='03:00';

                            $poyaday = Holydays::model()->findByAttributes(array('Date' => $first_day, 'Is_Poyaday' => "POYADAY"));
                            $ETime = !empty($poyaday) ? '18:00' : '02:00';

                            $ShiftStart = date('Y-m-d H:i:s', strtotime($first_day . $STime));
                            $Shift_end = date('Y-m-d', strtotime($first_day . ' +1 day'));
                            $ShiftEnd = date('Y-m-d H:i:s', strtotime($Shift_end . $ETime));

                            Yii::app()->CreateNewEmployeeToShift->ShiftCreate($first_day, $ShiftStart, $ShiftEnd, $NightShiftName, $SiteId, $NightTeamName, $Employees);
                        } else if ($i == 5 or $i == 6) {
                            Yii::app()->CreateNewEmployeeToShift->CreateLeaves($first_day, $SiteId, $Employees, $userid);
                        }

                        $i = $i == 6 ? 0 : $i;
                        $i += 1;
                        $first_day = date('Y-m-d', strtotime($first_day . ' +1 day'));
                    }

                    break;
            }
            $this->redirect(array('roster/create'));
        }
        $this->render('AddNewEmployeeToShift', array('model' => $model, 'employees' => $employees));
    }

}
