<?php

class SkuSalaryController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'view', 'GetSalary', 'GetSiteId'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update', 'admin'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

/**
* Creates a new model.
* If creation is successful, the browser will be redirected to the 'view' page.
*/
public function actionCreate()
{
$model=new SkuSalary;

$model->CreatedBy = Yii::app()->user->id;
$model->CreatedOn = date('Y-m-d H:m:s');
$model->Status = 1;
 if (Yii::app()->user->data()->superuser == 1) {
            $Sku = Sku::model()->findAll();
 } else {
       $SiteId = Yii::app()->user->data()->SiteId;
       $Sku = Sku::model()->findAllByAttributes(array('site_id' => $SiteId));
   }

    if (isset($_POST['SkuSalary'])) {
        
            $model->attributes = $_POST['SkuSalary'];
            $model->basic_plus_bra = $model->basic + $model->BRA1 + $model->BRA2 + $model->BRA3;
            $Skum = Sku::model()->findByAttributes(array('id' => $model->sku_id));

            if ($model->validate()) {
                SkuSalary::model()->updateAll(array('Status' => 0), 'sku_id ="' . $model->sku_id . '"');
                $model->site_id =$Skum->site_id;
                if ($model->save())
                    $this->redirect(array('view', 'id' => $model->id));
            }
        }

        $this->render('create', array(
            'model' => $model, 'Sku' => $Sku
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['SkuSalary'])) {
            $model->attributes = $_POST['SkuSalary'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('SkuSalary');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new SkuSalary('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['SkuSalary']))
            $model->attributes = $_GET['SkuSalary'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = SkuSalary::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'sku-salary-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionGetSalary() {

        $skuId = $_POST["skuId"];
        $skuSalary = SkuSalary::model()->findByAttributes(array("sku_id" => $skuId, "Status" => 1));


        if ($skuSalary != null) {
            $this->_sendResponse(200, CJSON::encode(array("basic_plus_bra" => $skuSalary->basic_plus_bra, "basic" => $skuSalary->basic, "BRA1" => $skuSalary->BRA1, "BRA2" => $skuSalary->BRA2, "BRA3" => $skuSalary->BRA3, "contract_fee" => $skuSalary->contract_fee, "mp_agent_rate" => $skuSalary->mp_agent_rate)));
        } else {
            $this->_sendResponse(200, CJSON::encode(array("basic_plus_bra" => 0, "basic" => 0, "BRA1" => 0, "BRA2" => 0, "BRA3" => 0, "contract_fee" => 0, "mp_agent_rate" => 0)));
        }
    }

    public function actionGetSiteId() {
        $this->_sendResponse(200, CJSON::encode(array('siteId' => Sku::model()->findByPk(1)->site_id)));
    }

}
