<?php

class SupplierController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'view', 'SupplierContactDocdelete','AverageCostPerEmployee'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update', 'alldocview', 'supplierdocdown'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete', 'alldocview'),
                'users' => array('admin'),
            ),
//========================================================
            array('allow', // allow only the owner to perform 'create'  actions
                'actions' => array('create'),
                'expression' => 'Yii::app()->user->can("Supplier_Create")',
            ),
            array('allow', // allow only the owner to perform 'index'  actions
                'actions' => array('index'),
                'expression' => 'Yii::app()->user->can("Supplier_Index")',
            ),
            array('allow', // allow only the owner to perform 'admin'  actions
                'actions' => array('admin'),
                'expression' => 'Yii::app()->user->can("Supplier_Admin")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('view'),
                'expression' => 'Yii::app()->user->can("Supplier_View")',
            ),
            array('allow', // allow only the owner to perform 'update'  actions
                'actions' => array('update'),
                'expression' => 'Yii::app()->user->can("Supplier_Update")',
            ),
            array('allow', // allow only the owner to perform 'delete'  actions
                'actions' => array('delete'),
                'expression' => 'Yii::app()->user->can("Supplier_Delete")',
            ),
            array('allow', // allow only the owner to perform 'Supplier_Document_Upload'  actions
                'actions' => array('docupload'),
                'expression' => 'Yii::app()->user->can("Supplier_Docupload")',
            ),
            array('allow', // allow only the owner to perform 'Supplier_Document_Update'  actions
                'actions' => array('docupdate'),
                'expression' => 'Yii::app()->user->can("Supplier_Docupdate")',
            ),
            array('allow', // allow only the owner to perform 'Supplier_Document_Delete'  actions
                'actions' => array('supplierdocdelete'),
                'expression' => 'Yii::app()->user->can("Supplier_Supplierdocdelete")',
            ),
            array('allow', // allow only the owner to perform 'Supplier_Document_View'  actions
                'actions' => array('supplierpdfview'),
                'expression' => 'Yii::app()->user->can("Supplier_Supplierpdfview")',
            ),
//========================================================
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionDocupload() {
        $supplierdoctypemodel = SupplierDocumentType::model()->findAll();



        if (Yii::app()->request->getParam('contract_submit')) {

            $currentDir = getcwd();
            if (Yii::app()->request->getParam('doctype') == '5') {

                $uploadDirectory = "/document/supplier/cd/";
                $fi_name = "cd";
            }
            $errors = []; // Store all foreseen and unforseen errors here


            $fileExtensions = ['pdf']; // Get all the file extensions


            $fileName = $_FILES['inputfile']['name'];
            $fileSize = $_FILES['inputfile']['size'];
            $fileTmpName = $_FILES['inputfile']['tmp_name'];
            $fileType = $_FILES['inputfile']['type'];

            $savefilename = (yii::app()->request->getParam('suplierid') . $fi_name . date('YmdHis') . '.pdf' );

            $tmp = explode('.', $savefilename);
            $fileExtension = end($tmp);




            $uploadPath = $currentDir . $uploadDirectory . basename($savefilename);



            if (isset($_POST['contract_submit'])) {

                if (!in_array($fileExtension, $fileExtensions)) {
                    $errors[] = "This file extension is not allowed. Please upload a JPEG or PNG file";
                }

                if ($fileSize > 4000000) {
                    $errors[] = "This file is more than 4MB. Sorry, it has to be less than or equal to 4MB";
                }

                if (empty($errors)) {
                    $didUpload = move_uploaded_file($fileTmpName, $uploadPath);

                    if ($didUpload) {
                        $supulir_id_contract = Yii::app()->request->getParam('suplierid');
                        $site_id_contract = Yii::app()->request->getParam('site_id');
                        $suppliercontractdocumentupdate = SupplierContractDocument::model()->find(" status='1' AND supplier_id='$supulir_id_contract' AND site_id='$site_id_contract'  ");

                        if ($suppliercontractdocumentupdate) {
                            $suppliercontractdocumentupdate->status = "0";
                            $suppliercontractdocumentupdate->save();

                            $supplierdocumentsmodel = new SupplierContractDocument();


                            $supplierdocumentsmodel->supplier_id = Yii::app()->request->getParam('suplierid');
                            $supplierdocumentsmodel->documents_type_id = Yii::app()->request->getParam('doctype');
                            $supplierdocumentsmodel->document_path = $uploadDirectory . basename($savefilename);
                            $supplierdocumentsmodel->inactive_date = Yii::app()->request->getParam('Expedia_date');
                            $supplierdocumentsmodel->status = "1";
                            $supplierdocumentsmodel->site_id = Yii::app()->request->getParam('site_id');
                            $supplierdocumentsmodel->assign_date = date('Y-m-d h:i:s');
                            if ($supplierdocumentsmodel->save()) {

                                $suppliername = Supplier::model()->findByPk(Yii::app()->request->getParam('suplierid'));
                                $this->redirect(array('view', 'id' => Yii::app()->request->getParam('suplierid')));
                            } else {
                                
                            }
                        } else {


                            $supplierdocumentsmodel = new SupplierContractDocument();


                            $supplierdocumentsmodel->supplier_id = Yii::app()->request->getParam('suplierid');
                            $supplierdocumentsmodel->documents_type_id = Yii::app()->request->getParam('doctype');
                            $supplierdocumentsmodel->document_path = $uploadDirectory . basename($savefilename);
                            $supplierdocumentsmodel->inactive_date = Yii::app()->request->getParam('Expedia_date');
                            $supplierdocumentsmodel->status = "1";
                            $supplierdocumentsmodel->site_id = Yii::app()->request->getParam('site_id');
                            $supplierdocumentsmodel->assign_date = date('Y-m-d h:i:s');
                            if ($supplierdocumentsmodel->save()) {

                                $suppliername = Supplier::model()->findByPk(Yii::app()->request->getParam('suplierid'));
                                $this->redirect(array('view', 'id' => Yii::app()->request->getParam('suplierid')));
                            } else {
                                
                            }
                        }
                    } else {
                        echo "An error occurred somewhere. Try again or contact the admin";
                    }
                } else {
                    foreach ($errors as $error) {
                        echo $error . "These are the errors" . "\n";
                    }
                }
            }
        }





        if (Yii::app()->request->getParam('submit')) {

            $currentDir = getcwd();
            if (Yii::app()->request->getParam('doctype') == '1') {

                $uploadDirectory = "/document/supplier/brc/";
                $fi_name = "brc";
            }
            if (Yii::app()->request->getParam('doctype') == '2') {

                $uploadDirectory = "/document/supplier/wcip/";
                $fi_name = "wcip";
            }
            if (Yii::app()->request->getParam('doctype') == '3') {

                $uploadDirectory = "/document/supplier/epf/";
                $fi_name = "epf";
            }
            if (Yii::app()->request->getParam('doctype') == '4') {

                $uploadDirectory = "/document/supplier/s_vat/";
                $fi_name = "s_vat";
            }
            if (Yii::app()->request->getParam('doctype') == '5') {

                $uploadDirectory = "/document/supplier/cd/";
                $fi_name = "cd";
            }




            $errors = []; // Store all foreseen and unforseen errors here


            $fileExtensions = ['pdf']; // Get all the file extensions


            $fileName = $_FILES['inputfile']['name'];
            $fileSize = $_FILES['inputfile']['size'];
            $fileTmpName = $_FILES['inputfile']['tmp_name'];
            $fileType = $_FILES['inputfile']['type'];

            $savefilename = (yii::app()->request->getParam('suplierid') . $fi_name . date('YmdHis') . '.pdf' );

            $tmp = explode('.', $savefilename);
            $fileExtension = end($tmp);




            $uploadPath = $currentDir . $uploadDirectory . basename($savefilename);



            if (isset($_POST['submit'])) {

                if (!in_array($fileExtension, $fileExtensions)) {
                    $errors[] = "This file extension is not allowed. Please upload a JPEG or PNG file";
                }

                if ($fileSize > 4000000) {
                    $errors[] = "This file is more than 4MB. Sorry, it has to be less than or equal to 4MB";
                }

                if (empty($errors)) {
                    $didUpload = move_uploaded_file($fileTmpName, $uploadPath);

                    if ($didUpload) {
                        $supplierdocumentsmodel = new SupplierDocuments();
                        $supplierdocumentsmodel->supplier_id = Yii::app()->request->getParam('suplierid');
                        $supplierdocumentsmodel->documents_type_id = Yii::app()->request->getParam('doctype');
                        $supplierdocumentsmodel->document_path = $uploadDirectory . basename($savefilename);
                        if (Yii::app()->request->getParam('Expedia_date')) {
                            $supplierdocumentsmodel->inactive_date = Yii::app()->request->getParam('Expedia_date');
                        } else {
                            $supplierdocumentsmodel->inactive_date = "0";
                        }

                        $supplierdocumentsmodel->status = "1";
                        $supplierdocumentsmodel->assign_date = date('Y-m-d h:i:s');
                        if ($supplierdocumentsmodel->save()) {

                            $suppliername = Supplier::model()->findByPk(Yii::app()->request->getParam('suplierid'));
                            $this->redirect(array('view', 'id' => Yii::app()->request->getParam('suplierid')));
                        } else {
                            
                        }
                    } else {
                        echo "An error occurred somewhere. Try again or contact the admin";
                    }
                } else {
                    foreach ($errors as $error) {
                        echo $error . "These are the errors" . "\n";
                    }
                }
            }
        }
    }

    public function actionDocupdate() {
        $supplierdoctypemodel = SupplierDocumentType::model()->findAll();


        if (Yii::app()->request->getParam('update')) {

            $sup_id = Yii::app()->request->getParam('suppleridupdate');
            $doc_id = Yii::app()->request->getParam('docutypeupdate'); {

                $currentDir = getcwd();
                if (Yii::app()->request->getParam('docutypeupdate') == '1') {

                    $uploadDirectory = "/document/supplier/brc/";
                    $fi_name = "brc";
                }
                if (Yii::app()->request->getParam('docutypeupdate') == '2') {

                    $uploadDirectory = "/document/supplier/wcip/";
                    $fi_name = "wcip";
                }
                if (Yii::app()->request->getParam('docutypeupdate') == '3') {

                    $uploadDirectory = "/document/supplier/epf/";
                    $fi_name = "epf";
                }
                if (Yii::app()->request->getParam('docutypeupdate') == '4') {

                    $uploadDirectory = "/document/supplier/s_vat/";
                    $fi_name = "s_vat";
                }
                if (Yii::app()->request->getParam('docutypeupdate') == '5') {

                    $uploadDirectory = "/document/supplier/cd/";
                    $fi_name = "cd";
                }




                $errors = []; // Store all foreseen and unforseen errors here


                $fileExtensions = ['pdf']; // Get all the file extensions


                $fileName = $_FILES['inputfileupdate']['name'];
                $fileSize = $_FILES['inputfileupdate']['size'];
                $fileTmpName = $_FILES['inputfileupdate']['tmp_name'];
                $fileType = $_FILES['inputfileupdate']['type'];

                $savefilename = (yii::app()->request->getParam('suppleridupdate') . $fi_name . date('YmdHis') . '.pdf' );

                $tmp = explode('.', $savefilename);
                $fileExtension = end($tmp);




                $uploadPath = $currentDir . $uploadDirectory . basename($savefilename);


                if (isset($_POST['update'])) {

                    if (!in_array($fileExtension, $fileExtensions)) {
                        $errors[] = "This file extension is not allowed. Please upload a JPEG or PNG file";
                    }

                    if ($fileSize > 4000000) {
                        $errors[] = "This file is more than 4MB. Sorry, it has to be less than or equal to 4MB";
                    }

                    if (empty($errors)) {
                        $didUpload = move_uploaded_file($fileTmpName, $uploadPath);

                        if ($didUpload) {
                            $supplierdocumentsmodel = SupplierDocuments::model()->find("supplier_id= '$sup_id' AND documents_type_id='$doc_id' AND status=1");

                            $supplierdocumentsmodel->document_path = $uploadDirectory . basename($savefilename);
                            if (Yii::app()->request->getParam('Expedia_date2')) {
                                $supplierdocumentsmodel->inactive_date = Yii::app()->request->getParam('Expedia_date2');
                            } else {

                                $supplierdocumentsmodel->inactive_date = "0";
                            }

                            if ($supplierdocumentsmodel->save()) {

                                $suppliername = Supplier::model()->findByPk(Yii::app()->request->getParam('suplierid'));
                                $this->redirect(array('view', 'id' => $sup_id));
                            } else {
                                
                            }
                        } else {
                            $supplierdocumentsmodel = SupplierDocuments::model()->find("supplier_id= '$sup_id' AND documents_type_id='$doc_id' AND status=1");
                            if (Yii::app()->request->getParam('Expedia_date2')) {
                                $supplierdocumentsmodel->inactive_date = Yii::app()->request->getParam('Expedia_date2');
                            } else {
                                $supplierdocumentsmodel->inactive_date = "0";
                            }

                            if ($supplierdocumentsmodel->save()) {

                                $suppliername = Supplier::model()->findByPk(Yii::app()->request->getParam('suplierid'));
                                $this->redirect(array('view', 'id' => $sup_id));
                            } else {

                                // print_r("ss");
                                // die;
                            }
                        }
                    } else {
                        foreach ($errors as $error) {
                            echo $error . "These are the errors" . "\n";
                        }
                    }
                } else {
                    
                }
            }
        }
    }

    public function actionView($id) {
        $supplierdoctypemodel = SupplierDocumentType::model()->findAll("site_status= '0'");
        $supplier_sitedoctypemodel = SupplierDocumentType::model()->findAll("site_status= '1'");
        $suppliercontractdocument = SupplierContractDocument::model()->findAll("status= '1' AND supplier_id=$id ");
        $SitesAll = Sites::model()->findAll();



        $this->render('view', array(
            'model' => $this->loadModel($id),
            'ss' => $this->loadModel($id),
            'supplierdoctypemodel' => $supplierdoctypemodel,
            'supplier_sitedoctypemodel' => $supplier_sitedoctypemodel,
            'suppliercontractdocument' => $suppliercontractdocument,
            'SitesAll' => $SitesAll
        ));
    }

// pdf view control


    public function actionSupplierpdfview() {

        if (Yii::app()->request->getParam('document_path')) {

            $this->render('supplierpdfview', array(
                'doc_detil' => Yii::app()->request->getParam('document_path')
            ));
        }


        $supp_id = Yii::app()->request->getParam('param1');


        $docu_type_id = Yii::app()->request->getParam('param2');


        $doc_detil = SupplierDocuments::model()->find("supplier_id= '$supp_id' AND documents_type_id='$docu_type_id' AND status=1");


        $this->render('supplierpdfview', array(
            'supp_id' => $supp_id,
            'doc_detil' => $doc_detil->document_path,
        ));
    }

    public function actionSupplierdocdown() {


        $supp_id = Yii::app()->request->getParam('param1');


        $docu_type_id = Yii::app()->request->getParam('param2');


        $doc_detil = SupplierDocuments::model()->find("supplier_id= '$supp_id' AND documents_type_id='$docu_type_id' AND status=1");


        $this->render('supplierdocdown', array(
            'supp_id' => $supp_id,
            'doc_detil' => $doc_detil,
        ));
    }

// supplier delete



    public function actionSupplierdocdelete() {

        $supp_id = Yii::app()->request->getParam('suppid');


        $docu_type_id = Yii::app()->request->getParam('docid');

        $deletedocmodel = SupplierDocuments::model()->find("supplier_id= '$supp_id' AND documents_type_id='$docu_type_id' AND status=1");

        if ($deletedocmodel) {

            $deletedocmodel->status = "2";
            if ($deletedocmodel->save()) {


                $this->redirect(array('view', 'id' => $supp_id));
            } else {
                print_r("error");
            }
        }



        $supplierdoctypemodel = SupplierDocumentType::model()->findAll();

        $this->redirect(array('view', 'id' => $supp_id));
    }

    public function actionSupplierContactDocdelete() {

        $supp_id = $_POST['suppid'];
        $docu_type_id = $_POST['docid'];
        $site_id = $_POST['siteid'];

        $deletedocmodel = SupplierContractDocument::model()->find("supplier_id= '$supp_id' AND documents_type_id='$docu_type_id' AND site_id='$site_id' AND status=1");

        if ($deletedocmodel) {

            $deletedocmodel->status = "2";
            if ($deletedocmodel->save()) {
               
            } else {
                print_r("error");
            }
        }



        $supplierdoctypemodel = SupplierDocumentType::model()->findAll();

        $this->redirect(array('view', 'id' => $supp_id));
    }

// supplier all document
    public function actionAlldocview() {
        $supp_id = Yii::app()->request->getParam('sup_id');
        $doc_id = Yii::app()->request->getParam('doc_id');

        $alldoc = SupplierDocuments::model()->findAll("supplier_id= '$supp_id' AND documents_type_id='$doc_id' ");





        $this->render('alldocview', array(
            'alldoc' => $alldoc,
            'supp_id' => $supp_id,
            'model' => $this->loadModel($supp_id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Supplier;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Supplier'])) {
            $model->attributes = $_POST['Supplier'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Supplier'])) {
            $model->attributes = $_POST['Supplier'];
            $model->status = $_POST['Supplier']['status'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Supplier');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Supplier('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Supplier']))
            $model->attributes = $_GET['Supplier'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Supplier::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'supplier-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }



public function actionAverageCostPerEmployee(){

                $m = date('m');
                $current_y = date('Y');
                $previous_y = date('Y',strtotime('-1 year'));
                $date = [];

                if($m >= 4){
                        for($i=4;$i<=$m;$i++){
                                array_push($date,$current_y.'-'.sprintf('%02d', $i).'-01');
                        }
                }else{
                        $date = array($previous_y.'-04-01',$previous_y.'-05-01',$previous_y.'-06-01',$previous_y.'-07-01',$previous_y.'-08-01',$previous_y.'-09-01',$previous_y.'-10-01',$previous_y.'-11-01',$previous_y.'-12-01');
                        for($i=1;$i<=$m;$i++){
                                array_push($date,$current_y.'-'.sprintf('%02d', $i).'-01');
                        }
                }
                
                if(Yii::app()->user->isAdmin()){
                        $sites = Yii::app()->db->createCommand("SELECT S.id,S.name FROM sites S")->queryAll();
                }else{
                        $sitid = Yii::app()->user->data()->SiteId;
                        $sites = Yii::app()->db->createCommand("SELECT S.id,S.name FROM sites S WHERE S.id = $sitid ")->queryAll();
                }

                $result = [];
                foreach($date as $aa){
                        $subArray = [];
                        $subArray['date'] = $aa;
                        foreach($sites as $site){
                                $averageCoust = Yii::app()->db->createCommand("SELECT IFNULL(IFNULL(sum(PI.CostOfCompany),0)/count(PI.id),0)
                                        FROM payroll P 
                                        INNER JOIN payroll_items PI ON PI.Payroll_id = P.id
                                        WHERE P.Status = 2 AND P.SiteId = '".$site['id']."' AND P.StartDate = '".$aa."' ")->queryScalar();  

                                $subArray[$site['name']] = round($averageCoust,2);
                        }
                        array_push($result,$subArray);
                }
                 print_r(CJSON::encode(array('$list' => $result)));die;
                $this->_sendResponse(200,CJSON::encode(array('$list' => $result)));

                
        }
}
