<?php

class SupplierDocumentsController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view'),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete','supplierdoc','supplierpdfview','supplierdocdelete'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */	
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new SupplierDocuments;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['SupplierDocuments']))
		{
			$model->attributes=$_POST['SupplierDocuments'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['SupplierDocuments']))
		{
			$model->attributes=$_POST['SupplierDocuments'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('SupplierDocuments');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * SupplierDocument edite And View.
	 */


	public function actionSupplierdoc()
	{
		$model = new Supplier;

		$suppliermodel=Supplier::model()->findAll();
		$supplierdoctypemodel=SupplierDocumentType::model()->findAll();


		if(isset($_POST['supplier']))

		{

			$suppliername=Supplier::model()->findByPk($_POST['supplier']);
			return	$this->render('supplierdoc',[
				
				'suppliermodel'=>$suppliermodel,
				'ss'=>$suppliername,
				'supplierdoctypemodel'=>$supplierdoctypemodel,
				
			]);

		
		}

		
		if ( Yii::app()->request->getParam('submit')) 

		{

			$currentDir = getcwd();
			if(Yii::app()->request->getParam('doctype')=='1'){

				$uploadDirectory = "/assets/supplier/brc/";
				$fi_name="brc";

			}
			if(Yii::app()->request->getParam('doctype')=='2'){

				$uploadDirectory = "/assets/supplier/wcip/";
				$fi_name="wcip";

			}
			if(Yii::app()->request->getParam('doctype')=='3'){

				$uploadDirectory = "/assets/supplier/epf/";
				$fi_name="epf";


			}
			if(Yii::app()->request->getParam('doctype')=='4'){

				$uploadDirectory = "/assets/supplier/s_vat/";
				$fi_name="s_vat";


			}
			if(Yii::app()->request->getParam('doctype')=='5'){

				$uploadDirectory = "/assets/supplier/cd/";
				$fi_name="cd";


			} 	
		
			
			
		
			$errors = []; // Store all foreseen and unforseen errors here
			
		
			$fileExtensions = ['pdf']; // Get all the file extensions
			
		
			$fileName = $_FILES['inputfile']['name'];
			$fileSize = $_FILES['inputfile']['size'];
			$fileTmpName  = $_FILES['inputfile']['tmp_name'];
			$fileType = $_FILES['inputfile']['type'];

			$savefilename=(yii::app()->request->getParam('suplierid').$fi_name.date('YmdHis').'.pdf' );

			$tmp = explode('.', $savefilename);
$fileExtension = end($tmp);
			
		
			
		
			$uploadPath = $currentDir . $uploadDirectory . basename($savefilename); 
			
			
		
			if (isset($_POST['submit'])) {
		
				if (! in_array($fileExtension,$fileExtensions)) {
					$errors[] = "This file extension is not allowed. Please upload a JPEG or PNG file";
				}
		
				if ($fileSize > 2000000) {
					$errors[] = "This file is more than 2MB. Sorry, it has to be less than or equal to 2MB";
				}
		
				if (empty($errors)) {
					$didUpload = move_uploaded_file($fileTmpName, $uploadPath);
		
					if ($didUpload) {
						$supplierdocumentsmodel=new SupplierDocuments();
						$supplierdocumentsmodel->supplier_id=Yii::app()->request->getParam('suplierid');
						$supplierdocumentsmodel->documents_type_id=Yii::app()->request->getParam('doctype');
						$supplierdocumentsmodel->document_path=$uploadDirectory . basename($savefilename);
						$supplierdocumentsmodel->assign_date=date('Y-m-d h:i:s');
						$supplierdocumentsmodel->status	="1";
						$supplierdocumentsmodel->inactive_date=date('Y-m-d h:i:s');
						if($supplierdocumentsmodel->save()){

							$suppliername=Supplier::model()->findByPk(Yii::app()->request->getParam('suplierid'));
			return	$this->render('supplierdoc',[
				
				'suppliermodel'=>$suppliermodel,
				'ss'=>$suppliername,
				'supplierdoctypemodel'=>$supplierdoctypemodel,
				
			]);




						}else{

						}

						
						
		

					} else {
						echo "An error occurred somewhere. Try again or contact the admin";
					}
				} else {
					foreach ($errors as $error) {
						echo $error . "These are the errors" . "\n";
					}
				}
			}
		
		
		}

	

	
		
		//$dataProvider=new CActiveDataProvider('SupplierDocuments');
		$this->render('supplierdoc',[
			
			'suppliermodel'=>$suppliermodel,
			'ss'=>'',
			'supplierdoctypemodel'=>''

			
		]);
	}


	/**
	 * Manages all Views.
	 */

	public function actionSupplierpdfview()
	{

		
	 $supp_id=Yii::app()->request->getParam('param1');
	// $supp_doc_id=Yii::app()->request->getParam('param2');

	 $docu_type_id=Yii::app()->request->getParam('param2');


	  $doc_detil=SupplierDocuments::model()->find("supplier_id= '$supp_id' AND documents_type_id='$docu_type_id'");


	 
	


		
	

		$this->render('supplierpdfview',array(
			'supp_id'=>$supp_id,
			'doc_detil'=>$doc_detil,
		
		
		));
	}

		/**
	 * Manages all models.
	 */

	public function actionAdmin()
	{
		$model=new SupplierDocuments('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['SupplierDocuments']))
			$model->attributes=$_GET['SupplierDocuments'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}
	/**
	 * manage supplier doc delete.
	 */

	public function actionSupplierdocdelete()
	{

		$supp_id=Yii::app()->request->getParam('suppid');
	

	 $docu_type_id=Yii::app()->request->getParam('docid');

		

		$this->render('supplierdocdelete',array(
			
		));
	}





	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return SupplierDocuments the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=SupplierDocuments::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param SupplierDocuments $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='supplier-documents-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
}