<?php

class TimeSheetController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            //==================================================================================================
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'OTApprove', 'OTApproveInTimsheet', 'CreateWorkingHoursReport', 'TimesheetsRecalculateFromEmplyee', 'HighOvertimeReport', 'DailyOvertimeReport', 'DailyOvertimeReportPDF', 'DailyOvertimeReportExcel', 'SundayWorkingReportExcel', 'SundayWorkingReportPDF', 'SundayWorkingReport', 'ResignEmployeesListExcel', 'ResignEmployeesListPDF', 'ResignEmployeesListReport', 'GetTimesheet', 'GetAllTimesheet', 'AddMOrningOT', 'DailyWorkingHoursReportExcel', 'DailyWorkingHoursReportPdf', 'Excel', 'CreateDailyWorkingHoursReport', 'CurrentSchedules', 'GetShiftByDate'),
                'users' => array('*'),
            ),
//            array('allow', // allow authenticated user to perform 'create' and 'update' actions
//                'actions' => array('create', 'update'),
//                'users' => array('@'),
//            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('Create', 'admin', 'delete'),
                'users' => array('admin'),
            ),
            //==================================================================================================
            array('allow', // allow only the owner to perform 'create'  actions
                'actions' => array('create'),
                'expression' => 'Yii::app()->user->can("TimeSheet_Create")',
            ),
            array('allow', // allow only the owner to perform 'index'  actions
                'actions' => array('index'),
                'expression' => 'Yii::app()->user->can("TimeSheet_Index")',
            ),
            array('allow', // allow only the owner to perform 'admin'  actions
                'actions' => array('admin'),
                'expression' => 'Yii::app()->user->can("TimeSheet_Admin")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('view'),
                'expression' => 'Yii::app()->user->can("TimeSheet_View")',
            ),
            array('allow', // allow only the owner to perform 'update'  actions
                'actions' => array('update'),
                'expression' => 'Yii::app()->user->can("TimeSheet_Update")',
            ),
            array('allow', // allow only the owner to perform 'delete'  actions
                'actions' => array('delete'),
                'expression' => 'Yii::app()->user->can("TimeSheet_Delete")',
            ),
            array('allow', // allow only the owner to perform 'GetTimesheet'  actions
                'actions' => array('GetTimesheet'),
                'expression' => 'Yii::app()->user->can("TimeSheet_GetTimesheet")',
            ),
            array('allow', // allow only the owner to perform 'AddMOrningOT'  actions
                'actions' => array('AddMOrningOT'),
                'expression' => 'Yii::app()->user->can("TimeSheet_AddMOrningOT")',
            ),
            array('allow', // allow only the owner to perform 'EditIntime'  actions
                'actions' => array('EditIntime'),
                'expression' => 'Yii::app()->user->can("TimeSheet_EditIntime")',
            ),
            array('allow', // allow only the owner to perform 'EditIntime'  actions
                'actions' => array('EditOutTime'),
                'expression' => 'Yii::app()->user->can("TimeSheet_EditOutTime")',
            ),
            array('allow', // allow only the owner to perform 'SalaryRecalculate'  actions
                'actions' => array('SalaryRecalculate'),
                'expression' => 'Yii::app()->user->can("TimeSheet_SalaryRecalculate")',
            ),
            array('allow', // allow only the owner to perform 'SalaryRecalculate'  actions
                'actions' => array('AllTimesheetRecalculate'),
                'expression' => 'Yii::app()->user->can("TimeSheet_AllTimesheetRecalculate")',
            ),
            array('allow', // allow only the owner to perform 'SalaryRecalculate'  actions
                'actions' => array('CreateTimesheetToDayRate'),
                'expression' => 'Yii::app()->user->can("TimeSheet_CreateTimesheetToDayRate")',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function beforeAction($action) {

        if (Yii::app()->user->isGuest && Yii::app()->controller->action->id != "login") {
            Yii::app()->user->loginRequired();
        }
        return true;
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Timesheet;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (Yii::app()->user->data()->superuser == 1) {
            $users = Employee::model()->findAllByAttributes(array());
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $users = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        $this->render('create', array(
            'model' => $model, 'users' => $users,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Timesheet'])) {
            $model->attributes = $_POST['Timesheet'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    /* public function actionDelete($id) {
      if (Yii::app()->request->isPostRequest) {
      // we only allow deletion via POST request
      $this->loadModel($id)->delete();

      // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
      if (!isset($_GET['ajax']))
      $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
      } else
      throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
      } */

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Timesheet');
        $users = Employee::model()->findAllByAttributes(array());
        $this->render('index', array(
            'dataProvider' => $dataProvider, 'users' => $users,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Timesheet('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Timesheet']))
            $model->attributes = $_GET['Timesheet'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Timesheet::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'timesheet-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionGetTimesheet() {


        $Date = ($_POST['Selecteddate']);
        $employeeid = ($_POST['Selectedemployee']);


        // $Timesheet = Timesheet::model()->findByAttributes(array('date' => $Date, 'EmployeeId' => $employeeid));
        $sql = "
             SELECT 
                timesheet.id,
                timesheet.date,
                timesheet.Intime,
                timesheet.OuteTime,
                timesheet.NOvertimeHours,
                timesheet.DOverTimeHour,
                timesheet.Dovertimesalary,
                timesheet.NOvertimeSalary,
                timesheet.SallaryRate,
                timesheet.EmployeeShiftid,
                timesheet.WorkedHour,
                timesheet.TotalOTHour,
                timesheet.LatedeductTime,
                timesheet.OutLateDeductTime,
                timesheet.TOverTimeHour,
                timesheet.PreOTHour,
                employee.Namewithini,
                employee.nic,
                designation.type,
                supplier.name AS Suppliername,
                sites.name AS sitesname

                FROM timesheet
                INNER JOIN  employee ON timesheet.EmployeeId = employee.id
                INNER JOIN designation ON employee.designationid = designation.id
                INNER JOIN supplier ON employee.supplierid = supplier.id
                INNER JOIN sites ON employee.siteid = sites.id

            WHERE timesheet.EmployeeId ='" . $employeeid . "'  AND timesheet.date ='" . $Date . "'";


        $data = Yii::app()->db->createCommand($sql)->queryAll();


        $timesheet = CJSON::encode($data);
        echo $timesheet;
    }

    public function actionGetAllTimesheet() {

        $StartDate = ($_POST['StartDate']);
        $EndDate = ($_POST['EndDate']);
        $employeeid = ($_POST['Selectedemployee']);

        if (Yii::app()->user->data()->superuser == 1) {

            $sql = "
             SELECT 
                timesheet.id,
                timesheet.date,
                timesheet.Intime,
                timesheet.OuteTime,
                timesheet.NOvertimeHours,
                timesheet.DOverTimeHour,
                timesheet.PreOTHour,
                timesheet.Dovertimesalary,
                timesheet.NOvertimeSalary,
                timesheet.PreOTAmount,
                timesheet.SallaryRate,
                timesheet.EmployeeShiftid,
                timesheet.WorkedHour,
                timesheet.TotalOTHour,
                timesheet.LatedeductTime,
                timesheet.OutLateDeductTime,
                timesheet.TOverTimeHour,
                employee.Namewithini,
                employee.nic,
                designation.type,
                supplier.name AS Suppliername,
                sites.name AS sitesname

                FROM timesheet
                INNER JOIN  employee ON timesheet.EmployeeId = employee.id
                INNER JOIN designation ON employee.designationid = designation.id
                INNER JOIN supplier ON employee.supplierid = supplier.id
                INNER JOIN sites ON employee.siteid = sites.id

            WHERE timesheet.EmployeeId ='" . $employeeid . "'  AND timesheet.date >='" . $StartDate . "'AND timesheet.date <='" . $EndDate . "' ORDER BY timesheet.date ASC";
            $data = Yii::app()->db->createCommand($sql)->queryAll();
            $timesheet = CJSON::encode($data);
            echo $timesheet;
        } else {

            $SiteId = Yii::app()->user->data()->SiteId;

            $sql = "
             SELECT 
                timesheet.id,
                timesheet.date,
                timesheet.Intime,
                timesheet.OuteTime,
                timesheet.NOvertimeHours,
                timesheet.DOverTimeHour,
                timesheet.PreOTHour,
                timesheet.Dovertimesalary,
                timesheet.NOvertimeSalary,
                timesheet.PreOTAmount,
                timesheet.SallaryRate,
                timesheet.EmployeeShiftid,
                timesheet.WorkedHour,
                timesheet.TotalOTHour,
                timesheet.LatedeductTime,
                timesheet.OutLateDeductTime,
                timesheet.TOverTimeHour,
                employee.Namewithini,
                employee.nic,
                designation.type,
                supplier.name AS Suppliername,
                sites.name AS sitesname

                FROM timesheet
                INNER JOIN  employee ON timesheet.EmployeeId = employee.id
                INNER JOIN designation ON employee.designationid = designation.id 
                INNER JOIN supplier ON employee.supplierid = supplier.id
                INNER JOIN sites ON employee.siteid = sites.id

                WHERE timesheet.EmployeeId ='" . $employeeid . "' AND timesheet.SiteId ='" . $SiteId . "'  AND timesheet.date >='" . $StartDate . "'AND timesheet.date <='" . $EndDate . "' ORDER BY timesheet.date ASC";

            $data = Yii::app()->db->createCommand($sql)->queryAll();
            $timesheet = CJSON::encode($data);
            echo $timesheet;
        }
    }

//============================================================================================


    public function actionEditIntime() {
        $TimeSheetid = ($_POST['id']);
        $NewInTime = ($_POST['NewinTime']);
        $OldInTime = ($_POST['OldInTime']);

        $newintime = date("Y-m-d H:i", strtotime($NewInTime));

        if (!empty($TimeSheetid)) {
            if (!empty($NewInTime)) {
                $Timesheet = Timesheet::model()->findByAttributes(array('id' => $TimeSheetid));

                if (!empty($Timesheet)) {

                    Timesheet::model()->updateAll(array('Intime' => $newintime), "id=" . $TimeSheetid . "");
                    $Timechange = new Timsheetchange;
                    $Timechange->CreatedBy = Yii::app()->user->id;
                    $date = date('Y-m-d H:i:s');
                    $Timechange->CreatedON = $date;
                    $Timechange->OldInTime = $OldInTime;
                    $Timechange->NewIntime = $newintime;
                    $Timechange->TimeSheetId = $TimeSheetid;

                    if ($Timechange->save()) {
                        $TimeLog = new Timelog;
                        $Emplyeedetail = Employee::model()->findByAttributes(array('id' => $Timesheet->EmployeeId));

                        Timelog::model()->updateAll(array('ValidStatus' => 0), 'Employeeid = " ' . $Timesheet->EmployeeId . '" AND PunchTime = "' . $OldInTime . '"');

                        $TimeLog->PunchTime = $newintime;
                        $TimeLog->Employeeid = $Timesheet->EmployeeId;
                        $TimeLog->manual = "YES";
                        $TimeLog->Type = "IN";
                        $TimeLog->Siteid = $Emplyeedetail->siteid;
                        $TimeLog->Accountid = $Emplyeedetail->Accountid;
                        $TimeLog->departmentid = $Emplyeedetail->departmentid;
                        $TimeLog->ValidStatus = 1;
                        $TimeLog->save();
                    }
                }
            }
        }

        echo 'Updated Successfully';
    }

    public function actionEditOutTime() {
        $TimeSheetid = ($_POST['id']);
        $NewOutTime = ($_POST['NewOuttime']);
        $OldOutTime = ($_POST['OldOutTime']);

        $newouttime = date("Y-m-d H:i", strtotime($NewOutTime));

        if (!empty($TimeSheetid)) {
            if (!empty($NewOutTime)) {
                $Timesheet = Timesheet::model()->findByAttributes(array('id' => $TimeSheetid));

                $EmployeeShift = EmployeeShift::model()->findByAttributes(array('id' => $Timesheet->EmployeeShiftid));
                $Shift = Shift::model()->findByAttributes(array('id' => $EmployeeShift->ShiftId));
                $NextTime = date('Y-m-d H:i:s', strtotime($Shift->EndTime . '+15hour'));

                if (!empty($Timesheet)) {

                    Timesheet::model()->updateAll(array('OuteTime' => $newouttime), "id=" . $TimeSheetid . "");
                    $Timechange = new Timsheetchange;
                    $Timechange->CreatedBy = Yii::app()->user->id;
                    $date = date('Y-m-d H:i:s');
                    $Timechange->CreatedON = $date;
                    $Timechange->OldOutTime = $OldOutTime;
                    $Timechange->NewOutTime = $newouttime;
                    $Timechange->TimeSheetId = $TimeSheetid;

//                     $sql = "DELETE
//                        FROM timelog
//                        WHERE timelog.Employeeid = '". $Timesheet->EmployeeId ."' AND timelog.Type ='OUT' AND timelog.PunchTime > '". $newouttime ."' AND timelog.PunchTime < '". $NextTime ."'";
//                     Yii::app()->db->createCommand($sql)->execute();
//                
                    //echo $Timechange->NewOutTime;
                    if ($Timechange->save()) {
                        $TimeLog = new Timelog;
                        $Emplyeedetail = Employee::model()->findByAttributes(array('id' => $Timesheet->EmployeeId));

                        Timelog::model()->updateAll(array('ValidStatus' => 0), 'Employeeid = " ' . $Timesheet->EmployeeId . '" AND PunchTime = "' . $OldOutTime . '"');

                        $TimeLog->PunchTime = $newouttime;
                        $TimeLog->Employeeid = $Timesheet->EmployeeId;
                        $TimeLog->manual = "YES";
                        $TimeLog->Type = "OUT";
                        $TimeLog->Siteid = $Emplyeedetail->siteid;
                        $TimeLog->Accountid = $Emplyeedetail->Accountid;
                        $TimeLog->departmentid = $Emplyeedetail->departmentid;
                        $TimeLog->ValidStatus = 1;
                        $TimeLog->save();
                    }
                }
            }
        }

        echo 'Updated Successfully';
    }

    public function actionSalaryRecalculate() {
        $TimeSheetid = ($_POST['id']);

        if (!empty($TimeSheetid)) {
            $Timesheet = Timesheet::model()->findByAttributes(array('id' => $TimeSheetid));
            $employee = Employee::model()->findByAttributes(array('id' => $Timesheet->EmployeeId));

            $Employeeshift = EmployeeShift::model()->findByAttributes(array('id' => $Timesheet->EmployeeShiftid));
            if (!empty($Employeeshift) and $Employeeshift->FlexyShift_Status == 1) {
                if ($employee->Paymentmethod->type == "DAILY") {

                    $S = Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                    $S = Yii::app()->FlexiShiftMonthlyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                }
            } else {
                if ($employee->Paymentmethod->type == "DAILY") {

                    if ($employee->EntitleOT == 1) {
                        $S = Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                    } else {

                        $S = Yii::app()->PayrollCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                    }
                } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                    if ($employee->EntitleOT == 1) {
                        $S = Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                    } else {

                        $S = Yii::app()->MonthlyPaymentCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                    }
                } elseif ($employee->Paymentmethod->type == "PIECE-RATE") {

                    $S = Yii::app()->PiecesPaymentCalculationUtil->TimesheetRecalculate($TimeSheetid);
                }
            }
          // $payroll = CJSON::encode($S);
          //    echo $payroll;
            echo 'Recalculated Successfully ';
        }
    }

    public function actionTimesheetsRecalculateFromEmplyee() {

        $Employeeid = $_POST['Selectedemployee'];
        $StartTime = $_POST['StartDate'];
        $EndTime = $_POST['EndDate'];

        if (!empty($Employeeid)and ! empty($StartTime) and ! empty($EndTime)) {

            if (Yii::app()->user->data()->superuser == 1) {

                $sql = " SELECT 
                     timesheet.id,
                     timesheet.date
                     FROM timesheet
                     WHERE timesheet.date >= '" . $StartTime . "' AND timesheet.date <= '" . $EndTime . "' AND timesheet.EmployeeId ='" . $Employeeid . "'";
                $AllTimeSheet = Yii::app()->db->createCommand($sql)->queryAll();

                if (!empty($AllTimeSheet)) {
                    foreach ($AllTimeSheet as $timesheet) {
                        $TimeSheetid = $timesheet['id'];
                        $Timesheet = Timesheet::model()->findByAttributes(array('id' => $TimeSheetid));
                        $employee = Employee::model()->findByAttributes(array('id' => $Timesheet->EmployeeId));

                        $Employeeshift = EmployeeShift::model()->findByAttributes(array('id' => $Timesheet->EmployeeShiftid));
                        if (!empty($Employeeshift) and $Employeeshift->FlexyShift_Status == 1) {
                            if ($employee->Paymentmethod->type == "DAILY") {

                                $S = Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                            } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                                $S = Yii::app()->FlexiShiftMonthlyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                            }
                        } else {

                            if ($employee->Paymentmethod->type == "DAILY") {

                                if ($employee->EntitleOT == 1) {
                                    Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                                } else {

                                    Yii::app()->PayrollCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                                }
                            } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                                if ($employee->EntitleOT == 1) {
                                    Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                                } else {

                                    Yii::app()->MonthlyPaymentCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                                }
                            } elseif ($employee->Paymentmethod->type == "PIECE-RATE") {

                                $S = Yii::app()->PiecesPaymentCalculationUtil->TimesheetRecalculate($TimeSheetid);
                            }
                        }
                    }
                }
            } else {

                $SiteId = Yii::app()->user->data()->SiteId;

                $sql = " SELECT 
                     timesheet.id,
                     timesheet.date
                     FROM timesheet
                     WHERE timesheet.date >= '" . $StartTime . "' AND timesheet.date <= '" . $EndTime . "'AND timesheet.EmployeeId ='" . $Employeeid . "' AND timesheet.SiteId ='" . $SiteId . "'";
                $AllTimeSheet = Yii::app()->db->createCommand($sql)->queryAll();

                if (!empty($AllTimeSheet)) {
                    foreach ($AllTimeSheet as $timesheet) {
                        $TimeSheetid = $timesheet['id'];
                        $Timesheet = Timesheet::model()->findByAttributes(array('id' => $TimeSheetid));
                        $employee = Employee::model()->findByAttributes(array('id' => $Timesheet->EmployeeId));

                        $Employeeshift = EmployeeShift::model()->findByAttributes(array('id' => $Timesheet->EmployeeShiftid));
                        if (!empty($Employeeshift) and $Employeeshift->FlexyShift_Status == 1) {
                            if ($employee->Paymentmethod->type == "DAILY") {

                                Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                            } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                                Yii::app()->FlexiShiftMonthlyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                            }
                        } else {
                            if ($employee->Paymentmethod->type == "DAILY") {

                                if ($employee->EntitleOT == 1) {
                                    Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                                } else {

                                    Yii::app()->PayrollCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                                }
                            } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                                if ($employee->EntitleOT == 1) {
                                    Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                                } else {

                                    Yii::app()->MonthlyPaymentCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                                }
                            } elseif ($employee->Paymentmethod->type == "PIECE-RATE") {

                                $S = Yii::app()->PiecesPaymentCalculationUtil->TimesheetRecalculate($TimeSheetid);
                            }
                        }
                    }
                }
            }
            echo 'Recalculated Successfully ';
        } else {
            echo 'Recalculated Not Successfully ';
        }
    }

    public function actionAllTimesheetRecalculate() {

        $model = new AllTimeSheetRecalculate;

        if (Yii::app()->user->data()->superuser == 1) {
            $SiteId = 0;
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
        }

        if (isset($_POST['AllTimeSheetRecalculate'])) {

            $StartTime = $_POST['AllTimeSheetRecalculate']['StartTime'];
            $EndTime = $_POST['AllTimeSheetRecalculate']['EndTime'];

            $sql = " SELECT 
                     timesheet.id,
                     timesheet.date
                     FROM timesheet
                     WHERE timesheet.date >= '" . $StartTime . "' AND timesheet.date <= '" . $EndTime . "' AND timesheet.SiteId ='" . $SiteId . "'";
            $AllTimeSheet = Yii::app()->db->createCommand($sql)->queryAll();

            if (!empty($AllTimeSheet)) {
                foreach ($AllTimeSheet as $timesheet) {
                    $TimeSheetid = $timesheet['id'];
                    $Timesheet = Timesheet::model()->findByAttributes(array('id' => $TimeSheetid));
                    $employee = Employee::model()->findByAttributes(array('id' => $Timesheet->EmployeeId));

                    $Employeeshift = EmployeeShift::model()->findByAttributes(array('id' => $Timesheet->EmployeeShiftid));
                    if (!empty($Employeeshift) and $Employeeshift->FlexyShift_Status == 1) {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                        } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                            Yii::app()->FlexiShiftMonthlyCalculationUtil->TimesheetRecalculate($TimeSheetid);
                        }
                    } else {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                            } else {

                                Yii::app()->PayrollCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                            }
                        } elseif ($employee->Paymentmethod->type == "MONTHLY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->TimesheetRecalculate($TimeSheetid);
                            } else {

                                Yii::app()->MonthlyPaymentCalculationUtilnew->TimesheetRecalculate($TimeSheetid);
                            }
                        } elseif ($employee->Paymentmethod->type == "PIECE-RATE") {

                            Yii::app()->PiecesPaymentCalculationUtil->TimesheetRecalculate($TimeSheetid);
                        }
                    }
                }
            }
        }

        $this->render('AllTimesheetRecalculate', array('model' => $model));
    }

//    public function actionAddMOrningOT() {
//        echo 'aaaaa';
//    }

    public function actionCurrentSchedules() {
        $this->render('calendarView', array());
    }

    public function actionCreateTimesheetToDayRate() {
        if (isset($_POST['CreateTimesheetToDayRate']['Date']) and isset($_POST['CreateTimesheetToDayRate']['Shift'])) {

            $shiftid = $_POST['CreateTimesheetToDayRate']['Shift'];
            $EmployeeShifts = EmployeeShift::model()->findAllByAttributes(array('ShiftId' => $shiftid));
            $shift = Shift::model()->findByAttributes(array('id' => $shiftid));

            if (!empty($EmployeeShifts)) {
                foreach ($EmployeeShifts as $EmployeeShift) {
                    Yii::app()->CreateTimsheetToDayRate->TimesheetCalculation($shift, $EmployeeShift);
                }
            }
        }
        $this->render('CreateTimeSheetToDayRate', array());
    }

    public function actionGetShiftByDate() {

        $Date = ($_POST['Date']);
        $Shedule = Schedule::model()->findByAttributes(array('Date' => $Date));
        if (!empty($Shedule)) {
            if (Yii::app()->user->isAdmin()) {
                $Shift = Shift::model()->findAllByAttributes(array('schedulid' => $Shedule->id));
            } else {
                $siteId = Yii::app()->user->data()->SiteId;
                $Shift = Shift::model()->findAllByAttributes(array('schedulid' => $Shedule->id, 'SiteId' => $siteId));
            }
            $Shifts = CJSON::encode($Shift);
            echo $Shifts;
        } else {
            $data = [];
            $Data = CJSON::encode($data);
            echo $Data;
        }
    }

    //=============================Attendance Summary Report==========================================================================
    //================================================================================================================================
//    public function actionCreateTimesheetByPieces() {
//       $model  = new CreateTimsheetByPieces;
//                    
//         if (Yii::app()->user->data()->superuser == 1) {
//            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
//        } else {
//            $SiteId = Yii::app()->user->data()->SiteId;
//            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
//        }
//        $Sku = Sku::model()->findAll();
//        
//        if (isset($_POST['CreateTimsheetByPieces'])) {
//
//         
//          
//         $Result=  Yii::app()->PiecesPaymentCalculationUtil->TimesheetCalculation($_POST['CreateTimsheetByPieces']);
//            print_r($Result);
//            die;      
//        }
//          $this->render('CreateTimesheetByPieces', array('model' => $model,'employees'=>$employees,'Sku'=>$Sku));
//        
//    }
    public function actionOTApprove() {
        $model = new OTApprove;

        if (Yii::app()->user->data()->superuser == 1) {
            $Departments = Department::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Departments = Department::model()->findAllByAttributes(array('siteid' => $SiteId));
        }

        if (isset($_POST['OTApprove'])) {

            $Date = $_POST['OTApprove']['Date'];
            $Department = $_POST['OTApprove']['Department'];
            $TimesheetList = Yii::app()->db->createCommand("SELECT timesheet.*,employee.nic,employee.Namewithini
                    FROM timesheet
                    INNER JOIN employee ON timesheet.EmployeeId = employee.id
                    WHERE timesheet.date ='" . $Date . "' AND timesheet.department_id ='" . $Department . "'")->queryAll();

            $model = new Timesheet;
            $this->render('OTApproveView', array('TimesheetList' => $TimesheetList, 'model' => $model));
        } elseif (isset($_POST['Timesheet'])) {
            $TimeSheetList = $_POST['Timesheet'];
            foreach ($TimeSheetList as $list) {
                if (isset($list['OTApproveStatus']) and $list['OTApproveStatus'] == "on") {

                    $NOTDecimalValue = Yii::app()->commonUtil->ConvertToDecimal($list['NOvertimeHours']);
                    $DOTDecimalValue = Yii::app()->commonUtil->ConvertToDecimal($list['DOverTimeHour']);
                    $TOTDecimalValue = Yii::app()->commonUtil->ConvertToDecimal($list['TOverTimeHour']);

                    Timesheet::model()->updateAll(array('NOvertimeHours' => $NOTDecimalValue, 'DOverTimeHour' => $DOTDecimalValue, 'TOverTimeHour' => $TOTDecimalValue, 'OTApproveStatus' => 1, 'OTApprovedBy' => Yii::app()->user->id, 'OTApprovedTime' => date("Y-m-d H:i:s")), 'id ="' . $list['id'] . '"');
                }
            }
            $this->render('OTApprove', array(
                'model' => $model, 'Departments' => $Departments,
            ));
        } else {
            $this->render('OTApprove', array(
                'model' => $model, 'Departments' => $Departments,
            ));
        }
    }

}
