<?php

class TimelogController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            //====================================================================================================================================
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'ImportTimeLogBulck', 'view', 'createInvalidAttendanceExcel', 'createLateAttendancePDF', 'createLateAttendanceExcel'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update', 'Attendance', 'Pdf', 'AttendanceRange', 'AttendanceRangePdf', 'findInvalidAttendanceDetails', 'Excel',
                    'findLateAttendanceDetails', 'findEarlyOutsDetails', 'createEarlyOutPDF', 'createEarlyOutExcel',
                    'findConsecutiveAbsenceDetails', 'findConsecutiveAbsenceDetails', 'findAttendanceSummaryDetails', 'createAttendanceSummaryPDF', 'createAttendanceSummaryExcel',
                    'createContinuousAbsencePDF', 'createContinuousAbsenceExcel', 'PresentTody', 'PresentEmployeesInSites', 'AllocatedEmployeesInSites',
                    'NonAllocatedEmployeesInSites', 'AbsentEmployeesInSites', 'CreateBulkTimelog', 'GetEmployeesTimelog', 'EditInTime',
                    'EditOutTime', 'DeleteTimelog', 'CreateNewTimelog'
                ),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
            //====================================================================================================================================
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'view', 'createInvalidAttendanceExcel', 'createLateAttendancePDF', 'PresentTody'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete'),
                'users' => array('admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function beforeAction($action) {

        if (Yii::app()->user->isGuest && Yii::app()->controller->action->id != "login") {
            Yii::app()->user->loginRequired();
        }
        return true;
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Timelog;

        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }

        if (isset($_POST['Timelog'])) {

            $model->attributes = $_POST['Timelog'];
            $model->manual = "YES";
            $empl_id = $_POST['Timelog']['Employeeid'];
            $Emplyeedetail = Employee::model()->find("id=$empl_id");
            $model->Siteid = $Emplyeedetail->siteid;
            $model->Accountid = $Emplyeedetail->Accountid;
            $model->departmentid = $Emplyeedetail->departmentid;
            $model->ValidStatus = 1;

            if ($model->save()) {
                //======create employee incentive eligibility================
                if ($model->Type == 'IN') {
                    $employeeIncentives = EmployeeIncentive::model()->findAllByAttributes(['employee_id' => $model->Employeeid, 'status' => 1]);
                    foreach ($employeeIncentives as $employeeIncentive) {
                        switch ($employeeIncentive['incentive_id']) {
                            case 1:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) < new DateTime('08:15:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                            case 2:
                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }

                                break;
                            case 3:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) > new DateTime('17:00:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                        }
                    }
                }
                //end
                //=========new change===========//
                $emplyeeid = $model->Employeeid;
                $employee = Employee::model()->findByAttributes(array('id' => $emplyeeid));

                if ($employee->statusId == 1) {

                    $flexiShift = Yii::app()->PublicFunctionForTimesheetUtil->GetFlexiShift($model);

                    if (!empty($flexiShift)) {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetCalculation($model, $flexiShift);
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            Yii::app()->FlexiShiftMonthlyCalculationUtil->CreateTimeSheet($model, $flexiShift);
                        }
                    } else {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetCalculation($model);
                            } else {

                                Yii::app()->PayrollCalculationUtilnew->TimesheetCalculation($model);
                            }
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->CreateTimeSheet($model);
                            } else {

                                Yii::app()->MonthlyPaymentCalculationUtilnew->CreateTimeSheet($model);
                            }
                        }
                    }
                }
            }
            $this->redirect(array('create'));
        }

        $this->render('create', array(
            'model' => $model, 'employees' => $employees,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);
        $employees = Employee::model()->findAll();
// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Timelog'])) {
            $model->attributes = $_POST['Timelog'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model, 'employees' => $employees,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {
// we only allow deletion via POST request
            $this->loadModel($id)->delete();

// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Timelog');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Timelog('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Timelog']))
            $model->attributes = $_GET['Timelog'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    //=============================================================================

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Timelog::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'timelog-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

//=====================================================================================================
// public function actionImportTimeLogBulck()
// {
//     if (($handle = fopen('abc.csv', 'r')) !== false) {
//         while (($row = fgetcsv($handle, 1000, ",")) !== false) {
//             $nic = $row[2];
//             $inTime = $row[0];
//             $outTime = $row[1];
//             $employee = Employee::model()->findByAttributes(array('nic'=>$nic));
//             $id = $employee->id;
//             $url = Yii::app()->getBaseUrl(true) . "/index.php/FingerPrintApi/CreateTimeLog";
//             if (!empty($nic) && !empty($inTime) && !empty($outTime)) {
//                $data = array('emp_id'=>$id,'time'=>$inTime);
//                $data2 = array('emp_id'=>$id,'time'=>$outTime); 
//                $array = array($data,$data2);
//                $output = Yii::app()->curl->post($url, CJSON::encode($array));
//                print_r($output);
//             } else {
//                print_r($nic);
//             }
//         }
//         fclose($handle);
//     }
// }

    public function actionPresentTody() {
        if (Yii::app()->user->isAdmin()) {
            $list = Yii::app()->db->createCommand("SELECT DISTINCT(E.id),E.Namewithini name,E.nic ,A.name account,D.type designation,S.name site,TIME(T.PunchTime) time,SP.name as supplier
        FROM timelog T
        INNER JOIN employee E ON T.Employeeid = E.id
        INNER JOIN accounts A ON A.id = E.Accountid
        INNER JOIN designation D ON D.id = E.designationid
        INNER JOIN sites S ON S.id = E.siteid
        INNER JOIN supplier SP ON SP.id = E.supplierid
        WHERE DATE(T.PunchTime) = CURDATE() AND E.statusId = 1 AND T.type = 'IN'
        GROUP BY E.id
        ORDER BY site,supplier,account")->queryAll();
        } else {
            $sitid = Yii::app()->user->data()->SiteId;
            $list = Yii::app()->db->createCommand("SELECT DISTINCT E.id,E.Namewithini name,E.nic ,A.name account,D.type designation,S.name site,TIME(T.PunchTime) time,SP.name as supplier
        FROM timelog T
        INNER JOIN employee E ON T.Employeeid = E.id
        INNER JOIN accounts A ON A.id = E.Accountid
        INNER JOIN designation D ON D.id = E.designationid
        INNER JOIN sites S ON S.id = E.siteid
        INNER JOIN supplier SP ON SP.id = E.supplierid
        WHERE DATE(T.PunchTime) = CURDATE() And E.siteid = $sitid AND E.statusId = 1 AND T.type = 'IN'
        GROUP BY E.id
        ORDER BY site,account,time")->queryAll();
        }
        $date = date("Y-M-d");
        $this->render('PresentToday', array('list' => $list, 'date' => $date));
    }

    //========================================== dashboard for sites ==================================
    public function actionPresentEmployeesInSites() {
        $sitid = Yii::app()->user->data()->SiteId;
        $list = Yii::app()->db->createCommand("SELECT DISTINCT E.id,E.Namewithini name,E.nic ,A.name account,D.type designation,TIME(T.PunchTime) time,S.name as supplier
            FROM timelog T
            INNER JOIN employee E ON E.id = T.Employeeid 
            INNER JOIN accounts A ON A.id = E.Accountid
            INNER JOIN designation D ON D.id = E.designationid
            INNER JOIN supplier S ON S.id = E.supplierid
            WHERE DATE(T.PunchTime) = CURDATE() AND E.siteid = $sitid AND E.statusId = 1 AND T.Type = 'IN'
            GROUP BY E.id
            ORDER BY S.name,A.name")->queryAll();

        $date = date("Y-M-d");
        $this->render('SiteVicePresentToday', array('list' => $list, 'date' => $date));
    }

    public function actionAllocatedEmployeesInSites() {
        $sitid = Yii::app()->user->data()->SiteId;
        $list = Yii::app()->db->createCommand("SELECT E.id,E.Namewithini name,E.nic ,A.name account,D.type designation
    FROM employee_shift ES 
    INNER JOIN employee E ON E.id = ES.EmployeeId
    INNER JOIN accounts A ON A.id = E.Accountid
    INNER JOIN designation D ON D.id = E.designationid
    WHERE E.statusId = 1 AND E.siteid = $sitid AND ES.ShiftId IN (SELECT SF.id 
                FROM schedule SCH
                INNER JOIN shift SF ON SF.schedulid = SCH.id
                WHERE SCH.Date = CURDATE() AND SF.SiteId = $sitid)
    ORDER BY A.name")->queryAll();

        $date = date("Y-M-d");
        $this->render('AllocatedEmployees', array('list' => $list, 'date' => $date));
    }

    public function actionNonAllocatedEmployeesInSites() {
        $sitid = Yii::app()->user->data()->SiteId;
        $list = Yii::app()->db->createCommand("SELECT DISTINCT(E.id),E.Namewithini name,E.nic ,A.name account,D.type designation
    FROM timelog T
    INNER JOIN employee E ON E.id = T.Employeeid
    INNER JOIN accounts A ON A.id = E.Accountid
    INNER JOIN designation D ON D.id = E.designationid
    WHERE E.statusId = 1 AND E.siteid = $sitid AND date(T.PunchTime) = CURDATE() AND E.siteid = $sitid AND T.Type = 'IN' AND T.Employeeid NOT IN (SELECT E.id
            FROM employee_shift ES 
            INNER JOIN employee E ON E.id = ES.EmployeeId
            WHERE E.statusId = 1 AND E.siteid = $sitid AND ES.ShiftId IN (SELECT SF.id 
                        FROM schedule SCH
                        INNER JOIN shift SF ON SF.schedulid = SCH.id
                        WHERE SCH.Date = CURDATE() AND SF.SiteId = $sitid))
    ORDER BY A.name")->queryAll();
        $date = date("Y-M-d");
        $this->render('NonAllocatedEmployees', array('list' => $list, 'date' => $date));
    }

    public function actionAbsentEmployeesInSites() {
        $sitid = Yii::app()->user->data()->SiteId;
        $list = Yii::app()->db->createCommand("SELECT DISTINCT E.id,E.Namewithini name,E.nic ,A.name account,D.type designation,SP.name as supplier
    FROM (SELECT E.id
            FROM employee_shift ES 
            INNER JOIN employee E ON E.id = ES.EmployeeId
            INNER JOIN accounts A ON A.id = E.Accountid
            WHERE E.statusId = 1 AND E.siteid = $sitid AND ES.ShiftId IN (SELECT SF.id 
                        FROM schedule SCH
                        INNER JOIN shift SF ON SF.schedulid = SCH.id
                        WHERE SCH.Date = CURDATE() AND SF.SiteId = $sitid)) ALLOCATED
    INNER JOIN employee E ON E.id =  ALLOCATED.id
    INNER JOIN accounts A ON A.id = E.Accountid
    INNER JOIN designation D ON D.id = E.designationid   
    INNER JOIN supplier SP ON SP.id = E.supplierid                 
    WHERE E.statusId = 1 AND ALLOCATED.id NOT IN (SELECT T.Employeeid
                        FROM timelog T 
                        WHERE date(T.PunchTime) = CURDATE() )
    ORDER BY SP.name,A.name")->queryAll();

        $date = date("Y-M-d");
        $this->render('AbsentEmployees', array('list' => $list, 'date' => $date));
    }

    //====================================== dashboard end ===========================================================   
    public function actionCreateBulkTimelog() {
        $model = new BulkTimelog;
        if (Yii::app()->user->data()->superuser == 1) {
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $employees = Employee::model()->findAllByAttributes(array('statusId' => 1, 'siteid' => $SiteId));
        }
// print_r('hit');die;
        if (isset($_POST['BulkTimelog'])) {
            
        } else {
            $this->render('bulkTimelog', array('model' => $model, 'employees' => $employees));
        }
    }

    public function actionGetEmployeesTimelog() {
        //get data from ajax function
        $employees = $_POST['employees'];
        $date = $_POST['date'];

        $list = array(); //crate empty array
        foreach ($employees as $employee) { //loop through employees one by one
            //get details about particular employee
            $employeeDetails = Employee::model()->findByPk($employee);
            $designation = Designation::model()->findByPk($employeeDetails->designationid);
            $supplier = Supplier::model()->findByPk($employeeDetails->supplierid);
            $site = Sites::model()->findByPk($employeeDetails->siteid);
            // check employee has time log on particular date
            $Criteria = new CDbCriteria;
            $Criteria->addCondition('PunchTime LIKE :date AND Employeeid = :empId');
            $Criteria->params = array(
                ':date' => '%' . $date . '%',
                ':empId' => $employee,
            );
            $timelogDetails = Timelog::model()->findAll($Criteria);
            //if record exist create a record in $list array
            if (!empty($timelogDetails)) {
                $array = [];
                $array['empId'] = $employeeDetails->id;
                $array['Namewithini'] = $employeeDetails->Namewithini;
                $array['nic'] = $employeeDetails->nic;
                $array['designation'] = $designation->type;
                $array['supplier'] = $supplier->name;
                $array['site'] = $site->name;
                $array['timelog'] = array(); //2d array
                foreach ($timelogDetails as $timelogDetail) {
                    $array2 = array();
                    $array2['type'] = $timelogDetail->Type;
                    $array2['log'] = $timelogDetail->PunchTime;
                    $array2['logId'] = $timelogDetail->id;
                    array_push($array['timelog'], $array2);

                    //if employee has only one timelog create default timelog for missing one(at least employee should has 2 timelogs)
                    if (count($timelogDetails) == 1) {
                        switch ($array2['type']) {
                            case 'IN':
                                $array3 = array();
                                $array3['type'] = 'OUT';
                                $array3['log'] = '0000-00-00 00:00:00';
                                $array3['logId'] = 0;
                                array_push($array['timelog'], $array3);
                                break;
                            case 'OUT':
                                $array3 = array();
                                $array3['type'] = 'IN';
                                $array3['log'] = '0000-00-00 00:00:00';
                                $array3['logId'] = 0;
                                array_push($array['timelog'], $array3);
                                break;
                        }
                    }
                }

                array_push($list, $array);
                //if employee has no timelogs, create two default IN and OUT timelogs and push into array
            } else {
                $array = [];
                $array['empId'] = $employeeDetails->id;
                $array['Namewithini'] = $employeeDetails->Namewithini;
                $array['nic'] = $employeeDetails->nic;
                $array['designation'] = $designation->type;
                $array['supplier'] = $supplier->name;
                $array['site'] = $site->name;
                $array['timelog'] = array();
                //default intime array
                $arrayIN = array();
                $arrayIN['type'] = 'IN';
                $arrayIN['log'] = '0000-00-00 00:00:00';
                $arrayIN['logId'] = '0';
                //default outtime array
                $arrayOUT = array();
                $arrayOUT['type'] = 'OUT';
                $arrayOUT['log'] = '0000-00-00 00:00:00';
                $arrayOUT['logId'] = '0';
                array_push($array['timelog'], $arrayIN, $arrayOUT);

                array_push($list, $array);
            }
        }
        $this->_sendResponse(200, CJSON::encode($list));
    }

    public function actionEditInTime() {
        $timelogId = $_POST['id'];
        $oldTimelog = $_POST['OldInTime'];
        $newTimelog = date('Y-m-d H:i', strtotime($_POST['NewinTime']));
        $empId = $_POST['empId'];
        if ($timelogId == 0) {

            $model = new Timelog;

            $model->PunchTime = $newTimelog;
            $model->Employeeid = $empId;
            $model->Type = 'IN';
            $model->manual = "YES";
            $Emplyeedetail = Employee::model()->findByPk($empId);
            $model->Siteid = $Emplyeedetail->siteid;
            $model->Accountid = $Emplyeedetail->Accountid;
            $model->departmentid = $Emplyeedetail->departmentid;

            if ($model->save()) {
                //======create employee incentive eligibility================
                if ($model->Type == 'IN') {
                    $employeeIncentives = EmployeeIncentive::model()->findAllByAttributes(['employee_id' => $model->Employeeid, 'status' => 1]);
                    foreach ($employeeIncentives as $employeeIncentive) {
                        switch ($employeeIncentive['incentive_id']) {
                            case 1:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) < new DateTime('08:15:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                            case 2:
                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }

                                break;
                            case 3:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) > new DateTime('17:00:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                        }
                    }
                }
                //end
                //=========new change===========//
                $emplyeeid = $model->Employeeid;
                $employee = Employee::model()->findByAttributes(array('id' => $emplyeeid));

                if ($employee->statusId == 1) {

                    $flexiShift = Yii::app()->PublicFunctionForTimesheetUtil->GetFlexiShift($model);

                    if (!empty($flexiShift)) {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetCalculation($model, $flexiShift);
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            Yii::app()->FlexiShiftMonthlyCalculationUtil->CreateTimeSheet($model, $flexiShift);
                        }
                    } else {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetCalculation($model);
                            } else {

                                Yii::app()->PayrollCalculationUtilnew->TimesheetCalculation($model);
                            }
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->CreateTimeSheet($model);
                            } else {

                                Yii::app()->MonthlyPaymentCalculationUtilnew->CreateTimeSheet($model);
                            }
                        }
                    }
                }

                $this->_sendResponse(200, 'Timelog Successfully Created');
            }
        } else {
            $model = Timelog::model()->findByPk($timelogId);

            $model->PunchTime = $newTimelog;
            if ($model->save()) {
                //======= save changes at tracking table====================
                $trackingModel = new TimelogChangesTrack;
                $trackingModel->timelog_id = $model->id;
                $trackingModel->old_value = $oldTimelog;
                $trackingModel->new_value = $newTimelog;
                $trackingModel->changed_by = Yii::app()->user->id;
                $trackingModel->changed_on = date('Y-m-d H:i:m');
                $trackingModel->timelog_type = 'IN';
                $trackingModel->save();

                //======create employee incentive eligibility================
                if ($model->Type == 'IN') {
                    $employeeIncentives = EmployeeIncentive::model()->findAllByAttributes(['employee_id' => $model->Employeeid, 'status' => 1]);
                    foreach ($employeeIncentives as $employeeIncentive) {
                        switch ($employeeIncentive['incentive_id']) {
                            case 1:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) < new DateTime('08:15:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                            case 2:
                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }

                                break;
                            case 3:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) > new DateTime('17:00:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                        }
                    }
                }
                //end
                //=========new change===========//
                $emplyeeid = $model->Employeeid;
                $employee = Employee::model()->findByAttributes(array('id' => $emplyeeid));

                if ($employee->statusId == 1) {

                    $flexiShift = Yii::app()->PublicFunctionForTimesheetUtil->GetFlexiShift($model);

                    if (!empty($flexiShift)) {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetCalculation($model, $flexiShift);
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            Yii::app()->FlexiShiftMonthlyCalculationUtil->CreateTimeSheet($model, $flexiShift);
                        }
                    } else {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetCalculation($model);
                            } else {

                                Yii::app()->PayrollCalculationUtilnew->TimesheetCalculation($model);
                            }
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->CreateTimeSheet($model);
                            } else {

                                Yii::app()->MonthlyPaymentCalculationUtilnew->CreateTimeSheet($model);
                            }
                        }
                    }
                }

                $this->_sendResponse(200, 'Timelog Successfully Updated.');
            }
        }
        // $this->_sendResponse(200, CJSON::encode($timelogId));
    }

    public function actionEditOutTime() {

        $timelogId = $_POST['id'];
        $oldTimelog = $_POST['OldOutTime'];
        $newTimelog = date('Y-m-d H:i', strtotime($_POST['NewOuttime']));
        $empId = $_POST['empId'];
        //TimelogChangesTrack
        if ($timelogId == 0) {

            $model = new Timelog;

            $model->PunchTime = $newTimelog;
            $model->Employeeid = $empId;
            $model->Type = 'OUT';
            $model->manual = "YES";
            $Emplyeedetail = Employee::model()->findByPk($empId);
            $model->Siteid = $Emplyeedetail->siteid;
            $model->Accountid = $Emplyeedetail->Accountid;
            $model->departmentid = $Emplyeedetail->departmentid;

            if ($model->save()) {
                //======create employee incentive eligibility================
                if ($model->Type == 'IN') {
                    $employeeIncentives = EmployeeIncentive::model()->findAllByAttributes(['employee_id' => $model->Employeeid, 'status' => 1]);
                    foreach ($employeeIncentives as $employeeIncentive) {
                        switch ($employeeIncentive['incentive_id']) {
                            case 1:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) < new DateTime('08:15:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                            case 2:
                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }

                                break;
                            case 3:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) > new DateTime('17:00:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                        }
                    }
                }
                //end
                //=========new change===========//
                $emplyeeid = $model->Employeeid;
                $employee = Employee::model()->findByAttributes(array('id' => $emplyeeid));

                if ($employee->statusId == 1) {

                    $flexiShift = Yii::app()->PublicFunctionForTimesheetUtil->GetFlexiShift($model);
                    if (!empty($flexiShift)) {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetCalculation($model, $flexiShift);
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            Yii::app()->FlexiShiftMonthlyCalculationUtil->CreateTimeSheet($model, $flexiShift);
                        }
                    } else {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetCalculation($model);
                            } else {

                                Yii::app()->PayrollCalculationUtilnew->TimesheetCalculation($model);
                            }
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->CreateTimeSheet($model);
                            } else {

                                Yii::app()->MonthlyPaymentCalculationUtilnew->CreateTimeSheet($model);
                            }
                        }
                    }
                }

                $this->_sendResponse(200, 'Timelog Successfully Created.');
            }
        } else {
            $model = Timelog::model()->findByPk($timelogId);

            $model->PunchTime = $newTimelog;
            if ($model->save()) {
                //======= save changes at tracking table====================
                $trackingModel = new TimelogChangesTrack;
                $trackingModel->timelog_id = $model->id;
                $trackingModel->old_value = $oldTimelog;
                $trackingModel->new_value = $newTimelog;
                $trackingModel->changed_by = Yii::app()->user->id;
                $trackingModel->changed_on = date('Y-m-d H:i:m');
                $trackingModel->timelog_type = 'OUT';
                $trackingModel->save();

                //======create employee incentive eligibility================
                if ($model->Type == 'IN') {
                    $employeeIncentives = EmployeeIncentive::model()->findAllByAttributes(['employee_id' => $model->Employeeid, 'status' => 1]);
                    foreach ($employeeIncentives as $employeeIncentive) {
                        switch ($employeeIncentive['incentive_id']) {
                            case 1:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) < new DateTime('08:15:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                            case 2:
                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }

                                break;
                            case 3:
                                if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) > new DateTime('17:00:00')) {

                                    $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                    if (empty($employeeIncentiveEligibility)) {
                                        $eligibility = new EmployeeIncentiveEligibility;

                                        $eligibility->emp_id = $model->Employeeid;
                                        $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                        $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                        $eligibility->timelog_id = $model->id;
                                        $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                        $eligibility->status = 1;
                                        $eligibility->save();
                                    }
                                }

                                break;
                        }
                    }
                }
                //end
                //=========new change===========//
                $emplyeeid = $model->Employeeid;
                $employee = Employee::model()->findByAttributes(array('id' => $emplyeeid));

                if ($employee->statusId == 1) {

                    $flexiShift = Yii::app()->PublicFunctionForTimesheetUtil->GetFlexiShift($model);
                    if (!empty($flexiShift)) {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetCalculation($model, $flexiShift);
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            Yii::app()->FlexiShiftMonthlyCalculationUtil->CreateTimeSheet($model, $flexiShift);
                        }
                    } else {
                        if ($employee->Paymentmethod->type == "DAILY") {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetCalculation($model);
                            } else {

                                Yii::app()->PayrollCalculationUtilnew->TimesheetCalculation($model);
                            }
                        } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                            if ($employee->EntitleOT == 1) {
                                Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->CreateTimeSheet($model);
                            } else {

                                Yii::app()->MonthlyPaymentCalculationUtilnew->CreateTimeSheet($model);
                            }
                        }
                    }
                }

                $this->_sendResponse(200, 'Timelog Successfully Updated.');
            }
        }
    }

    public function actionDeleteTimelog() {
        $timelogId = $_POST['id'];

        $model = Timelog::model()->findByPk($timelogId);
        if ($model) {
            if ($model->delete()) {

                $trackingModal = new TimelogDeleteTrack;
                $trackingModal->timelog_id = $model->id;
                $trackingModal->punch_time = $model->PunchTime;
                $trackingModal->employee_id = $model->Employeeid;
                $trackingModal->manual = $model->manual;
                $trackingModal->type = $model->Type;
                $trackingModal->site_id = $model->Siteid;
                $trackingModal->account_id = $model->Accountid;
                $trackingModal->department_id = $model->departmentid;
                $trackingModal->deleted_on = date('Y-m-d H:i:m');
                $trackingModal->deleted_by = Yii::app()->user->id;

                $trackingModal->save();
                $this->_sendResponse(200, CJSON::encode(true));
            }
        } else {
            $this->_sendResponse(200, CJSON::encode(false));
        }
    }

    public function actionCreateNewTimelog() {
        $employeeId = $_POST['empId'];
        $punchTime = $_POST['date'];
        $type = $_POST['type'];

        $model = new Timelog;

        $model->PunchTime = $punchTime;
        $model->Employeeid = $employeeId;
        $model->Type = $type;
        $model->manual = "YES";
        $Emplyeedetail = Employee::model()->find("id=$employeeId");
        $model->Siteid = $Emplyeedetail->siteid;
        $model->Accountid = $Emplyeedetail->Accountid;
        $model->departmentid = $Emplyeedetail->departmentid;

        if ($model->save()) {
            //======create employee incentive eligibility================
            if ($model->Type == 'IN') {
                $employeeIncentives = EmployeeIncentive::model()->findAllByAttributes(['employee_id' => $model->Employeeid, 'status' => 1]);
                foreach ($employeeIncentives as $employeeIncentive) {
                    switch ($employeeIncentive['incentive_id']) {
                        case 1:
                            if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) < new DateTime('08:15:00')) {

                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }
                            }

                            break;
                        case 2:
                            $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                            if (empty($employeeIncentiveEligibility)) {
                                $eligibility = new EmployeeIncentiveEligibility;

                                $eligibility->emp_id = $model->Employeeid;
                                $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                $eligibility->timelog_id = $model->id;
                                $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                $eligibility->status = 1;
                                $eligibility->save();
                            }

                            break;
                        case 3:
                            if (new DateTime(date("H:i:s", strtotime($model->PunchTime))) > new DateTime('17:00:00')) {

                                $employeeIncentiveEligibility = EmployeeIncentiveEligibility::model()->findByAttributes(['emp_id' => $model->Employeeid, 'incentive_id' => $employeeIncentive['incentive_id'], 'date' => date("Y-m-d", strtotime($model->PunchTime)), 'status' => 1]);
                                if (empty($employeeIncentiveEligibility)) {
                                    $eligibility = new EmployeeIncentiveEligibility;

                                    $eligibility->emp_id = $model->Employeeid;
                                    $eligibility->incentive_id = $employeeIncentive['incentive_id'];
                                    $eligibility->incentive_amount = $employeeIncentive['incentive_amount'];
                                    $eligibility->timelog_id = $model->id;
                                    $eligibility->date = date("Y-m-d", strtotime($model->PunchTime));
                                    $eligibility->status = 1;
                                    $eligibility->save();
                                }
                            }

                            break;
                    }
                }
            }
            //end
            //=========new change===========//
            $emplyeeid = $model->Employeeid;
            $employee = Employee::model()->findByAttributes(array('id' => $emplyeeid));

            if ($employee->statusId == 1) {

                $flexiShift = Yii::app()->PublicFunctionForTimesheetUtil->GetFlexiShift($model);
                if (!empty($flexiShift)) {
                    if ($employee->Paymentmethod->type == "DAILY") {

                        Yii::app()->FlexiShiftDailyCalculationUtil->TimesheetCalculation($model, $flexiShift);
                    } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                        Yii::app()->FlexiShiftMonthlyCalculationUtil->CreateTimeSheet($model, $flexiShift);
                    }
                } else {

                    if ($employee->Paymentmethod->type == "DAILY") {

                        if ($employee->EntitleOT == 1) {
                            Yii::app()->PayrollCalculationEntitleUtilnew->TimesheetCalculation($model);
                        } else {

                            Yii::app()->PayrollCalculationUtilnew->TimesheetCalculation($model);
                        }
                    } elseif (($employee->Paymentmethod->type == "MONTHLY")) {

                        if ($employee->EntitleOT == 1) {
                            Yii::app()->MonthlyPaymentCalculationEntitleUtilnew->CreateTimeSheet($model);
                        } else {

                            Yii::app()->MonthlyPaymentCalculationUtilnew->CreateTimeSheet($model);
                        }
                    }
                }
            }

            $this->_sendResponse(200, CJSON::encode(true));
        }
    }

}
