import React from "react";
import Taucharts from "taucharts";
import ReactApexChart from "react-apexcharts";
import { Col, Icon, Row, Table } from "antd";
import Warning from "../message";
import "taucharts/dist/plugins/tooltip";
import diff from "deep-diff";
import { ExportButton } from '../Buttons';

import "./style.css";
import "taucharts/dist/taucharts.css";
import "taucharts/dist/plugins/tooltip.dark.css";

Taucharts.api.tickFormat.add('num_to_percentage', (originalValue) => originalValue + '%')

class StackedBarChart extends React.Component {
  constructor(props) {
    super(props);
    this.myRef = React.createRef();
  }

  componentDidMount() {
    this.renderChart();
  }

  renderChart() {
    const { axis, guide, data } = this.props;

    if (data && data.length > 0 && this.myRef) {
      this.chart = new Taucharts.Chart({
        data: data,
        type: "stacked-bar",
        ...axis,
        guide: {
          ...guide,
          padding: { t: 1, r: 1, b: 1, l: 1 },
          showGridLines: "xy",
          size: {
            // func: 'linear',
            // minSize: 3,
            // maxSize: 3
          }
        },
        // lineOrientation: 'none',
        settings: {
          fitModel: "none"
        },
        plugins: [
          Taucharts.api.plugins.get("tooltip")({
            clickable: false
          })
        ]
      });

this.chart.renderTo(this.myRef.current);
    }
  }

  shouldComponentUpdate(nextProps) {
    if (diff(nextProps, this.props)) return true;
    return false;
  }

  componentDidUpdate() {
    this.renderChart();
  }

  render() {
    return (
      <div class="wfm-dashboard-tile-container">
        <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>

        {this.props.href && <ExportButton href={this.props.href}>Export</ExportButton>}
  
        <div class="wfm-dashboard-tile-payload">
          <span class="wfm-dashboard-icon-container">
            <i data-feather="bar-chart" />
          </span>
          <div id="pie-chart-test" class="wfm-graph-container">
            {this.props.data ? (
              this.props.data.error ? (
                <Warning
                  message={this.props.data.error.message}
                  icon="warning"
                  color="#ff2828"
                />
              ) : (
                <div
                  ref={this.myRef}
                  style={{ height: "100%", width: "100%" }}
                />
              )
            ) : (
              <div className="center">
                <Icon type="loading" className="wfm-loading-icon" />
              </div>
            )}
          </div>
        </div>
        {/* <div class="wfm-dashboard-tile-footer">
          <a href="!">
            <i data-feather="external-link" />
          </a>
        </div> */}
      </div>
    );
  }
}

class BarChart extends React.Component {
  constructor(props) {
    super(props);
    this.myRef = React.createRef();
  }

  componentDidMount() {
    this.renderChart();
  }

  renderChart() {
    const { axis, guide, data } = this.props;

    if (data && data.length > 0 && this.myRef) {
      this.chart = new Taucharts.Chart({
        data: data,
        type: "bar",
        ...axis,
        guide: {
          ...guide,
          padding: { t: 1, r: 1, b: 1, l: 1 },
          showGridLines: "xy",
          size: {
            // func: 'linear',
            // minSize: 3,
            // maxSize: 3
          }
        },
        // lineOrientation: 'none',
        settings: {
          fitModel: "none"
        },
        plugins: [
          Taucharts.api.plugins.get("tooltip")({
            clickable: false
          })
        ]
      });

      this.chart.renderTo(this.myRef.current);
    }
  }

  shouldComponentUpdate(nextProps) {
    if (diff(nextProps, this.props)) return true;
    return false;
  }

  componentDidUpdate() {
    this.renderChart();
  }

  render() {
    return (
      <div class="wfm-dashboard-tile-container">
        <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>
        
        {this.props.href && <ExportButton href={this.props.href}>Export</ExportButton>}

        <div class="wfm-dashboard-tile-payload">
          <span class="wfm-dashboard-icon-container">
            <i data-feather="bar-chart" />
          </span>
          <div id="pie-chart-test" class="wfm-graph-container">
            {this.props.data ? (
              this.props.data.error ? (
                <Warning
                  message={this.props.data.error.message}
                  icon="warning"
                  color="#ff2828"
                />
              ) : (
                <div
                  ref={this.myRef}
                  style={{ height: "100%", width: "100%" }}
                />
              )
            ) : (
              <div className="center">
                <Icon type="loading" className="wfm-loading-icon" />
              </div>
            )}
          </div>
        </div>
        {/* <div class="wfm-dashboard-tile-footer">
          <a href="!">
            <i data-feather="external-link" />
          </a>
        </div> */}
      </div>
    );
  }
}

class FilterableLineChart extends React.Component {
  constructor(props) {
    super(props);
    this.myRef = React.createRef();
    this.state = { statedData: [], useStatedData: false }
  }

  componentDidMount() {
    this.renderChart(this.props.data);
  }

  renderChart(data) {
    const { axis, guide } = this.props;

    if (data && data.length > 0 && this.myRef) {
      this.chart = new Taucharts.Chart({
        data: data,
        type: "line",
        ...axis,
        guide: {
          ...guide,
          padding: { t: 1, r: 1, b: 1, l: 1 },
          showGridLines: "xy",
          size: {
            // func: 'linear',
            minSize: 3,
            maxSize: 3
          }
        },
        // lineOrientation: 'none',
        settings: {
          fitModel: "none"
        },
        plugins: [
          Taucharts.api.plugins.get("tooltip")({
            clickable: false
          })
        ]
      });

      this.chart.renderTo(this.myRef.current);
    }
  }

  shouldComponentUpdate(nextProps) {
    if (diff(nextProps, this.props))
      return true
    return false;
  }

  componentDidUpdate() {
    console.log(this.props.data)
      this.renderChart(this.props.data);
  }

  activateLasers(){
    // this.props.clearData();
    this.props.api.url = `${this.props.api.baseUrl}/DashboardApi/DepartmentWiseCost`;
    this.props.fetch()
  }

  render() {
    return (
      <div class="wfm-dashboard-tile-container">
        <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>
        
        {this.props.href && <ExportButton href={this.props.href}>Export</ExportButton>}

        <div class="wfm-dashboard-tile-payload">
          <span class="wfm-dashboard-icon-container">
            <i data-feather="bar-chart-2" />
          </span>
          <button onClick={this.activateLasers.bind(this)}>
            Activate Lasers
          </button>
          <div id="pie-chart-test" class="wfm-graph-container">
            {this.props.data ? (
              this.props.data.error ? (
                <Warning
                  message={this.props.data.error.message}
                  icon="warning"
                  color="#ff2828"
                />
              ) : (
                <div
                  ref={this.myRef}
                  style={{ height: "100%", width: "80%" }}
                />
                // this.props.data.length < 1 && <Warning message="Nothing to show here." icon="warning" color="#ff2828"/>
              )
            ) : (
              <div className="center">
                <Icon type="loading" className="wfm-loading-icon" />
              </div>
            )}
          </div>
        </div>
        {/* <div class="wfm-dashboard-tile-footer">
          <a href="!">
            <i data-feather="external-link" />
          </a>
        </div> */}
      </div>
    );
  }
}

class LineChart extends React.Component {
  constructor(props) {
    super(props);
    this.myRef = React.createRef();
  }

  componentDidMount() {
    this.renderChart();
  }

  renderChart() {
    const { axis, guide, data } = this.props;

    if (data && data.length > 0 && this.myRef) {
      this.chart = new Taucharts.Chart({
        data: data,
        type: "line",
        ...axis,
        guide: {
          ...guide,
          padding: { t: 1, r: 1, b: 1, l: 1 },
          showGridLines: "xy",
          size: {
            // func: 'linear',
            minSize: 3,
            maxSize: 3
          }
        },
        // lineOrientation: 'none',
        settings: {
          fitModel: "none"
        },
        plugins: [
          Taucharts.api.plugins.get("tooltip")({
            clickable: false
          })
        ]
      });
      this.chart.renderTo(this.myRef.current);
    }
  }

  shouldComponentUpdate(nextProps) {
    if (diff(nextProps, this.props)) return true;
    return false;
  }

  componentDidUpdate() {
    this.renderChart();
  }

  render() {
    return (
      <div class="wfm-dashboard-tile-container">
        <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>
        
        {this.props.href && <ExportButton href={this.props.href}>Export</ExportButton>}

        <div class="wfm-dashboard-tile-payload">
          <span class="wfm-dashboard-icon-container">
            <i data-feather="bar-chart-2" />
          </span>
          <div id="pie-chart-test" class="wfm-graph-container">
            {this.props.data ? (
              this.props.data.error ? (
                <Warning
                  message={this.props.data.error.message}
                  icon="warning"
                  color="#ff2828"
                />
              ) : (
                <div
                  ref={this.myRef}
                  style={{ height: "100%", width: "80%" }}
                />
                // this.props.data.length < 1 && <Warning message="Nothing to show here." icon="warning" color="#ff2828"/>
              )
            ) : (
              <div className="center">
                <Icon type="loading" className="wfm-loading-icon" />
              </div>
            )}
          </div>
        </div>
        {/* <div class="wfm-dashboard-tile-footer">
          <a href="!">
            <i data-feather="external-link" />
          </a>
        </div> */}
      </div>
    );
  }
}

class PieChart extends React.PureComponent {
  constructor(props) {
    super(props);
    this.myRef = React.createRef();
    this.state = {
      options: {
        plotOptions: {
          pie: {
            size: 35
          }
        },
        stroke: {
          width: 1
        },
        theme: {
          monochrome: {
            enabled: true
          }
        },
        legend: {
          show: false
        },
        dataLabels: {
          enabled: true,
          // formatter: function (val) {
          //   return val
          // },
          textAnchor: "middle",
          offsetX: 0,
          offsetY: 1,
          style: {
            fontSize: "20px",
            fontFamily: [
              "Trade Gothic",
              "Lucida Sans Unicode",
              "Lucida Grande",
              "Lucida Sans",
              "Arial",
              "sans-serif"
            ],
            colors: ["#262626"]
          },
          dropShadow: {
            enabled: true,
            color: "#fff",
            top: 0,
            left: 1,
            blur: 0,
            opacity: 1
          }
        },
        fill: {
          type: "solid",
          colors: ["#F79727", "#424242"] // array of colors,
        },
        states: {
          hover: {
            enabled: false
          }
        },
        responsive: [
          
        ]
      },
      series: [1, 1]
    };
  }

  componentDidMount() {
    console.log(Object.values(this.props.data));
  }

  render() {
    return (
      <div className="pie-chart-container" style={this.props.style}>
        <center>
          <ReactApexChart
            // options={{...this.state.options, labels: this.props.data.keys()}}
            // series={this.props.data.values()}
            options={{
              ...this.state.options,
              labels: Object.keys(this.props.data)
            }}
            series={Object.values(this.props.data).map(str => parseInt(str))}
            type="donut"
            height={130}
            // height={this.props.height}
            // width={this.props.width}
          />
        </center>
        {this.props.title && (
          <div className="pie-chart-title">{this.props.title}</div>
        )}
      </div>
    );
  }
}

class SolidPieChart extends React.PureComponent {
  constructor(props) {
    super(props);
    this.myRef = React.createRef();
    this.state = {
      options: {
        pie: {
          donut: {
            // size: "100%"
          }
        },
        stroke: {
          width: 1
        },
        theme: {
          monochrome: {
            enabled: true,
            color: "#F79727",
            shadeTo: "dark",
            shadeIntensity: 1
          }
        },
        legend: {
          show: false
        },
        dataLabels: {
          enabled: true,
          // formatter: function (val) {
          //   return val
          // },
          textAnchor: "middle",
          offsetX: 0,
          offsetY: 1,
          style: {
            fontSize: "12px",
            fontFamily: [
              "Trade Gothic",
              "Lucida Sans Unicode",
              "Lucida Grande",
              "Lucida Sans",
              "Arial",
              "sans-serif"
            ],
            colors: ["#262626"]
          },
          dropShadow: {
            enabled: true,
            color: "#fff",
            top: 0,
            left: 1,
            blur: 0,
            opacity: 1
          }
        },
        fill: {
          type: "solid"
          // colors: ["#F79727", "#424242"] // array of colors,
        },
        states: {
          hover: {
            enabled: false
          }
        },
        responsive: [
          {
            // breakpoint: 480,
          }
        ]
      },
      series: [1, 1]
    };
  }

  componentDidMount() {
    console.log(Object.values(this.props.data));
  }

  render() {
    return (
      <div className="pie-chart-container" style={this.props.style}>
      
        <center>
          <ReactApexChart
            // options={{...this.state.options, labels: this.props.data.keys()}}
            // series={this.props.data.values()}
            options={{
              ...this.state.options,
              labels: Object.keys(this.props.data)
            }}
            series={Object.values(this.props.data).map(str => parseInt(str))}
            type="pie"
            height={this.props.height}
            width={this.props.width}
          />
        </center>
        {this.props.title && (
          <div className="pie-chart-title">{this.props.title}</div>
        )}
      </div>
    );
  }
}

class PieChartGrid extends React.PureComponent {
  constructor(props) {
    super(props);
    this.layout = {
      xl: 4,
      lg: 4,
      md: 6,
      sm: 6,
      xs: 12
    };
  }
  render() {
    return (
      <div class="wfm-dashboard-tile-container">
        <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>
        {this.props.href && (
          <a href={this.props.href}>
            <div className="wf-link-button">Click</div>
          </a>
        )}
        <div class="wfm-dashboard-tile-payload">
          <span class="wfm-dashboard-icon-container">
            <i data-feather="pie-chart" />
          </span>

          {/* <Row gutter={5} className="wfm-dashboard-card-payload">
            <Col {...this.layout}>
              <PieChart data={} title={}/>
            </Col>
          </Row> */}

          {this.props.data ? (
            this.props.data.error ? (
              <Warning
                message={this.props.data.error.message}
                icon="warning"
                color="#ff2828"
              />
            ) : (
              <Row gutter={5} className="wfm-dashboard-card-payload pie-chart-grid">
                {this.props.data.map(({ data, title }) => (
                  <Col {...this.layout}>
                    <PieChart
                      data={data}
                      title={title}
                      // height={150}
                      // width={150}
                    />
                  </Col>
                ))}
              </Row>
            )
          ) : (
            <div className="center">
              <Icon type="loading" className="wfm-loading-icon" />
            </div>
          )}
        </div>
        {/* <div class="wfm-dashboard-tile-footer">
          <a href="!">
            <i data-feather="external-link" />
          </a>
        </div> */}
      </div>
    );
  }
}

class PieChartCard extends React.PureComponent {
  render() {
    return (
      <div class="wfm-dashboard-tile-container">
        <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>
        
        {this.props.href && <ExportButton href={this.props.href}>Export</ExportButton>}

        <div class="wfm-dashboard-tile-payload">
          <span class="wfm-dashboard-icon-container">
            <i data-feather="pie-chart" />
          </span>

          {this.props.data ? (
            this.props.data.error ? (
              <Warning
                message={this.props.data.error.message}
                icon="warning"
                color="#ff2828"
              />
            ) : (
              <div className="wfm-graph-container">
                <SolidPieChart
                  data={this.props.data}
                  height={270}
                  width={270}
                  style={{ height: 222 }}
                />
              </div>
              // this.props.data.length < 1 && <Warning message="Nothing to show here." icon="warning" color="#ff2828"/>
            )
          ) : (
            <div className="center">
              <Icon type="loading" className="wfm-loading-icon" />
            </div>
          )}
        </div>
        {/* <div class="wfm-dashboard-tile-footer">
          <a href="!">
            <i data-feather="external-link" />
          </a>
        </div> */}
      </div>
    );
  }
}

class TwoColumnGridChart extends React.PureComponent{
  render(){
    return (<div class="wfm-dashboard-tile-container">
    <div>{this.props.title ? this.props.title.toUpperCase() : "-"}</div>
    
    {this.props.href && <ExportButton href={this.props.href}>Export</ExportButton>}

    <div class="wfm-dashboard-tile-payload">
      <span class="wfm-dashboard-icon-container">
        <i data-feather="list" />
      </span>

      {this.props.data ? (
        this.props.data.error ? (
          <Warning
            message={this.props.data.error.message}
            icon="warning"
            color="#ff2828"
          />
        ) : (
          <div className="wfm-graph-container">
          {
              this.props.data.map(({left, right}, i) => <div className={`two-column-grid-container ${i%2==0 ? 'odd' : 'even'}`}>
                <div className="two-column-grid-left">{left}</div>
                <div className="two-column-grid-right">{right}</div>
              </div>)
            }
          
          </div>         
        )
      ) : (
        <div className="center">
          <Icon type="loading" className="wfm-loading-icon" />
        </div>
      )}
    </div>
  </div>)
  }
}

export {
  LineChart,
  FilterableLineChart,
  PieChart,
  PieChartGrid,
  BarChart,
  StackedBarChart,
  PieChartCard,
  TwoColumnGridChart
};
