import React from "react";
import _ from "lodash";
import axios from "axios";
import dashboard from "../dashboard.config";

const Context = React.createContext();
const withContext = Component => (
  <Context.Consumer>{data => <Component {...data}/>}</Context.Consumer>
);

class DataContext extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      Tree: this.initElementTree(),
      isLoading: false
    };
    this.methods = {
      onFilter: args => {
        this.state.Tree.forEach(element => {
          if(_.includes(element.filters, args.filter)){
            element.data = null
            this.setState({
              Tree: this.state.Tree,
              isLoading: true
            },this.fetch.bind(this, element, args))
          } 
        })
      }
    };
  }

  initElementTree(){
    return dashboard.map((element, i) => ({
      ...element,
      data: null,
      id: i.toString(),
      fetch: this.fetch.bind(this, element)
    }))
  }

  fetch(el, filter){
    
    try{
      const { method = 'get', url = null, body } = (typeof el.api === "function") ? el.api(filter) : el.api

      axios[method](url, body || null).then(
        data => this.setState({
          Tree : this.state.Tree.map(element => {
            if(element.id === el.id)
              return {...element, data: element.formater(data)}
            else return element
          }),
          isLoading: false
        })
      ).catch(this.onError.bind(this, el))
    }
    catch(err){
      this.onError(el, err)
    }
  }

  updateTree(){
    this.setState({
      Tree: this.state.Tree.map(element => ({ ...element, data: null})),
      isLoading: true
    },() => this.state.Tree.forEach(this.fetch.bind(this)))
  }

  onError(el, error){    
    this.setState({
      Tree : this.state.Tree.map(element => {
        if(element.id === el.id)
          return {...element, data: { error }}
        else return element
      }),
      isLoading: false
    })
  }

  componentDidMount(){
    this.updateTree();
  }

  render() {
    return (
      <Context.Provider value={{ ...this.methods, ...this.state }}>
        {this.props.children}
      </Context.Provider>
    );
  }
}

export { DataContext, withContext };
