import React from "react";
import _ from "lodash";
import axios from "axios";
import dashboard from "../dashboard.config";
import initConfig from "../init.config";
import network from "./network";

const Context = React.createContext();
const withContext = Component => (
  <Context.Consumer>{data => <Component {...data}/>}</Context.Consumer>
);

class DataContext extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      Tree: [],
      isLoading: false,
      roll: 50
    };
    this.methods = {
      onFilter: args => {
        this.state.Tree.forEach(element => {
          if(_.includes(element.filters, args.filter)){
            element.data = null
            this.setState({
              Tree: this.state.Tree,
              isLoading: true
            },this.fetch.bind(this, element, args))
          } 
        })
      },
      UpdateTree: this.updateTree.bind(this)
    };
  }

  initElementTree(rule){
    return dashboard(rule).map((element, i) => ({
      ...element,
      data: null,
      id: i.toString(),
      fetch: this.fetch.bind(this, element),
      clearData: this.clearData.bind(this, i)
    }))
  }

  fetch(el, filter){
    try{
      const { method = 'get', url = null, body } = (typeof el.api === "function") ? el.api(filter) : el.api

      axios[method](url, body || null).then(
        // update render tree if data is avalable
        data => data && this.setState({
          Tree : this.state.Tree.map(element => {
            if(element.id === el.id)
              return {...element, data: element.formater(data)}
            else return element
          }),
          isLoading: false
        })
      ).catch(this.onError.bind(this, el))
    }
    catch(err){
      this.onError(el, err)
    }
  }
///todo
  clearData(el){
    this.setState({
      Tree : this.state.Tree.map(element => {
        if(element.id == el){
          return {...element, data: []};
        }else return element;
      }),
      isLoading: false
    })
  }

  beforeInit(){
    initConfig.beforeInit().then(this.updateTree.bind(this))
  }

  updateTree(roll){
    this.setState({
      Tree: this.state.Tree.map(element => ({ ...element, data: null})),
      isLoading: true
    },() => this.state.Tree.forEach(this.fetch.bind(this)))
    initConfig.afterInit();
  }

  onError(el, error){    
    this.setState({
      Tree : this.state.Tree.map(element => {
        if(element.id === el.id)
          return {...element, data: { error }}
        else return element
      }),
      isLoading: false
    })
  }

  componentDidMount(){
    network('DashboardApi/GetUserDetails' ,'GET', null, ({role}) => 
      {
        this.setState({
          Tree: this.initElementTree(role)
        },() => this.updateTree(role))
      }
    )
  }

  render() {
    return (
      <Context.Provider value={{ ...this.methods, ...this.state }}>
        {this.props.children}
      </Context.Provider>
    );
  }
}

export { DataContext, withContext, network };
