import Card from "../components/Card";
import AvatarGrid from "../components/AvatarGrid";
import {
  PieChartGrid,
  LineChart,
  BarChart,
  StackedBarChart,
  PieChartCard,
  TwoColumnGridChart
} from "../components/Charts";
import moment from 'moment';

let formatter = ({ data }) => data.Count;

let base_url = window.location.toString() + "/";

let colors = ["#1e1b17","#ffad32","#d68306","#a36100","#68440d"];

if (process.env.NODE_ENV === "production") {
  base_url = window.location.toString() + "/";
}

let lastmonth = moment().subtract(1, 'month').format('MMMM - YYYY');
let currentmonth = moment().subtract(1, 'month').format('YYYY MMMM');
let today = moment().format('YYYY - MMMM - DD');


export default [
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetSiteAllocatedEmployees`,
      method: "get"
    },
    href: `${base_url}timelog/AllocatedEmployeesInSites`,
    title: "Allocated Today",
    icon: "users",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetSitePresentEmployees`,
      method: "get"
    },
    href: `${base_url}timelog/PresentEmployeesInSites`,
    title: "PRESENT TODAY",
    icon: "users",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetSiteAbsentEmployees`,
      method: "get"
    },
    href: `${base_url}timelog/AbsentEmployeesInSites`,
    title: "Absent Employees",
    icon: "users",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetSiteNonAllocatedEmployees`,
      method: "get"
    },
    href: `${base_url}timelog/NonAllocatedEmployeesInSites`,
    title: "NON ALLOCATED",
    icon: "users",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: PieChartGrid,
    api: {
      url: `${base_url}/DashboardApi/GetSiteAccountWiseAttendance`,
      method: "get"
    },
    title: "Site-wise Attendance",
    icon: "users",
    formater: ({ data }) =>
      data.$list.map(item => ({
        title: item.name,
        data: {
          Present: parseInt(item.pre),
          Absent: parseInt(item.abs)
        }
      })),
    layout: {
      xl: 24,
      lg: 24,
      md: 24,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: AvatarGrid,
    api: {
      url: `${base_url}/DashboardApi/GetSiteInvalidAttendance`,
      method: "get"
    },
    href: `${base_url}DashboardApi/DownloadInvalidAttendance`,
    title: "Invalid Attendance",
    icon: "users",
    formater: ({ data }) => data.$list,
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: AvatarGrid,
    api: {
      url: `${base_url}/DashboardApi/GetSiteTenuesList`,
      method: "get"
    },
    href: `${base_url}DashboardApi/DownloadTenure`,
    title: "Tenure List",
    icon: "users",
    formater: ({ data }) => data.$list,
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: BarChart,
    api: {
      url: `${base_url}/DashboardApi/GetAccountVicePresentAbsent`,
      method: "get"
    },
    href: `${base_url}report/SiteBarChartDownload`,
    title: "Details Attendance Chart",
    formater: ({ data }) => {
      let temp = [];
      data.list.forEach(({ name, allocated, present, absent }) => {
        temp.push({
          name,
          y: parseInt(allocated),
          group: "Allocated"
        });

        temp.push({
          name,
          y: parseInt(present),
          group: "Present"
        });

        temp.push({
          name,
          y: parseInt(absent),
          group: "Absent"
        });
      });

      return temp;
    },
    axis: {
      x: "name",
      y: "y",
      color: "group"
    },
    guide: {
      x: {
        label: {
          text: "Outlet"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: PieChartCard,
    api: {
      url: `${base_url}/DashboardApi/GetAccountViceAttendance`,
      method: "get"
    },
    href: `${base_url}report/SitePieChartDownload`,
    title: `Account-wice Attendance | ${today} (today)`,
    formater: ({ data }) => {
      let obj = {};

      data.list.forEach(dat => {
        obj = {
          ...obj,
          [dat.name]: dat.count
        }
      })

      return obj;
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: PieChartCard,
    api: {
      url: `${base_url}/DashboardApi/GetAccountViceAttendance`,
      method: "get"
    },
    href: `${base_url}report/SitePieChartDownload`,
    title: `hello`,
    formater: ({ data }) => {
      let obj = {};

      data.list.forEach(dat => {
        obj = {
          ...obj,
          [dat.name]: dat.count
        }
      })

      return obj;
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/OvertimeSalaryTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Overtime Salary Trend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/BasicSalaryTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Basic Salary Trend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/TotalSalaryTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Total Salary Trend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/AverageCostPerEmployee`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Average Cost Per Employee`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/AdhocTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `AdhocTrend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/PayrollAndAdhocTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `PayrollAndAdhocTrend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/AdhocTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `AdhocTrend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/PayrollAndAdhocTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `PayrollAndAdhocTrend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/SupplierWiseCost`,
      method: "get"
    },
    title: `for agent SupplierWiseCost | ${lastmonth} (last month)`,
    formater: ({ data }) => {
      let temp = [];
      let _date;
      // TODO
        Object.keys(data.$list).forEach((key) => {
          if (key == 'site') {
            _date = data.$list[key];
          } else {
            temp.push({
            
              y: parseFloat(data.$list[key]),
              Category: key
            });
          }
        })
      ;
      return temp;
    },
    axis: {
      x: "Category",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Category"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/DepartmentWiseCost`,
      method: "get"
    },
    title: `for agent DepartmentWiseCost | ${lastmonth} (last month)`,
    formater: ({ data }) => {
      let temp = [];
      let _date;
      // TODO
        Object.keys(data.$list).forEach((key) => {
          if (key == 'site') {
            _date = data.$list[key];
          } else {
            temp.push({
            
              y: parseFloat(data.$list[key]),
              Category: key
            });
          }
        })
      ;
      return temp;
    },
    axis: {
      x: "Category",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Category"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/TotalNumOfEmp`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Total Number Of Employees`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/EmpTurnover`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Employee Turnover`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        tickFormat: 'num_to_percentage',
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/AbsenteeismRate`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Employee Absenteeism Rate`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        tickFormat: 'num_to_percentage',
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
    {
    Element: TwoColumnGridChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/MonthlySummery`,
      method: "get"
    },
    title: `Monthly Summery of ${currentmonth}`,
    formater: ({
      data
    }) => {
      return [{
        left: "Total OT Hours",
        right: data.$list.total_ot_hrs
      },{
        left: "Total Worked Hours",
        right: data.$list.total_worked_hrs
      },{
        left: "Normal OT Avg.",
        right: data.$list.Not_avg 
      },{
        left: "Double OT Avg.",
        right: data.$list.Dot_avg
      },{
        left: "Total OT Avg.",
        right: data.$list.Tot_avg
      },{
        left: "Avg. Man Hour per Head",
        right: data.$list.man_hr_hd
      },{
        left: "Avg. OT Hour per Head",
        right: data.$list.ot_hr_hd
      },{
        left: "Total OT Cost",
        right: data.$list.ttl_ot_cost
      },{
        left: "Total Day Wage",
        right: data.$list.ttl_day_wage
      },{
        left: "Total MP Cost",
        right: data.$list.ttl_mp_cost
      },
    ]
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
];
