import Card from "../components/Card";
import {
  PieChartGrid,
  LineChart,
  BarChart,
  StackedBarChart,
  PieChartCard,
  FilterableLineChart
} from "../components/Charts";
import AvatarGrid from "../components/AvatarGrid";
import moment from "moment";

let formatter = ({ data }) => data.Count;

let base_url = window.location.toString() + "/";

let colors = ["#1e1b17","#ffad32","#d68306","#a36100","#68440d"];

if (process.env.NODE_ENV === "production") {
  base_url = window.location.toString() + "/";
}

let lastmonth = moment()
  .subtract(1, "month")
  .format("MMMM - YYYY");
let today = moment().format("YYYY - MMMM - DD");

export default [
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetAdminTotalEmployees`,
      method: "get"
    },
    href: `${base_url}employee/admin`,
    title: "Total Employees",
    icon: "users",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetAdminPresentEmployees`,
      method: "get"
    },
    href: `${base_url}timelog/PresentTody`,
    title: "PRESENT TODAY",
    icon: "user-check",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetAdminSuppliers`,
      method: "get"
    },
    href: `${base_url}supplier/admin`,
    title: "NO OF SUPPLIERS",
    icon: "package",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: Card,
    api: {
      url: `${base_url}/DashboardApi/GetAdminSites`,
      method: "get"
    },
    href: `${base_url}sites/admin`,
    title: `NO OF SITES`,
    icon: "flag",
    formater: formatter,
    layout: {
      xl: 6,
      lg: 6,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: PieChartGrid,
    api: {
      url: `${base_url}/DashboardApi/GetAdminSiteWiseAttendance`,
      method: "get"
    },
    title: "Site-Wise Attendance",
    icon: "users",
    formater: ({ data }) =>
      data.$list.map(item => ({
        title: item.name,
        data: {
          Present: item.pres,
          Absent: item.abs
        }
      })),
    layout: {
      xl: 24,
      lg: 24,
      md: 24,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: AvatarGrid,
    api: {
      url: `${base_url}/DashboardApi/GetAdminInvalidAttendance`,
      method: "get"
    },
    href: `${base_url}DashboardApi/DownloadInvalidAttendance`,
    title: "Invalid Attendance",
    icon: "users",
    formater: ({ data }) => data.$list,
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: AvatarGrid,
    api: {
      url: `${base_url}/DashboardApi/GetAdminTenuesList`,
      method: "get"
    },
    href: `${base_url}DashboardApi/DownloadTenure`,
    title: "Tenure List",
    icon: "users",
    formater: ({ data }) => data.$list,
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/AreaChart`,
      method: "get"
    },
    href: `${base_url}report/LineChartDownload`,
    title: `Monthly Attendance Chart | ${lastmonth} (last month)`,
    formater: ({ data }) => {
      let temp = [];
      data.list.forEach(({ date, total, present, absent }) => {
        let _date = date;
        console.dir(date);

        temp.push({
          date: _date,
          y: parseInt(total),
          Category: "Total"
        });

        temp.push({
          date: _date,
          y: parseInt(present),
          Category: "Present"
        });

        temp.push({
          date: _date,
          y: parseInt(absent),
          Category: "Absent"
        });
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: BarChart,
    api: {
      url: `${base_url}/DashboardApi/PresenceAbsenceChart`,
      method: "get"
    },
    href: `${base_url}report/BarChartDownload`,
    title: `Daily Attendance Chart | ${today} (today)`,
    formater: ({ data }) => {
      let temp = [];
      data.list.forEach(({ name, TTL, PRE, ABS }) => {
        temp.push({
          name,
          y: parseInt(TTL),
          Category: "Total"
        });

        temp.push({
          name,
          y: parseInt(PRE),
          Category: "Present"
        });

        temp.push({
          name,
          y: parseInt(ABS),
          Category: "Absent"
        });
      });

      return temp;
    },
    axis: {
      x: "name",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Site"
        }
      },
      y: {
        label: {
          text: "Count"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: StackedBarChart,
    api: {
      url: `${base_url}/DashboardApi/PayrollChart`,
      method: "get"
    },
    href: `${base_url}report/StackChartDownload`,
    title: `Payroll Chart | ${lastmonth} (last month)`,
    formater: ({ data }) => {
      let temp = [];
      data.list.forEach(({ name, basic, ot, allownce }) => {
        temp.push({
          name,
          y: parseInt(allownce),
          Category: "Allowance"
        });

        temp.push({
          name,
          y: parseInt(ot),
          Category: "OT"
        });

        temp.push({
          name,
          y: parseInt(basic),
          Category: "Basic"
        });
      });

      return temp;
    },
    axis: {
      x: "name",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Site"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  {
    Element: PieChartCard,
    api: {
      url: `${base_url}/DashboardApi/PieChart`,
      method: "get"
    },
    href: `${base_url}report/PieChartDownload`,
    title: `Non Allocated Employees | ${today} (today)`,
    formater: ({ data }) => {
      let obj = {};

      data.list.forEach(dat => {
        obj = {
          ...obj,
          [dat.name]: dat.count
        };
      });
      console.log({ obj });
      return obj;
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },

    info: "~"
  },

  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/OvertimeSalaryTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Overtime Salary Trend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/BasicSalaryTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Basic Salary Trend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/TotalSalaryTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Total Salary Trend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/AverageCostPerEmployee`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Average Cost Per Employee`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  
  {
    Element: StackedBarChart,
    api: {
      url: `${base_url}/DashboardApi/SupplierWiseCost`,
      method: "get"
    },
    title: `SupplierWiseCost | ${lastmonth} (last month)`,
    formater: ({ data }) => {
      let temp = [];
      let name;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
          if (key == 'site') {
            name = obj[key];
          } else {
            temp.push({
              name,
              y: parseInt(obj[key]),
              Supplier: key
            });
          }
        })
      });

      return temp;
    },
    axis: {
      x: "name",
      y: "y",
      color: "Supplier"
    },
    guide: {
      x: {
        label: {
          text: "Site"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
  
  {
    Element: StackedBarChart,
    api: {
      url: `${base_url}/DashboardApi/DepartmentWiseCost`,
      method: "get"
    },
    title: `DepartmentWiseCost | ${lastmonth} (last month)`,
    formater: ({ data }) => {
      let temp = [];
      let name;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
          if (key == 'site') {
            name = obj[key];
          } else {
            temp.push({
              name,
              y: parseInt(obj[key]),
              Department: key
            });
          }
        })
      });

      return temp;
    },
    axis: {
      x: "name",
      y: "y",
      color: "Department"
    },
    guide: {
      x: {
        label: {
          text: "Site"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 24,
      xs: 24
    },
    info: "~"
  },
   {
    Element: LineChart,
    api: {
      url: `${base_url}/DashboardApi/AdhocTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `AdhocTrend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/PayrollAndAdhocTrend`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `PayrollAndAdhocTrend`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
   {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/TotalNumOfEmp`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Total Number Of Employees`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/EmpTurnover`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Employee Turnover`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        tickFormat: 'num_to_percentage',
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
  {
    Element: LineChart,
    api: {
      baseUrl: base_url,
      url: `${base_url}/DashboardApi/AbsenteeismRate`,
      method: "get"
    },
    // href: `${base_url}report/SitePieChartDownload`,
    title: `Employee Absenteeism Rate`,
    formater: ({
      data
    }) => {
      let temp = [];
      let _date;
      data.$list.forEach((obj) => {
        Object.keys(obj).forEach((key) => {
            if (key == 'date') {
              _date = obj[key];
            }else{
              temp.push({
                date: _date,
                y: parseFloat(obj[key]),
                Category: key
              });
            }
          }
        )
      });

      return temp;
    },
    axis: {
      x: "date",
      y: "y",
      color: "Category"
    },
    guide: {
      x: {
        label: {
          text: "Date"
        }
      },
      y: {
        tickFormat: 'num_to_percentage',
        label: {
          text: "Value"
        }
      },
      color: {
        brewer: colors
      },
      interpolate: "smooth-keep-extremum"
    },
    layout: {
      xl: 12,
      lg: 12,
      md: 12,
      sm: 12,
      xs: 12
    },

    info: "~"
  },
];
