<?php

/**
 * This is the model class for table "accounts".
 *
 * The followings are the available columns in table 'accounts':
 * @property integer $id
 * @property string $name
 * @property string $contact
 * @property integer $siteid
 */
class Accounts extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'accounts';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('name, contact, siteid', 'required'),
			array('siteid', 'numerical', 'integerOnly'=>true),
			array('name, contact', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, name, contact,SAPCoustomCode, siteid', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'site' => array(self::BELONGS_TO, 'Sites', 'siteid'),
			'categories' => array(self::HAS_MANY, 'Category', 'accountid'),
		);
	}

        public static function getList() {
        return array('' => '') + CHtml::listData(self::model()->findAll(), 'id', 'name');
	}
	
	
	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'contact' => 'Contact',
			'siteid' => 'Siteid',
                        'SAPCoustomCode'=>'Oracle Code',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('contact',$this->contact,true);
		$criteria->compare('siteid',$this->siteid);
                $criteria->compare('SAPCoustomCode',$this->SAPCoustomCode);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Accounts the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	//=====================This method can be added to other models to track the DB operations related to that model========
	public function behaviors()
	{
		return array(
			// Classname => path to Class
			'DBRecordTracker'=>
				'application.behaviors.DBRecordTracker',
		);
	}

	//======================================================================================================================

	public static function getAccountsByUser(){
		if(Yii::app()->user->isAdmin()){
			return self::model()->findAll();

		}
		else{
			$site = Yii::app()->user->data()->SiteId;
			return self::model()->findAllByAttributes(array('siteid'=>$site));
		}
	}
}
