<?php

/**
 * This is the model class for table "adhoc_cadre_data".
 *
 * The followings are the available columns in table 'adhoc_cadre_data':
 * @property integer $id
 * @property string $date
 * @property string $manpowe_supplier
 * @property string $department
 * @property string $customer_name
 * @property string $special_designation
 * @property integer $number_of_heads
 * @property string $daily_rate
 * @property string $total_basic
 * @property string $normal_ot_rate
 * @property string $total_normal_ot_hours
 * @property string $total_normal_ot
 * @property string $double_ot_rate
 * @property string $total_double_ot_hours
 * @property string $total_double_ot
 * @property string $total_salary
 */
class AdhocCadreData extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return AdhocCadreData the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'adhoc_cadre_data';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('date, total_normal_ot_hours, total_normal_ot, double_ot_rate, total_double_ot_hours, total_double_ot, total_salary', 'required'),
			array('number_of_heads', 'numerical', 'integerOnly'=>true),
			array('manpowe_supplier, department, customer_name, special_designation', 'length', 'max'=>100),
			array('daily_rate, total_basic, normal_ot_rate, total_normal_ot_hours, total_normal_ot, double_ot_rate, total_double_ot_hours, total_double_ot, total_salary', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, date, manpowe_supplier, department, customer_name, special_designation, number_of_heads, daily_rate, total_basic, normal_ot_rate, total_normal_ot_hours, total_normal_ot, double_ot_rate, total_double_ot_hours, total_double_ot, total_salary', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'date' => 'Date',
			'manpowe_supplier' => 'Manpower Supplier',
			'department' => 'Department',
			'customer_name' => 'Customer Name',
			'special_designation' => 'Special Designation',
			'number_of_heads' => 'Number Of Heads',
			'daily_rate' => 'Daily Rate',
			'total_basic' => 'Total Basic',
			'normal_ot_rate' => 'Normal OT Rate',
			'total_normal_ot_hours' => 'Total Normal OT Hours',
			'total_normal_ot' => 'Total Normal OT',
			'double_ot_rate' => 'Double OT Rate',
			'total_double_ot_hours' => 'Total Double OT Hours',
			'total_double_ot' => 'Total Double OT',
			'total_salary' => 'Total Salary',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('date',$this->date,true);
		$criteria->compare('manpowe_supplier',$this->manpowe_supplier,true);
		$criteria->compare('department',$this->department,true);
		$criteria->compare('customer_name',$this->customer_name,true);
		$criteria->compare('special_designation',$this->special_designation,true);
		$criteria->compare('number_of_heads',$this->number_of_heads);
		$criteria->compare('daily_rate',$this->daily_rate,true);
		$criteria->compare('total_basic',$this->total_basic,true);
		$criteria->compare('normal_ot_rate',$this->normal_ot_rate,true);
		$criteria->compare('total_normal_ot_hours',$this->total_normal_ot_hours,true);
		$criteria->compare('total_normal_ot',$this->total_normal_ot,true);
		$criteria->compare('double_ot_rate',$this->double_ot_rate,true);
		$criteria->compare('total_double_ot_hours',$this->total_double_ot_hours,true);
		$criteria->compare('total_double_ot',$this->total_double_ot,true);
		$criteria->compare('total_salary',$this->total_salary,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}