<?php

/**
 * This is the model class for table "adhoc_cadre_employees".
 *
 * The followings are the available columns in table 'adhoc_cadre_employees':
 * @property integer $id
 * @property string $full_name
 * @property string $nic
 * @property string $current_address
 * @property string $permanent_address
 * @property string $department
 * @property string $supplier
 * @property string $site_id
 */
class AdhocCadreEmployees extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return AdhocCadreEmployees the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'adhoc_cadre_employees';
	}

	public static function getList() {
		if(!Yii::app()->user->isAdmin())
			return array('' => '') + CHtml::listData(self::model()->findAllByAttributes(array('site_id'=>Yii::app()->user->data()->SiteId)), 'id', 'full_name');
		else
			return array('' => '') + CHtml::listData(self::model()->findAll(), 'id', 'full_name');
    }

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('full_name, nic, current_address, permanent_address', 'required'),
			array('full_name', 'length', 'max'=>200),
			array('nic', 'length', 'max'=>20),
			array('current_address, permanent_address', 'length', 'max'=>300),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, full_name, nic, current_address, permanent_address', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'full_name' => 'FULL NAME',
			'nic' => 'NIC',
			'current_address' => 'CURRENT ADDRESS',
			'permanent_address' => 'PERMANENT ADDRESS',
			'site_id' => 'SITE ID',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('full_name',$this->full_name,true);
		$criteria->compare('nic',$this->nic,true);
		$criteria->compare('current_address',$this->current_address,true);
		$criteria->compare('permanent_address',$this->permanent_address,true);
		if(!Yii::app()->user->isAdmin())
			$criteria->compare('site_id',Yii::app()->user->data()->SiteId,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
	
}