<?php

/**
 * This is the model class for table "adhoc_cadre_timelog".
 *
 * The followings are the available columns in table 'adhoc_cadre_timelog':
 * @property integer $id
 * @property integer $adhoc_employee_id
 * @property string $in_time
 * @property string $out_time
 * @property string $in_late_hrs
 * @property string $in_late_deduction
 * @property string $out_late_hrs
 * @property string $out_late_deduction
 * @property string $N_OT_hrs
 * @property string $N_OT_cost
 * @property string $D_OT_hrs
 * @property string $D_OT_cost
 * @property string $basic_day_wage
 * @property string $BRA1
 * @property string $BRA2
 * @property string $BRA3
 * @property string $transport
 * @property string $per_day_incentive
 * @property string $night_shift_incentive
 * @property string $meal
 * @property string $cont_Fee
 * @property string $EPF
 * @property string $ETF
 * @property string $cost_to_company
 * @property string $created_on
 * @property integer $created_by
 */
class AdhocCadreTimelog extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return AdhocCadreTimelog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'adhoc_cadre_timelog';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('adhoc_employee_id, in_time, out_time, in_late_hrs, in_late_deduction, out_late_hrs, out_late_deduction, N_OT_hrs, N_OT_cost, D_OT_hrs, D_OT_cost, basic_day_wage, BRA1, BRA2, BRA3, transport, per_day_incentive, night_shift_incentive, meal, cont_Fee, EPF, ETF, cost_to_company, department, supplier,Site_id', 'required'),
			array('adhoc_employee_id, created_by', 'numerical', 'integerOnly'=>true),
			array('in_late_hrs, in_late_deduction, out_late_hrs, out_late_deduction, N_OT_hrs, N_OT_cost, D_OT_hrs, D_OT_cost, basic_day_wage, BRA1, BRA2, BRA3, transport, per_day_incentive, night_shift_incentive, meal, cont_Fee, EPF, ETF, cost_to_company', 'length', 'max'=>50),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, adhoc_employee_id, in_time, out_time, in_late_hrs, in_late_deduction, out_late_hrs, out_late_deduction, N_OT_hrs, N_OT_cost, D_OT_hrs, D_OT_cost, basic_day_wage, BRA1, BRA2, BRA3, transport, per_day_incentive, night_shift_incentive, meal, cont_Fee, EPF, ETF, cost_to_company, created_on, created_by, department, supplier', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'employee' => array(self::BELONGS_TO, 'AdhocCadreEmployees', 'adhoc_employee_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'adhoc_employee_id' => 'Adhoc Employee',
			'in_time' => 'In Time',
			'out_time' => 'Out Time',
			'in_late_hrs' => 'In Late Hrs',
			'in_late_deduction' => 'In Late Deduction',
			'out_late_hrs' => 'Out Late Hrs',
			'out_late_deduction' => 'Out Late Deduction',
			'N_OT_hrs' => 'N Ot Hrs',
			'N_OT_cost' => 'N Ot Cost',
			'D_OT_hrs' => 'D Ot Hrs',
			'D_OT_cost' => 'D Ot Cost',
			'basic_day_wage' => 'Basic Day Wage',
			'BRA1' => 'Bra1',
			'BRA2' => 'Bra2',
			'BRA3' => 'Bra3',
			'transport' => 'Transport',
			'per_day_incentive' => 'Per Day Incentive',
			'night_shift_incentive' => 'Night Shift Incentive',
			'meal' => 'Meal',
			'cont_Fee' => 'Cont Fee',
			'EPF' => 'Epf',
			'ETF' => 'Etf',
			'cost_to_company' => 'Cost To Company',
			'created_on' => 'Created On',
			'created_by' => 'Created By',
			'department' => 'Department',
			'supplier' => 'Supplier',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = 'employee';

		$criteria->compare('id',$this->id);
		$criteria->compare('employee.full_name',$this->adhoc_employee_id,true);
		$criteria->compare('employee.site_id',Yii::app()->user->data()->SiteId,true);

		// $criteria->compare('employee.nic',$this->adhoc_employee_id,true);
		// $criteria->compare('adhoc_employee_id',$this->adhoc_employee_id);
		$criteria->compare('in_time',$this->in_time,true);
		$criteria->compare('out_time',$this->out_time,true);
		$criteria->compare('in_late_hrs',$this->in_late_hrs,true);
		$criteria->compare('in_late_deduction',$this->in_late_deduction,true);
		$criteria->compare('out_late_hrs',$this->out_late_hrs,true);
		$criteria->compare('out_late_deduction',$this->out_late_deduction,true);
		$criteria->compare('N_OT_hrs',$this->N_OT_hrs,true);
		$criteria->compare('N_OT_cost',$this->N_OT_cost,true);
		$criteria->compare('D_OT_hrs',$this->D_OT_hrs,true);
		$criteria->compare('D_OT_cost',$this->D_OT_cost,true);
		$criteria->compare('basic_day_wage',$this->basic_day_wage,true);
		$criteria->compare('BRA1',$this->BRA1,true);
		$criteria->compare('BRA2',$this->BRA2,true);
		$criteria->compare('BRA3',$this->BRA3,true);
		$criteria->compare('transport',$this->transport,true);
		$criteria->compare('per_day_incentive',$this->per_day_incentive,true);
		$criteria->compare('night_shift_incentive',$this->night_shift_incentive,true);
		$criteria->compare('meal',$this->meal,true);
		$criteria->compare('cont_Fee',$this->cont_Fee,true);
		$criteria->compare('EPF',$this->EPF,true);
		$criteria->compare('ETF',$this->ETF,true);
		$criteria->compare('cost_to_company',$this->cost_to_company,true);
		$criteria->compare('created_on',$this->created_on,true);
		$criteria->compare('created_by',$this->created_by);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}