<?php

/**
 * This is the model class for table "battery_level".
 *
 * The followings are the available columns in table 'battery_level':
 * @property integer $id
 * @property integer $Site
 * @property string $Device_emi
 * @property string $Time
 * @property string $Status
 * @property string $Battery_level
 *
 * The followings are the available model relations:
 * @property Sites $site
 */
class BatteryLevel extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'battery_level';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Site, Device_emi, Time, Status, Battery_level', 'required'),
			array('Site', 'numerical', 'integerOnly'=>true),
			array('Device_emi, Status, Battery_level', 'length', 'max'=>250),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, Site, Device_emi, Time, Status, Battery_level', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'site' => array(self::BELONGS_TO, 'Sites', 'Site'),
		);
	}
        public static function getList() {
			return array('CHARGING' => 'CHARGING','NOT_CHARGING' => 'NOT_CHARGING') ;
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'Site' => 'Site',
			'Device_emi' => 'Device Emi',
			'Time' => 'Time',
			'Status' => 'Status',
			'Battery_level' => 'Battery Level',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
                if(Yii::app()->user->isAdmin()){
			$criteria->compare('Site',$this->Site);
		}

		else{
			$sitid = Yii::app()->user->data()->SiteId;			
			$criteria->compare('Site',$sitid);	
		}
                
		$criteria->compare('id',$this->id);
		$criteria->compare('Site',$this->Site);
		$criteria->compare('Device_emi',$this->Device_emi,true);
		$criteria->compare('Time',$this->Time,true);
		$criteria->compare('Status',$this->Status,true);
		$criteria->compare('Battery_level',$this->Battery_level,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return BatteryLevel the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
