<?php

/**
 * This is the model class for table "daily_vas".
 *
 * The followings are the available columns in table 'daily_vas':
 * @property integer $id
 * @property string $nic
 * @property string $sku
 * @property string $dec
 * @property string $client_rate
 * @property string $employee_rate
 * @property integer $no_of_pieces
 * @property integer $source_id
 */
class DailyVas extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'daily_vas';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('nic, sku, dec, client_rate, employee_rate, no_of_pieces, source_id', 'required'),
			array('no_of_pieces, source_id', 'numerical', 'integerOnly'=>true),
			array('nic', 'length', 'max'=>20),
			array('sku', 'length', 'max'=>150),
			array('dec', 'length', 'max'=>50),
			array('client_rate, employee_rate', 'length', 'max'=>9),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, nic, sku, dec, client_rate, employee_rate, no_of_pieces, source_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'nic' => 'Nic',
			'sku' => 'Sku',
			'dec' => 'Dec',
			'client_rate' => 'Client Rate',
			'employee_rate' => 'Employee Rate',
			'no_of_pieces' => 'No Of Pieces',
			'source_id' => 'Source',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('nic',$this->nic,true);
		$criteria->compare('sku',$this->sku,true);
		$criteria->compare('dec',$this->dec,true);
		$criteria->compare('client_rate',$this->client_rate,true);
		$criteria->compare('employee_rate',$this->employee_rate,true);
		$criteria->compare('no_of_pieces',$this->no_of_pieces);
		$criteria->compare('source_id',$this->source_id);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return DailyVas the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
