<?php

/**
 * This is the model class for table "deleted_payroll".
 *
 * The followings are the available columns in table 'deleted_payroll':
 * @property integer $id
 * @property string $StartDate
 * @property string $EndDate
 * @property integer $CreatedBy
 * @property string $CreatedTime
 * @property string $PayrollMethod
 * @property integer $ApprovedBy
 * @property string $ApprovedTime
 * @property integer $RejectedBy
 * @property string $RejectedTime
 * @property integer $Status
 * @property integer $SiteId
 * @property string $ReasontoReject
 */
class DeletedPayroll extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return DeletedPayroll the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'deleted_payroll';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('StartDate, EndDate, CreatedBy, CreatedTime, PayrollMethod', 'required'),
			array('CreatedBy, ApprovedBy, RejectedBy, Status, SiteId', 'numerical', 'integerOnly'=>true),
			array('PayrollMethod', 'length', 'max'=>50),
			array('ReasontoReject', 'length', 'max'=>500),
			array('ApprovedTime, RejectedTime', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, StartDate, EndDate, CreatedBy, CreatedTime, PayrollMethod, ApprovedBy, ApprovedTime, RejectedBy, RejectedTime, Status, SiteId, ReasontoReject', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'StartDate' => 'Start Date',
			'EndDate' => 'End Date',
			'CreatedBy' => 'Created By',
			'CreatedTime' => 'Created Time',
			'PayrollMethod' => 'Payroll Method',
			'ApprovedBy' => 'Approved By',
			'ApprovedTime' => 'Approved Time',
			'RejectedBy' => 'Rejected By',
			'RejectedTime' => 'Rejected Time',
			'Status' => 'Status',
			'SiteId' => 'Site',
			'ReasontoReject' => 'Reasonto Reject',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('StartDate',$this->StartDate,true);
		$criteria->compare('EndDate',$this->EndDate,true);
		$criteria->compare('CreatedBy',$this->CreatedBy);
		$criteria->compare('CreatedTime',$this->CreatedTime,true);
		$criteria->compare('PayrollMethod',$this->PayrollMethod,true);
		$criteria->compare('ApprovedBy',$this->ApprovedBy);
		$criteria->compare('ApprovedTime',$this->ApprovedTime,true);
		$criteria->compare('RejectedBy',$this->RejectedBy);
		$criteria->compare('RejectedTime',$this->RejectedTime,true);
		$criteria->compare('Status',$this->Status);
		$criteria->compare('SiteId',$this->SiteId);
		$criteria->compare('ReasontoReject',$this->ReasontoReject,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}