<?php

/**
 * This is the model class for table "designation".
 *
 * The followings are the available columns in table 'designation':
 * @property integer $id
 * @property string $type
 *
 * The followings are the available model relations:
 * @property DesignationSallary[] $designationSallaries
 * @property Employee[] $employees
 * @property EmployeeDesignation[] $employeeDesignations
 */
class Designation extends CActiveRecord {
    

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'designation';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('type,site', 'required'),
            array('type', 'length', 'max' => 100),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, type', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'designationSallaries' => array(self::HAS_MANY, 'DesignationSallary', 'DesignationId'),
            'employees' => array(self::HAS_MANY, 'Employee', 'designationid'),
            'employeeDesignations' => array(self::HAS_MANY, 'EmployeeDesignation', 'DesignationId'),
            'sites' => array(self::BELONGS_TO, 'Sites', 'site'),
        );
    }

    public function getSiteName(){
        return  $this->type.'-'.$this->sites->name;
    }

    public static function getList() {

        if (Yii::app()->user->isAdmin()) {
            return array('' => '') + CHtml::listData(self::model()->findAll(), 'id', 'SiteName');
        }else{

            return self::getListAccourdingToSite();
        }
    }

    public static function getListAccourdingToSite() {
        $siteId = Yii::app()->user->data()->SiteId;
        return array('' => '') + CHtml::listData(self::model()->findAllByAttributes(["site"=>$siteId]), 'id', 'type');
    }

    public static function getListAccourdingToEmployeeSite($emp_id) {
        $employee = Employee::model()->findByPk($emp_id);
        return array('' => '') + CHtml::listData(self::model()->findAllByAttributes(["site"=>$employee->siteid]), 'id', 'type');
    }
        public static function getListAccourdingToEmployeeSiteNonP($emp_id) {
        $employee = NonpayrollEmployee::model()->findByPk($emp_id);
        return array('' => '') + CHtml::listData(self::model()->findAllByAttributes(["site"=>$employee->siteid]), 'id', 'type');
    }

    public static function getResult(){
        return array(''=>'--Select Designation--')+CHtml::listData(self::model()->findAll(),'id','type');
        
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'type' => 'Type',
            'site' => 'Site',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('type', $this->type, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Designation the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    //=====================This method can be added to other models to track the DB operations related to that model========
	public function behaviors()
	{
		return array(
			// Classname => path to Class
			'DBRecordTracker'=>
				'application.behaviors.DBRecordTracker',
		);
	}

    //======================================================================================================================

}
