<?php

/**
 * This is the model class for table "employee".
 *
 * The followings are the available columns in table 'employee':
 * @property integer $id
 * @property string $title
 * @property string $gender
 * @property string $CivilStatus
 * @property string $FirstName
 * @property string $LastName
 * @property string $SurName
 * @property string $Namewithini
 * @property string $FullName
 * @property string $nic
 * @property string $date_of_birth
 * @property string $address
 * @property integer $designationid
 * @property string $joindate
 * @property integer $paymentmethodid
 * @property integer $siteid
 * @property integer $departmentid
 * @property integer $categoryid
 * @property integer $supplierid
 * @property integer $tshirtsize
 * @property integer $shoesize
 * @property string $EPFNo
 * @property string $Appointment
 * @property string $Confirmationdate
 * @property string $resigndate
 * @property string $description
 * @property integer $LabourCategory
 * @property integer $statusId
 * @property string $profileImage

 * The followings are the available model relations:
 * @property Contact[] $contacts
 * @property Category $category
 * @property Supplier $supplier
 * @property Sites $site
 * @property Paymentmethod $paymentmethod
 * @property Department $department
 * @property Tshirt $tshirtsize0
 * @property Shoes $shoesize0
 * @property EmployeeAccount[] $employeeAccounts
 * @property EmployeeDesignation[] $employeeDesignations
 * @property EmployeeShift[] $employeeShifts
 * @property Leave[] $leaves
 * @property Payment[] $payments
 * @property Timelog[] $timelogs
 * @property Timesheet[] $timesheets
 */
class Employee extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Employee the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'employee';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('title, gender,address,supplierid, CivilStatus, FirstName, LastName, SurName, Namewithini, FullName, nic,Accountid, designationid, joindate,EntitleOT, paymentmethodid, siteid, departmentid, categoryid, Shift_mode', 'required'),
			array('designationid,contact_number, paymentmethodid,LabourCategory, siteid, departmentid, categoryid, supplierid, tshirtsize,Accountid,TeamStatus,EntitleOT, shoesize, payroll_status', 'numerical', 'integerOnly'=>true),
			array('nic', 'unique'),
			array('FirstName, LastName, SurName, Namewithini, FullName', 'filter', 'filter'=>'strtoupper'),
			//array('nic', 'validateNIC'),   // Uncomment this line and below validateNIC() to enable nic validations
			array('title, gender', 'length', 'max'=>20),
			array('CivilStatus, nic, EPFNo', 'length', 'max'=>50),
			array('FirstName, LastName', 'length', 'max'=>100),
			array('SurName, Namewithini,PresentAddress,ResidentType,FullName, description,EmployeeNumber,profileImage,nic_photo', 'length', 'max'=>250),
			array('address,GNDivision,PoliceDivision,GNDLockdown,PDLockdown', 'length', 'max'=>250),
			array('date_of_birth,dualShiftMode, Appointment, Confirmationdate, resigndate,LabourCategory,nic_photo', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, title, gender, CivilStatus, FirstName, LastName, SurName, Namewithini,Accountid,FullName, nic, date_of_birth, address, designationid, joindate, paymentmethodid, siteid, departmentid, categoryid, supplierid, tshirtsize, shoesize, EPFNo, Appointment, Confirmationdate, resigndate, description, LabourCategory,TeamStatus,EntitleOT, statusId,profileImage,nic_photo', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'contacts' => array(self::HAS_MANY, 'Contact', 'employeeid'),
			'category' => array(self::BELONGS_TO, 'Category', 'categoryid'),
			'labourcategory' => array(self::BELONGS_TO, 'Labourcategory', 'LabourCategory'),
			'supplier' => array(self::BELONGS_TO, 'Supplier', 'supplierid'),
			'status0' => array(self::BELONGS_TO, 'EmployeeStatus', 'statusId'),
			'site' => array(self::BELONGS_TO, 'Sites', 'siteid'),
			'paymentmethod' => array(self::BELONGS_TO, 'Paymentmethod', 'paymentmethodid'),
			'department' => array(self::BELONGS_TO, 'Department', 'departmentid'),
			'account' => array(self::BELONGS_TO, 'Accounts', 'Accountid'),
			'tshirtsize0' => array(self::BELONGS_TO, 'Tshirt', 'tshirtsize'),
			'shoesize0' => array(self::BELONGS_TO, 'Shoes', 'shoesize'),
			'employeeAccounts' => array(self::HAS_MANY, 'EmployeeAccount', 'employeeid'),
			'employeeDesignations' => array(self::HAS_MANY, 'EmployeeDesignation', 'EmployeeId'),
			'employeeShifts' => array(self::HAS_MANY, 'EmployeeShift', 'EmployeeId'),
			'leaves' => array(self::HAS_MANY, 'Leave', 'EmoloyeeId'),
			'payments' => array(self::HAS_MANY, 'Payment', 'employeeid'),
			'timelogs' => array(self::HAS_MANY, 'Timelog', 'Employeeid'),
			'timesheets' => array(self::HAS_MANY, 'Timesheet', 'EmployeeId'),
			'Paymentmethod' => array(self::BELONGS_TO, 'Paymentmethod', 'paymentmethodid'),
			'Designation' => array(self::BELONGS_TO, 'Designation', 'designationid'),

		);
	}
	public static function getList() {
			return array('' => '') + CHtml::listData(self::model()->findAll(), 'id', 'Namewithini');
	}

//=========================Uncomment Following method and the relevant line in rules to enable NIC validations =================

/* 	
		public function validateNIC($attribute,$params) {
		$this->$attribute = strtoupper($this->$attribute);	
		$userNIC =$this->$attribute;
		$lengthNIC = strlen($userNIC);
		

		if($lengthNIC != 10){
			if($lengthNIC != 12)
			$this->addError($attribute, 'Invalid NIC number');

			else{
				if(!is_numeric($userNIC))
				$this->addError($attribute, 'Invalid  new NIC number');
			}
			
		}

		else {

		$element = str_split($userNIC,9);
		
			if(!(is_numeric($element[0]) && ($element[1] == 'V'))){
				 
				$this->addError($attribute, 'Invalid old NIC number');
			}
				

		}

   }
 */

//===============================================================================================================================

	public static function getResults(){
		return array(''=>'-- select employee--')+CHtml::listData(self::model()->findAll(),'id','nic');
	}
	
	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'title' => 'Title',
			'gender' => 'Gender',
			'CivilStatus' => 'Civil Status',
			'FirstName' => 'First Name',
			'LastName' => 'Last Name',
			'SurName' => 'Sur Name',
			'Namewithini' => 'Name With Initials',
			'FullName' => 'Full Name',
			'nic' => 'NIC',
			'date_of_birth' => 'Date Of Birth',
			'address' => 'Address',
			'designationid' => 'Designation',
			'joindate' => 'Joined Date',
			'paymentmethodid' => 'Payment Method',
			'siteid' => 'Site',
			'departmentid' => 'Department',
			'categoryid' => 'Category',
			'supplierid' => 'Supplier',
			'tshirtsize' => 'Tshirt Size',
			'shoesize' => 'Shoe Size',
			'EPFNo' => 'EPF No',
			'Appointment' => 'Appointment',
			'Confirmationdate' => 'Confirmation Date',
			'resigndate' => 'Resign Date',
			'description' => 'Description',
			'LabourCategory' => 'Labour Category',
			'Accountid' => 'Account',
			'TeamStatus'=>'TeamStatus',
			'statusId' => 'Status',
			'profileImage'=> 'Profile Image',
			'EntitleOT'=> 'OT Entitle',
			'EmployeeNumber'=> 'Employee Number',
			'nic_photo'=>'NIC Photo',
                        'PresentAddress'=> 'Present Address',
			'ResidentType'=>'Resident Type',
                        'GNDivision'=>'Grama Niladhari Division',
                        'PoliceDivision'=>'Police Division',
                        'GNDLockdown'=>'GN Division Lockdown ',
                        'PDLockdown'=>'Police Division Lockdown ',
                        'contact_number'=>'Contact Number'
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;
		$criteria->compare('id',$this->id);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('gender',$this->gender,true);
		$criteria->compare('CivilStatus',$this->CivilStatus,true);
		$criteria->compare('FirstName',$this->FirstName,true);
		$criteria->compare('LastName',$this->LastName,true);
		$criteria->compare('SurName',$this->SurName,true);
		$criteria->compare('Namewithini',$this->Namewithini,true);
		$criteria->compare('FullName',$this->FullName,true);
		$criteria->compare('nic',$this->nic,true);
		$criteria->compare('date_of_birth',$this->date_of_birth,true);
		$criteria->compare('address',$this->address,true);
		$criteria->compare('designationid',$this->designationid);
		$criteria->compare('joindate',$this->joindate,true);
		$criteria->compare('paymentmethodid',$this->paymentmethodid);
		
		//========================================================User Site Dependency============================================================

		if(Yii::app()->user->isAdmin()){
			$criteria->compare('siteid',$this->siteid);
		}

		else{
			$sitid = Yii::app()->user->data()->SiteId;
			$criteria->compare('siteid',$sitid);	
		}
		//===========================================================================================================================================


            //    
              //  $criteria->compare('department.name', $this->departmentid, true);
		$criteria->compare('departmentid',$this->departmentid);
		$criteria->compare('categoryid',$this->categoryid);
		$criteria->compare('supplierid',$this->supplierid);
		$criteria->compare('tshirtsize',$this->tshirtsize);
		$criteria->compare('shoesize',$this->shoesize);
		$criteria->compare('EPFNo',$this->EPFNo,true);
		$criteria->compare('Appointment',$this->Appointment,true);
		$criteria->compare('Confirmationdate',$this->Confirmationdate,true);
		$criteria->compare('resigndate',$this->resigndate,true);
		$criteria->compare('description',$this->description,true);
		$criteria->compare('LabourCategory',$this->LabourCategory);
		$criteria->compare('statusId',$this->statusId);
		$criteria->compare('profileImage',$this->profileImage,true);
		$criteria->compare('Accountid',$this->Accountid,false);
		$criteria->compare('TeamStatus',$this->TeamStatus,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
//=====================This method can be added to other models to track the DB operations related to that model========
	public function behaviors()
	{
		return array(
			// Classname => path to Class
			'DBRecordTracker'=>
				'application.behaviors.DBRecordTracker',
		);
	}

//======================================================================================================================

}