<?php

/**
 * This is the model class for table "employee_assets".
 *
 * The followings are the available columns in table 'employee_assets':
 * @property integer $id
 * @property integer $empId
 * @property string $issuedDate
 * @property string $returnedDate
 * @property string $Status
 * @property integer $asset_id
 * @property integer $assetType_id
 *
 * The followings are the available model relations:
 * @property Asset $asset
 * @property AssetTypes $assetType
 */
class EmployeeAssets extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'employee_assets';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('empId, issuedDate, asset_id, assetType_id', 'required'),
			array('empId, asset_id, assetType_id', 'numerical', 'integerOnly'=>true),
			array('Status', 'length', 'max'=>15),
			array('returnedDate', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, empId, issuedDate, returnedDate, Status, asset_id, assetType_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'asset' => array(self::BELONGS_TO, 'Asset', 'asset_id'),
			'assetType' => array(self::BELONGS_TO, 'AssetTypes', 'assetType_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'empId' => 'Emp',
			'issuedDate' => 'Issued Date',
			'returnedDate' => 'Returned Date',
			'Status' => 'Status',
			'asset_id' => 'Asset',
			'assetType_id' => 'Asset Type',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('empId',$this->empId);
		$criteria->compare('issuedDate',$this->issuedDate,true);
		$criteria->compare('returnedDate',$this->returnedDate,true);
		$criteria->compare('Status',$this->Status,true);
		$criteria->compare('asset_id',$this->asset_id);
		$criteria->compare('assetType_id',$this->assetType_id);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return EmployeeAssets the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
