<?php

/**
 * This is the model class for table "employee_documents".
 *
 * The followings are the available columns in table 'employee_documents':
 * @property integer $id
 * @property integer $emp_id
 * @property integer $document_id
 * @property integer $status
 * @property string $assign_date
 * @property string $inactive_date
 * @property string $document_path
 *
 * The followings are the available model relations:
 * @property Employee $emp
 * @property EmployeeDocumentType $document
 */
class EmployeeDocuments extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'employee_documents';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('emp_id, document_id, status, assign_date, inactive_date, document_path', 'required'),
			array('emp_id, document_id, status', 'numerical', 'integerOnly'=>true),
			array('assign_date, inactive_date', 'length', 'max'=>200),
			array('document_path', 'length', 'max'=>300),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, emp_id, document_id, status, assign_date, inactive_date, document_path', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'emp' => array(self::BELONGS_TO, 'Employee', 'emp_id'),
			'document' => array(self::BELONGS_TO, 'EmployeeDocumentType', 'document_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'emp_id' => 'Emp',
			'document_id' => 'Document',
			'status' => 'Status',
			'assign_date' => 'Assign Date',
			'inactive_date' => 'Inactive Date',
			'document_path' => 'Document Path',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('emp_id',$this->emp_id);
		$criteria->compare('document_id',$this->document_id);
		$criteria->compare('status',$this->status);
		$criteria->compare('assign_date',$this->assign_date,true);
		$criteria->compare('inactive_date',$this->inactive_date,true);
		$criteria->compare('document_path',$this->document_path,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return EmployeeDocuments the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
