<?php

/**
 * This is the model class for table "employee_ot_overwrite_track".
 *
 * The followings are the available columns in table 'employee_ot_overwrite_track':
 * @property integer $id
 * @property integer $emp_id
 * @property integer $employee_salary_id
 * @property double $old_normal_ot_rate
 * @property double $new_normal_ot_rate
 * @property double $old_double_ot_rate
 * @property double $new_double_ot_rate
 * @property string $overwrite_on
 * @property integer $overwrite_by
 */
class EmployeeOtOverwriteTrack extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return EmployeeOtOverwriteTrack the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'employee_ot_overwrite_track';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('emp_id, employee_salary_id, old_normal_ot_rate, new_normal_ot_rate, old_double_ot_rate, new_double_ot_rate, overwrite_on, overwrite_by', 'required'),
			array('emp_id, employee_salary_id, overwrite_by', 'numerical', 'integerOnly'=>true),
			array('old_normal_ot_rate, new_normal_ot_rate, old_double_ot_rate, new_double_ot_rate', 'numerical'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, emp_id, employee_salary_id, old_normal_ot_rate, new_normal_ot_rate, old_double_ot_rate, new_double_ot_rate, overwrite_on, overwrite_by', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'emp_id' => 'Emp',
			'employee_salary_id' => 'Employee Salary',
			'old_normal_ot_rate' => 'Old Normal Ot Rate',
			'new_normal_ot_rate' => 'New Normal Ot Rate',
			'old_double_ot_rate' => 'Old Double Ot Rate',
			'new_double_ot_rate' => 'New Double Ot Rate',
			'overwrite_on' => 'Overwrite On',
			'overwrite_by' => 'Overwrite By',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('emp_id',$this->emp_id);
		$criteria->compare('employee_salary_id',$this->employee_salary_id);
		$criteria->compare('old_normal_ot_rate',$this->old_normal_ot_rate);
		$criteria->compare('new_normal_ot_rate',$this->new_normal_ot_rate);
		$criteria->compare('old_double_ot_rate',$this->old_double_ot_rate);
		$criteria->compare('new_double_ot_rate',$this->new_double_ot_rate);
		$criteria->compare('overwrite_on',$this->overwrite_on,true);
		$criteria->compare('overwrite_by',$this->overwrite_by);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}