<?php

/**
 * This is the model class for table "employee_salary_change_approval".
 *
 * The followings are the available columns in table 'employee_salary_change_approval':
 * @property integer $id
 * @property integer $emp_id
 * @property integer $payment_method
 * @property integer $old_emp_salary_id
 * @property integer $new_emp_salary_id
 * @property integer $changed_by
 * @property string $changed_on
 * @property integer $approved_or_rejected_by
 * @property string $approved_or_rejected_on
 * @property integer $status
 */
class EmployeeSalaryChangeApproval extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'employee_salary_change_approval';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('emp_id, payment_method, new_emp_salary_id, changed_by, changed_on, status', 'required'),
			array('emp_id, payment_method, old_emp_salary_id, new_emp_salary_id, changed_by, approved_or_rejected_by, status', 'numerical', 'integerOnly'=>true),
			array('approved_or_rejected_on', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, emp_id, payment_method, old_emp_salary_id, new_emp_salary_id, changed_by, changed_on, approved_or_rejected_by, approved_or_rejected_on, status', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'emp_id' => 'Emp',
			'payment_method' => 'Payment Method',
			'old_emp_salary_id' => 'Old Emp Salary',
			'new_emp_salary_id' => 'New Emp Salary',
			'changed_by' => 'Changed By',
			'changed_on' => 'Changed On',
			'approved_or_rejected_by' => 'Approved Or Rejected By',
			'approved_or_rejected_on' => 'Approved Or Rejected On',
			'status' => 'Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('emp_id',$this->emp_id);
		$criteria->compare('payment_method',$this->payment_method);
		$criteria->compare('old_emp_salary_id',$this->old_emp_salary_id);
		$criteria->compare('new_emp_salary_id',$this->new_emp_salary_id);
		$criteria->compare('changed_by',$this->changed_by);
		$criteria->compare('changed_on',$this->changed_on,true);
		$criteria->compare('approved_or_rejected_by',$this->approved_or_rejected_by);
		$criteria->compare('approved_or_rejected_on',$this->approved_or_rejected_on,true);
		$criteria->compare('status',$this->status);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return EmployeeSalaryChangeApproval the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
