<?php

/**
 * This is the model class for table "nonpayroll_timelog".
 *
 * The followings are the available columns in table 'nonpayroll_timelog':
 * @property integer $id
 * @property string $PunchTime
 * @property integer $Employeeid
 * @property string $manual
 * @property string $Type
 * @property integer $Siteid
 * @property integer $Accountid
 * @property integer $departmentid
 * @property string $CreatedTime
 * @property integer $ValidStatus
 */
class NonpayrollTimelog extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'nonpayroll_timelog';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Employeeid', 'required'),
			array('Employeeid, Siteid, Accountid, departmentid, ValidStatus', 'numerical', 'integerOnly'=>true),
			array('manual, Type', 'length', 'max'=>50),
			array('PunchTime, CreatedTime', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, PunchTime, Employeeid, manual, Type, Siteid, Accountid, departmentid, CreatedTime, ValidStatus', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'nonpayrollemoloyee' => array(self::BELONGS_TO, 'NonpayrollEmployee', 'Employeeid'),
                    'Site' => array(self::BELONGS_TO, 'Sites', 'Siteid'),
                    );
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'PunchTime' => 'Punch Time',
			'Employeeid' => 'Employee',
			'manual' => 'Manual',
			'Type' => 'Type',
			'Siteid' => 'Site',
			'Accountid' => 'Account',
			'departmentid' => 'Department',
			'CreatedTime' => 'Created Time',
			'ValidStatus' => 'Valid Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

                $criteria->with = 'nonpayrollemoloyee';
                $criteria->with = 'Site';
		$criteria->compare('id',$this->id);
		$criteria->compare('PunchTime',$this->PunchTime,true);
		$criteria->compare('nonpayrollemoloyee.nic',$this->Employeeid,true);
		$criteria->compare('manual',$this->manual,true);
		$criteria->compare('Type',$this->Type,true);
		$criteria->compare('Site.name',$this->Siteid,true);
		$criteria->compare('Accountid',$this->Accountid);
		$criteria->compare('departmentid',$this->departmentid);
		$criteria->compare('CreatedTime',$this->CreatedTime,true);
		$criteria->compare('ValidStatus',$this->ValidStatus);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return NonpayrollTimelog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
