<?php

/**
 * This is the model class for table "payment".
 *
 * The followings are the available columns in table 'payment':
 * @property integer $id
 * @property integer $paymenttypeid
 * @property integer $employeeid
 * @property double $amount
 * @property string $time
 * @property string $description
 *
 * The followings are the available model relations:
 * @property Employee $employee
 * @property Paymenttype $paymenttype
 */
class Payment extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'payment';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('paymenttypeid, amount', 'required'),
			array('paymenttypeid, employeeid', 'numerical', 'integerOnly'=>true),
			array('amount', 'numerical'),
			array('description', 'length', 'max'=>250),
			array('time', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, paymenttypeid, employeeid, amount, time, description', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'employee' => array(self::BELONGS_TO, 'Employee', 'employeeid'),
			'paymenttype' => array(self::BELONGS_TO, 'Paymenttype', 'paymenttypeid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'paymenttypeid' => 'Payment Type',
			'employeeid' => 'Employee',
			'amount' => 'Amount',
			'time' => 'Time',
			'description' => 'Description',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('paymenttypeid',$this->paymenttypeid);
		$criteria->compare('employeeid',$this->employeeid);
		$criteria->compare('amount',$this->amount);
		$criteria->compare('time',$this->time,true);
		$criteria->compare('description',$this->description,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Payment the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	//=====================This method can be added to other models to track the DB operations related to that model========
	public function behaviors()
	{
		return array(
			// Classname => path to Class
			'DBRecordTracker'=>
				'application.behaviors.DBRecordTracker',
		);
	}

	//======================================================================================================================
}
