<?php

/**
 * This is the model class for table "payroll".
 *
 * The followings are the available columns in table 'payroll':
 * @property integer $id
 * @property string $StartDate
 * @property string $EndDate
 * @property integer $CreatedBy
 * @property string $CreatedTime
 * @property integer $ApprovedBy
 * @property string $ApprovedTime
 * @property integer $Status
 *
 * The followings are the available model relations:
 * @property PayrollItems[] $payrollItems
 */
class Payroll extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'payroll';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('StartDate, EndDate, CreatedBy, CreatedTime,PayrollMethod', 'required'),
            array('CreatedBy, ApprovedBy,RejectedBy, Status,SiteId', 'numerical', 'integerOnly' => true),
            array('ApprovedTime,RejectedTime', 'safe'),
            array('PayrollMethod', 'length', 'max' => 50),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, StartDate, EndDate, CreatedBy, CreatedTime, ApprovedBy, ApprovedTime,RejectedBy,RejectedTime, Status', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'payrollItems' => array(self::HAS_MANY, 'PayrollItems', 'Payroll_id'),
            'CreatedUser' => array(self::BELONGS_TO, 'User', 'CreatedBy'),
            'ApprovedUser' => array(self::BELONGS_TO, 'User', 'ApprovedBy'),
            'RejectedUser' => array(self::BELONGS_TO, 'User', 'RejectedBy'),
            'site' => array(self::BELONGS_TO, 'Sites', 'SiteId'),
        );
    }

    public static function itemAlias($type, $code = NULL) {
        $_items = array(
            'Status' => array(
                '0' => Yum::t('Not Send To Approve'),
                '1' => Yum::t('Pending'),
                '2' => Yum::t('Approved'),
                '3' => Yum::t('Rejected'),
            ),
        );
        if (isset($code)) {
            return isset($_items[$type][$code]) ? $_items[$type][$code] : false;
        } else {
            return isset($_items[$type]) ? $_items[$type] : false;
        }
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'StartDate' => 'Start Date',
            'EndDate' => 'End Date',
            'CreatedBy' => 'Created By',
            'CreatedTime' => 'Created Time',
            'ApprovedBy' => 'Approved By',
            'ApprovedTime' => 'Approved Time',
            'RejectedBy' => 'Rejected By',
            'RejectedTime' => 'Rejected Time',
            'Status' => 'Status',
            'PayrollMethod' => 'Payroll Method',
            'SiteId' => 'Site',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;
        if (Yii::app()->user->data()->superuser == 1) {
            $criteria->compare('SiteId', $this->SiteId);
        } else {
            $sitid = Yii::app()->user->data()->SiteId;
            $criteria->compare('SiteId', $sitid);
        }

        $criteria->compare('id', $this->id);
        $criteria->compare('StartDate', $this->StartDate, true);
        $criteria->compare('EndDate', $this->EndDate, true);
        $criteria->compare('CreatedBy', $this->CreatedBy);
        $criteria->compare('CreatedTime', $this->CreatedTime, true);
        $criteria->compare('ApprovedBy', $this->ApprovedBy);
        $criteria->compare('ApprovedTime', $this->ApprovedTime, true);
        $criteria->compare('Status', $this->Status);
        $criteria->compare('SiteId', $this->SiteId);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 'StartDate DESC',
            )
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Payroll the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
