<?php

/**
 * This is the model class for table "pieces_datails".
 *
 * The followings are the available columns in table 'pieces_datails':
 * @property integer $id
 * @property integer $Employee
 * @property string $Date
 * @property string $PieceType
 * @property integer $numberofpices
 */
class PiecesDatails extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pieces_datails';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Employee, Date, PieceType, numberofpices', 'required'),
			array('Employee,site_id, numberofpices', 'numerical', 'integerOnly'=>true),
			array('PieceType', 'length', 'max'=>250),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, Employee, Date, PieceType, numberofpices', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'employees' => array(self::BELONGS_TO, 'Employee', 'Employee'),
                    'Piece' => array(self::BELONGS_TO, 'Sku', 'PieceType'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'Employee' => 'Employee',
			'Date' => 'Date',
			'PieceType' => 'Piece Type',
			'numberofpices' => 'Number Of Pices',
                        'site_id'=>'site_id',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('Employee',$this->Employee);
		$criteria->compare('Date',$this->Date,true);
		$criteria->compare('PieceType',$this->PieceType,true);
		$criteria->compare('numberofpices',$this->numberofpices);
                if(Yii::app()->user->isAdmin()){
			$criteria->compare('site_id',$this->site_id);
		}

		else{
			$sitid = Yii::app()->user->data()->SiteId;
			$criteria->compare('site_id',$sitid);	
		}

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PiecesDatails the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
