<?php

/**
 * This is the model class for table "pomaterial".
 *
 * The followings are the available columns in table 'pomaterial':
 * @property integer $id
 * @property integer $Companyid
 * @property integer $Sectorid
 * @property integer $Clustorid
 * @property integer $Sitesid
 * @property integer $Accountid
 * @property integer $Designationid
 * @property string $POmeterialCode
 *
 * The followings are the available model relations:
 * @property Company $company
 * @property Sector $sector
 * @property Cluster $clustor
 * @property Sites $sites
 * @property Accounts $account
 */
class Pomaterial extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pomaterial';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Companyid, Sectorid, Clustorid, Sitesid, Accountid, Designationid,PaymentMethod', 'required'),
			array('Companyid, Sectorid, Clustorid, Sitesid, Accountid, Designationid', 'numerical', 'integerOnly'=>true),
			array('POmeterialCode,SaleOrderMCode', 'length', 'max'=>250),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, Companyid, Sectorid, Clustorid, Sitesid, Accountid, Designationid, POmeterialCode,SaleOrderMCode', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'company' => array(self::BELONGS_TO, 'Company', 'Companyid'),
			'sector' => array(self::BELONGS_TO, 'Sector', 'Sectorid'),
			'clustor' => array(self::BELONGS_TO, 'Cluster', 'Clustorid'),
			'sites' => array(self::BELONGS_TO, 'Sites', 'Sitesid'),
			'account' => array(self::BELONGS_TO, 'Accounts', 'Accountid'),
                        'designation' => array(self::BELONGS_TO, 'Designation', 'Designationid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'Companyid' => 'Company',
			'Sectorid' => 'Sector',
			'Clustorid' => 'Cluster',
			'Sitesid' => 'Sites',
			'Accountid' => 'Account',
			'Designationid' => 'Designation',
			'POmeterialCode' => 'Pometerial Code',
                        'SaleOrderMCode'=>'Sales Order Code',
                        'PaymentMethod'=>'Payment Method'
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

                $criteria->with = 'designation';
                
		$criteria->compare('id',$this->id);
		$criteria->compare('company',$this->Companyid);
               	$criteria->compare('Sectorid',$this->Sectorid);
		$criteria->compare('Clustorid',$this->Clustorid);
		$criteria->compare('Sitesid',$this->Sitesid);
		$criteria->compare('Accountid',$this->Accountid);
                $criteria->compare('PaymentMethod',$this->PaymentMethod);
		$criteria->compare('designation.type',$this->Designationid,true);
		$criteria->compare('POmeterialCode',$this->POmeterialCode,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Pomaterial the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
