<?php

/**
 * This is the model class for table "sku_salary".
 *
 * The followings are the available columns in table 'sku_salary':
 * @property integer $id
 * @property string $basic_plus_bra
 * @property string $basic
 * @property string $BRA1
 * @property string $BRA2
 * @property string $BRA3
 * @property string $contract_fee
 * @property string $mp_agent_rate
 * @property integer $CreatedBy
 * @property string $CreatedOn
 * @property integer $Status
 * @property integer $sku_id
 * @property integer $site_id
 */
class SkuSalary extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return SkuSalary the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'sku_salary';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(

			array('basic, BRA1, BRA2, BRA3, contract_fee, mp_agent_rate, CreatedBy, CreatedOn, Status, sku_id, site_id', 'required'),
			array('CreatedBy, Status, sku_id, site_id', 'numerical', 'integerOnly'=>true),
			array('basic_plus_bra, basic, BRA1, BRA2, BRA3, mp_agent_rate', 'length', 'max'=>20),
			array('contract_fee', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, basic_plus_bra, basic, BRA1, BRA2, BRA3, contract_fee, mp_agent_rate, CreatedBy, CreatedOn, Status, sku_id, site_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'basic_plus_bra' => 'BASIC + BRA',
			'basic' => 'BASIC',
			'BRA1' => 'BRA1',
			'BRA2' => 'BRA2',
			'BRA3' => 'BRA3',
			'contract_fee' => 'CONTRACT FEE',
			'mp_agent_rate' => 'MP AGENT RATE',
			'CreatedBy' => 'Created By',
			'CreatedOn' => 'Created On',
			'Status' => 'Status',
			'sku_id' => 'Sku',
			'site_id' => 'Site',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('basic_plus_bra',$this->basic_plus_bra,true);
		$criteria->compare('basic',$this->basic,true);
		$criteria->compare('BRA1',$this->BRA1,true);
		$criteria->compare('BRA2',$this->BRA2,true);
		$criteria->compare('BRA3',$this->BRA3,true);
		$criteria->compare('contract_fee',$this->contract_fee,true);
		$criteria->compare('mp_agent_rate',$this->mp_agent_rate,true);
		$criteria->compare('CreatedBy',$this->CreatedBy);
		$criteria->compare('CreatedOn',$this->CreatedOn,true);
		$criteria->compare('Status',$this->Status);
		$criteria->compare('sku_id',$this->sku_id);

		if(Yii::app()->user->isAdmin()){
			$criteria->compare('site_id',$this->site_id);
		}

		else{
			$sitid = Yii::app()->user->data()->SiteId;
			$criteria->compare('site_id',$sitid);	
		}

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}