<?php

/**
 * This is the model class for table "team".
 *
 * The followings are the available columns in table 'team':
 * @property integer $id
 * @property string $name
 * @property integer $siteid
 * @property integer $departmentid
 * @property string $description
 */
class Team extends CActiveRecord
{
       public $employees;
    
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'team';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('name,siteid', 'required'),
			array('siteid, Accountid', 'numerical', 'integerOnly'=>true),
			array('name', 'length', 'max'=>100),
                        array('SalaryOverrideStatus','numerical'),
                        array('SectionDaySalary', 'length', 'max' => 9),
			array('description', 'length', 'max'=>250),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, name,SectionDaySalary, siteid, Accountid, description', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'Sites' => array(self::BELONGS_TO, 'Sites', 'siteid'),
                    'Accounts' => array(self::BELONGS_TO, 'Accounts', 'Accountid'),
		
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'siteid' => 'Site',
			'Accountid' => 'Account',
			'description' => 'Description',
                        'SectionDaySalary' => '',
                        'SalaryOverrideStatus' => 'Salary Override Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

                if(Yii::app()->user->data()->superuser == 1){
			$criteria->compare('siteid',$this->siteid);
		}

		else{
			$sitid = Yii::app()->user->data()->SiteId;			
			$criteria->compare('siteid',$sitid);	
		}
		$criteria->compare('id',$this->id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('siteid',$this->siteid);
		$criteria->compare('Accountid',$this->Accountid);
		$criteria->compare('description',$this->description,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Team the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
