<?php

/**
 * This is the model class for table "team_shift".
 *
 * The followings are the available columns in table 'team_shift':
 * @property integer $id
 * @property integer $shiftid
 * @property integer $teamid
 * @property string $time
 * @property integer $Status
 * @property integer $shedulid
 *
 * The followings are the available model relations:
 * @property Shift $shift
 * @property Team $team
 */
class TeamShift extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'team_shift';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('shiftid, teamid, Status', 'required'),
			array('shiftid, teamid, Status, shedulid', 'numerical', 'integerOnly'=>true),
			array('time', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, shiftid, teamid, time, Status, shedulid', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'shift' => array(self::BELONGS_TO, 'Shift', 'shiftid'),
			'team' => array(self::BELONGS_TO, 'Team', 'teamid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'shiftid' => 'Shiftid',
			'teamid' => 'Teamid',
			'time' => 'Time',
			'Status' => 'Status',
			'shedulid' => 'Shedulid',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('shiftid',$this->shiftid);
		$criteria->compare('teamid',$this->teamid);
		$criteria->compare('time',$this->time,true);
		$criteria->compare('Status',$this->Status);
		$criteria->compare('shedulid',$this->shedulid);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return TeamShift the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public static function getTeamShift($shift){
		//echo $shift;
		//die;
		if(Yii::app()->user->isAdmin()){
			return CHtml::listData(self::model()->findAllBySql("select * from team_shift, team where team.id = team_shift.teamid AND team_shift.shiftid = ".$shift." "), 'team.id','team.name');
		}
		else{
			$sitid = Yii::app()->user->data()->SiteId;

			return CHtml::listData(self::model()->findAllBySql("select * from team_shift, team where team.id = team_shift.teamid AND team_shift.shiftid = ".$shift." AND team.siteid =$sitid"), 'team.id','team.name');
			
		}
	}
}
