<?php

/**
 * This is the model class for table "timelog".
 *
 * The followings are the available columns in table 'timelog':
 * @property integer $id
 * @property string $PunchTime
 * @property integer $Employeeid
 *
 * The followings are the available model relations:
 * @property Employee $employee
 */
class Timelog extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'timelog';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('PunchTime,Employeeid,Type', 'required'),
			array('Employeeid', 'numerical', 'integerOnly'=>true),
                        array('Type,Temperature', 'length', 'max'=>20),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id,manual, PunchTime, Employeeid,Type,ValidStatus', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'employee' => array(self::BELONGS_TO, 'Employee', 'Employeeid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'PunchTime' => 'Punch Time',
			'Employeeid' => 'Employeeid',
                        'manual' => 'Manual',
                        'Type' => 'Type',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
                if(Yii::app()->user->isAdmin()){
			$criteria->compare('siteid',$this->siteid);
		}

		else{
			$sitid = Yii::app()->user->data()->SiteId;			
			$criteria->compare('siteid',$sitid);	
		}

		$criteria->compare('id',$this->id);
		$criteria->compare('PunchTime',$this->PunchTime,true);
		$criteria->compare('Employeeid',$this->Employeeid);
                $criteria->compare('manual',$this->manual);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Timelog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
