<?php

/**
 * This is the model class for table "timelog_changes_track".
 *
 * The followings are the available columns in table 'timelog_changes_track':
 * @property integer $id
 * @property integer $timelog_id
 * @property string $old_value
 * @property string $new_value
 * @property integer $changed_by
 * @property string $changed_on
 * @property string $timelog_type
 */
class TimelogChangesTrack extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return TimelogChangesTrack the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'timelog_changes_track';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('timelog_id, old_value, new_value, changed_by, changed_on, timelog_type', 'required'),
			array('timelog_id, changed_by', 'numerical', 'integerOnly'=>true),
			array('timelog_type', 'length', 'max'=>20),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, timelog_id, old_value, new_value, changed_by, changed_on, timelog_type', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'timelog_id' => 'Timelog',
			'old_value' => 'Old Value',
			'new_value' => 'New Value',
			'changed_by' => 'Changed By',
			'changed_on' => 'Changed On',
			'timelog_type' => 'Timelog Type',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('timelog_id',$this->timelog_id);
		$criteria->compare('old_value',$this->old_value,true);
		$criteria->compare('new_value',$this->new_value,true);
		$criteria->compare('changed_by',$this->changed_by);
		$criteria->compare('changed_on',$this->changed_on,true);
		$criteria->compare('timelog_type',$this->timelog_type,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}