<?php

/**
 * This is the model class for table "timelog_delete_track".
 *
 * The followings are the available columns in table 'timelog_delete_track':
 * @property integer $id
 * @property integer $timelog_id
 * @property string $punch_time
 * @property integer $employee_id
 * @property string $manual
 * @property string $type
 * @property integer $site_id
 * @property integer $account_id
 * @property integer $department_id
 * @property string $deleted_on
 * @property integer $deleted_by
 */
class TimelogDeleteTrack extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return TimelogDeleteTrack the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'timelog_delete_track';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('timelog_id, punch_time, employee_id, manual, type, site_id, account_id, department_id, deleted_on, deleted_by', 'required'),
			array('timelog_id, employee_id, site_id, account_id, department_id, deleted_by', 'numerical', 'integerOnly'=>true),
			array('manual, type', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, timelog_id, punch_time, employee_id, manual, type, site_id, account_id, department_id, deleted_on, deleted_by', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'timelog_id' => 'Timelog',
			'punch_time' => 'Punch Time',
			'employee_id' => 'Employee',
			'manual' => 'Manual',
			'type' => 'Type',
			'site_id' => 'Site',
			'account_id' => 'Account',
			'department_id' => 'Department',
			'deleted_on' => 'Deleted On',
			'deleted_by' => 'Deleted By',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('timelog_id',$this->timelog_id);
		$criteria->compare('punch_time',$this->punch_time,true);
		$criteria->compare('employee_id',$this->employee_id);
		$criteria->compare('manual',$this->manual,true);
		$criteria->compare('type',$this->type,true);
		$criteria->compare('site_id',$this->site_id);
		$criteria->compare('account_id',$this->account_id);
		$criteria->compare('department_id',$this->department_id);
		$criteria->compare('deleted_on',$this->deleted_on,true);
		$criteria->compare('deleted_by',$this->deleted_by);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}