<?php

/**
 * This is the model class for table "timesheet".
 *
 * The followings are the available columns in table 'timesheet':
 * @property integer $id
 * @property string $date
 * @property string $Intime
 * @property string $OuteTime
 * @property string $WorkedHour
 * @property string $SallaryRate
 * @property string $LatedeductTime
 * @property string $LatedeductAmount
 * @property string $OutLateDeductTime
 * @property string $OutLateDeductAmount
 * @property string $NOvertimeHours
 * @property string $NOvertimeSalary
 * @property string $DOverTimeHour
 * @property string $Dovertimesalary
 * @property string $TotalOTHour
 * @property integer $EmployeeId
 * @property integer $EmployeeShiftid
 * @property integer $DesignaId
 * @property string $MorningOT
 * @property integer $M_OTStatus
 * @property string $DayName
 * @property string $PaymentMethod
 * @property integer $SiteId
 * @property string $TOverTimeHour
 * @property string $Tovertimesalary
 * @property string $WorkedDay
 * @property integer $Category
 * @property integer $account_id
 * @property integer $department_id
 * @property integer $MP_suplier_id
 * @property string $full_Basic_Salary
 * @property string $Sub_Basic_salary
 * @property string $BRA1
 * @property string $BRA2
 * @property string $BRA3
 *
 * The followings are the available model relations:
 * @property Employee $employee
 * @property Designation $designa
 * @property Timsheetchange[] $timsheetchanges
 */
class Timesheet extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'timesheet';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('date, Intime, OuteTime, WorkedHour, SallaryRate, NOvertimeHours, NOvertimeSalary, DOverTimeHour, Dovertimesalary, TotalOTHour, EmployeeId, DesignaId', 'required'),
			array('EmployeeId, EmployeeShiftid, DesignaId, M_OTStatus, SiteId, Category, account_id, department_id, MP_suplier_id', 'numerical', 'integerOnly'=>true),
			array('contract_fee,ActualNOT,ActualDOT,ActualTOT, OTApprovedBy,OTApprovedTime, OTApproveStatus, numberof_pieces,pieces_datails_id,WorkedHour, SallaryRate, LatedeductTime, LatedeductAmount, OutLateDeductTime, OutLateDeductAmount, NOvertimeSalary, Dovertimesalary, MorningOT, TOverTimeHour, Tovertimesalary, WorkedDay, full_Basic_Salary, Sub_Basic_salary, BRA1, BRA2, BRA3,Actual_WorkHourInShift', 'length', 'max'=>100),
			array('NOvertimeHours, DOverTimeHour, TotalOTHour', 'length', 'max'=>100),
			array('DayName, PaymentMethod', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, date, Intime, OuteTime, WorkedHour, SallaryRate, LatedeductTime, LatedeductAmount, OutLateDeductTime, OutLateDeductAmount, NOvertimeHours, NOvertimeSalary, DOverTimeHour, Dovertimesalary, TotalOTHour, EmployeeId, EmployeeShiftid, DesignaId, MorningOT, M_OTStatus, DayName, PaymentMethod, SiteId, TOverTimeHour, Tovertimesalary, WorkedDay, Category, account_id, department_id, MP_suplier_id, full_Basic_Salary, Sub_Basic_salary, BRA1, BRA2, BRA3,PreOTHour,PreOTAmount', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'employee' => array(self::BELONGS_TO, 'Employee', 'EmployeeId'),
			'designa' => array(self::BELONGS_TO, 'Designation', 'DesignaId'),
			'timsheetchanges' => array(self::HAS_MANY, 'Timsheetchange', 'TimeSheetId'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'date' => 'Date',
			'Intime' => 'Intime',
			'OuteTime' => 'Oute Time',
			'WorkedHour' => 'Worked Hour',
			'SallaryRate' => 'Sallary Rate',
			'LatedeductTime' => 'Latededuct Time',
			'LatedeductAmount' => 'Latededuct Amount',
			'OutLateDeductTime' => 'Out Late Deduct Time',
			'OutLateDeductAmount' => 'Out Late Deduct Amount',
			'NOvertimeHours' => 'Novertime Hours',
			'NOvertimeSalary' => 'Novertime Salary',
			'DOverTimeHour' => 'Dover Time Hour',
			'Dovertimesalary' => 'Dovertimesalary',
			'TotalOTHour' => 'Total Othour',
			'EmployeeId' => 'Employee',
			'EmployeeShiftid' => 'Employee Shiftid',
			'DesignaId' => 'Designa',
			'MorningOT' => 'Morning Ot',
			'M_OTStatus' => 'M Otstatus',
			'DayName' => 'Day Name',
			'PaymentMethod' => 'Payment Method',
			'SiteId' => 'Site',
			'TOverTimeHour' => 'Tover Time Hour',
			'Tovertimesalary' => 'Tovertimesalary',
			'WorkedDay' => 'Worked Day',
			'Category' => 'Category',
			'account_id' => 'Account',
			'department_id' => 'Department',
			'MP_suplier_id' => 'Mp Suplier',
			'full_Basic_Salary' => 'Full Basic Salary',
			'Sub_Basic_salary' => 'Sub Basic Salary',
			'BRA1' => 'Bra1',
			'BRA2' => 'Bra2',
			'BRA3' => 'Bra3',
                        'contract_fee'=>'Contract Fee'
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('date',$this->date,true);
		$criteria->compare('Intime',$this->Intime,true);
		$criteria->compare('OuteTime',$this->OuteTime,true);
		$criteria->compare('WorkedHour',$this->WorkedHour,true);
		$criteria->compare('SallaryRate',$this->SallaryRate,true);
		$criteria->compare('LatedeductTime',$this->LatedeductTime,true);
		$criteria->compare('LatedeductAmount',$this->LatedeductAmount,true);
		$criteria->compare('OutLateDeductTime',$this->OutLateDeductTime,true);
		$criteria->compare('OutLateDeductAmount',$this->OutLateDeductAmount,true);
		$criteria->compare('NOvertimeHours',$this->NOvertimeHours,true);
		$criteria->compare('NOvertimeSalary',$this->NOvertimeSalary,true);
		$criteria->compare('DOverTimeHour',$this->DOverTimeHour,true);
		$criteria->compare('Dovertimesalary',$this->Dovertimesalary,true);
		$criteria->compare('TotalOTHour',$this->TotalOTHour,true);
		$criteria->compare('EmployeeId',$this->EmployeeId);
		$criteria->compare('EmployeeShiftid',$this->EmployeeShiftid);
		$criteria->compare('DesignaId',$this->DesignaId);
		$criteria->compare('MorningOT',$this->MorningOT,true);
		$criteria->compare('M_OTStatus',$this->M_OTStatus);
		$criteria->compare('DayName',$this->DayName,true);
		$criteria->compare('PaymentMethod',$this->PaymentMethod,true);
		$criteria->compare('SiteId',$this->SiteId);
		$criteria->compare('TOverTimeHour',$this->TOverTimeHour,true);
		$criteria->compare('Tovertimesalary',$this->Tovertimesalary,true);
		$criteria->compare('WorkedDay',$this->WorkedDay,true);
		$criteria->compare('Category',$this->Category);
		$criteria->compare('account_id',$this->account_id);
		$criteria->compare('department_id',$this->department_id);
		$criteria->compare('MP_suplier_id',$this->MP_suplier_id);
		$criteria->compare('full_Basic_Salary',$this->full_Basic_Salary,true);
		$criteria->compare('Sub_Basic_salary',$this->Sub_Basic_salary,true);
		$criteria->compare('BRA1',$this->BRA1,true);
		$criteria->compare('BRA2',$this->BRA2,true);
		$criteria->compare('BRA3',$this->BRA3,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Timesheet the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
