<?php

class PayrollController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column1';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            //==========================================================================================================================
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('PieceRatePayrollCalculation', 'AddPerIncentive', 'AttendanceIncentive2', 'AttendanceIncentive3', 'CreatePieceRatePayroll', 'AddDeduction3', 'MonthlyPayrollCalculation', 'SendApproveFromReject', 'AddDeduction2', 'PayrollReject', 'PayrollReCalculation', 'PayrollApprovement', 'SendApprovement', 'GetTimesheets', 'GetPayrollSheet', 'PayrollDelete', 'AddPAllowence', 'AddBonus', 'AddDeduction', 'AddAllowance', 'AddInsentive', 'AddVAllowance', 'AddArrears', 'view', 'PayrollCalculation', 'GetTimesheetBYNic', 'PayrollAccountReport', 'PayrollCostReport', 'CreateAccountCostReportExcel', 'MPSCostSummeryReport', 'CreateMPSCostSummeryReportExcel', 'OTCostSummeryReport', 'CreateOTCostSummeryReporttExcel', 'AllowanceCostSummeryReport', 'AllowanceCostSummeryReportExcel', 'HolidayCostReport', 'CreateHolidayCostReporttExcel', 'PayrollAccountwiseCostReport', 'PayrollAccountwiseCostReportExcel', 'CreateOTCostSummeryReporttPDF', 'AllowanceCostSummeryReportPDF', 'HolidayCostReportPDF'),
                'users' => array('*'),
            ),
//            array('allow', // allow authenticated user to perform 'create' and 'update' actions
//                'actions' => array('create', 'update'),
//                'users' => array('@'),
//            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('Create', 'admin', 'delete', 'PayrollManage', 'Rejected'),
                'users' => array('admin'),
            ),
            //==========================================================================================================================
            array('allow', // allow only the owner to perform 'create'  actions
                'actions' => array('create'),
                'expression' => 'Yii::app()->user->can("Payroll_Create")',
            ),
            array('allow', // allow only the owner to perform 'index'  actions
                'actions' => array('index'),
                'expression' => 'Yii::app()->user->can("Payroll_Index")',
            ),
            array('allow', // allow only the owner to perform 'admin'  actions
                'actions' => array('admin'),
                'expression' => 'Yii::app()->user->can("Payroll_Admin")',
            ),
            array('allow', // allow only the owner to perform 'view'  actions
                'actions' => array('view'),
                'expression' => 'Yii::app()->user->can("Payroll_View")',
            ),
            array('allow', // allow only the owner to perform 'update'  actions
                'actions' => array('update'),
                'expression' => 'Yii::app()->user->can("Payroll_Update")',
            ),
            array('allow', // allow only the owner to perform 'delete'  actions
                'actions' => array('delete'),
                'expression' => 'Yii::app()->user->can("Payroll_Delete")',
            ),
            array('allow', // allow only the owner to perform 'PayrollCalculation'  actions
                'actions' => array('PayrollCalculation'),
                'expression' => 'Yii::app()->user->can("Payroll_PayrollCalculation")',
            ),
            array('allow', // allow only the owner to perform 'GetTimesheetBYNic'  actions
                'actions' => array('GetTimesheetBYNic'),
                'expression' => 'Yii::app()->user->can("Payroll_GetTimesheetBYNic")',
            ),
            array('allow', // allow only the owner to perform 'GetTimesheetBYNic'  actions
                'actions' => array('CreateMonthPayment'),
                'expression' => 'Yii::app()->user->can("Payroll_CreateMonthPayment")',
            ),
            array('allow', // allow only the owner to perform 'GetTimesheetBYNic'  actions
                'actions' => array('Rejected'),
                'expression' => 'Yii::app()->user->can("Payroll_Rejected")',
            ),
            array('allow', // allow only the owner to perform 'GetTimesheetBYNic'  actions
                'actions' => array('PayrollManage'),
                'expression' => 'Yii::app()->user->can("Payroll_PayrollManage")',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function beforeAction($action) {

        if (Yii::app()->user->isGuest && Yii::app()->controller->action->id != "login") {
            Yii::app()->user->loginRequired();
        }
        return true;
    }

    public function actionView($id) {

        $PayrollSheet = PayrollItems::model()->findAllByAttributes(array('Payroll_id' => $id));
        $Payroll = Payroll::model()->findByAttributes(array('id' => $id));
//        print_r($Payroll);
//        die;
        $this->render('view', array(
            'model' => $this->loadModel($id), 'PayrollSheet' => $PayrollSheet, 'Payroll' => $Payroll,
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Payroll;

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Payroll'])) {
            $model->attributes = $_POST['Payroll'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

// Uncomment the following line if AJAX validation is needed
// $this->performAjaxValidation($model);

        if (isset($_POST['Payroll'])) {
            $model->attributes = $_POST['Payroll'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->id));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        if (Yii::app()->request->isPostRequest) {

            //=======Track payroll ================
            $deletePayroll = new DeletedPayroll;
            $payroll = $this->loadModel($id);

            DeletedPayroll::model()->updateAll(array('Status' => 0), 'StartDate = :StartDate AND EndDate = :EndDate AND SiteId = :SiteId AND Status = 1 AND PayrollMethod = :PayrollMethod', array(':StartDate' => $payroll->StartDate, ':EndDate' => $payroll->EndDate, ':SiteId' => $payroll->SiteId, ':PayrollMethod' => $payroll->PayrollMethod));

            $deletePayroll->StartDate = $payroll->StartDate;
            $deletePayroll->EndDate = $payroll->EndDate;
            $deletePayroll->CreatedBy = $payroll->CreatedBy;
            $deletePayroll->CreatedTime = $payroll->CreatedTime;
            $deletePayroll->PayrollMethod = $payroll->PayrollMethod;
            $deletePayroll->ApprovedBy = $payroll->ApprovedBy;
            $deletePayroll->ApprovedTime = $payroll->ApprovedTime;
            $deletePayroll->RejectedBy = $payroll->RejectedBy;
            $deletePayroll->RejectedTime = $payroll->RejectedTime;
            $deletePayroll->Status = 1;
            $deletePayroll->SiteId = $payroll->SiteId;
            $deletePayroll->ReasontoReject = $payroll->ReasontoReject;
            $deletePayroll->save();

            Yii::app()->db->createCommand("INSERT INTO deleted_payroll_items (EmployeeName,NIC,JobTitle,Designationid,RateType,MPSuplier,`Site`,Account,WorkDay,NoPayDays,BasicWage,PoyadayPayment,MercantilePayment,SundayPayment,DayOfSundayP,`NOT`,DOT,TOT,Bonus,Allowance,Insentive,EPF,PAllowance,VAllowance,TotalGross,Deduction,Deduction2,Deduction3,TotalNet,EPFByCompany,ETFByCompany,ContractorFee,CostOfCompany,Payroll_id,LateDeductTime,LateDeductAmount,Arrears,NOTHour,DOTHour,TOTHour,TotalForEPF,TotalAddition,TotalDeduction,EarlyOutDeductTime,EarlyOutDeductAmount,SiteHolidayAmount,Accountid,MPSupplierid,Departmentid,DepartmentName,full_Basic_Salary,Sub_Basic_salary,BRA1,BRA2,BRA3,Perday_incentive,Lunch_incentive,NightShift_incentive,TotalForEPFPoyaday,number_of_pieces,performance_incentive,Incentive4,MonthIncentive,Incentive3)
                SELECT EmployeeName,NIC,JobTitle,Designationid,RateType,MPSuplier,`Site`,Account,WorkDay,NoPayDays,BasicWage,PoyadayPayment,MercantilePayment,SundayPayment,DayOfSundayP,`NOT`,DOT,TOT,Bonus,Allowance,Insentive,EPF,PAllowance,VAllowance,TotalGross,Deduction,Deduction2,Deduction3,TotalNet,EPFByCompany,ETFByCompany,ContractorFee,CostOfCompany,$deletePayroll->id,LateDeductTime,LateDeductAmount,Arrears,NOTHour,DOTHour,TOTHour,TotalForEPF,TotalAddition,TotalDeduction,EarlyOutDeductTime,EarlyOutDeductAmount,SiteHolidayAmount,Accountid,MPSupplierid,Departmentid,DepartmentName,full_Basic_Salary,Sub_Basic_salary,BRA1,BRA2,BRA3,Perday_incentive,Lunch_incentive,NightShift_incentive,TotalForEPFPoyaday,number_of_pieces,performance_incentive,Incentive4,MonthIncentive,Incentive3
                FROM payroll_items
                WHERE Payroll_id =$id")->query();
            //=====================================
            PayrollItems::model()->deleteAllByAttributes(array('Payroll_id' => $id));
            $this->loadModel($id)->delete();

            if (!isset($_GET['ajax']))
                $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
        } else
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $status = 1;
        if (Yii::app()->user->data()->superuser == 1) {
            $Pendinglist = Payroll::model()->findAllByAttributes(array('Status' => $status));
            $dataProvider = new CActiveDataProvider('Payroll');
            $this->render('index', array(
                'dataProvider' => $dataProvider, 'Pendinglist' => $Pendinglist,
            ));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Pendinglist = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId, 'Status' => $status));
            $dataProvider = new CActiveDataProvider('Payroll');
            $this->render('index', array(
                'dataProvider' => $dataProvider, 'Pendinglist' => $Pendinglist,
            ));
        }
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Payroll('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Payroll']))
            $model->attributes = $_GET['Payroll'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer the ID of the model to be loaded
     */
    public function loadModel($id) {
        $model = Payroll::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param CModel the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'payroll-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionRejected() {
        if (Yii::app()->user->data()->superuser == 1) {
            $model = new Payroll;
            $status = 3;
            $RejectedList = Payroll::model()->findAllByAttributes(array('Status' => $status));

            $this->render('rejected', array(
                'model' => $model, 'RejectedList' => $RejectedList,
            ));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $model = new Payroll;
            $status = 3;
            $RejectedList = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId, 'Status' => $status));

            $this->render('rejected', array(
                'model' => $model, 'RejectedList' => $RejectedList,
            ));
        }
    }

    public function actionPayrollManage() {
        $status = 0;
        if (Yii::app()->user->data()->superuser == 1) {
            $Pendinglist = Payroll::model()->findAllByAttributes(array('Status' => $status));
            $this->render('NotSendToApprove', array(
                'Pendinglist' => $Pendinglist,
            ));
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Pendinglist = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId, 'Status' => $status));
            $this->render('NotSendToApprove', array(
                'Pendinglist' => $Pendinglist,
            ));
        }
    }

//------------------------------------//
    public function actionPayrollCalculation() {

        $StartDate = ($_POST['Startdate']);
        $EndDate = ($_POST['Enddate']);

        if (Yii::app()->user->data()->superuser == 1) {
            $payroll = CJSON::encode([]);
            echo $payroll;
        } else {
            //------Payroll for Site Wise------//    
            $SiteId = Yii::app()->user->data()->SiteId;

            $Criteria1 = new CDbCriteria();
            $Criteria1->condition = 'date(EndDate) >= :StartDate AND SiteId = :siteid AND PayrollMethod = :paymentmethod';
            $Criteria1->params = array(':StartDate' => $StartDate, ':siteid' => $SiteId, ':paymentmethod' => "DAILY");
            $Criteria1->select = "*";
            $Payrollsheet = Payroll::model()->findAll($Criteria1);

            if (empty($Payrollsheet)) {

                $sql = " SELECT 
            COUNT(timesheet.id) AS NoOftimesheet,
            SUM(timesheet.SallaryRate) AS BasicSalary,
            SUM(timesheet.full_Basic_Salary) AS Full_Basicsalary,
            SUM(timesheet.Sub_Basic_salary) AS Sub_Basicsalary,
            SUM(timesheet.BRA1) AS BRA1,
            SUM(timesheet.BRA2) AS BRA2,
            SUM(timesheet.BRA3) AS BRA3,
            SUM(timesheet.NOvertimeSalary) AS NOTAmout,
            SUM(timesheet.Dovertimesalary) AS DOTAmount,
            SUM(timesheet.Tovertimesalary) AS TOTAmount,
            SUM(timesheet.NOvertimeHours) AS NOTHour,
            SUM(timesheet.DOverTimeHour) AS DOTHour,
            SUM(timesheet.TOverTimeHour) AS TOTHour,
            SUM(timesheet.PreOTHour) AS PreOTHour,
            SUM(timesheet.LatedeductTime) AS LatedeductTime,
            SUM(timesheet.LatedeductAmount) AS LatedeductAmount,
            SUM(timesheet.OutLateDeductTime) AS EarlyOutLatedeductTime,
            SUM(timesheet.OutLateDeductAmount) AS EarlyOutLatedeductAmount,
        --  designation.id AS Designationid,
            employee.designationid AS Designationid,
            designation.type,
            employee.id AS Empid,
            employee.Namewithini,
            employee.nic,
            employee.Accountid,
            employee.departmentid,
            employee.supplierid,
            paymentmethod.type AS paymentmethod ,
            sites.name AS SiteName,
            supplier.name AS SupplierName,
            accounts.name As AccountName,
            department.name As DepartmentName,
            timesheet.SiteId
            
            FROM timesheet
            INNER JOIN employee ON timesheet.EmployeeId = employee.id
            INNER JOIN designation ON employee.designationid = designation.id
            INNER JOIN paymentmethod ON employee.paymentmethodid =paymentmethod.id
            INNER JOIN supplier ON employee.supplierid = supplier.id
            INNER JOIN accounts ON employee.Accountid = accounts.id
            INNER JOIN department ON employee.departmentid = department.id
            INNER JOIN sites ON timesheet.SiteId =sites.id

             WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.PaymentMethod ='DAILY' AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'
             GROUP BY employee.nic
             ORDER BY employee.Accountid ASC ";

                $rowdata = Yii::app()->db->createCommand($sql)->queryAll();

                if (!empty($rowdata)) {

                    $PayRoll = new Payroll;
                    $PayRoll->StartDate = $StartDate;
                    $PayRoll->EndDate = $EndDate;
                    $PayRoll->CreatedBy = Yii::app()->user->id;
                    $PayRoll->CreatedTime = date("Y-m-d H:i");
                    $PayRoll->PayrollMethod = "DAILY";
                    $PayRoll->SiteId = $SiteId;
                    $PayRoll->Status = 0;
                    if ($PayRoll->save()) {

                        foreach ($rowdata as $Rowdata) {
                            $PayrollItems = new PayrollItems;
                            $employeeid = $Rowdata['Empid'];

                            $sql1 = " SELECT 
                                      COUNT(timesheet.id) AS NumOfWorkday,
                                      employee.id AS Empid,
                                      employee.nic
           
                                      FROM timesheet
                                      INNER JOIN employee ON timesheet.EmployeeId = employee.id
                                      WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "'  AND timesheet.PaymentMethod ='DAILY' AND timesheet.EmployeeId='" . $employeeid . "' AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'
                                      GROUP BY employee.nic";
                            $Data = Yii::app()->db->createCommand($sql1)->queryAll();

                            $NumberOfWeekDays = Yii::app()->db->createCommand("SELECT 
                            COUNT(timesheet.id) AS NumberOftimesheet,
                            timesheet.DayName
                            FROM timesheet
                            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.EmployeeId ='" . $employeeid . "' AND timesheet.PaymentMethod ='DAILY' AND DAYNAME(timesheet.Date) NOT IN ('Saturday', 'Sunday') AND timesheet.DayName ='WEEKDAY'AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'")->queryAll();

                            $PayrollItems->Payroll_id = $PayRoll->id;
                            $PayrollItems->EmployeeName = $Rowdata['Namewithini'];
                            $PayrollItems->NIC = $Rowdata['nic'];
                            $PayrollItems->JobTitle = $Rowdata['type'];
                            $PayrollItems->Designationid = $Rowdata['Designationid'];
                            $PayrollItems->RateType = $Rowdata['paymentmethod'];
                            $PayrollItems->MPSuplier = $Rowdata['SupplierName'];
                            $PayrollItems->Site = $Rowdata['SiteName'];
                            $PayrollItems->Account = $Rowdata['AccountName'];
                            $WorkedDays = empty($Data) ? 0 : $Data[0]['NumOfWorkday'];
                            $NumberOf_WeekDays = empty($NumberOfWeekDays) ? 0 : $NumberOfWeekDays[0]['NumberOftimesheet'];
                            $PayrollItems->WorkDay = $WorkedDays;
                            $PayrollItems->Actual_WorkedDay = $NumberOf_WeekDays;
                            $PayrollItems->Accountid = $Rowdata['Accountid'];
                            $PayrollItems->MPSupplierid = $Rowdata['supplierid'];
                            $PayrollItems->Departmentid = $Rowdata['departmentid'];
                            $PayrollItems->DepartmentName = $Rowdata['DepartmentName'];
                            $PayrollItems->NoPayDays = 0;

                            $employeesalary = Employeesalary::model()->findByAttributes(array('employeeid' => $employeeid, 'site_id' => $SiteId, 'Status' => 1));
                            if (empty($employeesalary)) {
                                $employeesalary = new Employeesalary;
                                $employeesalary->monthsalary = 0;
                                $employeesalary->DalySalary = 0;
                                $employeesalary->HourlyRate = 0;
                                $employeesalary->OTRate = 0;
                                $employeesalary->DoubleOTRate = 0;
                                $employeesalary->BasicSalary = 0;
                                $employeesalary->BRA1 = 0;
                                $employeesalary->BRA2 = 0;
                                $employeesalary->BRA3 = 0;
                            }

                            $PoyadayPayment = Yii::app()->MonthlyPayrollCalculationUtil->PoyadayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $poyadayoutdeduct = $PoyadayPayment[5];
                            $poyadayearlydeduct = $PoyadayPayment[6];
                            $AllDeductInPoyaDay = $PoyadayPayment[5] + $PoyadayPayment[6];
                            $PoyaDayAmount = $PoyadayPayment[1] - $AllDeductInPoyaDay;
                            $PayrollItems->PoyadayPayment = $PoyaDayAmount > 0 ? $PoyaDayAmount : 0;

                            $MercantilePayment = Yii::app()->MonthlyPayrollCalculationUtil->MercantilePayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $marcantiloutdeduct = $MercantilePayment[5];
                            $marcantilearlydeduct = $MercantilePayment[6];
                            $AllDeductInmarcday = $MercantilePayment[5] + $MercantilePayment[6];
                            $MercantileDayAmount = $MercantilePayment[1] - $AllDeductInmarcday;
                            $PayrollItems->MercantilePayment = $MercantileDayAmount > 0 ? $MercantileDayAmount : 0;

                            $SundayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SundayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $sundayoutdeduct = $SundayPayment[5];
                            $sundayearlydeduct = $SundayPayment[6];
                            $AllDeductInSunday = $SundayPayment[5] + $SundayPayment[6];
                            $SundayAmount = $SundayPayment[1] - $AllDeductInSunday;
                            $PayrollItems->SundayPayment = $SundayAmount > 0 ? $SundayAmount : 0;

                            $SiteHolidayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SiteHolidaydayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $siteholidayoutdeduct = $SiteHolidayPayment[5];
                            $siteholidayearlydeduct = $SiteHolidayPayment[6];
                            $AllDeductInSiteholiday = $SiteHolidayPayment[5] + $SiteHolidayPayment[6];
                            $SiteHolidayAmount = $SiteHolidayPayment[1] - $AllDeductInSiteholiday;
                            $PayrollItems->SiteHolidayAmount = $SiteHolidayAmount > 0 ? $SiteHolidayAmount : 0;

                            $AllHolidayElyded = $poyadayearlydeduct + $marcantilearlydeduct + $sundayearlydeduct + $siteholidayearlydeduct;
                            $AllHolidayoutyded = $poyadayoutdeduct + $marcantiloutdeduct + $sundayoutdeduct + $siteholidayoutdeduct;

                            $AllHolidayElydedHours = $PoyadayPayment[8] + $MercantilePayment[8] + $SundayPayment[8] + $SiteHolidayPayment[8];
                            $AllHolidayoutydedHours = $PoyadayPayment[7] + $MercantilePayment[7] + $SundayPayment[7] + $SiteHolidayPayment[7];

                            $PayrollItems->DayOfSundayP = 0;
                            //already late deduct in Timesheet allso again deduct in payroll therefor add deduct to basic
                            $PayrollItems->BasicWage = $Rowdata['BasicSalary'] - ($PoyadayPayment[1] + $MercantilePayment[1] + $SundayPayment[1] + $SiteHolidayPayment[1]);

                            $PayrollItems->full_Basic_Salary = $Rowdata['Full_Basicsalary'];
                            $PayrollItems->Sub_Basic_salary = $Rowdata['Sub_Basicsalary'];
                            $PayrollItems->BRA1 = $Rowdata['BRA1'];
                            $PayrollItems->BRA2 = $Rowdata['BRA2'];
                            $PayrollItems->BRA3 = $Rowdata['BRA3'];
                            $PayrollItems->daysalary = $employeesalary->DalySalary;

//                            $LateDeductTime = ($Rowdata['LatedeductTime'] - $AllHolidayElydedHours) > 0 ? ($Rowdata['LatedeductTime'] - $AllHolidayElydedHours) : 0;
//                            $PayrollItems->LateDeductTime = $LateDeductTime;
//                            $EarlyLateD_hours = $hours = floor($PayrollItems->LateDeductTime);
//                            $EarlyLateD_minutes = ($PayrollItems->LateDeductTime * 60 % 60);
//                            $PayrollItems->LateDeductAmount = $employeesalary->HourlyRate * ($EarlyLateD_hours + $EarlyLateD_minutes / 60);
//                            
                            $LateD = round((($Rowdata['LatedeductTime'] - $AllHolidayElydedHours) > 0 ? ($Rowdata['LatedeductTime'] - $AllHolidayElydedHours) : 0) * 60);
                            $LDH = $LateD / 60;
                            $EarlyLateD_hours = floor($LDH);
                            $Lminits = round($LDH * 60);
                            $EarlyLateD_minutes = $Lminits % 60;
                            $LateDeductHours = ($EarlyLateD_hours + $EarlyLateD_minutes / 60 );
                            $PayrollItems->LateDeductTime = $LateDeductHours;
                            $PayrollItems->LateDeductAmount = $employeesalary->HourlyRate * $LateDeductHours;

                            $WeekdaysdayElydeduct = $PayrollItems->LateDeductAmount;

//                            $EarlyLateDeductTime = ($Rowdata['EarlyOutLatedeductTime'] - $AllHolidayoutydedHours) > 0 ? ($Rowdata['EarlyOutLatedeductTime'] - $AllHolidayoutydedHours) : 0;
//                            $PayrollItems->EarlyOutDeductTime = $EarlyLateDeductTime;
//                            $EarlyOut_hours = $hours = floor($PayrollItems->EarlyOutDeductTime);
//                            $EarlyOut_minutes = ($PayrollItems->EarlyOutDeductTime * 60 % 60);
//                            $PayrollItems->EarlyOutDeductAmount = $employeesalary->HourlyRate * ($EarlyOut_hours + $EarlyOut_minutes / 60);


                            $OLateD = round((($Rowdata['EarlyOutLatedeductTime'] - $AllHolidayoutydedHours) > 0 ? ($Rowdata['EarlyOutLatedeductTime'] - $AllHolidayoutydedHours) : 0) * 60);
                            $OLDH = $OLateD / 60;
                            $EarlyOut_hours = floor($OLDH);
                            $OLminits = round($OLDH * 60);
                            $EarlyOut_minutes = $OLminits % 60;
                            $OutLateDeductHours = ($EarlyOut_hours + $EarlyOut_minutes / 60 );
                            $PayrollItems->EarlyOutDeductTime = $OutLateDeductHours;
                            $PayrollItems->EarlyOutDeductAmount = $employeesalary->HourlyRate * $OutLateDeductHours;

                            $Weekdaysdayoutdeduct = $PayrollItems->EarlyOutDeductAmount;

                            $SaturdayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SaturdayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $WeekdayBasicAmount = $Rowdata['BasicSalary'] - ($PoyadayPayment[1] + $MercantilePayment[1] + $SundayPayment[1] + $SiteHolidayPayment[1] + $SaturdayPayment[1]);

                            $NumberofPoyaday = $PoyadayPayment[9];
                            $NumberofMercantile = $MercantilePayment[9];
                            $NumberOfSunday = $SundayPayment[9];
                            $NumberOfSiteholiday = $SiteHolidayPayment[9];
                            $NumberOfSaturday = $SaturdayPayment[9];

                            $HolidayWithoutpoyadaPaymentforEpf = ($NumberofMercantile + $NumberOfSunday + $NumberOfSiteholiday + $NumberOfSaturday) * $employeesalary->DalySalary;
                            $PoyadayAmountForEpf = $NumberofPoyaday * $employeesalary->DalySalary * 1.5;

                            //  $Amount = ($PayrollItems->BasicWage + $PayrollItems->SundayPayment) - ($WeekdaysdayElydeduct + $Weekdaysdayoutdeduct);
                            $Amount = ($WeekdayBasicAmount + $HolidayWithoutpoyadaPaymentforEpf + $PoyadayAmountForEpf) - ($WeekdaysdayElydeduct + $Weekdaysdayoutdeduct);
                            $AmountForCon = ($WeekdayBasicAmount + $HolidayWithoutpoyadaPaymentforEpf + $PoyadayAmountForEpf);
                            $Amountforcontactfee = $AmountForCon > 0 ? $AmountForCon : 0;
                            $AmountforEpf = $Amount > 0 ? $Amount : 0;
                            $PayrollItems->TotalForEPF = $AmountforEpf;

//                            $PayrollItems->NOTHour = $Rowdata['NOTHour'];
//                            $not_hours = $hours = floor($Rowdata['NOTHour']);
//                            $not_minutes = ($Rowdata['NOTHour'] * 60 % 60);
//                            $PayrollItems->NOT = $employeesalary->HourlyRate * 1.5 * ($not_hours + $not_minutes / 60);
//                            

                            $T1 = round($Rowdata['NOTHour'] * 60);
                            $T2 = $T1 / 60;
                            $NOTH = $T2;
                            $not_hours = $hours = floor($NOTH);
                            $minits = round($NOTH * 60);
                            $not_minutes = $minits % 60;
                            $NOTHours = ($not_hours + $not_minutes / 60 );
                            $PayrollItems->NOTHour = $NOTHours;
                            $WithoutRound = floor($employeesalary->OTRate * $NOTHours * 100) / 100;
                            $PayrollItems->NOT = $WithoutRound;

                            $T3 = round($Rowdata['DOTHour'] * 60);
                            $T4 = $T3 / 60;
                            $DOTH = $T4;
                            $DOT_hours = $hours = floor($DOTH);
                            $DOTminits = round($DOTH * 60);
                            $DOT_minutes = ($DOTminits % 60);
                            $DOTHours = ($DOT_hours + $DOT_minutes / 60 );
                            $PayrollItems->DOTHour = $DOTHours;
                            $PayrollItems->DOT = $employeesalary->DoubleOTRate * $DOTHours;

                            $T5 = round($Rowdata['TOTHour'] * 60);
                            $T6 = $T5 / 60;
                            $TOTH = $T6;
                            $TOT_hours = floor($TOTH);
                            $TOTminits = round($TOTH * 60);
                            $TOT_minutes = ($TOTminits % 60);
                            $TOTHours = ($TOT_hours + $TOT_minutes / 60 );
                            $PayrollItems->TOTHour = $TOTHours;
                            $PayrollItems->TOT = $employeesalary->HourlyRate * 3 * $TOTHours;

                            $T7 = round($Rowdata['PreOTHour'] * 60);
                            $T8 = $T7 / 60;
                            $POTH = $T8;
                            $POT_hours = floor($POTH);
                            $POTminits = round($POTH * 60);
                            $POT_minutes = ($POTminits % 60);
                            $POTHours = ($POT_hours + $POT_minutes / 60 );
                            $PayrollItems->PreOTHour = $POTHours;
                            $PayrollItems->PreOTAmount = $employeesalary->HourlyRate * 1.5 * $POTHours;

                            $AT1 = round($Rowdata['NOTHour'] * 60);
                            $AT2 = $AT1 / 60;
                            $ANOTH = $AT2;
                            $Anot_hours = floor($ANOTH);
                            $Aminits = round($ANOTH * 60);
                            $Anot_minutes = $Aminits % 60;
                            $ANOTHours = ($Anot_hours + $Anot_minutes / 60 );
                            $PayrollItems->ActualNOTHour = $ANOTHours;

                            $AT3 = round($Rowdata['DOTHour'] * 60);
                            $AT4 = $AT3 / 60;
                            $ADOTH = $AT4;
                            $ADOT_hours = floor($ADOTH);
                            $ADOTminits = round($ADOTH * 60);
                            $ADOT_minutes = ($ADOTminits % 60);
                            $ADOTHours = ($ADOT_hours + $ADOT_minutes / 60 );
                            $PayrollItems->ActualDOTHour = $ADOTHours;

                            $AT5 = round($Rowdata['TOTHour'] * 60);
                            $AT6 = $AT5 / 60;
                            $ATOTH = $AT6;
                            $ATOT_hours = floor($ATOTH);
                            $ATOTminits = round($ATOTH * 60);
                            $ATOT_minutes = ($ATOTminits % 60);
                            $ATOTHours = ($ATOT_hours + $ATOT_minutes / 60 );
                            $PayrollItems->TOTHour = $ATOTHours;

                            $PayrollItems->Perday_incentive = 0;
                            $PayrollItems->Lunch_incentive = 0;
                            $PayrollItems->NightShift_incentive = 0;
                            $PayrollItems->travaling_incentive = 0;
                            $PayrollItems->accomondation_incentive = 0;
                            $PayrollItems->performance_incentive = 0;
                            $PayrollItems->Special_Incentive = 0;
                            $PayrollItems->Trip_Commission_Incentive = 0;
                            $PayrollItems->Rural_incentive = 0;
                            $PayrollItems->BioPass_incentive = 0;
                            $PayrollItems->Incentive1 = 0;
                            $PayrollItems->Incentive2 = 0;
                            $PayrollItems->Incentive3 = 0;

                            $Perday_Attendance = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 1, 'status' => 1));
                            if (!empty($Perday_Attendance)) {
                                $NumberOfDay = $SiteId == 2 ? $NumberOf_WeekDays : $WorkedDays;
                                $WorkedDays_amount = $NumberOfDay * $Perday_Attendance->incentive_amount;
                                $P_incentive = $WorkedDays_amount > 0 ? $WorkedDays_amount : 0;
                                $PayrollItems->Perday_incentive = $P_incentive;
                            }

                            $Perday_Lunch = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 2, 'status' => 1));
                            if (!empty($Perday_Lunch)) {
                                $NumberOfDay = $SiteId == 2 ? $NumberOf_WeekDays : $WorkedDays;
                                $WorkedDays_amount = $NumberOfDay * $Perday_Lunch->incentive_amount;
                                $P_incentive = $WorkedDays_amount > 0 ? $WorkedDays_amount : 0;
                                $PayrollItems->Lunch_incentive = $P_incentive;
                            }

                            $Special_Incentive = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 7, 'status' => 1));
                            if (!empty($Special_Incentive)) {
                                $NumberOfDay = $SiteId == 2 ? $NumberOf_WeekDays : $WorkedDays;
                                $SWorkedDays_amount = $NumberOfDay * $Special_Incentive->incentive_amount;
                                $SP_incentive = $SWorkedDays_amount > 0 ? $SWorkedDays_amount : 0;
                                $PayrollItems->Special_Incentive = $SP_incentive;
                            }


                            $date1 = date_create($StartDate);
                            $date2 = date_create($EndDate);
                            $diff = date_diff($date1, $date2);
                            $numberofdayinmonth = $diff->format("%R%a");
                            $NumberofDayinMonth = $numberofdayinmonth + 1;

                            $AllSunday = Yii::app()->MonthlyPayrollCalculationUtil->GetSpecificDayBetweenDates($StartDate, $EndDate, 0);
                            $AllSaturday = Yii::app()->MonthlyPayrollCalculationUtil->GetSpecificDayBetweenDates($StartDate, $EndDate, 6);
                            $Sunday_count = count($AllSunday);
                            $Saturday_count = count($AllSaturday);

                            $All_Holiday = Yii::app()->db->createCommand("SELECT COUNT(DISTINCT holydays.Date ) AS HolidayCount
                                FROM holydays
                                WHERE holydays.Date >='" . $StartDate . "' AND holydays.Date <='" . $EndDate . "' AND( holydays.type ='GENERAL' OR holydays.siteId ='" . $SiteId . "') AND DAYNAME(holydays.Date) NOT IN ('Saturday', 'Sunday')")->queryAll();

                            $AllHolidayCount = !empty($All_Holiday) ? $All_Holiday[0]['HolidayCount'] : 0;
                            $NumberOfWorkindDay = $NumberofDayinMonth - ($Sunday_count + $Saturday_count + $AllHolidayCount + 1);

//                            $AttendanceIncentive2 = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'incentive_id' => 13, 'status' => 1));
//                            if (!empty($AttendanceIncentive2)) {
//
//
//                                $PayrollItems->Incentive3 = $NumberOfWeekDays >= $NumberOfWorkindDay ? $AttendanceIncentive2->incentive_amount : 0;
//                            }

                            $PayrollItems->Incentive3 = 0;

                            $PerMonthAttendance = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'incentive_id' => 14, 'status' => 1));
                            if (!empty($PerMonthAttendance)) {

                                $NopayDayInWeekday = $NumberOfWorkindDay - $NumberOfWeekDays;

                                $PayrollItems->MonthIncentive = $NopayDayInWeekday > 2 ? 0 : $PerMonthAttendance->incentive_amount;
                            }

                            $PayrollItems->Insentive = $PayrollItems->Perday_incentive + $PayrollItems->Lunch_incentive + $PayrollItems->NightShift_incentive + $PayrollItems->performance_incentive + $PayrollItems->Special_Incentive + $PayrollItems->Trip_Commission_Incentive + $PayrollItems->Rural_incentive + $PayrollItems->BioPass_incentive + $PayrollItems->Incentive1 + $PayrollItems->Incentive2 + $PayrollItems->Incentive3;

                            $PayrollItems->Bonus = 0;
                            $PayrollItems->Allowance = 0;
                            $PayrollItems->PAllowance = 0;
                            $PayrollItems->VAllowance = 0;
                            $PayrollItems->Arrears = 0;

                            $A = $PayrollItems->BasicWage - ($WeekdaysdayElydeduct + $Weekdaysdayoutdeduct);
                            $WorkedDayAmount = $A > 0 ? $A : 0;
                            $TotalGross = $WorkedDayAmount + $PayrollItems->NOT + $PayrollItems->DOT + $PayrollItems->TOT + $PayrollItems->PreOTAmount + $PayrollItems->PoyadayPayment + $PayrollItems->MercantilePayment + $PayrollItems->SiteHolidayAmount+ $PayrollItems->SundayPayment + $PayrollItems->Insentive;
                            $PayrollItems->TotalGross = $TotalGross;

                            $PayrollItems->Deduction = 0;
                            $PayrollItems->Deduction2 = 0;
                            $PayrollItems->Deduction3 = 0;

                            $PayrollItems->TotalNet = $TotalGross;

                            $EPFByCompany = (12 / 100) * $AmountforEpf;
                            //Yii::app()->MonthlyPayrollCalculationUtil->EPFByCompany($Rowdata['BasicSalary'], $PoyadayPayment, $MercantilePayment, $SundayPayment);
                            $PayrollItems->EPFByCompany = $EPFByCompany;

                            $ETFByCompany = (3 / 100) * $AmountforEpf;
                            //Yii::app()->MonthlyPayrollCalculationUtil->ETFByCompany($Rowdata['BasicSalary'], $PoyadayPayment, $MercantilePayment, $SundayPayment);
                            $PayrollItems->ETFByCompany = $ETFByCompany;

                            $Contractfee = Employeecontractfee::model()->findByAttributes(array('employeeid' => $employeeid, 'site_id' => $SiteId, 'status' => 1));
                            $contractfeevalue = $Contractfee != null ? $Contractfee->contractfee : 0;
                            $PayrollItems->contractorfee_rate = $contractfeevalue;
                            $PayrollItems->ContractorFee = ($contractfeevalue / 100) * $Amountforcontactfee;

                            $ConF = $PayrollItems->ContractorFee;
                            $CostOfCompany = $PayrollItems->TotalNet + $EPFByCompany + $ETFByCompany + $ConF;
                            $PayrollItems->CostOfCompany = $CostOfCompany;

                            $PayrollItems->TotalAddition = 0;
                            $PayrollItems->TotalDeduction = 0;

                            $PayrollItems->save();

                            $Deleted_payroll = Yii::app()->db->createCommand("SELECT DPI.id,DPI.NIC,DPI.Bonus,DPI.Allowance,DPI.Insentive,DPI.performance_incentive,DPI.PAllowance,DPI.VAllowance,DPI.Arrears,DPI.Deduction,DPI.Deduction2,DPI.Deduction3,DP.SiteId,DPI.Incentive4,DPI.Incentive3
                                FROM deleted_payroll_items AS DPI
                                INNER JOIN deleted_payroll DP ON DPI.Payroll_id = DP.id
                                WHERE DPI.NIC = '" . $PayrollItems->NIC . "' AND DP.StartDate ='" . $StartDate . "' AND DP.EndDate ='" . $EndDate . "' AND DP.PayrollMethod ='DAILY' AND DP.Status=1 AND DP.SiteId ='" . $SiteId . "'")->queryAll();
                            if (!empty($Deleted_payroll)) {

                                PayrollItems::model()->updateAll(array('Bonus' => $Deleted_payroll[0]['Bonus'], 'Allowance' => $Deleted_payroll[0]['Allowance'], 'Insentive' => $Deleted_payroll[0]['Insentive'], 'performance_incentive' => $Deleted_payroll[0]['performance_incentive'], 'PAllowance' => $Deleted_payroll[0]['PAllowance'], 'VAllowance' => $Deleted_payroll[0]['VAllowance'], 'Deduction' => $Deleted_payroll[0]['Deduction'], 'Deduction2' => $Deleted_payroll[0]['Deduction2'], 'Deduction3' => $Deleted_payroll[0]['Deduction3'], 'Arrears' => $Deleted_payroll[0]['Arrears'], 'Incentive4' => $Deleted_payroll[0]['Incentive4'], 'Incentive3' => $Deleted_payroll[0]['Incentive3']), 'id ="' . $PayrollItems->id . '"');

                                $PayrollItem = $PayrollItems::model()->findByAttributes(array('id' => $PayrollItems->id));

                                $TotalAddition = $PayrollItem->Bonus + $PayrollItem->Allowance + $PayrollItem->PAllowance + $PayrollItem->VAllowance + $PayrollItem->Arrears;
                                $TotalIncentive = $PayrollItems->Insentive + $PayrollItem->performance_incentive + $PayrollItem->Incentive3 + $PayrollItem->Incentive4;
                                $TotalGros = $PayrollItems->TotalGross + $TotalAddition + $PayrollItem->performance_incentive + $PayrollItem->Incentive3 + $PayrollItem->Incentive4;
                                $TotalDeduction = $PayrollItem->Deduction + $PayrollItem->Deduction2 + $PayrollItem->Deduction3;
                                $TotalNet = $TotalGros - $TotalDeduction;
                                $CostToCompany = $TotalNet + $PayrollItem->EPFByCompany + $PayrollItem->ETFByCompany + $PayrollItem->ContractorFee;

                                PayrollItems::model()->updateAll(array('TotalAddition' => $TotalAddition, 'Insentive' => $TotalIncentive, 'TotalGross' => $TotalGros, 'TotalDeduction' => $TotalDeduction, 'TotalNet' => $TotalNet, 'CostOfCompany' => $CostToCompany), 'id ="' . $PayrollItem->id . '"');
                            }
                        }
                        $GetPayrollShSheet = Yii::app()->MonthlyPayrollCalculationUtil->GetMonthlyPayrollSheet($PayRoll->id);
                        $payroll = CJSON::encode($GetPayrollShSheet);
                        echo $payroll;
                    }
                } else {
                    $payroll = CJSON::encode([]);
                    echo $payroll;
                }
            } else {
                $payroll = CJSON::encode(true);
                echo $payroll;
            }
        }
    }

    public function actionPayrollReCalculation() {

        $Payrollid = ($_POST['id']);
        $StartDate = ($_POST['Startdate']);
        $EndDate = ($_POST['Enddate']);

        $payroll = Payroll::model()->findByAttributes(array('id' => $Payrollid));
        $paymentmethod = $payroll->PayrollMethod;

        if ($paymentmethod == "DAILY") {
            Yii::app()->MonthlyPayrollCalculationUtil->DailyPayrollReCalculation($Payrollid, $StartDate, $EndDate);
        } elseif ($paymentmethod == "MONTHLY") {

            Yii::app()->MonthlyPayrollCalculationUtil->MonthlyPayrollReCalculation($Payrollid, $StartDate, $EndDate);
        }
    }

    public function actionGetTimesheetBYNic() {

        $nic = ($_POST['Nic']);
        $startdate = ($_POST['Startdat']);
        $enddate = ($_POST['Enddate']);

        // $Timesheet = Timesheet::model()->findByAttributes(array('date' => $Date, 'EmployeeId' => $employeeid));
        $sql = "
            SELECT 
                timesheet.id,
                timesheet.date,
                timesheet.Intime,
                timesheet.OuteTime,
                timesheet.NOvertimeHours,
                timesheet.DOverTimeHour,
                timesheet.Dovertimesalary,
                timesheet.TOverTimeHour,
                timesheet.Tovertimesalary,
                timesheet.LatedeductTime,
                timesheet.LatedeductAmount,
                timesheet.OutLateDeductTime,
                timesheet.OutLateDeductAmount,
                timesheet.DayName,
                timesheet.WorkedHour,
                timesheet.NOvertimeSalary,
                timesheet.SallaryRate,
                timesheet.EmployeeShiftid,
                employee.Namewithini,
                employee.nic,
                designation.type,
                supplier.name AS Suppliername,
                sites.name AS sitesname

                FROM timesheet
                INNER JOIN  employee ON timesheet.EmployeeId = employee.id
                INNER JOIN designation ON employee.designationid = designation.id
                INNER JOIN supplier ON employee.supplierid = supplier.id
                INNER JOIN sites ON employee.siteid = sites.id

            WHERE timesheet.date >='" . $startdate . "'  AND timesheet.date <='" . $enddate . "' AND employee.nic = '" . $nic . "' ORDER BY timesheet.date ASC";
        $data = Yii::app()->db->createCommand($sql)->queryAll();
        $timesheets = CJSON::encode($data);
        echo $timesheets;
    }

    public function actionPayrollDelete() {

        $PayrollId = ($_POST['Payroll_id']);

        $Payroll = Payroll::model()->findByAttributes(array('id' => $PayrollId));
        if (!empty($Payroll)) {

            //=======Track payroll ================
            $deletePayroll = new DeletedPayroll;

            DeletedPayroll::model()->updateAll(array('Status' => 0), 'StartDate = :StartDate AND EndDate = :EndDate AND SiteId = :SiteId AND Status = 1 AND PayrollMethod = :PayrollMethod', array(':StartDate' => $Payroll->StartDate, ':EndDate' => $Payroll->EndDate, ':SiteId' => $Payroll->SiteId, ':PayrollMethod' => $Payroll->PayrollMethod));

            $deletePayroll->StartDate = $Payroll->StartDate;
            $deletePayroll->EndDate = $Payroll->EndDate;
            $deletePayroll->CreatedBy = $Payroll->CreatedBy;
            $deletePayroll->CreatedTime = $Payroll->CreatedTime;
            $deletePayroll->PayrollMethod = $Payroll->PayrollMethod;
            $deletePayroll->ApprovedBy = $Payroll->ApprovedBy;
            $deletePayroll->ApprovedTime = $Payroll->ApprovedTime;
            $deletePayroll->RejectedBy = $Payroll->RejectedBy;
            $deletePayroll->RejectedTime = $Payroll->RejectedTime;
            $deletePayroll->Status = 1;
            $deletePayroll->SiteId = $Payroll->SiteId;
            $deletePayroll->ReasontoReject = $Payroll->ReasontoReject;
            $deletePayroll->save();

            Yii::app()->db->createCommand("INSERT INTO deleted_payroll_items (EmployeeName,NIC,JobTitle,Designationid,RateType,MPSuplier,`Site`,Account,WorkDay,NoPayDays,BasicWage,PoyadayPayment,MercantilePayment,SundayPayment,DayOfSundayP,`NOT`,DOT,TOT,Bonus,Allowance,Insentive,EPF,PAllowance,VAllowance,TotalGross,Deduction,Deduction2,Deduction3,TotalNet,EPFByCompany,ETFByCompany,ContractorFee,CostOfCompany,Payroll_id,LateDeductTime,LateDeductAmount,Arrears,NOTHour,DOTHour,TOTHour,TotalForEPF,TotalAddition,TotalDeduction,EarlyOutDeductTime,EarlyOutDeductAmount,SiteHolidayAmount,Accountid,MPSupplierid,Departmentid,DepartmentName,full_Basic_Salary,Sub_Basic_salary,BRA1,BRA2,BRA3,Perday_incentive,Lunch_incentive,NightShift_incentive,TotalForEPFPoyaday,number_of_pieces)
                    SELECT EmployeeName,NIC,JobTitle,Designationid,RateType,MPSuplier,`Site`,Account,WorkDay,NoPayDays,BasicWage,PoyadayPayment,MercantilePayment,SundayPayment,DayOfSundayP,`NOT`,DOT,TOT,Bonus,Allowance,Insentive,EPF,PAllowance,VAllowance,TotalGross,Deduction,Deduction2,Deduction3,TotalNet,EPFByCompany,ETFByCompany,ContractorFee,CostOfCompany,$deletePayroll->id,LateDeductTime,LateDeductAmount,Arrears,NOTHour,DOTHour,TOTHour,TotalForEPF,TotalAddition,TotalDeduction,EarlyOutDeductTime,EarlyOutDeductAmount,SiteHolidayAmount,Accountid,MPSupplierid,Departmentid,DepartmentName,full_Basic_Salary,Sub_Basic_salary,BRA1,BRA2,BRA3,Perday_incentive,Lunch_incentive,NightShift_incentive,TotalForEPFPoyaday,number_of_pieces
                    FROM payroll_items
                    WHERE Payroll_id =$Payroll->id")->query();
            //=====================================

            PayrollItems::model()->deleteAllByAttributes(array('Payroll_id' => $Payroll->id));
            Payroll::model()->deleteAllByAttributes(array('id' => $Payroll->id));
        }
        $msg = CJSON::encode("Deleted Succsess!!");
        echo $msg;
    }

    public function actionAddDeduction() {

        $id = ($_POST['id']);
        $Deduction = ($_POST['Deduction']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalDeduction = ($Payroll->TotalDeduction - $Payroll->Deduction) + $Deduction;
            $newTotalNet = $Payroll->TotalGross - $newTotalDeduction;
            $newCostOfCompany = $newTotalNet + $Payroll->EPFByCompany + $Payroll->ETFByCompany + $Payroll->ContractorFee;
            PayrollItems::model()->updateAll(array('Deduction' => $Deduction, 'TotalDeduction' => $newTotalDeduction, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddDeduction2() {

        $id = ($_POST['id']);
        $Deduction2 = ($_POST['Deduction2']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalDeduction = ($Payroll->TotalDeduction - $Payroll->Deduction2) + $Deduction2;
            $newTotalNet = $Payroll->TotalGross - $newTotalDeduction;
            $newCostOfCompany = $newTotalNet + $Payroll->EPFByCompany + $Payroll->ETFByCompany + $Payroll->ContractorFee;
            PayrollItems::model()->updateAll(array('Deduction2' => $Deduction2, 'TotalDeduction' => $newTotalDeduction, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddDeduction3() {

        $id = ($_POST['id']);
        $Deduction3 = ($_POST['Deduction3']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalDeduction = ($Payroll->TotalDeduction - $Payroll->Deduction3) + $Deduction3;
            $newTotalNet = $Payroll->TotalGross - $newTotalDeduction;
            $newCostOfCompany = $newTotalNet + $Payroll->EPFByCompany + $Payroll->ETFByCompany + $Payroll->ContractorFee;
            PayrollItems::model()->updateAll(array('Deduction3' => $Deduction3, 'TotalDeduction' => $newTotalDeduction, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddBonus() {

        $id = ($_POST['id']);
        $Bonus = ($_POST['Bonus']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalAddition = ($Payroll->TotalAddition - $Payroll->Bonus) + $Bonus;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->Bonus) + $Bonus;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->Bonus) + $Bonus;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->Bonus) + $Bonus;
            PayrollItems::model()->updateAll(array('Bonus' => $Bonus, 'TotalAddition' => $newTotalAddition, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddAllowance() {

        $id = ($_POST['id']);
        $Allowance = ($_POST['Allowance']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalAddition = ($Payroll->TotalAddition - $Payroll->Allowance) + $Allowance;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->Allowance) + $Allowance;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->Allowance) + $Allowance;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->Allowance) + $Allowance;
            PayrollItems::model()->updateAll(array('Allowance' => $Allowance, 'TotalAddition' => $newTotalAddition, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddArrears() {

        $id = ($_POST['id']);
        $Arrears = ($_POST['Arrears']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalAddition = ($Payroll->TotalAddition - $Payroll->Arrears) + $Arrears;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->Arrears) + $Arrears;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->Arrears) + $Arrears;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->Arrears) + $Arrears;
            PayrollItems::model()->updateAll(array('Arrears' => $Arrears, 'TotalAddition' => $newTotalAddition, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddInsentive() {

        $id = ($_POST['id']);
        $Insentive = ($_POST['Insentive']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalAddition = ($Payroll->TotalAddition - $Payroll->Insentive) + $Insentive;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->Insentive) + $Insentive;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->Insentive) + $Insentive;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->Insentive) + $Insentive;
            PayrollItems::model()->updateAll(array('Insentive' => $Insentive, 'TotalAddition' => $newTotalAddition, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddPAllowence() {

        $id = ($_POST['id']);
        $PAllowans = ($_POST['PAllowans']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));

        if (!empty($Payroll)) {
            $newTotalAddition = ($Payroll->TotalAddition - $Payroll->PAllowance) + $PAllowans;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->PAllowance) + $PAllowans;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->PAllowance) + $PAllowans;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->PAllowance) + $PAllowans;
            PayrollItems::model()->updateAll(array('PAllowance' => $PAllowans, 'TotalAddition' => $newTotalAddition, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddVAllowance() {

        $id = ($_POST['id']);
        $VAllowans = ($_POST['VAllowans']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalAddition = ($Payroll->TotalAddition - $Payroll->VAllowance) + $VAllowans;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->VAllowance) + $VAllowans;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->VAllowance) + $VAllowans;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->VAllowance) + $VAllowans;
            PayrollItems::model()->updateAll(array('VAllowance' => $VAllowans, 'TotalAddition' => $newTotalAddition, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAddPerIncentive() {

        $id = ($_POST['id']);
        $PerIncentive = ($_POST['PerIncentive']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalIncentive = ($Payroll->Insentive - $Payroll->performance_incentive) + $PerIncentive;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->performance_incentive) + $PerIncentive;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->performance_incentive) + $PerIncentive;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->performance_incentive) + $PerIncentive;
            PayrollItems::model()->updateAll(array('performance_incentive' => $PerIncentive, 'Insentive' => $newTotalIncentive, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAttendanceIncentive2() {

        $id = ($_POST['id']);
        $AttIncentive2 = ($_POST['Incentive']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalIncentive = ($Payroll->Insentive - $Payroll->Incentive3) + $AttIncentive2;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->Incentive3) + $AttIncentive2;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->Incentive3) + $AttIncentive2;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->Incentive3) + $AttIncentive2;
            PayrollItems::model()->updateAll(array('Incentive3' => $AttIncentive2, 'Insentive' => $newTotalIncentive, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionAttendanceIncentive3() {

        $id = ($_POST['id']);
        $AttIncentive3 = ($_POST['Incentive']);

        $Payroll = PayrollItems::model()->findByAttributes(array('id' => $id));
        if (!empty($Payroll)) {

            $newTotalIncentive = ($Payroll->Insentive - $Payroll->Incentive4) + $AttIncentive3;
            $newTotalGross = ($Payroll->TotalGross - $Payroll->Incentive4) + $AttIncentive3;
            $newTotalNet = ($Payroll->TotalNet - $Payroll->Incentive4) + $AttIncentive3;
            $newCostOfCompany = ($Payroll->CostOfCompany - $Payroll->Incentive4) + $AttIncentive3;
            PayrollItems::model()->updateAll(array('Incentive4' => $AttIncentive3, 'Insentive' => $newTotalIncentive, 'TotalGross' => $newTotalGross, 'TotalNet' => $newTotalNet, 'CostOfCompany' => $newCostOfCompany), 'id ="' . $id . '"');
        }
        $msg = CJSON::encode("Updated Successfully");
        echo $msg;
    }

    public function actionGetPayrollSheet() {

        $id = ($_POST['Id']);
        $Payroll = PayrollItems::model()->findAllByAttributes(array('Payroll_id' => $id));
        $msg = CJSON::encode($Payroll);
        echo $msg;
    }

    public function actionGetTimesheets() {

        $nic = ($_POST['Nic']);
        $id = ($_POST['Id']);
        $Payroll = Payroll::model()->findByAttributes(array('id' => $id));

        $startdate = $Payroll->StartDate;
        $enddate = $Payroll->EndDate;
        $siteid = $Payroll->SiteId;

        $sql = "
            SELECT 
                timesheet.id,
                timesheet.date,
                timesheet.Intime,
                timesheet.OuteTime,
                timesheet.NOvertimeHours,
                timesheet.DOverTimeHour,
                timesheet.Dovertimesalary,
                timesheet.NOvertimeSalary,
                timesheet.TOverTimeHour,
                timesheet.Tovertimesalary,
                timesheet.LatedeductTime,
                timesheet.LatedeductAmount,
                timesheet.OutLateDeductTime,
                timesheet.OutLateDeductAmount,
                timesheet.DayName,
                timesheet.WorkedHour,
                timesheet.SallaryRate,
                timesheet.EmployeeShiftid,
                employee.Namewithini,
                employee.nic,
                designation.type,
                supplier.name AS Suppliername,
                sites.name AS sitesname

                FROM timesheet
                INNER JOIN  employee ON timesheet.EmployeeId = employee.id
                INNER JOIN designation ON employee.designationid = designation.id
                INNER JOIN supplier ON employee.supplierid = supplier.id
                INNER JOIN sites ON employee.siteid = sites.id

            WHERE timesheet.date >='" . $startdate . "'  AND timesheet.date <='" . $enddate . "' AND timesheet.SiteId ='" . $siteid . "' AND employee.nic = '" . $nic . "'ORDER BY timesheet.date ASC";
        $data = Yii::app()->db->createCommand($sql)->queryAll();
        $timesheets = CJSON::encode($data);
        echo $timesheets;
    }

    public function actionSendApprovement() {

        $id = ($_POST['Id']);
        if (!empty($id)) {
            Payroll::model()->updateAll(array('Status' => 1), 'id ="' . $id . '"');
        }

        $msg = CJSON::encode("Sent Succsessfuly!!");
        echo $msg;
    }

    public function actionSendApproveFromReject() {
        $Id = ($_POST['Payrollid']);

        if (!empty($Id)) {
            Payroll::model()->updateAll(array('Status' => 1), 'id ="' . $Id . '"');
        }

        $msg = CJSON::encode("Sent Succsessfuly!!");
        echo $msg;
    }

    public function actionPayrollApprovement() {
        $Id = ($_POST['Id']);

        if (!empty($Id)) {
            Payroll::model()->updateAll(array('Status' => 2, 'ApprovedBy' => Yii::app()->user->id, 'ApprovedTime' => date("Y-m-d H:i:s")), 'id ="' . $Id . '"');
        }

        $msg = CJSON::encode("Approved Succsessfuly!!");
        echo $msg;
    }

    public function actionPayrollReject() {

        $Id = ($_POST['Id']);
        $Discription = ($_POST['Discription']);

        if (!empty($Id)) {
            Payroll::model()->updateAll(array('Status' => 3, 'RejectedBy' => Yii::app()->user->id, 'RejectedTime' => date("Y-m-d H:i"), 'ReasontoReject' => $Discription), 'id ="' . $Id . '"');
        }

        $msg = CJSON::encode("Rejected Succsessfuly!!");
        echo $msg;
    }

    //-------Payrol for monthly----//
    public function actionCreateMonthPayment() {
        $model = new Payroll;

        $this->render('monthlypayment', array(
            'model' => $model,
        ));
    }

    public function actionMonthlyPayrollCalculation() {

        $StartDate = ($_POST['Startdate']);
        $EndDate = ($_POST['Enddate']);
        
         if (Yii::app()->user->data()->superuser == 1) {

            $payroll = CJSON::encode([]);
            echo $payroll;
        } else {
            //------Month Payroll for Site Wise------//    
            $SiteId = Yii::app()->user->data()->SiteId;

            $Criteria1 = new CDbCriteria();
            $Criteria1->condition = 'date(EndDate) >= :StartDate AND SiteId = :siteid AND PayrollMethod = :paymentmethod';
            $Criteria1->params = array(':StartDate' => $StartDate, ':siteid' => $SiteId, ':paymentmethod' => "MONTHLY");
            $Criteria1->select = "*";
            $Payrollsheet = Payroll::model()->findAll($Criteria1);

          if (empty($Payrollsheet)) {

                $sql = " SELECT 
            COUNT(timesheet.id) AS NoOftimesheet,
            SUM(timesheet.SallaryRate) AS BasicSalary,
            SUM(timesheet.full_Basic_Salary) AS Full_Basicsalary,
            SUM(timesheet.Sub_Basic_salary) AS Sub_Basicsalary,
            SUM(timesheet.BRA1) AS BRA1,
            SUM(timesheet.BRA2) AS BRA2,
            SUM(timesheet.BRA3) AS BRA3,
            SUM(timesheet.NOvertimeSalary) AS NOTAmout,
            SUM(timesheet.Dovertimesalary) AS DOTAmount,
            SUM(timesheet.Tovertimesalary) AS TOTAmount,
            SUM(timesheet.NOvertimeHours) AS NOTHour,
            SUM(timesheet.DOverTimeHour) AS DOTHour,
            SUM(timesheet.TOverTimeHour) AS TOTHour,
            SUM(timesheet.PreOTHour) AS PreOTHour,
            SUM(timesheet.LatedeductTime) AS LatedeductTime,
            SUM(timesheet.LatedeductAmount) AS LatedeductAmount,
            SUM(timesheet.OutLateDeductTime) AS EarlyOutLatedeductTime,
            SUM(timesheet.OutLateDeductAmount) AS EarlyOutLatedeductAmount,

           -- employee.designationid AS Designationid,
			designation.id AS Designationid,
            designation.type,
            employee.id AS Empid,
            employee.Namewithini,
            employee.nic,
            accounts.id AS Accountid,
            department.id AS departmentid,
            supplier.id AS supplierid,
            paymentmethod.type AS paymentmethod ,
            sites.name AS SiteName,
            supplier.name AS SupplierName,
            accounts.name As AccountName,
            department.name As DepartmentName,
            timesheet.SiteId

            FROM timesheet
            INNER JOIN employee ON timesheet.EmployeeId = employee.id
            INNER JOIN designation ON timesheet.DesignaId = designation.id
            INNER JOIN paymentmethod ON employee.paymentmethodid =paymentmethod.id
        --  INNER JOIN sites ON employee.siteid = sites.id
            INNER JOIN supplier ON timesheet.MP_suplier_id = supplier.id
            INNER JOIN accounts ON timesheet.account_id = accounts.id
            INNER JOIN department ON timesheet.department_id = department.id
            INNER JOIN sites ON timesheet.SiteId =sites.id

            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.PaymentMethod ='MONTHLY' AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00' AND (timesheet.date,timesheet.EmployeeId) NOT IN (SELECT leavedays.leaveDays,leavedays.EmpId
            FROM leavedays
            INNER JOIN `leave` ON leavedays.leaveId = (leave.id)
            WHERE leavedays.leaveDays >='" . $StartDate . "' AND leavedays.leaveDays <='" . $EndDate . "' AND leavedays.leave_type_status = 0 AND (leave.site) = '" . $SiteId . "' AND (leave.Status) =1)
            GROUP BY employee.nic
            ORDER BY employee.Accountid ASC ";

                $rowdata = Yii::app()->db->createCommand($sql)->queryAll();

                if (!empty($rowdata)) {

                    $PayRoll = new Payroll;
                    $PayRoll->StartDate = $StartDate;
                    $PayRoll->EndDate = $EndDate;
                    $PayRoll->CreatedBy = Yii::app()->user->id;
                    $PayRoll->CreatedTime = date("Y-m-d H:i:s");
                    $PayRoll->PayrollMethod = "MONTHLY";
                    $PayRoll->SiteId = $SiteId;
                    $PayRoll->Status = 0;

                    if ($PayRoll->save()) {

                        foreach ($rowdata as $Rowdata) {
                            $PayrollItems = new PayrollItems;
                            $employeeid = $Rowdata['Empid'];
                            $Employee = Employee::model()->findByAttributes(array('id' => $employeeid));

                            $employeesalary = Employeesalary::model()->findByAttributes(array('employeeid' => $employeeid, 'site_id' => $SiteId, 'Status' => 1));
                            if (empty($employeesalary)) {
                                $employeesalary = new Employeesalary;
                                $employeesalary->monthsalary = 0;
                                $employeesalary->DalySalary = 0;
                                $employeesalary->HourlyRate = 0;
                                $employeesalary->OTRate = 0;
                                $employeesalary->DoubleOTRate = 0;
                                $employeesalary->BasicSalary = 0;
                                $employeesalary->BRA1 = 0;
                                $employeesalary->BRA2 = 0;
                                $employeesalary->BRA3 = 0;
                            }
                            $PayrollItems->Payroll_id = $PayRoll->id;
                            $PayrollItems->EmployeeName = $Rowdata['Namewithini'];
                            $PayrollItems->NIC = $Rowdata['nic'];
                            $PayrollItems->JobTitle = $Rowdata['type'];
                            $PayrollItems->Designationid = $Rowdata['Designationid'];
                            $PayrollItems->RateType = $Rowdata['paymentmethod'];
                            $PayrollItems->MPSuplier = $Rowdata['SupplierName'];
                            $PayrollItems->Site = $Rowdata['SiteName'];
                            $PayrollItems->Account = $Rowdata['AccountName'];
                            $PayrollItems->Accountid = $Rowdata['Accountid'];
                            $PayrollItems->MPSupplierid = $Rowdata['supplierid'];
                            $PayrollItems->Departmentid = $Rowdata['departmentid'];
                            $PayrollItems->DepartmentName = $Rowdata['DepartmentName'];

                            $PoyadayPayment = Yii::app()->MonthlyPayrollCalculationUtil->PoyadayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $poyadayoutdeduct = $PoyadayPayment[5];
                            $poyadayearlydeduct = $PoyadayPayment[6];
                            $AllDeductInPoyaDay = $PoyadayPayment[5] + $PoyadayPayment[6];
                            $PoyaDayAmount = $PoyadayPayment[1] - $AllDeductInPoyaDay;
                            $PayrollItems->PoyadayPayment = $PoyaDayAmount > 0 ? $PoyaDayAmount : 0;

                            $MercantilePayment = Yii::app()->MonthlyPayrollCalculationUtil->MercantilePayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $marcantiloutdeduct = $MercantilePayment[5];
                            $marcantilearlydeduct = $MercantilePayment[6];
                            $AllDeductInmarcday = $MercantilePayment[5] + $MercantilePayment[6];
                            $MercantileDayAmount = $MercantilePayment[1] - $AllDeductInmarcday;
                            $PayrollItems->MercantilePayment = $MercantileDayAmount > 0 ? $MercantileDayAmount : 0;

                            $SiteHolidayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SiteHolidaydayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $siteholidayoutdeduct = $SiteHolidayPayment[5];
                            $siteholidayearlydeduct = $SiteHolidayPayment[6];
                            $AllDeductInSiteholiday = $SiteHolidayPayment[5] + $SiteHolidayPayment[6];
                            $SiteHolidayAmount = $SiteHolidayPayment[1] - $AllDeductInSiteholiday;
                            $PayrollItems->SiteHolidayAmount = $SiteHolidayAmount > 0 ? $SiteHolidayAmount : 0;

                            $JoiningDate = $StartDate;
                            $JoiningDateNew = $StartDate;
                            $EmployeeJoindate = EmployeeJoinDetails::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'status' => 1));
                            if (!empty($EmployeeJoindate)) {
                                $JoiningDate = $EmployeeJoindate->join_date >= $StartDate ? $EmployeeJoindate->join_date : $StartDate;
                                $JoiningDateNew = $EmployeeJoindate->join_date;
                            }
                            $ResignDate = $EndDate;
                            $EmployeeResignDate = EmployeeResignDetails::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'status' => 1));
                            if (!empty($EmployeeResignDate)) {
                                $ResignDate = $EmployeeResignDate->resign_date <= $EndDate ? $EmployeeResignDate->resign_date : $EndDate;
                            }

                            if ($Employee->Shift_mode == "ROSTER-BASE") {

                                $PayrollItems->SundayPayment = 0;

                                $AllHolidayElyded = $poyadayearlydeduct + $marcantilearlydeduct + $siteholidayearlydeduct;
                                $AllHolidayoutyded = $poyadayoutdeduct + $marcantiloutdeduct + $siteholidayoutdeduct;

                                $LateD = round($Rowdata['LatedeductTime'] * 60);
                                $LDH = $LateD / 60;
                                $EarlyLateD_hours = floor($LDH);
                                $Lminits = round($LDH * 60);
                                $EarlyLateD_minutes = $Lminits % 60;
                                $LateDeductHours = ($EarlyLateD_hours + $EarlyLateD_minutes / 60 );
                                $PayrollItems->LateDeductTime = $LateDeductHours;
                                $PayrollItems->LateDeductAmount = $employeesalary->HourlyRate * $LateDeductHours;

                                $WeekdaysdayElydeduct = $PayrollItems->LateDeductAmount;

                                $OutLateD = round($Rowdata['EarlyOutLatedeductTime'] * 60);
                                $OLDH = $OutLateD / 60;
                                $EarlyOut_hours = floor($OLDH);
                                $OLminits = round($OLDH * 60);
                                $EarlyOut_minutes = $OLminits % 60;
                                $OutLateDeductHours = ($EarlyOut_hours + $EarlyOut_minutes / 60 );
                                $PayrollItems->EarlyOutDeductTime = $OutLateDeductHours;
                                $PayrollItems->EarlyOutDeductAmount = $employeesalary->HourlyRate * $OutLateDeductHours;

                                $Weekdaysdayoutdeduct = $PayrollItems->EarlyOutDeductAmount;

                                $Basic = Yii::app()->MonthlyPayrollCalculationUtil->CalculateBasicforMonthlyPaymentRosterBase($StartDate, $EndDate, $employeeid, $SiteId, $JoiningDate, $ResignDate,$JoiningDateNew);

                                $WorkedDays = $Basic[1] > 0 ? $Basic[1] : 0;
                                $BasicWage = $Basic[0] >= 0 ? $Basic[0] : 0;
                                $noPayDays = $Basic[2] >= 0 ? $Basic[2] : 0;

                                $PayrollItems->BasicWage = $BasicWage;
                                $PayrollItems->WorkDay = $WorkedDays;
                                $PayrollItems->NoPayDays = $noPayDays;

                                $Amount = $PayrollItems->BasicWage - ($WeekdaysdayElydeduct + $Weekdaysdayoutdeduct);
                                $AmountforEpf = $Amount > 0 ? $Amount : 0;
                                $PayrollItems->TotalForEPF = $AmountforEpf;
                            } else {

                                $SundayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SundayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                                $sundayoutdeduct = $SundayPayment[5];
                                $sundayearlydeduct = $SundayPayment[6];
                                $AllDeductInSunday = $SundayPayment[5] + $SundayPayment[6];
                                $SundayAmount = $SundayPayment[1] - $AllDeductInSunday;
                                $PayrollItems->SundayPayment = $SundayAmount > 0 ? $SundayAmount : 0;

                                $AllHolidayElyded = $poyadayearlydeduct + $marcantilearlydeduct + $sundayearlydeduct + $siteholidayearlydeduct;
                                $AllHolidayoutyded = $poyadayoutdeduct + $marcantiloutdeduct + $sundayoutdeduct + $siteholidayoutdeduct;

                                $AllHolidayElydedHours = $PoyadayPayment[8] + $MercantilePayment[8] + $SundayPayment[8] + $SiteHolidayPayment[8];
                                $AllHolidayoutydedHours = $PoyadayPayment[7] + $MercantilePayment[7] + $SundayPayment[7] + $SiteHolidayPayment[7];

                                $LateD = round(($Rowdata['LatedeductTime'] - $AllHolidayElydedHours) * 60);
                                $LDH = $LateD / 60;
                                $EarlyLateD_hours = floor($LDH);
                                $Lminits = round($LDH * 60);
                                $EarlyLateD_minutes = $Lminits % 60;
                                $LateDeductHours = ($EarlyLateD_hours + $EarlyLateD_minutes / 60 );
                                $PayrollItems->LateDeductTime = $LateDeductHours;
                                $PayrollItems->LateDeductAmount = $employeesalary->HourlyRate * $LateDeductHours;

                                $WeekdaysdayElydeduct = $PayrollItems->LateDeductAmount;

                                $OutLateD = round(($Rowdata['EarlyOutLatedeductTime'] - $AllHolidayoutydedHours) * 60);
                                $OLDH = $OutLateD / 60;
                                $EarlyOut_hours = floor($OLDH);
                                $OLminits = round($OLDH * 60);
                                $EarlyOut_minutes = $OLminits % 60;
                                $OutLateDeductHours = ($EarlyOut_hours + $EarlyOut_minutes / 60 );
                                $PayrollItems->EarlyOutDeductTime = $OutLateDeductHours;
                                $PayrollItems->EarlyOutDeductAmount = $employeesalary->HourlyRate * $OutLateDeductHours;

                                $Weekdaysdayoutdeduct = $PayrollItems->EarlyOutDeductAmount;

                                $Basic = Yii::app()->MonthlyPayrollCalculationUtil->CalculateBasicforMonthlyPayment($StartDate, $EndDate, $employeeid, $SiteId, $JoiningDate, $ResignDate,$JoiningDateNew);
                                $WorkedDays = $Basic[1] > 0 ? $Basic[1] : 0;
                                $BasicWage = $Basic[0] >= 0 ? $Basic[0] : 0;
                                $noPayDays = $Basic[2] >= 0 ? $Basic[2] : 0;

                                $PayrollItems->BasicWage = $BasicWage;
                                $PayrollItems->WorkDay = $WorkedDays;
                                $PayrollItems->NoPayDays = $noPayDays;

                                $Amount = $PayrollItems->BasicWage - ($WeekdaysdayElydeduct + $Weekdaysdayoutdeduct);
                                $AmountforEpf = $Amount > 0 ? $Amount : 0;
                                $PayrollItems->TotalForEPF = $AmountforEpf;
                            }

                            $PayrollItems->DayOfSundayP = 0;

                            $PayrollItems->full_Basic_Salary = $employeesalary->monthsalary;
                            $PayrollItems->Sub_Basic_salary = $employeesalary->BasicSalary;
                            $PayrollItems->BRA1 = $employeesalary->BRA1;
                            $PayrollItems->BRA2 = $employeesalary->BRA2;
                            $PayrollItems->BRA3 = $employeesalary->BRA3;

                            $PayrollItems->TotalForEPFPoyaday = 0;

                            $Criteria1 = new CDbCriteria();
                            $Criteria1->condition = 'date(Date) >= :SDate AND date(Date) <= :EDate AND Is_Poyaday = :Poya';
                            $Criteria1->params = array(':SDate' => $JoiningDate, ':EDate' => $ResignDate, ':Poya' => "POYADAY");
                            $Criteria1->select = "*";
                            $Poyaday = Holydays::model()->findAll($Criteria1);

                            if (!empty($Poyaday)) {
                                $Timsheet = Timesheet::model()->findByAttributes(array('EmployeeId' => $employeeid, 'date' => $Poyaday[0]['Date']));
                                if (!empty($Timsheet)) {
                                    $PayrollItems->TotalForEPFPoyaday = $employeesalary->DalySalary / 2;
                                }
                            }

                            $T1 = round($Rowdata['NOTHour'] * 60);
                            $T2 = $T1 / 60;
                            $NOTH = $T2;
                            $not_hours = $hours = floor($NOTH);
                            $minits = round($NOTH * 60);
                            $not_minutes = $minits % 60;
                            $NOTHours = ($not_hours + $not_minutes / 60 );
                            $PayrollItems->NOTHour = $NOTHours;
                            $PayrollItems->NOT = $employeesalary->OTRate * $NOTHours;

                            $T3 = round($Rowdata['DOTHour'] * 60);
                            $T4 = $T3 / 60;
                            $DOTH = $T4;
                            $DOT_hours = $hours = floor($DOTH);
                            $DOTminits = round($DOTH * 60);
                            $DOT_minutes = ($DOTminits % 60);
                            $DOTHours = ($DOT_hours + $DOT_minutes / 60 );
                            $PayrollItems->DOTHour = $DOTHours;
                            $PayrollItems->DOT = $employeesalary->DoubleOTRate * $DOTHours;

                            $PayrollItems->TOTHour = $Rowdata['TOTHour'];
                            $TOT_hours = $hours = floor($Rowdata['TOTHour']);
                            $TOT_minutes = ($Rowdata['TOTHour'] * 60 % 60);
                            $PayrollItems->TOT = $employeesalary->HourlyRate * 3 * ($TOT_hours + $TOT_minutes / 60);

                            $PreOTH = $Rowdata['PreOTHour'];
                            $PreOT_hours = floor($PreOTH);
                            $POTminits = round($PreOTH * 60);
                            $PreTOT_minutes = ($POTminits % 60);
                            $PreOTTHours = ($PreOT_hours + $PreTOT_minutes / 60 );
                            $PayrollItems->PreOTHour = $PreOTTHours;
                            $PayrollItems->PreOTAmount = $employeesalary->OTRate * $PreOTTHours;

                            $AT1 = round($Rowdata['NOTHour'] * 60);
                            $AT2 = $AT1 / 60;
                            $ANOTH = $AT2;
                            $Anot_hours = floor($ANOTH);
                            $Aminits = round($ANOTH * 60);
                            $Anot_minutes = $Aminits % 60;
                            $ANOTHours = ($Anot_hours + $Anot_minutes / 60 );
                            $PayrollItems->ActualNOTHour = $ANOTHours;

                            $AT3 = round($Rowdata['DOTHour'] * 60);
                            $AT4 = $AT3 / 60;
                            $ADOTH = $AT4;
                            $ADOT_hours = floor($ADOTH);
                            $ADOTminits = round($ADOTH * 60);
                            $ADOT_minutes = ($ADOTminits % 60);
                            $ADOTHours = ($ADOT_hours + $ADOT_minutes / 60 );
                            $PayrollItems->ActualDOTHour = $ADOTHours;

                            $AT5 = round($Rowdata['TOTHour'] * 60);
                            $AT6 = $AT5 / 60;
                            $ATOTH = $AT6;
                            $ATOT_hours = floor($ATOTH);
                            $ATOTminits = round($ATOTH * 60);
                            $ATOT_minutes = ($ATOTminits % 60);
                            $ATOTHours = ($ATOT_hours + $ATOT_minutes / 60 );
                            $PayrollItems->TOTHour = $ATOTHours;

                            $PayrollItems->Perday_incentive = 0;
                            $PayrollItems->Lunch_incentive = 0;
                            $PayrollItems->NightShift_incentive = 0;
                            $PayrollItems->travaling_incentive = 0;
                            $PayrollItems->accomondation_incentive = 0;
                            $PayrollItems->performance_incentive = 0;
                            $PayrollItems->Trip_Commission_Incentive = 0;
                            $PayrollItems->Rural_incentive = 0;
                            $PayrollItems->BioPass_incentive = 0;
                            $PayrollItems->Incentive1 = 0;
                            $PayrollItems->Incentive2 = 0;
                            $PayrollItems->Incentive3 = 0;

                            $ActualPresentDate = Yii::app()->db->createCommand("SELECT 
                            COUNT(DISTINCT timesheet.date) AS NumberOftimesheet,
                            timesheet.DayName
                            FROM timesheet
                            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.EmployeeId ='" . $employeeid . "' AND timesheet.PaymentMethod ='MONTHLY' AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'")->queryAll();
                            $NumberOfActualPresentDate = !empty($ActualPresentDate) ? $ActualPresentDate[0]['NumberOftimesheet'] : 0;

                            $WeekDays = Yii::app()->db->createCommand("SELECT 
                            COUNT(DISTINCT timesheet.date) AS NumberOftimesheet,
                            timesheet.DayName
                            FROM timesheet
                            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.EmployeeId ='" . $employeeid . "' AND timesheet.PaymentMethod ='MONTHLY' AND DAYNAME(timesheet.Date) NOT IN ('Saturday', 'Sunday') AND timesheet.DayName ='WEEKDAY'AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'")->queryAll();
                            $NumberOfWeekDays = empty($WeekDays) ? 0 : $WeekDays[0]['NumberOftimesheet'];

                            $Weekday_Leaves = Yii::app()->db->createCommand("SELECT 
                            COUNT(DISTINCT leavedays.leaveDays) AS NumberOfDays
                            FROM leavedays
                            INNER JOIN `leave` L ON leavedays.leaveId = L.id
                            WHERE  leavedays.leaveDays >='" . $JoiningDate . "' AND leavedays.leaveDays <='" . $ResignDate . "' AND L.site = '" . $SiteId . "' AND DAYNAME(leavedays.leaveDays) NOT IN ('Saturday', 'Sunday') AND leavedays.leaveDays NOT IN (SELECT holydays.Date FROM holydays WHERE holydays.Date >='" . $StartDate . "' AND holydays.Date <='" . $EndDate . "' AND ( holydays.type ='GENERAL' OR holydays.siteId = '" . $SiteId . "')) AND L.Status = 1 AND leavedays.EmpId = '" . $employeeid . "' AND L.PaidType ='Pay' AND leavedays.leave_type_status = 0 AND ( L.LeaveType = 1 OR L.LeaveType = 3 OR L.LeaveType = 4 OR L.LeaveType = 5 OR L.LeaveType = 6 OR L.LeaveType = 9 OR L.LeaveType = 11)")->queryAll();
                            $NumberOfWeekdayLeaves = !empty($Weekday_Leaves) ? $Weekday_Leaves[0]['NumberOfDays'] : 0;

                            $PayrollItems->Actual_WorkedDay = $NumberOfWeekDays;
                            $WeekdayWithLeaveCount = $NumberOfWeekDays + $NumberOfWeekdayLeaves;

                            $Perday_Attendance = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 1, 'status' => 1));

                            if (!empty($Perday_Attendance)) {
                                // $R = intval($Perday_Attendance->incentive_amount * 30);
                                $Perdayincentive_inmonth = intval($Perday_Attendance->incentive_amount * 30);

                                if ($PayrollItems->Designationid == 31 || $PayrollItems->Designationid == 32 || $PayrollItems->Designationid == 33 || $PayrollItems->Designationid == 34 || $PayrollItems->Designationid == 35 || $PayrollItems->Designationid == 63 || $PayrollItems->Designationid == 148) {
                                    if ($WeekdayWithLeaveCount >= 20) {
                                        $PayrollItems->Perday_incentive = $Perdayincentive_inmonth;
                                    } elseif ($WeekdayWithLeaveCount < 20 && $WeekdayWithLeaveCount >= 15) {
                                        $PayrollItems->Perday_incentive = $Perdayincentive_inmonth / 2;
                                    } else {
                                        $PayrollItems->Perday_incentive = 0;
                                    }
                                } else {
                                    $NotWorkedDays = $Basic[2] > 0 ? $Basic[2] : 0;
                                    $NotWorkedDays_amount = $NotWorkedDays * $Perday_Attendance->incentive_amount;
                                    $A = $Perdayincentive_inmonth - $NotWorkedDays_amount;
                                    $P_incentive = $A > 0 ? $A : 0;
                                    $PayrollItems->Perday_incentive = $P_incentive;
                                }
                            }

                            $Perday_Lunch = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 2, 'status' => 1));
                            if (!empty($Perday_Lunch)) {
                                $Perdayincentive_inmonth = $Perday_Lunch->incentive_amount * $NumberOfActualPresentDate;
                                $P_incentive = $Perdayincentive_inmonth > 0 ? $Perdayincentive_inmonth : 0;
                                $PayrollItems->Lunch_incentive = $P_incentive;
                            }


                            $travaling = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 4, 'status' => 1));

                            $JoinedDate = date_create($Employee->joindate);
                            $PayrollStartDate = date_create($StartDate);
                            $DateDiff = date_diff($JoinedDate, $PayrollStartDate);
                            $NumberOfDay = $DateDiff->format("%R%a");

                            if (!empty($travaling) && $NumberOfDay > 365) {

                                $Traveling_inmonth = intval($travaling->incentive_amount * 30);

                                if ($Employee->designationid == 31 || $Employee->designationid == 32 || $Employee->designationid == 33 || $Employee->designationid == 34 || $Employee->designationid == 35 || $PayrollItems->Designationid == 63 || $PayrollItems->Designationid == 148) {

                                    if ($WeekdayWithLeaveCount >= 20) {
                                        $PayrollItems->travaling_incentive = $Traveling_inmonth;
                                    } else if ($WeekdayWithLeaveCount >= 15 && $WeekdayWithLeaveCount < 20) {
                                        $PayrollItems->travaling_incentive = $Traveling_inmonth / 2;
                                    } else {
                                        $PayrollItems->travaling_incentive = 0;
                                    }
                                } else {
                                    $noPayDays = $Basic[2] > 0 ? $Basic[2] : 0;
                                    $PayrollItems->travaling_incentive = ($travaling->incentive_amount * 30) - ($travaling->incentive_amount * $noPayDays);
                                }
                            }

                            $accomondation = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 5, 'status' => 1));
                            if (!empty($accomondation)) {

                                 $Accomodation_inmonth = intval($accomondation->incentive_amount * 30);

                                if ($Employee->designationid == 31 || $Employee->designationid == 32 || $Employee->designationid == 33 || $Employee->designationid == 34 || $Employee->designationid == 35 || $PayrollItems->Designationid == 63 || $PayrollItems->Designationid == 148) {

                                    if ($WeekdayWithLeaveCount >= 20) {
                                        $PayrollItems->accomondation_incentive = $Accomodation_inmonth;
                                    } else if ($WeekdayWithLeaveCount >= 15 && $WeekdayWithLeaveCount < 20) {
                                        $PayrollItems->accomondation_incentive = $Accomodation_inmonth / 2;
                                    } else {
                                        $PayrollItems->accomondation_incentive = 0;
                                    }
                                } else {
                                    $noPayDays = $Basic[2] > 0 ? $Basic[2] : 0;
                                    $PayrollItems->accomondation_incentive = ($accomondation->incentive_amount * 30) - ($accomondation->incentive_amount * $noPayDays);
                                }
                            }

                            $date1 = date_create($StartDate);
                            $date2 = date_create($EndDate);
                            $diff = date_diff($date1, $date2);
                            $numberofdayinmonth = $diff->format("%R%a");
                            $NumberofDayinMonth = $numberofdayinmonth + 1;

                            $AllSunday = Yii::app()->MonthlyPayrollCalculationUtil->GetSpecificDayBetweenDates($StartDate, $EndDate, 0);
                            $AllSaturday = Yii::app()->MonthlyPayrollCalculationUtil->GetSpecificDayBetweenDates($StartDate, $EndDate, 6);
                            $Sunday_count = count($AllSunday);
                            $Saturday_count = count($AllSaturday);

                            $All_Holiday = Yii::app()->db->createCommand("SELECT COUNT(DISTINCT holydays.Date ) AS HolidayCount
                                FROM holydays
                                WHERE holydays.Date >='" . $StartDate . "' AND holydays.Date <='" . $EndDate . "' AND( holydays.type ='GENERAL' OR holydays.siteId ='" . $SiteId . "') AND DAYNAME(holydays.Date) NOT IN ('Saturday', 'Sunday')")->queryAll();

                            $AllHolidayCount = !empty($All_Holiday) ? $All_Holiday[0]['HolidayCount'] : 0;
                            $NumberOfWorkindDay = $NumberofDayinMonth - ($Sunday_count + $Saturday_count + $AllHolidayCount);

                            $AttendanceIncentive2 = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'incentive_id' => 13, 'status' => 1));
                            if (!empty($AttendanceIncentive2)) {


                                //$PayrollItems->Incentive3 = $WeekdayWithLeaveCount >= $NumberOfWorkindDay ? $AttendanceIncentive2->incentive_amount : 0;
                            }

                            $PayrollItems->Incentive3 = 0;

                            $PerMonthAttendance = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'incentive_id' => 14, 'status' => 1));
                            if (!empty($PerMonthAttendance)) {

                                $NopayDayInWeekday = $NumberOfWorkindDay - $WeekdayWithLeaveCount;

                                $PayrollItems->MonthIncentive = $NopayDayInWeekday > 2 ? 0 : $PerMonthAttendance->incentive_amount;
                            }

                            $PayrollItems->Insentive = $PayrollItems->Perday_incentive + $PayrollItems->Lunch_incentive + $PayrollItems->NightShift_incentive + $PayrollItems->travaling_incentive + $PayrollItems->accomondation_incentive + $PayrollItems->performance_incentive + $PayrollItems->Special_Incentive + $PayrollItems->Trip_Commission_Incentive + $PayrollItems->Rural_incentive + $PayrollItems->BioPass_incentive + $PayrollItems->Incentive1 + $PayrollItems->Incentive2 + $PayrollItems->Incentive3 + $PayrollItems->MonthIncentive;

                            $PayrollItems->Bonus = 0;
                            $PayrollItems->Allowance = 0;
                            $PayrollItems->PAllowance = 0;
                            $PayrollItems->VAllowance = 0;
                            $PayrollItems->Arrears = 0;
                            $PayrollItems->Incentive4 = 0;

                            $TotalGross = $AmountforEpf + $PayrollItems->PoyadayPayment + $PayrollItems->MercantilePayment + $PayrollItems->SundayPayment + $PayrollItems->SiteHolidayAmount + $PayrollItems->NOT + $PayrollItems->DOT + $PayrollItems->TOT + $PayrollItems->PreOTAmount + $PayrollItems->Insentive;
                            $PayrollItems->TotalGross = $TotalGross;

                            $PayrollItems->Deduction = 0;
                            $PayrollItems->Deduction2 = 0;
                            $PayrollItems->Deduction3 = 0;

                            $PayrollItems->TotalNet = $TotalGross;

                            $EPFByCompany = (12 / 100) * ($AmountforEpf + $PayrollItems->TotalForEPFPoyaday);
                            //Yii::app()->MonthlyPayrollCalculationUtil->EPFByCompany($Rowdata['BasicSalary'], $PoyadayPayment, $MercantilePayment, $SundayPayment);
                            $PayrollItems->EPFByCompany = $EPFByCompany;

                            $ETFByCompany = (3 / 100) * ($AmountforEpf + $PayrollItems->TotalForEPFPoyaday);
                            //Yii::app()->MonthlyPayrollCalculationUtil->ETFByCompany($Rowdata['BasicSalary'], $PoyadayPayment, $MercantilePayment, $SundayPayment);
                            $PayrollItems->ETFByCompany = $ETFByCompany;

                            $Contractfee = Employeecontractfee::model()->findByAttributes(array('employeeid' => $employeeid, 'site_id' => $SiteId, 'status' => 1));
                            $contractfeevalue = $Contractfee != null ? $Contractfee->contractfee : 0;
							$PayrollItems->contractorfee_rate = $contractfeevalue;
                            $PayrollItems->ContractorFee = ($contractfeevalue / 100) * $BasicWage;

                            $ConF = $PayrollItems->ContractorFee;
                            $CostOfCompany = $PayrollItems->TotalNet + $EPFByCompany + $ETFByCompany + $ConF;
                            $PayrollItems->CostOfCompany = $CostOfCompany;
                            $PayrollItems->TotalAddition = 0;
                            $PayrollItems->TotalDeduction = 0;

                            $PayrollItems->save();
                            //==========get manual entered values in privious payroll========

                            $Deleted_payroll = Yii::app()->db->createCommand("SELECT DPI.id,DPI.NIC,DPI.Bonus,DPI.Allowance,DPI.Insentive,DPI.performance_incentive,DPI.PAllowance,DPI.VAllowance,DPI.Arrears,DPI.Deduction,DPI.Deduction2,DPI.Deduction3,DP.SiteId,DPI.Incentive4,DPI.Incentive3
                                FROM deleted_payroll_items AS DPI
                                INNER JOIN deleted_payroll DP ON DPI.Payroll_id = DP.id
                                WHERE DPI.NIC = '" . $PayrollItems->NIC . "' AND DP.StartDate ='" . $StartDate . "' AND DP.EndDate ='" . $EndDate . "' AND DP.PayrollMethod ='MONTHLY' AND DP.Status=1 AND DP.SiteId ='" . $SiteId . "'")->queryAll();
                            if (!empty($Deleted_payroll)) {

                                PayrollItems::model()->updateAll(array('Bonus' => $Deleted_payroll[0]['Bonus'], 'Allowance' => $Deleted_payroll[0]['Allowance'], 'Insentive' => $Deleted_payroll[0]['Insentive'], 'performance_incentive' => $Deleted_payroll[0]['performance_incentive'], 'PAllowance' => $Deleted_payroll[0]['PAllowance'], 'VAllowance' => $Deleted_payroll[0]['VAllowance'], 'Deduction' => $Deleted_payroll[0]['Deduction'], 'Deduction2' => $Deleted_payroll[0]['Deduction2'], 'Deduction3' => $Deleted_payroll[0]['Deduction3'], 'Arrears' => $Deleted_payroll[0]['Arrears'], 'Incentive4' => $Deleted_payroll[0]['Incentive4'], 'Incentive3' => $Deleted_payroll[0]['Incentive3']), 'id ="' . $PayrollItems->id . '"');

                                $PayrollItem = $PayrollItems::model()->findByAttributes(array('id' => $PayrollItems->id));

                                $TotalAddition = $PayrollItem->Bonus + $PayrollItem->Allowance + $PayrollItem->PAllowance + $PayrollItem->VAllowance + $PayrollItem->Arrears;
                                $TotalIncentive = $PayrollItems->Insentive + $PayrollItem->performance_incentive + $PayrollItem->Incentive3 + $PayrollItem->Incentive4;
                                $TotalGros = $PayrollItems->TotalGross + $TotalAddition + $PayrollItem->performance_incentive + $PayrollItem->Incentive3 + $PayrollItem->Incentive4;
                                $TotalDeduction = $PayrollItem->Deduction + $PayrollItem->Deduction2 + $PayrollItem->Deduction3;
                                $TotalNet = $TotalGros - $TotalDeduction;
                                $CostToCompany = $TotalNet + $PayrollItem->EPFByCompany + $PayrollItem->ETFByCompany + $PayrollItem->ContractorFee;

                                PayrollItems::model()->updateAll(array('TotalAddition' => $TotalAddition, 'Insentive' => $TotalIncentive, 'TotalGross' => $TotalGros, 'TotalDeduction' => $TotalDeduction, 'TotalNet' => $TotalNet, 'CostOfCompany' => $CostToCompany), 'id ="' . $PayrollItem->id . '"');
                            }
                        }
                        $MaternityLeaveEmployees = Yii::app()->db->createCommand("SELECT L.EmoloyeeId
                                FROM leavedays
                                INNER JOIN `leave` L ON leavedays.leaveId = L.id
                                WHERE leavedays.leaveDays >= '" . $StartDate . "' AND leavedays.leaveDays <='" . $EndDate . "' AND L.site ='" . $SiteId . "' AND L.Status = 1 AND L.PaidType ='Pay' AND leavedays.leave_type_status = 0 AND L.EmoloyeeId NOT IN (SELECT timesheet.EmployeeId
                                FROM timesheet
                                WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId = '" . $SiteId . "' AND timesheet.PaymentMethod ='MONTHLY' AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'
                                GROUP BY timesheet.EmployeeId)
                                GROUP BY L.EmoloyeeId")->queryAll();

                        if (!empty($MaternityLeaveEmployees)) {

                           Yii::app()->MonthlyPayrollCalculationUtil->MonthlyPaymentForMaternityLeave($MaternityLeaveEmployees, $PayRoll->id, $StartDate, $EndDate, $SiteId);
                       
                        }

                        $GetPayrollShSheet = Yii::app()->MonthlyPayrollCalculationUtil->GetMonthlyPayrollSheet($PayRoll->id);
                        $payroll = CJSON::encode($GetPayrollShSheet);
                        echo $payroll;
                    }
                } else {
                    $payroll = CJSON::encode([]);
                    echo $payroll;
                }
            } else {
                $payroll = CJSON::encode(true);
                echo $payroll;
            }
        }
    }

    public function actionCreatePieceRatePayroll() {
        $model = new Payroll;

        $this->render('PieceRatePayroll', array(
            'model' => $model,
        ));
    }

    public function actionPieceRatePayrollCalculation() {

        $StartDate = ($_POST['Startdate']);
        $EndDate = ($_POST['Enddate']);

        if (Yii::app()->user->data()->superuser == 1) {

            $payroll = CJSON::encode([]);
            echo $payroll;
        } else {
            //------Month Payroll for Site Wise------//    
            $SiteId = Yii::app()->user->data()->SiteId;

            $Criteria1 = new CDbCriteria();
            $Criteria1->condition = 'date(EndDate) >= :StartDate AND SiteId = :siteid AND PayrollMethod = :paymentmethod';
            $Criteria1->params = array(':StartDate' => $StartDate, ':siteid' => $SiteId, ':paymentmethod' => "PIECE-RATE");
            $Criteria1->select = "*";
            $Payrollsheet = Payroll::model()->findAll($Criteria1);
          if (empty($Payrollsheet)) {


           $sql = " SELECT 

            COUNT(timesheet.id) AS NoOftimesheet,
            SUM(timesheet.SallaryRate) AS BasicSalary,
            SUM(timesheet.full_Basic_Salary) AS Full_Basicsalary,
            SUM(timesheet.Sub_Basic_salary) AS Sub_Basicsalary,
            SUM(timesheet.BRA1) AS BRA1,
            SUM(timesheet.BRA2) AS BRA2,
            SUM(timesheet.BRA3) AS BRA3,
            SUM(timesheet.NOvertimeSalary) AS NOTAmout,
            SUM(timesheet.Dovertimesalary) AS DOTAmount,
            SUM(timesheet.Tovertimesalary) AS TOTAmount,
            SUM(timesheet.NOvertimeHours) AS NOTHour,
            SUM(timesheet.DOverTimeHour) AS DOTHour,
            SUM(timesheet.TOverTimeHour) AS TOTHour,
            SUM(timesheet.LatedeductTime) AS LatedeductTime,
            SUM(timesheet.LatedeductAmount) AS LatedeductAmount,
            SUM(timesheet.OutLateDeductTime) AS EarlyOutLatedeductTime,
            SUM(timesheet.OutLateDeductAmount) AS EarlyOutLatedeductAmount,
            SUM(timesheet.numberof_pieces) AS NumberOfPieces,
            SUM(timesheet.contract_fee) AS ContractFee,
            employee.designationid AS Designationid,
            designation.type,
            employee.id AS Empid,
            employee.Namewithini,
            employee.nic,
            employee.Accountid,
            employee.departmentid,
            employee.supplierid,
            paymentmethod.type AS paymentmethod ,
            sites.name AS SiteName,
            supplier.name AS SupplierName,
            accounts.name As AccountName,
            department.name As DepartmentName,
            timesheet.SiteId

            FROM timesheet
            INNER JOIN employee ON timesheet.EmployeeId = employee.id
            INNER JOIN designation ON employee.designationid = designation.id
            INNER JOIN paymentmethod ON employee.paymentmethodid =paymentmethod.id
        --  INNER JOIN sites ON employee.siteid = sites.id
            INNER JOIN supplier ON employee.supplierid = supplier.id
            INNER JOIN accounts ON employee.Accountid = accounts.id
            INNER JOIN department ON employee.departmentid = department.id
            INNER JOIN sites ON timesheet.SiteId =sites.id

            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.PaymentMethod ='PIECE-RATE' AND (timesheet.date,timesheet.EmployeeId) NOT IN (SELECT leavedays.leaveDays,leavedays.EmpId
            FROM leavedays
            INNER JOIN `leave` ON leavedays.leaveId = (leave.id)
            WHERE leavedays.leaveDays >='" . $StartDate . "' AND leavedays.leaveDays <='" . $EndDate . "' AND (leave.site) = '" . $SiteId . "' AND (leave.Status) =1)
            GROUP BY employee.nic
            ORDER BY employee.Accountid ASC ";

                $rowdata = Yii::app()->db->createCommand($sql)->queryAll();

                if (!empty($rowdata)) {

                    $PayRoll = new Payroll;
                    $PayRoll->StartDate = $StartDate;
                    $PayRoll->EndDate = $EndDate;
                    $PayRoll->CreatedBy = Yii::app()->user->id;
                    $PayRoll->CreatedTime = date("Y-m-d H:i");
                    $PayRoll->PayrollMethod = "PIECE-RATE";
                    $PayRoll->SiteId = $SiteId;
                    $PayRoll->Status = 0;

                    if ($PayRoll->save()) {

                        foreach ($rowdata as $Rowdata) {
                            $PayrollItems = new PayrollItems;
                            $employeeid = $Rowdata['Empid'];
                            $Employee = Employee::model()->findByAttributes(array('id' => $employeeid));

                            $sql1 = " SELECT COUNT(DISTINCT timesheet.date) AS WorkedDays
                                         FROM timesheet 
                                         WHERE timesheet.date >= '" . $StartDate . "' AND timesheet.date <='" . $EndDate . "' AND timesheet.EmployeeId ='" . $employeeid . "'";
                            $Worked_Days = Yii::app()->db->createCommand($sql1)->queryAll();

                            $WorkedDays = !empty($Worked_Days) ? $Worked_Days[0]['WorkedDays'] : 0;

                            $PayrollItems->Payroll_id = $PayRoll->id;
                            $PayrollItems->EmployeeName = $Rowdata['Namewithini'];
                            $PayrollItems->NIC = $Rowdata['nic'];
                            $PayrollItems->JobTitle = $Rowdata['type'];
                            $PayrollItems->Designationid = $Rowdata['Designationid'];
                            $PayrollItems->RateType = $Rowdata['paymentmethod'];
                            $PayrollItems->MPSuplier = $Rowdata['SupplierName'];
                            $PayrollItems->Site = $Rowdata['SiteName'];
                            $PayrollItems->Account = $Rowdata['AccountName'];
                            $PayrollItems->Accountid = $Rowdata['Accountid'];
                            $PayrollItems->MPSupplierid = $Rowdata['supplierid'];
                            $PayrollItems->Departmentid = $Rowdata['departmentid'];
                            $PayrollItems->DepartmentName = $Rowdata['DepartmentName'];
                            $PayrollItems->WorkDay = $WorkedDays;
                            $PayrollItems->NoPayDays = 0;

                            $PoyadayPayment = Yii::app()->MonthlyPayrollCalculationUtil->PoyadayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $PoyaDayAmount = $PoyadayPayment[1];
                           // $PayrollItems->PoyadayPayment = $PoyaDayAmount > 0 ? $PoyaDayAmount : 0;
                            $PayrollItems->PoyadayPayment = 0;

                            $MercantilePayment = Yii::app()->MonthlyPayrollCalculationUtil->MercantilePayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $MercantileDayAmount = $MercantilePayment[1];
                           // $PayrollItems->MercantilePayment = $MercantileDayAmount > 0 ? $MercantileDayAmount : 0;
                            $PayrollItems->MercantilePayment = 0;

                            $SundayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SundayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $SundayAmount = $SundayPayment[1];
                          //  $PayrollItems->SundayPayment = $SundayAmount > 0 ? $SundayAmount : 0;
                            $PayrollItems->SundayPayment = 0;

                            $SiteHolidayPayment = Yii::app()->MonthlyPayrollCalculationUtil->SiteHolidaydayPayment($StartDate, $EndDate, $Rowdata['nic'], $SiteId);
                            $SiteHolidayAmount = $SiteHolidayPayment[1];
                          //  $PayrollItems->SiteHolidayAmount = $SiteHolidayAmount > 0 ? $SiteHolidayAmount : 0;
                            $PayrollItems->SiteHolidayAmount = 0;

                            $PayrollItems->LateDeductTime = 0;
                            $PayrollItems->LateDeductAmount = 0;
                            $PayrollItems->EarlyOutDeductTime = 0;
                            $PayrollItems->EarlyOutDeductAmount = 0;
                            $PayrollItems->DayOfSundayP = 0;

                            $Basic = $Rowdata['BasicSalary'];

                            $PayrollItems->BasicWage = $Rowdata['BasicSalary'];
                            $PayrollItems->full_Basic_Salary = $Rowdata['Full_Basicsalary'];
                            $PayrollItems->Sub_Basic_salary = $Rowdata['Sub_Basicsalary'];
                            $PayrollItems->BRA1 = $Rowdata['BRA1'];
                            $PayrollItems->BRA2 = $Rowdata['BRA2'];
                            $PayrollItems->BRA3 = $Rowdata['BRA3'];

                            $PayrollItems->TotalForEPF = $PayrollItems->BasicWage;

                            $PayrollItems->TotalForEPFPoyaday = 0;

                            $PayrollItems->NOT = $Rowdata['NOTAmout'];
                            $PayrollItems->DOT = $Rowdata['DOTAmount'];
                            $PayrollItems->TOT = $Rowdata['TOTAmount'];
                            $PayrollItems->NOTHour = $Rowdata['NOTHour'];
                            $PayrollItems->DOTHour = $Rowdata['DOTHour'];
                            $PayrollItems->TOTHour = $Rowdata['TOTHour'];

                            $JoiningDate = $StartDate;
                            $EmployeeJoindate = EmployeeJoinDetails::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'status' => 1));
                            if (!empty($EmployeeJoindate)) {
                                $JoiningDate = $EmployeeJoindate->join_date >= $StartDate ? $EmployeeJoindate->join_date : $StartDate;
                            }

                            $PayrollItems->Perday_incentive = 0;
                            $PayrollItems->Lunch_incentive = 0;
                            $PayrollItems->NightShift_incentive = 0;
                            $PayrollItems->travaling_incentive = 0;
                            $PayrollItems->accomondation_incentive = 0;
                            $PayrollItems->performance_incentive = 0;
                            $PayrollItems->Trip_Commission_Incentive = 0;
                            $PayrollItems->Rural_incentive = 0;
                            $PayrollItems->BioPass_incentive = 0;
                            $PayrollItems->Incentive1 = 0;
                            $PayrollItems->Incentive2 = 0;
                            $PayrollItems->Incentive3 = 0;

                            $ActualPresentDate = Yii::app()->db->createCommand("SELECT 
                            COUNT(timesheet.id) AS NumberOftimesheet,
                            timesheet.DayName
                            FROM timesheet
                            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.EmployeeId ='" . $employeeid . "' AND timesheet.PaymentMethod ='MONTHLY' AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'")->queryAll();
                            $NumberOfActualPresentDate = !empty($ActualPresentDate) ? $ActualPresentDate[0]['NumberOftimesheet'] : 0;

                            $WeekDays = Yii::app()->db->createCommand("SELECT 
                            COUNT(timesheet.id) AS NumberOftimesheet,
                            timesheet.DayName
                            FROM timesheet
                            WHERE timesheet.date >='" . $StartDate . "'  AND timesheet.date <='" . $EndDate . "' AND timesheet.SiteId ='" . $SiteId . "' AND timesheet.EmployeeId ='" . $employeeid . "' AND timesheet.PaymentMethod ='MONTHLY' AND DAYNAME(timesheet.Date) NOT IN ('Saturday', 'Sunday') AND timesheet.DayName ='WEEKDAY'AND timesheet.Intime != '0000-00-00 00:00:00' AND timesheet.OuteTime != '0000-00-00 00:00:00'")->queryAll();
                            $NumberOfWeekDays = empty($WeekDays) ? 0 : $WeekDays[0]['NumberOftimesheet'];

                            $PayrollItems->Actual_WorkedDay = $NumberOfWeekDays;

                            $Perday_Attendance = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 1, 'status' => 1));
                            if (!empty($Perday_Attendance)) {
                                $R = intval($Perday_Attendance->incentive_amount * 30);
                                $Perdayincentive_inmonth = $R;

                                if ($PayrollItems->Designationid == 31 || $PayrollItems->Designationid == 32 || $PayrollItems->Designationid == 33 || $PayrollItems->Designationid == 34 || $PayrollItems->Designationid == 35 || $PayrollItems->Designationid == 63) {
                                    if ($NumberOfWeekDays >= 20) {
                                        $PayrollItems->Perday_incentive = $Perdayincentive_inmonth;
                                    } elseif ($NumberOfWeekDays < 20 && $NumberOfWeekDays >= 15) {
                                        $PayrollItems->Perday_incentive = $Perdayincentive_inmonth / 2;
                                    } else {
                                        $PayrollItems->Perday_incentive = 0;
                                    }
                                } else {
                                    $NotWorkedDays = $Basic[2] > 0 ? $Basic[2] : 0;
                                    $NotWorkedDays_amount = $NotWorkedDays * $Perday_Attendance->incentive_amount;
                                    $A = $Perdayincentive_inmonth - $NotWorkedDays_amount;
                                    $P_incentive = $A > 0 ? $A : 0;
                                    $PayrollItems->Perday_incentive = $P_incentive;
                                }
                            }

                            $Perday_Lunch = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 2, 'status' => 1));
                            if (!empty($Perday_Lunch)) {
                                $Perdayincentive_inmonth = $Perday_Lunch->incentive_amount * $NumberOfActualPresentDate;
                                $P_incentive = $Perdayincentive_inmonth > 0 ? $Perdayincentive_inmonth : 0;
                                $PayrollItems->Lunch_incentive = $P_incentive;
                            }

                            $travaling = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 4, 'status' => 1));

                            $JoinedDate = date_create($JoiningDate);
                            $PayrollStartDate = date_create($StartDate);
                            $DateDiff = date_diff($JoinedDate, $PayrollStartDate);
                            $NumberOfDay = $DateDiff->format("%R%a");

                            if (!empty($travaling) && $NumberOfDay > 365) {
                                $dayCount = $NumberOfWeekDays;
                                $R = intval($travaling->incentive_amount * 30);
                                $Traveling_inmonth = $R;

                                if ($Employee->designationid == 31 || $Employee->designationid == 32 || $Employee->designationid == 33 || $Employee->designationid == 34 || $Employee->designationid == 35 || $PayrollItems->Designationid == 63) {

                                    if ($dayCount >= 20) {
                                        $PayrollItems->travaling_incentive = $Traveling_inmonth;
                                    } else if ($dayCount >= 15 && $dayCount < 20) {
                                        $PayrollItems->travaling_incentive = $Traveling_inmonth / 2;
                                    } else {
                                        $PayrollItems->travaling_incentive = 0;
                                    }
                                } else {
                                    $noPayDays = $Basic[2] > 0 ? $Basic[2] : 0;
                                    $PayrollItems->travaling_incentive = ($travaling->incentive_amount * 30) - ($travaling->incentive_amount * $noPayDays);
                                }
                            }

                            $accomondation = EmployeeIncentive::model()->findByAttributes(array('employee_id' => $employeeid, 'site_id' => $SiteId, 'incentive_id' => 5, 'status' => 1));
                            if (!empty($accomondation)) {
                                $dayCount = $NumberOfWeekDays;
                                $R = intval($accomondation->incentive_amount * 30);
                                $Accomodation_inmonth = $R;

                                if ($Employee->designationid == 31 || $Employee->designationid == 32 || $Employee->designationid == 33 || $Employee->designationid == 34 || $Employee->designationid == 35 || $PayrollItems->Designationid == 63) {

                                    if ($dayCount >= 20) {
                                        $PayrollItems->accomondation_incentive = $Accomodation_inmonth;
                                    } else if ($dayCount >= 15 && $dayCount < 20) {
                                        $PayrollItems->accomondation_incentive = $Accomodation_inmonth / 2;
                                    } else {
                                        $PayrollItems->accomondation_incentive = 0;
                                    }
                                } else {
                                    $noPayDays = $Basic[2] > 0 ? $Basic[2] : 0;
                                    $PayrollItems->accomondation_incentive = ($accomondation->incentive_amount * 30) - ($accomondation->incentive_amount * $noPayDays);
                                }
                            }

                            $PayrollItems->Insentive = $PayrollItems->Perday_incentive + $PayrollItems->Lunch_incentive + $PayrollItems->NightShift_incentive + $PayrollItems->travaling_incentive + $PayrollItems->accomondation_incentive + $PayrollItems->performance_incentive + $PayrollItems->Special_Incentive + $PayrollItems->Trip_Commission_Incentive + $PayrollItems->Rural_incentive + $PayrollItems->BioPass_incentive + $PayrollItems->Incentive1 + $PayrollItems->Incentive2 + $PayrollItems->Incentive3;

                            $PayrollItems->Bonus = 0;
                            $PayrollItems->Allowance = 0;
                            $PayrollItems->PAllowance = 0;
                            $PayrollItems->VAllowance = 0;
                            $PayrollItems->Arrears = 0;

                            $TotalGross = $Basic + $PayrollItems->PoyadayPayment + $PayrollItems->MercantilePayment + $PayrollItems->SundayPayment + $PayrollItems->SiteHolidayAmount + $Rowdata['NOTAmout'] + $Rowdata['DOTAmount'] + $Rowdata['TOTAmount'] + $PayrollItems->Insentive;
                            $PayrollItems->TotalGross = $TotalGross;

                            $PayrollItems->Deduction = 0;
                            $PayrollItems->Deduction2 = 0;
                            $PayrollItems->Deduction3 = 0;

                            $PayrollItems->TotalNet = $TotalGross;

                            $EPFByCompany = (12 / 100) * ($Basic + $PayrollItems->TotalForEPFPoyaday);
                            //Yii::app()->MonthlyPayrollCalculationUtil->EPFByCompany($Rowdata['BasicSalary'], $PoyadayPayment, $MercantilePayment, $SundayPayment);
                            $PayrollItems->EPFByCompany = $EPFByCompany;

                            $ETFByCompany = (3 / 100) * ($Basic + $PayrollItems->TotalForEPFPoyaday);
                            //Yii::app()->MonthlyPayrollCalculationUtil->ETFByCompany($Rowdata['BasicSalary'], $PoyadayPayment, $MercantilePayment, $SundayPayment);
                            $PayrollItems->ETFByCompany = $ETFByCompany;

                            //   $Contractfee = Employeecontractfee::model()->findByAttributes(array('employeeid' => $employeeid, 'status' => 1));
                            //   $contractfeevalue = $Contractfee != null ? $Contractfee->contractfee : 0;
                            $PayrollItems->ContractorFee = $Rowdata['ContractFee'];

                            $ConF = $PayrollItems->ContractorFee;
                            $CostOfCompany = $PayrollItems->TotalNet + $EPFByCompany + $ETFByCompany + $ConF;
                            $PayrollItems->CostOfCompany = $CostOfCompany;
                            $PayrollItems->TotalAddition = 0;
                            $PayrollItems->TotalDeduction = 0;
                            $PayrollItems->number_of_pieces = $Rowdata['NumberOfPieces'];

                            $PayrollItems->save();
                        }
                        $GetPayrollShSheet = Yii::app()->MonthlyPayrollCalculationUtil->GetMonthlyPayrollSheet($PayRoll->id);
                        $payroll = CJSON::encode($GetPayrollShSheet);
                        echo $payroll;
                    }
                } else {
                    $payroll = CJSON::encode([]);
                    echo $payroll;
                }
            } else {
                $payroll = CJSON::encode(true);
                echo $payroll;
            }
        }
    }

    //-------Payrol for monthly----//
    public function actionPayrollAccountReport() {
        $model = new Payroll;

        $this->render('PayrollAccountReport', array(
            'model' => $model,
        ));
    }

    //===========================payroll reports ========================================//

    public function actionPayrollCostReport() {
        if (Yii::app()->user->data()->superuser == 1) {
            $Payroll_list = Payroll::model()->findAll();
            $Accounts = Accounts::model()->findAll();
            $Suppliers = Supplier::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Payroll_list = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId));
            $Accounts = Accounts::model()->findAllByAttributes(array('siteid' => $SiteId));
            $Suppliers = Supplier::model()->findAll();
        }



        if (isset($_POST['PayrollCostReport'])) {

            $payroll_id = $_POST['PayrollCostReport']['Payroll'];
            $account_id = $_POST['PayrollCostReport']['Account'];
            $Suplier_id = $_POST['PayrollCostReport']['Supplier'];

            $Payroll = Payroll::model()->findByAttributes(array('id' => $payroll_id));
            $Account = Accounts::model()->findByAttributes(array('id' => $account_id));

            if ($Suplier_id == 0) {
                $sql = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany, 
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "'
                    GROUP BY payroll_items.MPSuplier";

                $MPWiseList = Yii::app()->db->createCommand($sql)->queryAll();
                $Alllist = array();
                $index = 0;

                foreach ($MPWiseList as $mplist) {

                    $Alllist[] = $mplist;

                    $sql1 = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Designationid,
                    payroll_items.JobTitle,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "' AND payroll_items.MPSuplier ='" . $mplist['MPSuplier'] . "'
                    GROUP BY payroll_items.MPSuplier,payroll_items.Designationid";

                    $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                    array_push($Alllist[$index], $PO_List);

                    $index1 = 0;
                    $index2 = 0;
                    foreach ($Alllist[$index][$index1] as $list) {

                        $sql = "
                SELECT *
                FROM payroll_items

                WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "' AND payroll_items.MPSuplier ='" . $list['MPSuplier'] . "' AND payroll_items.Designationid ='" . $list['Designationid'] . "'";
                        $PO = Yii::app()->db->createCommand($sql)->queryAll();
                        array_push($Alllist[$index][$index1][$index2], $PO);

                        $index2++;
                    }

                    $index1++;
                    $index++;
                }
                $this->render('PayrollCostReportView', array('Alllist' => $Alllist, 'Account' => $Account, 'Payroll' => $Payroll));
            } else {

                $sql = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany, 
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "' AND payroll_items.MPSupplierid ='" . $Suplier_id . "'
                    GROUP BY payroll_items.MPSuplier";

                $MPWiseList = Yii::app()->db->createCommand($sql)->queryAll();
                $Alllist = array();
                $index = 0;

                foreach ($MPWiseList as $mplist) {

                    $Alllist[] = $mplist;

                    $sql1 = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Designationid,
                    payroll_items.JobTitle,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "' AND payroll_items.MPSuplier ='" . $mplist['MPSuplier'] . "'
                    GROUP BY payroll_items.MPSuplier,payroll_items.Designationid";

                    $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                    array_push($Alllist[$index], $PO_List);

                    $index1 = 0;
                    $index2 = 0;
                    foreach ($Alllist[$index][$index1] as $list) {

                        $sql = "
                SELECT *
                FROM payroll_items

                WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "' AND payroll_items.MPSuplier ='" . $list['MPSuplier'] . "' AND payroll_items.Designationid ='" . $list['Designationid'] . "'";
                        $PO = Yii::app()->db->createCommand($sql)->queryAll();
                        array_push($Alllist[$index][$index1][$index2], $PO);

                        $index2++;
                    }

                    $index1++;
                    $index++;
                }
//           print_r($Alllist);
//          die;
                $this->render('PayrollCostReportView', array('Alllist' => $Alllist, 'Account' => $Account, 'Payroll' => $Payroll));
            }
        } else {

            $this->render('PayrollCostReport', array('Payroll_list' => $Payroll_list, 'Accounts' => $Accounts, 'Suppliers' => $Suppliers));
        }
    }

    public function actionCreateAccountCostReportExcel() {


        $objPHPExcel = new PHPExcel();
        $Account_List = CJSON::decode($_POST['AccountList']);
        $Account = CJSON::decode($_POST['Account']);
        $Payroll = CJSON::decode($_POST['Payroll']);
//         print_r($Payroll);
//          die;
        if (!empty($Account)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Account['siteid']));
        }

        // Set document properties
        $objPHPExcel->getProperties()->setCreator("K'iin Balam")
                ->setLastModifiedBy("K'iin Balam")
                ->setTitle("YiiExcel Test Document")
                ->setSubject("YiiExcel Test Document")
                ->setDescription("Test document for YiiExcel, generated using PHP classes.")
                ->setKeywords("office PHPExcel php YiiExcel UPNFM")
                ->setCategory("Test result file");

        // Add some data
        $styleArray = array(
            'font' => array(
                'bold' => true,
                'color' => array('rgb' => '#3498db'),
                'size' => 10
        ));

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 1, 'ACCOUNTWISE PAY ROLL SUMMARY REPORT ');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 2, 'PAYROLL MONTH :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 2, 'FROME');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 2, $Payroll['StartDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 2, 'TO');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 2, $Payroll['EndDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 3, 'SITE :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 3, $Site->name);

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 4, 'Client Name :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 4, $Account['name']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 5, 'Client Code :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 5, $Account['id']);

        $row = 6;
        foreach ($Account_List as $list) {
            $col1 = 1;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'CONTRACTOR :');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col1, $row, $list['MPSuplier']);
            $row++;
            foreach ($list[0] as $list1) {
                $col2 = 1;
                $col3 = 1;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'DESIGNATION :');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['JobTitle']);
                $row++;
                $row++;

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'Employee Name');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col3, $row, 'NIC');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Job Title');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Rate type');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Worked Days');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Basic Wage');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'In Late Deduct');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Out Late Deduct');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total For EPF');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Poyaday payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Mercantile Payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Sunday payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Site Holiday ');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, Yii::app()->commonUtil->convertToHoursMins('NOTHour'));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, Yii::app()->commonUtil->convertToHoursMins('DOTHour'));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, Yii::app()->commonUtil->convertToHoursMins('TOTHour'));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'N-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Att Bonus');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Perform Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Variable Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Arrears');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Addition');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Gross');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Deduction');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Net');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'EPF 12 %');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'ETF 03%');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Contractor fee');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Cost to Company');
                $row++;
                foreach ($list1[0] as $list2) {

                    $col = 1;

                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, $list2['EmployeeName']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col, $row, $list2['NIC']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['JobTitle']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['RateType']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['WorkDay']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['BasicWage']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['LateDeductAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['EarlyOutDeductAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalForEPF']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['PoyadayPayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['MercantilePayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['SundayPayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['SiteHolidayAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['NOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['DOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['TOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['NOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['DOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Bonus']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Allowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Insentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['PAllowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['VAllowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Arrears']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalAddition']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalGross']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalDeduction']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalNet']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['EPFByCompany']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['ETFByCompany']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['ContractorFee']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['CostOfCompany']);

                    $row++;
                }
                $col4 = 4;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(12, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(13, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(14, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(15, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(16, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(17, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(18, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(19, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(20, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(21, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(22, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(23, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(24, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(25, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(26, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(27, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(28, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(29, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(30, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(31, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(32, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(33, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, $row, 'TOTAL OF DESIGNATION');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col4, $row, $list1['WorkedDay']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['BasivWage']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['LateDeductAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['EarlyOutDeductAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalForEPF']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['PoyadayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['MercantilePayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['SundayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['SiteHolidayAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['NOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['DOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['TOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['NOTAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['DOT']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TOT']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Bonus']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Allowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Insentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['PAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['VAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Arrears']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalAddition']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalGross']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalDeduction']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalNet']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['EPFByCompany']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['ETFByCompany']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['contractfee']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['CostOfCompany']);
                $row++;
            }
            $col5 = 4;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(12, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(13, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(14, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(15, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(16, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(17, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(18, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(19, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(20, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(21, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(22, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(23, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(24, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(25, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(26, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(27, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(28, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(29, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(30, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(31, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(32, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(33, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, $row, 'TOTAL OF MP SUPPLIER');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col5, $row, $list['WorkedDay']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['BasivWage']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['LateDeductAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['EarlyOutDeductAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalForEPF']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PoyadayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['MercantilePayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SundayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SiteHolidayAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['NOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['DOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['TOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['NOTAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['DOT']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TOT']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Bonus']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Allowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Insentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['VAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Arrears']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalAddition']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalGross']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalDeduction']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalNet']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['EPFByCompany']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['ETFByCompany']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['contractfee']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['CostOfCompany']);
            $row++;
            $row++;
        }

        $objPHPExcel->getActiveSheet()->setTitle('YiiExcel');
        $filename = "Account Cost Report";
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="' . $filename . '.xls"');
        header('Cache-Control: max-age=0');

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');

        $objWriter->save('php://output');
        unset($this->objWriter);
        unset($this->objWorksheet);
        unset($this->objReader);
        unset($this->objPHPExcel);
        exit();
    }

    public function actionMPSCostSummeryReport() {

        if (Yii::app()->user->data()->superuser == 1) {
            $Payroll_list = Payroll::model()->findAll();
            $Suppliers = Supplier::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Payroll_list = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId));
            $Suppliers = Supplier::model()->findAll();
        }



        if (isset($_POST['PayrollMPSCostReport'])) {

            $payroll_id = $_POST['PayrollMPSCostReport']['Payroll'];
            $supplier_id = $_POST['PayrollMPSCostReport']['Supplier'];

            $Payroll = Payroll::model()->findByAttributes(array('id' => $payroll_id));
            $Supplier = Supplier::model()->findByAttributes(array('id' => $supplier_id));

            $sql = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Departmentid,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany, 
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    SUM(payroll_items.full_Basic_Salary) AS full_Basic_Salary,
                    SUM(payroll_items.Sub_Basic_salary) AS Sub_Basic_salary,
                    SUM(payroll_items.BRA1) AS BRA1,
                    SUM(payroll_items.BRA2) AS BRA2,
                    SUM(payroll_items.BRA3) AS BRA3,
                    SUM(payroll_items.LateDeductTime) AS LateDeductTime,
                    SUM(payroll_items.EarlyOutDeductTime) AS EarlyOutDeductTime,
                    SUM(payroll_items.Perday_incentive) AS Perday_incentive,
                    SUM(payroll_items.Lunch_incentive) AS Lunch_incentive,
                    SUM(payroll_items.NightShift_incentive) AS NightShift_incentive,
                    SUM(payroll_items.travaling_incentive) AS travaling_incentive,
                    SUM(payroll_items.accomondation_incentive) AS accomondation_incentive,
                    SUM(payroll_items.performance_incentive) AS performance_incentive,
                    SUM(payroll_items.Special_Incentive) AS Special_Incentive,
                    SUM(payroll_items.Trip_Commission_Incentive) AS Trip_Commission_Incentive,
                    SUM(payroll_items.Rural_incentive) AS Rural_incentive,
                    SUM(payroll_items.BioPass_incentive) AS BioPass_incentive,
                    SUM(payroll_items.Incentive1) AS Incentive1,
                    SUM(payroll_items.Incentive2) AS Incentive2,
                    SUM(payroll_items.Incentive3) AS Incentive3,
                    department.name
                    
                    
                    FROM payroll_items
                    INNER JOIN department ON payroll_items.Departmentid = department.id

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.MPSupplierid = '" . $supplier_id . "'
                    GROUP BY payroll_items.Departmentid";

            $MPWiseList = Yii::app()->db->createCommand($sql)->queryAll();
            $Alllist = array();
            $index = 0;

            foreach ($MPWiseList as $mplist) {

                $Alllist[] = $mplist;

                $sql1 = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Designationid,
                    payroll_items.Departmentid,
                    payroll_items.JobTitle,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    SUM(payroll_items.full_Basic_Salary) AS full_Basic_Salary,
                    SUM(payroll_items.Sub_Basic_salary) AS Sub_Basic_salary,
                    SUM(payroll_items.BRA1) AS BRA1,
                    SUM(payroll_items.BRA2) AS BRA2,
                    SUM(payroll_items.BRA3) AS BRA3,
                    SUM(payroll_items.LateDeductTime) AS LateDeductTime,
                    SUM(payroll_items.EarlyOutDeductTime) AS EarlyOutDeductTime,
                    SUM(payroll_items.Perday_incentive) AS Perday_incentive,
                    SUM(payroll_items.Lunch_incentive) AS Lunch_incentive,
                    SUM(payroll_items.NightShift_incentive) AS NightShift_incentive,
                    SUM(payroll_items.travaling_incentive) AS travaling_incentive,
                    SUM(payroll_items.accomondation_incentive) AS accomondation_incentive,
                    SUM(payroll_items.performance_incentive) AS performance_incentive,
                    SUM(payroll_items.Special_Incentive) AS Special_Incentive,
                    SUM(payroll_items.Trip_Commission_Incentive) AS Trip_Commission_Incentive,
                    SUM(payroll_items.Rural_incentive) AS Rural_incentive,
                    SUM(payroll_items.BioPass_incentive) AS BioPass_incentive,
                    SUM(payroll_items.Incentive1) AS Incentive1,
                    SUM(payroll_items.Incentive2) AS Incentive2,
                    SUM(payroll_items.Incentive3) AS Incentive3
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.MPSupplierid = '" . $supplier_id . "' AND payroll_items.Departmentid ='" . $mplist['Departmentid'] . "'
                    GROUP BY payroll_items.Departmentid, payroll_items.Designationid";

                $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                array_push($Alllist[$index], $PO_List);

                $index1 = 0;
                $index2 = 0;
                foreach ($Alllist[$index][$index1] as $list) {

                    $sql = "
                SELECT *
                FROM payroll_items

                WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.MPSupplierid = '" . $supplier_id . "' AND payroll_items.Departmentid ='" . $list['Departmentid'] . "' AND payroll_items.Designationid ='" . $list['Designationid'] . "'";
                    $PO = Yii::app()->db->createCommand($sql)->queryAll();
                    array_push($Alllist[$index][$index1][$index2], $PO);

                    $index2++;
                }

                $index1++;
                $index++;
            }
//           print_r($Alllist);
//          die;
            $this->render('PayrollMPSCostReportView', array('Alllist' => $Alllist, 'Supplier' => $Supplier, 'Payroll' => $Payroll));
        } else {

            $this->render('PayrollMPSCostReport', array('Payroll_list' => $Payroll_list, 'Suppliers' => $Suppliers));
        }
    }

    public function actionCreateMPSCostSummeryReportExcel() {


        $objPHPExcel = new PHPExcel();
        $AllList = CJSON::decode($_POST['AllList']);
        $Supplier = CJSON::decode($_POST['Supplier']);
        $Payroll = CJSON::decode($_POST['Payroll']);
        // print_r($Payroll['SiteId']);
        //  die;
        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }

        // Set document properties
        $objPHPExcel->getProperties()->setCreator("K'iin Balam")
                ->setLastModifiedBy("K'iin Balam")
                ->setTitle("YiiExcel Test Document")
                ->setSubject("YiiExcel Test Document")
                ->setDescription("Test document for YiiExcel, generated using PHP classes.")
                ->setKeywords("office PHPExcel php YiiExcel UPNFM")
                ->setCategory("Test result file");

        // Add some data
        $styleArray = array(
            'font' => array(
                'bold' => true,
                'color' => array('rgb' => '#3498db'),
                'size' => 10
        ));

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 1, 'MPS WISE COST SUMMARY REPORT ');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 2, 'PAYROLL MONTH :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 2, 'FROME');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 2, $Payroll['StartDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 2, 'TO');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 2, $Payroll['EndDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 3, 'SITE :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 3, $Site->name);

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 4, 'MP SUPPLIER :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 4, $Supplier['name']);

        $row = 6;
        foreach ($AllList as $list) {
            $col1 = 1;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'DEPARTMENT :');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col1, $row, $list['name']);
            $row++;
            foreach ($list[0] as $list1) {
                $col2 = 1;
                $col3 = 1;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'DESIGNATION :');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['JobTitle']);
                $row++;
                $row++;

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'Employee Name');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col3, $row, 'NIC');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Client Code');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Client Name');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Job Title');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Rate type');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Worked Days');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Basic Wage');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'In Late Deduct');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Out Late Deduct');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total For EPF');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Poyaday payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Mercantile Payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Sunday payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Site Holiday ');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'NOTHour');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'DOTHour');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'TOTHour');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'N-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Amount');

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Per Day Attendance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Per Day Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Night Shift Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Traveling Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Accommodation Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Performance Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Special Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Trip Commission Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Rural Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Bio Pass Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Incentive1');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Incentive2');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Incentive3');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Incentive');

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Att Bonus');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Perform Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Variable Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Arrears');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Gross');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Deduction');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Net');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'EPF 12 %');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'ETF 03%');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Contractor fee');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Cost to Company');
                $row++;
                foreach ($list1[0] as $list2) {

                    $col = 1;

                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, $list2['EmployeeName']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col, $row, $list2['NIC']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Accountid']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Account']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['JobTitle']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['RateType']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['WorkDay']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['BasicWage']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['LateDeductAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['EarlyOutDeductAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalForEPF']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['PoyadayPayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['MercantilePayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['SundayPayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['SiteHolidayAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['NOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['DOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['TOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['NOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['DOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TOT']);

                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Perday_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Lunch_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['NightShift_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['travaling_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['accomondation_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['performance_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Special_Incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Trip_Commission_Incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Rural_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['BioPass_incentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Incentive1']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Incentive2']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Incentive3']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Insentive']);

                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Bonus']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Allowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['PAllowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['VAllowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Arrears']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalAddition']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalGross']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalDeduction']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalNet']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['EPFByCompany']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['ETFByCompany']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['ContractorFee']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['CostOfCompany']);

                    $row++;
                }
                $col4 = 6;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(12, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(13, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(14, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(15, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(16, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(17, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(18, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(19, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(20, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(21, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(22, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(23, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(24, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(25, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(26, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(27, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(28, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(29, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(30, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(31, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(32, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(33, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(34, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(35, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(35, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(36, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(37, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(38, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(39, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(40, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(41, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(42, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(43, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(44, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(45, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(46, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(47, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(48, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, $row, 'TOTAL OF DESIGNATION');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col4, $row, $list1['WorkedDay']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['BasivWage']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['LateDeductAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['EarlyOutDeductAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalForEPF']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['PoyadayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['MercantilePayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['SundayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['SiteHolidayAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['NOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['DOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['TOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['NOTAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['DOT']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TOT']);

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Perday_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Lunch_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['NightShift_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['travaling_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['accomondation_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['performance_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Special_Incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Trip_Commission_Incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Rural_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['BioPass_incentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Incentive1']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Incentive2']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Incentive3']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Insentive']);

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Bonus']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Allowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['PAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['VAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Arrears']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalAddition']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalGross']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalDeduction']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalNet']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['EPFByCompany']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['ETFByCompany']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['contractfee']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['CostOfCompany']);
                $row++;
            }
            $col5 = 6;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(12, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(13, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(14, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(15, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(16, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(17, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(18, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(19, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(20, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(21, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(22, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(23, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(24, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(25, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(26, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(27, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(28, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(29, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(30, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(31, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(32, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(33, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(34, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(35, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(36, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(37, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(38, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(39, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(40, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(41, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(42, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(43, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(44, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(45, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(46, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(47, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(48, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, $row, 'TOTAL OF DEPARTMENT');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col5, $row, $list['WorkedDay']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['BasivWage']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['LateDeductAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['EarlyOutDeductAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalForEPF']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PoyadayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['MercantilePayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SundayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SiteHolidayAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['NOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['DOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['TOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['NOTAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['DOT']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TOT']);

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Perday_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Lunch_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['NightShift_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['travaling_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['accomondation_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['performance_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Special_Incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Trip_Commission_Incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Rural_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['BioPass_incentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Incentive1']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Incentive2']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Incentive3']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Insentive']);

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Bonus']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Allowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['VAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Arrears']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalAddition']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalGross']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalDeduction']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalNet']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['EPFByCompany']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['ETFByCompany']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['contractfee']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['CostOfCompany']);
            $row++;
            $row++;
        }

        $objPHPExcel->getActiveSheet()->setTitle('YiiExcel');
        $filename = "MP Supplier Cost Summery Report";
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="' . $filename . '.xls"');
        header('Cache-Control: max-age=0');

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');

        $objWriter->save('php://output');
        unset($this->objWriter);
        unset($this->objWorksheet);
        unset($this->objReader);
        unset($this->objPHPExcel);
        exit();
    }

    public function actionOTCostSummeryReport() {

        if (Yii::app()->user->data()->superuser == 1) {
            $Payroll_list = Payroll::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Payroll_list = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId));
            //$Suppliers = Supplier::model()->findAll();
        }



        if (isset($_POST['PayrollOTCostSummeryReport'])) {

            $payroll_id = $_POST['PayrollOTCostSummeryReport']['Payroll'];

            $Payroll = Payroll::model()->findByAttributes(array('id' => $payroll_id));

            $sql = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Departmentid,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany, 
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    department.name
                    
                    FROM payroll_items
                    INNER JOIN department ON payroll_items.Departmentid = department.id

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "'
                    GROUP BY payroll_items.Departmentid";

            $DepartmentWiseList = Yii::app()->db->createCommand($sql)->queryAll();
            $Alllist = array();
            $index = 0;

            foreach ($DepartmentWiseList as $mplist) {

                $Alllist[] = $mplist;

                $sql1 = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Designationid,
                    payroll_items.Departmentid,
                    payroll_items.JobTitle,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Departmentid ='" . $mplist['Departmentid'] . "'
                    GROUP BY payroll_items.Departmentid, payroll_items.Designationid";

                $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                array_push($Alllist[$index], $PO_List);

                $index++;
            }
//           print_r($Alllist);
//           die;
            $this->render('OTCOstSummeryReportView', array('Alllist' => $Alllist, 'Payroll' => $Payroll));
        } else {

            $this->render('OTCOstSummeryReport', array('Payroll_list' => $Payroll_list));
        }
    }

    public function actionCreateOTCostSummeryReporttPDF() {

        $AllList = CJSON::decode($_POST['AllList']);
        $Payroll = CJSON::decode($_POST['Payroll']);

        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }
        // print_r($MPSupplier);
        // die;
        $mPDF1 = Yii::app()->ePdf->mpdf('', 'A4');
        $mPDF1->setAutoBottomMargin = 'stretch';
        $mPDF1->SetFooter('Report generated by ' . Yii::app()->user->name . '<br> Powered By Eimsky Business Solutions Pvt Ltd <br> Page {PAGENO} of {nb}');
        $mPDF1->WriteHTML($this->renderPartial('//payroll/OTCOstSummeryReportViewPDF', array('AllList' => $AllList, 'Payroll' => $Payroll, 'Site' => $Site), true));
        $file_name = 'OT COST SUMMARY REPORT' . 'Created On' . date("Y-m-d  -  h:i:sa") . '.pdf';

        ob_end_clean();
        $mPDF1->Output($file_name, EYiiPdf::OUTPUT_TO_DOWNLOAD);
    }

    public function actionCreateOTCostSummeryReporttExcel() {


        $objPHPExcel = new PHPExcel();
        $AllList = CJSON::decode($_POST['AllList']);
        $Payroll = CJSON::decode($_POST['Payroll']);
        // print_r($Payroll['SiteId']);
        //  die;
        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }

        // Set document properties
        $objPHPExcel->getProperties()->setCreator("K'iin Balam")
                ->setLastModifiedBy("K'iin Balam")
                ->setTitle("YiiExcel Test Document")
                ->setSubject("YiiExcel Test Document")
                ->setDescription("Test document for YiiExcel, generated using PHP classes.")
                ->setKeywords("office PHPExcel php YiiExcel UPNFM")
                ->setCategory("Test result file");

        // Add some data
        $styleArray = array(
            'font' => array(
                'bold' => true,
                'color' => array('rgb' => '#3498db'),
                'size' => 10
        ));

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 1, 'OT COST SUMMARY REPORT ');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 2, 'PAYROLL MONTH :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 2, 'FROME');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 2, $Payroll['StartDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 2, 'TO');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 2, $Payroll['EndDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 3, 'SITE :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 3, $Site->name);

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 6, 'Number Of Employee');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 6, '1.5 OT HRS');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(5, 6, '2.0 OT HRS');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(6, 6, '3.0 OT HRS');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(7, 6, '1.5 AMOUNT');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(8, 6, '2.0 AMOUNT');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(9, 6, '3.0 AMOUNT');

        $row = 7;
        foreach ($AllList as $list) {
            $col1 = 1;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'DEPARTMENT :');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col1, $row, $list['name']);
            $row++;
            foreach ($list[0] as $list1) {
                $col2 = 0;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow($col2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['JobTitle']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, '');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, '');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['numberofrecords']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, Yii::app()->commonUtil->convertToHoursMins($list1['NOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, Yii::app()->commonUtil->convertToHoursMins($list1['DOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, Yii::app()->commonUtil->convertToHoursMins($list1['TOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['NOTAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['DOT']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['TOT']);

                $row++;
            }
            $col5 = 2;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(3, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, $row, 'TOTAL OF DEPARTMENT');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col5, $row, '');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['numberofrecords']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['NOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['DOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list['TOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['NOTAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['DOT']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TOT']);

            $row++;
            $row++;
        }

        $objPHPExcel->getActiveSheet()->setTitle('YiiExcel');
        $filename = "OT Cost Summery Report";
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="' . $filename . '.xls"');
        header('Cache-Control: max-age=0');

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');

        $objWriter->save('php://output');
        unset($this->objWriter);
        unset($this->objWorksheet);
        unset($this->objReader);
        unset($this->objPHPExcel);
        exit();
    }

    public function actionAllowanceCostSummeryReport() {

        if (Yii::app()->user->data()->superuser == 1) {
            $Payroll_list = Payroll::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Payroll_list = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId));
        }



        if (isset($_POST['PayrollAllowanceCostSummeryReport'])) {

            $payroll_id = $_POST['PayrollAllowanceCostSummeryReport']['Payroll'];

            $Payroll = Payroll::model()->findByAttributes(array('id' => $payroll_id));
//           print_r($payroll_id);
//           die;
            $sql = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Departmentid,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany,
                    department.name
                    
                    FROM payroll_items
                    INNER JOIN department ON payroll_items.Departmentid = department.id

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "'
                    GROUP BY payroll_items.Departmentid";

            $DepartmentWiseList = Yii::app()->db->createCommand($sql)->queryAll();
            $Alllist = array();
            $index = 0;

            foreach ($DepartmentWiseList as $mplist) {

                $Alllist[] = $mplist;

                $sql1 = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Designationid,
                    payroll_items.Departmentid,
                    payroll_items.JobTitle,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany                   
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Departmentid ='" . $mplist['Departmentid'] . "'
                    GROUP BY payroll_items.Departmentid, payroll_items.Designationid";

                $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                array_push($Alllist[$index], $PO_List);

                $index++;
            }
//           print_r($Alllist);
//           die;
            $this->render('AllowanceCostSummeryReportView', array('Alllist' => $Alllist, 'Payroll' => $Payroll));
        } else {

            $this->render('AllowanceCostSummeryReport', array('Payroll_list' => $Payroll_list));
        }
    }

    public function actionAllowanceCostSummeryReportPDF() {

        $AllList = CJSON::decode($_POST['AllList']);
        $Payroll = CJSON::decode($_POST['Payroll']);

        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }
        // print_r($MPSupplier);
        // die;
        $mPDF1 = Yii::app()->ePdf->mpdf('', 'A4');
        $mPDF1->setAutoBottomMargin = 'stretch';
        $mPDF1->SetFooter('Report generated by ' . Yii::app()->user->name . '<br> Powered By Eimsky Business Solutions Pvt Ltd <br> Page {PAGENO} of {nb}');
        $mPDF1->WriteHTML($this->renderPartial('//payroll/AllowanceCostSummeryReportPDF', array('AllList' => $AllList, 'Payroll' => $Payroll, 'Site' => $Site), true));
        $file_name = 'ALLOWANCE COST SUMMARY REPORT' . 'Created On' . date("Y-m-d  -  h:i:sa") . '.pdf';

        ob_end_clean();
        $mPDF1->Output($file_name, EYiiPdf::OUTPUT_TO_DOWNLOAD);
    }

    public function actionAllowanceCostSummeryReportExcel() {


        $objPHPExcel = new PHPExcel();
        $AllList = CJSON::decode($_POST['AllList']);
        $Payroll = CJSON::decode($_POST['Payroll']);
        // print_r($Payroll['SiteId']);
        //  die;
        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }

        // Set document properties
        $objPHPExcel->getProperties()->setCreator("K'iin Balam")
                ->setLastModifiedBy("K'iin Balam")
                ->setTitle("YiiExcel Test Document")
                ->setSubject("YiiExcel Test Document")
                ->setDescription("Test document for YiiExcel, generated using PHP classes.")
                ->setKeywords("office PHPExcel php YiiExcel UPNFM")
                ->setCategory("Test result file");

        // Add some data
        $styleArray = array(
            'font' => array(
                'bold' => true,
                'color' => array('rgb' => '#3498db'),
                'size' => 10
        ));

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 1, 'Allowance COST SUMMARY REPORT ');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 2, 'PAYROLL MONTH :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 2, 'FROME');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 2, $Payroll['StartDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 2, 'TO');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 2, $Payroll['EndDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 3, 'SITE :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 3, $Site->name);

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 6, 'Number Of Employee');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 6, 'Att Bonus');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(5, 6, 'Arrears');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(6, 6, 'Incentive');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(7, 6, 'Allowance');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(8, 6, 'Perform Allowance');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(9, 6, 'Variable Allowance');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(10, 6, 'Total Addition');

        $row = 7;
        foreach ($AllList as $list) {
            $col1 = 1;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'DEPARTMENT :');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col1, $row, $list['name']);
            $row++;
            foreach ($list[0] as $list1) {
                $col2 = 0;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow($col2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['JobTitle']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, '');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, '');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['numberofrecords']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['Bonus']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['Arrears']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['Insentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['Allowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['PAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['VAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['TotalAddition']);

                $row++;
            }
            $col5 = 2;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(3, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, $row, 'TOTAL OF DEPARTMENT');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col5, $row, '');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['numberofrecords']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Bonus']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Arrears']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Insentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Allowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['VAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalAddition']);

            $row++;
            $row++;
        }

        $objPHPExcel->getActiveSheet()->setTitle('YiiExcel');
        $filename = "Allowance Cost Summery Report";
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="' . $filename . '.xls"');
        header('Cache-Control: max-age=0');

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');

        $objWriter->save('php://output');
        unset($this->objWriter);
        unset($this->objWorksheet);
        unset($this->objReader);
        unset($this->objPHPExcel);
        exit();
    }

    public function actionHolidayCostReport() {

        if (Yii::app()->user->data()->superuser == 1) {
            $Payroll_list = Payroll::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Payroll_list = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId));
            //$Suppliers = Supplier::model()->findAll();
        }



        if (isset($_POST['PayrollHolidayCostReport'])) {

            $payroll_id = $_POST['PayrollHolidayCostReport']['Payroll'];

            $Payroll = Payroll::model()->findByAttributes(array('id' => $payroll_id));

            $sql = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Accountid,
                    payroll_items.Account,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount
                                                            
                    FROM payroll_items
                   
                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "'
                    GROUP BY payroll_items.Accountid";

            $DepartmentWiseList = Yii::app()->db->createCommand($sql)->queryAll();
            $Alllist = array();
            $index = 0;

            foreach ($DepartmentWiseList as $mplist) {

                $Alllist[] = $mplist;

                $sql1 = " SELECT 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Designationid,
                    payroll_items.Accountid,
                    payroll_items.Account,
                    payroll_items.JobTitle,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount
                                        
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid ='" . $mplist['Accountid'] . "'
                    GROUP BY payroll_items.Accountid, payroll_items.Designationid";

                $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                array_push($Alllist[$index], $PO_List);

                $index++;
            }
//           print_r($Alllist);
//           die;
            $this->render('HolidayPaymentcostReportView', array('Alllist' => $Alllist, 'Payroll' => $Payroll));
        } else {

            $this->render('HolidayPaymentcostReport', array('Payroll_list' => $Payroll_list));
        }
    }

    public function actionHolidayCostReportPDF() {

        $AllList = CJSON::decode($_POST['AllList']);
        $Payroll = CJSON::decode($_POST['Payroll']);

        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }
        // print_r($MPSupplier);
        // die;
        $mPDF1 = Yii::app()->ePdf->mpdf('', 'A4');
        $mPDF1->setAutoBottomMargin = 'stretch';
        $mPDF1->SetFooter('Report generated by ' . Yii::app()->user->name . '<br> Powered By Eimsky Business Solutions Pvt Ltd <br> Page {PAGENO} of {nb}');
        $mPDF1->WriteHTML($this->renderPartial('//payroll/HolidayPaymentcostReportPDF', array('AllList' => $AllList, 'Payroll' => $Payroll, 'Site' => $Site), true));
        $file_name = 'HOLIDAY COST SUMMARY REPORT' . 'Created On' . date("Y-m-d  -  h:i:sa") . '.pdf';

        ob_end_clean();
        $mPDF1->Output($file_name, EYiiPdf::OUTPUT_TO_DOWNLOAD);
    }

    public function actionCreateHolidayCostReporttExcel() {


        $objPHPExcel = new PHPExcel();
        $AllList = CJSON::decode($_POST['AllList']);
        $Payroll = CJSON::decode($_POST['Payroll']);
        // print_r($Payroll['SiteId']);
        //  die;
        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }

        // Set document properties
        $objPHPExcel->getProperties()->setCreator("K'iin Balam")
                ->setLastModifiedBy("K'iin Balam")
                ->setTitle("YiiExcel Test Document")
                ->setSubject("YiiExcel Test Document")
                ->setDescription("Test document for YiiExcel, generated using PHP classes.")
                ->setKeywords("office PHPExcel php YiiExcel UPNFM")
                ->setCategory("Test result file");

        // Add some data
        $styleArray = array(
            'font' => array(
                'bold' => true,
                'color' => array('rgb' => '#3498db'),
                'size' => 10
        ));

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 1, 'HOLIDAY COST REPORT ');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 2, 'PAYROLL MONTH :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 2, 'FROME');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 2, $Payroll['StartDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 2, 'TO');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 2, $Payroll['EndDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 3, 'SITE :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 3, $Site->name);

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 5, 'Number Of Employee');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 5, 'Sunday Payment');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(5, 5, 'Poyaday Payment');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(6, 5, 'Mercantile payment');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(7, 5, 'Site Holiday');

        $row = 6;
        foreach ($AllList as $list) {
            $col1 = 1;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'ACCOUNT :');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col1, $row, $list['Account']);
            $row++;
            foreach ($list[0] as $list1) {
                $col2 = 0;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow($col2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['JobTitle']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, '');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, '');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['numberofrecords']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['SundayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['PoyadayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['MercantilePayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col2, $row, $list1['SiteHolidayAmount']);

                $row++;
            }
            $col5 = 2;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(3, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, $row, 'TOTAL OF ACCOUNT');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col5, $row, '');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['numberofrecords']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SundayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PoyadayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['MercantilePayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SiteHolidayAmount']);

            $row++;
            $row++;
        }

        $objPHPExcel->getActiveSheet()->setTitle('YiiExcel');
        $filename = "Holiday Cost Report";
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="' . $filename . '.xls"');
        header('Cache-Control: max-age=0');

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');

        $objWriter->save('php://output');
        unset($this->objWriter);
        unset($this->objWorksheet);
        unset($this->objReader);
        unset($this->objPHPExcel);
        exit();
    }

    public function actionPayrollAccountwiseCostReport() {
        if (Yii::app()->user->data()->superuser == 1) {
            $Payroll_list = Payroll::model()->findAll();
            $Accounts = Accounts::model()->findAll();
        } else {
            $SiteId = Yii::app()->user->data()->SiteId;
            $Payroll_list = Payroll::model()->findAllByAttributes(array('SiteId' => $SiteId));
            $Accounts = Accounts::model()->findAllByAttributes(array('siteid' => $SiteId));
        }



        if (isset($_POST['PayrollAccountWiseCostReport'])) {

            $payroll_id = $_POST['PayrollAccountWiseCostReport']['Payroll'];
            $account_id = $_POST['PayrollAccountWiseCostReport']['account'];

            $Payroll = Payroll::model()->findByAttributes(array('id' => $payroll_id));
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll->SiteId));
            if ($account_id == 0) {
                $sql = " SELECT 
                    payroll_items.Payroll_id, 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany 
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "'
                    GROUP BY payroll_items.Payroll_id";

                $MPWiseList = Yii::app()->db->createCommand($sql)->queryAll();
                $Alllist = array();
                $index = 0;

                foreach ($MPWiseList as $mplist) {

                    $Alllist[] = $mplist;

                    $sql1 = " SELECT 
                     payroll_items.Payroll_id, 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Accountid,
                    payroll_items.Account,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany  
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "'
                    GROUP BY payroll_items.Payroll_id,payroll_items.Accountid";

                    $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                    array_push($Alllist[$index], $PO_List);

                    $index1 = 0;
                    $index2 = 0;
                    foreach ($Alllist[$index][$index1] as $list) {

                        $sql = "
                SELECT *
                FROM payroll_items

                WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $list['Accountid'] . "'";
                        $PO = Yii::app()->db->createCommand($sql)->queryAll();
                        array_push($Alllist[$index][$index1][$index2], $PO);

                        $index2++;
                    }

                    $index1++;
                    $index++;
                }
//           print_r($Alllist);
//          die;
                $this->render('PayrollAccountWiseCostReportView', array('Alllist' => $Alllist, 'Payroll' => $Payroll, 'Site' => $Site));
            } else {
                $sql = " SELECT 
                    payroll_items.Payroll_id, 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.MPSuplier,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany 
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "'AND payroll_items.Accountid = '" . $account_id . "'
                    GROUP BY payroll_items.Payroll_id";

                $MPWiseList = Yii::app()->db->createCommand($sql)->queryAll();
                $Alllist = array();
                $index = 0;

                foreach ($MPWiseList as $mplist) {

                    $Alllist[] = $mplist;

                    $sql1 = " SELECT 
                     payroll_items.Payroll_id, 
                    COUNT(payroll_items.id) AS numberofrecords,
                    payroll_items.Accountid,
                    payroll_items.Account,
                    SUM(payroll_items.WorkDay) AS WorkedDay,
                    SUM(payroll_items.BasicWage) AS BasivWage,
                    SUM(payroll_items.TotalForEPF) AS TotalForEPF,
                    SUM(payroll_items.PoyadayPayment) AS PoyadayPayment,
                    SUM(payroll_items.MercantilePayment) AS MercantilePayment,
                    SUM(payroll_items.SundayPayment) AS SundayPayment,
                    SUM(payroll_items.NOTHour) AS NOTHour, 
                    SUM(payroll_items.DOTHour) AS DOTHour, 
                    SUM(payroll_items.TOTHour) AS TOTHour,
                    SUM(payroll_items.NOT) AS NOTAmount,
                    SUM(payroll_items.DOT) AS DOT,
                    SUM(payroll_items.Arrears) AS Arrears,
                    SUM(payroll_items.TOT) AS TOT,
                    SUM(payroll_items.Bonus) AS Bonus,
                    SUM(payroll_items.Allowance) AS Allowance,
                    SUM(payroll_items.Insentive) AS Insentive,
                    SUM(payroll_items.PAllowance) AS PAllowance,
                    SUM(payroll_items.VAllowance) AS VAllowance,
                    SUM(payroll_items.TotalGross) AS TotalGross,
                    SUM(payroll_items.TotalAddition) AS TotalAddition,
                    SUM(payroll_items.EarlyOutDeductAmount) AS EarlyOutDeductAmount,
                    SUM(payroll_items.LateDeductAmount) AS LateDeductAmount,
                    SUM(payroll_items.TotalDeduction) AS TotalDeduction,
                    SUM(payroll_items.SiteHolidayAmount) AS SiteHolidayAmount,
                    SUM(payroll_items.TotalNet) AS TotalNet,
                    SUM(payroll_items.EPFByCompany) AS EPFByCompany,
                    SUM(payroll_items.ETFByCompany) AS ETFByCompany,
                    SUM(payroll_items.ContractorFee) AS contractfee, 
                    SUM(payroll_items.CostOfCompany) AS CostOfCompany  
                    
                    FROM payroll_items

                    WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $account_id . "'
                    GROUP BY payroll_items.Payroll_id,payroll_items.Accountid";

                    $PO_List = Yii::app()->db->createCommand($sql1)->queryAll();
                    array_push($Alllist[$index], $PO_List);

                    $index1 = 0;
                    $index2 = 0;
                    foreach ($Alllist[$index][$index1] as $list) {

                        $sql = "
                SELECT *
                FROM payroll_items

                WHERE payroll_items.Payroll_id ='" . $payroll_id . "' AND payroll_items.Accountid = '" . $list['Accountid'] . "'";
                        $PO = Yii::app()->db->createCommand($sql)->queryAll();
                        array_push($Alllist[$index][$index1][$index2], $PO);

                        $index2++;
                    }

                    $index1++;
                    $index++;
                }

                $this->render('PayrollAccountWiseCostReportView', array('Alllist' => $Alllist, 'Payroll' => $Payroll, 'Site' => $Site));
            }
        } else {

            $this->render('PayrollAccountWiseCostReport', array('Payroll_list' => $Payroll_list, 'Accounts' => $Accounts));
        }
    }

    public function actionPayrollAccountwiseCostReportExcel() {


        $objPHPExcel = new PHPExcel();
        $Account_List = CJSON::decode($_POST['AccountList']);
        $Payroll = CJSON::decode($_POST['Payroll']);
//         print_r($Payroll);
//          die;
        if (!empty($Payroll)) {
            $Site = Sites::model()->findByAttributes(array('id' => $Payroll['SiteId']));
        }

        // Set document properties
        $objPHPExcel->getProperties()->setCreator("K'iin Balam")
                ->setLastModifiedBy("K'iin Balam")
                ->setTitle("YiiExcel Test Document")
                ->setSubject("YiiExcel Test Document")
                ->setDescription("Test document for YiiExcel, generated using PHP classes.")
                ->setKeywords("office PHPExcel php YiiExcel UPNFM")
                ->setCategory("Test result file");

        // Add some data
        $styleArray = array(
            'font' => array(
                'bold' => true,
                'color' => array('rgb' => '#3498db'),
                'size' => 10
        ));

        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 1, 'PAYROLL ACCOUNT WISE REPORT ');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 2, 'PAYROLL MONTH :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 2, 'FROME');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 2, $Payroll['StartDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, 2, 'TO');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, 2, $Payroll['EndDate']);
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, 3, 'SITE :');
        $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, 3, $Site->name);

        $row = 6;
        foreach ($Account_List as $list) {
//            
            foreach ($list[0] as $list1) {
                $col2 = 1;
                $col3 = 1;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(0, $row)->applyFromArray(array('font' => array('size' => 11, 'bold' => true, 'color' => array('rgb' => '000000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 11, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'Client Code :');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['Account']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, ++$row, 'Client Name :');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col2, $row, $list1['Accountid']);
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(0, $row)->applyFromArray(array('font' => array('size' => 11, 'bold' => true, 'color' => array('rgb' => '000000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 11, 'bold' => true, 'color' => array('rgb' => '0000ff'))));
                $row++;
                $row++;

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, 'Employee Name');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col3, $row, 'NIC');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Job Title');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Rate type');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Worked Days');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Basic Wage');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'In Late Deduct');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Out Late Deduct');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total For EPF');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Poyaday payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Mercantile Payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Sunday payment');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Site Holiday ');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'N-OT Hour');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Hour');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'T-OT Hour');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'N-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'D-OT Amount');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Att Bonus');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Incentive');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Perform Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Variable Allowance');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Arrears');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Addition');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Gross');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Deduction');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Total Net');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'EPF 12 %');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'ETF 03%');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Contractor fee');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col3, $row, 'Cost to Company');
                $row++;
                foreach ($list1[0] as $list2) {

                    $col = 1;

                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $row, $list2['EmployeeName']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col, $row, $list2['NIC']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['JobTitle']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['RateType']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['WorkDay']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['BasicWage']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['LateDeductAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['EarlyOutDeductAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalForEPF']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['PoyadayPayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['MercantilePayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['SundayPayment']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['SiteHolidayAmount']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['NOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['DOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, Yii::app()->commonUtil->convertToHoursMins($list2['TOTHour']));
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['NOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['DOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TOT']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Bonus']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Allowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Insentive']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['PAllowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['VAllowance']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['Arrears']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalAddition']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalGross']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalDeduction']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['TotalNet']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['EPFByCompany']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['ETFByCompany']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['ContractorFee']);
                    $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col, $row, $list2['CostOfCompany']);

                    $row++;
                }
                $col4 = 4;
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(2, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(12, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(13, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(14, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(15, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(16, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(17, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(18, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(19, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(20, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(21, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(22, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(23, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(24, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(25, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(26, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(27, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(28, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(29, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(30, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(31, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(32, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));
                $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(33, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => 'ff0000'))));

                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, $row, 'TOTAL OF ACCOUNT');
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col4, $row, $list1['WorkedDay']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['BasivWage']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['LateDeductAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['EarlyOutDeductAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalForEPF']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['PoyadayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['MercantilePayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['SundayPayment']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['SiteHolidayAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['NOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['DOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, Yii::app()->commonUtil->convertToHoursMins($list1['TOTHour']));
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['NOTAmount']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['DOT']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TOT']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Bonus']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Allowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Insentive']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['PAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['VAllowance']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['Arrears']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalAddition']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalGross']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalDeduction']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['TotalNet']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['EPFByCompany']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['ETFByCompany']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['contractfee']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col4, $row, $list1['CostOfCompany']);
                $row++;
                $row++;
            }
            $col5 = 4;
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(1, $row)->applyFromArray(array('font' => array('size' => 11, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(4, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(5, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(6, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(7, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(8, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(9, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(10, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(11, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(12, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(13, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(14, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(15, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(16, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(17, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(18, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(19, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(20, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(21, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(22, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(23, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(24, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(25, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(26, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(27, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(28, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(29, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(30, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(31, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(32, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));
            $objPHPExcel->getActiveSheet()->getStyleByColumnAndRow(33, $row)->applyFromArray(array('font' => array('size' => 10, 'bold' => true, 'color' => array('rgb' => '990000'))));

            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, $row, 'TOTAL OF PAYROLL');
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow($col5, $row, $list['WorkedDay']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['BasivWage']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['LateDeductAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['EarlyOutDeductAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalForEPF']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PoyadayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['MercantilePayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SundayPayment']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['SiteHolidayAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list1['NOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list1['DOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, Yii::app()->commonUtil->convertToHoursMins($list1['TOTHour']));
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['NOTAmount']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['DOT']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TOT']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Bonus']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Allowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Insentive']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['PAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['VAllowance']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['Arrears']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalAddition']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalGross']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalDeduction']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['TotalNet']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['EPFByCompany']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['ETFByCompany']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['contractfee']);
            $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(++$col5, $row, $list['CostOfCompany']);
            $row++;
            $row++;
        }

        $objPHPExcel->getActiveSheet()->setTitle('YiiExcel');
        $filename = "Payroll Account Wise Report";
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="' . $filename . '.xls"');
        header('Cache-Control: max-age=0');

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');

        $objWriter->save('php://output');
        unset($this->objWriter);
        unset($this->objWorksheet);
        unset($this->objReader);
        unset($this->objPHPExcel);
        exit();
    }

}
